﻿Imports System.Math

#Region "Tronçons de tuyauterie constituant le réseau"
''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un tuyau
''' </summary>
<Serializable()> Public Class Tuyau

    Dim _Øimposée As Boolean = False
    Dim _Øimp As Double = 0
    Dim _Qimposée As Boolean = False
    Dim _Qimp As Double = 0
    Dim _mat As Integer = 1
    Dim _L As Double = 0.1
    Dim _Hp As Double = 0.1
    Dim _PdcLoc As Double = 0
    Dim _Exutoire As Boolean = False
    Dim _Tete_Colonne As Boolean = False
    Dim _Tronçon_Distrib As Integer = 0
    Dim _i_colonne As Integer = 0
    Dim _i_collecteur As Integer = 0
    Dim _Appareils_Nbre As Integer = 0
    Dim _Qbrut As Double = 0
    Dim _Qprob As Double = 0
    Dim _Qbcl As Double = 0
    Dim _Øint As Double = 0
    Dim _Nom As String = String.Empty
    Dim _Yind As Double = 0
    Dim _Vlimit As Double = 1.5
    Dim _Isol_ep As Double = 0.00001
    Dim _Isol_λ As Double = 0.00001
    Dim _Isol_T As Double = 0.00001
    Dim _Pth As Double = 0
    Dim _PthCumul As Double = 0

    ''' <summary>
    '''indique si le diamètre intérieur du tuyau est imposé - Vrai si c'est le cas /  False dans le cas contraire
    ''' </summary>
    Public Property Øimposée As Boolean
        Get
            Øimposée = _Øimposée
        End Get
        Set(value As Boolean)

            _Øimposée = value
        End Set
    End Property

    ''' <summary>
    '''diamètre intérieur imposé du tuyau - Unité: m
    ''' </summary>
    Public Property Øimp As Double
        Get
            Øimp = _Øimp
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            Else
                _Øimp = value
            End If
        End Set
    End Property

    ''' <summary>
    '''indique si le débit dans le tronçon est imposé - Vrai si c'est le cas /  False dans le cas contraire
    ''' </summary>
    Public Property Qimposée As Boolean
        Get
            Qimposée = _Qimposée
        End Get
        Set(value As Boolean)
            _Qimposée = value
        End Set
    End Property

    ''' <summary>
    '''débit imposé du tuyau - Unité: m3/s
    ''' </summary>
    Public Property Qimp As Double
        Get
            Qimp = _Qimp
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            Else
                _Qimp = value
            End If
        End Set
    End Property

    ''' <summary>
    '''matière du tuyau - 1 = cuivre/ 2 = Acier galvanisé/ 3 = PER/ 4 = Multicouche/ 5 = PVC-C
    ''' </summary>
    Public Property Mat As Integer
        Get
            Mat = _mat
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            Else
                _mat = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Longueur du tuyau - Unité: m
    ''' </summary>
    Public Property L As Double
        Get
            L = _L
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur ne peut pas être négative.")
            Else
                _L = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Hauteur piézométrique - Unité: mCE (équivalent m en altitude)
    ''' </summary>
    Public Property Hp As Double
        Get
            Hp = _Hp
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            Else
                _Hp = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Perte de charge locale liée à un tronçon - Unité: mCE
    ''' </summary>
    Public Property PdcLoc As Double
        Get
            PdcLoc = _PdcLoc
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être nulle ou positive.")
            Else
                _PdcLoc = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Exutoire raccordé au tronçon - Vrai si c'est le cas /  False dans le cas contraire
    ''' </summary>
    Public Property Exutoire As Boolean
        Get
            Exutoire = _Exutoire
        End Get
        Set(value As Boolean)

            _Exutoire = value
        End Set
    End Property

    ''' <summary>
    '''n° d'Exutoire raccordé au tronçon - clé / n° d'exutoire
    ''' </summary>
    Public Property Exut_Type As New List(Of Integer)
    ''' <summary>
    '''nombre d'Exutoire raccordé au tronçon de type correspondant à la clé - clé / nombre d'exutoire
    ''' </summary>
    Public Property Exut_nbType As New List(Of Integer)
    ''' <summary>
    '''Matière (cuivre, PVc, ...) assurant le raccordement de l'Exutoire raccordé au tronçon de type correspondant à la clé - clé / natière
    ''' </summary>
    Public Property Exut_Mat As New List(Of Integer)

    ''' <summary>
    '''Indique si le tronçon est tête de colonne - Vrai si c'est le cas /  False dans le cas contraire
    ''' </summary>
    Public Property Tete_Colonne As Boolean
        Get
            Tete_Colonne = _Tete_Colonne
        End Get
        Set(value As Boolean)

            _Tete_Colonne = value
        End Set
    End Property

    ''' <summary>
    '''n° du tronçon amont (distribution) ou des tronçons amonts (retour boucle) qui alimente le présent tronçon - Attention, pour des soucis de simplification du code, il correspond à l'index dans la collection soit pour l'affichage index+1 
    ''' </summary>
    Public Property Tronçon_Amont As New List(Of Integer)

    ''' <summary>
    '''n° de tronçon alimenté par le présent tronçon soit le ou les tronçons avals
    ''' </summary>
    Public Property Tronçon_Aval As New List(Of Integer)

    ''' <summary>
    '''n° de tronçon du réseau de distribution formant colonne montante et sur lequel est raccordé le présent tronçon du retour boucle ECS - Attention, pour des soucis de simplification du code, il correspond à l'index dans la collection soit pour l'affichage index+1 
    ''' </summary>
    Public Property Tronçon_Distrib As Integer
        Get
            Tronçon_Distrib = _Tronçon_Distrib
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            Else
                _Tronçon_Distrib = value
            End If
        End Set
    End Property

    ''' <summary>
    '''n° de colonne à laquelle est affecté le tuyau
    ''' </summary>
    Public Property i_colonne As Integer
        Get
            i_colonne = _i_colonne
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            Else
                _i_colonne = value
            End If
        End Set
    End Property

    ''' <summary>
    '''n° de collecteur auquel est affecté le tuyau
    ''' </summary>
    Public Property collecteur As Integer
        Get
            collecteur = _i_collecteur
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            Else
                _i_collecteur = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Nombre d'appareils raccordés au présent tronçon
    ''' </summary>
    Public Property Appareils_Nbre As Integer
        Get
            Appareils_Nbre = _Appareils_Nbre
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur ne peut pas être négative.")
            Else
                _Appareils_Nbre = value
            End If
        End Set
    End Property

    ''' <summary>
    '''débit brut passant par le tronçon - unité: L/s
    ''' </summary>
    Public Property Qbrut As Double
        Get
            Qbrut = _Qbrut
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur ne peut pas être négative.")
            Else
                _Qbrut = value
            End If
        End Set
    End Property

    ''' <summary>
    '''débit probable passant par le tronçon - unité: L/s
    ''' </summary>
    Public Property Qprob As Double
        Get
            Qprob = _Qprob
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur ne peut pas être négative.")
            Else
                _Qprob = value
            End If
        End Set
    End Property

    ''' <summary>
    '''débit de bouclage passant par le tronçon - unité: L/s
    ''' </summary>
    Public Property Qbcl As Double
        Get
            Qbcl = _Qbcl
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur ne peut pas être négative.")
            Else
                _Qbcl = value
            End If
        End Set
    End Property

    ''' <summary>
    '''diamètre intérieur imposé du tuyau - Unité: m
    ''' </summary>
    Public Property Øint As Double
        Get
            Øint = _Øint
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            Else
                _Øint = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Nomenclature du tuyau (ex: 26/34 ou 10/12 ...)
    ''' </summary>
    Public Property Nom As String
        Get
            Nom = _Nom
        End Get
        Set(value As String)
            _Nom = value
        End Set
    End Property

    ''' <summary>
    '''Coefficient de groupage fonction du nombre d'appareil - cf DTU60.11 §2.12
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Yind As Double
        Get
            Yind = _Yind
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Yind = value
            End If
        End Set
    End Property
    '''' <summary>
    ''''Coefficient de simultanéité pour les débits traversant le tronçon
    '''' </summary>
    'Public Property Y As Double
    '    Get
    '        Y = _Y
    '    End Get
    '    Set(value As Double)
    '        If Not IsNumeric(value) Then
    '            Throw New ArgumentException("La valeur n'est pas numérique.")
    '        Else
    '            _Y = value
    '        End If
    '    End Set
    'End Property

    ''' <summary>
    '''Vitesse limite pour les débits traversant le tronçon - unite: m/s
    ''' </summary>
    Public Property Vlimit As Double
        Get
            Vlimit = _Vlimit
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value <= 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Vlimit = value
            End If
        End Set
    End Property

    ''' <summary>
    '''epaisseur isolant - unite: m
    ''' </summary>
    Public Property Isol_ep As Double
        Get
            Isol_ep = _Isol_ep
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Isol_ep = value
            End If
        End Set
    End Property

    ''' <summary>
    '''conductivité thermique de l'isolant - unite:  
    ''' </summary>
    Public Property Isol_λ As Double
        Get
            Isol_λ = _Isol_λ
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Isol_λ = value
            End If
        End Set
    End Property

    ''' <summary>
    '''température ambiante du tuyau - unite: °C
    ''' </summary>
    Public Property Isol_T As Double
        Get
            Isol_T = _Isol_T
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            Else
                _Isol_T = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Détermination de la perte thermique locale par valeur directe: VRAI si c'est le cas / FALSE si ce n'est pas le cas
    ''' </summary>
    Public Property Pth_Val_Directe As Boolean

    ''' <summary>
    '''Perte thermique linéaire locale - unite: W/ml
    ''' </summary>
    Public Property Pth As Double
        Get
            Pth = _Pth
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Pth = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Perte thermique cumulée - unite: W
    ''' </summary>
    Public Property PthCumul As Double
        Get
            PthCumul = _PthCumul
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _PthCumul = value
            End If
        End Set
    End Property
End Class

#End Region

#Region "Exutoires"
''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un exutoire
''' </summary>
<Serializable()> Public Class Exutoire

    Dim _nType As Integer = 1
    Dim _Q_ES As Double = 0
    Dim _Q_EC As Double = 0
    Dim _mat As Integer = 1
    Dim _Ø_int As Double = 0.01
    Dim _App_nb As Integer = 1
    Dim _Yind As Double = 0
    Dim _Nom As String = String.Empty

#Region "Propriétés"

    ''' <summary>
    '''débit brut de l'exutoire - Eau Froide sanitaire - Unité: l/s
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Q_ES As Double
        Get
            Q_ES = _Q_ES
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_ES = value
            End If
        End Set
    End Property

    ''' <summary>
    '''débit brut de l'exutoire - Eau Chaude Sanitaire - Unité: l/s
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property

    ''' <summary>
    '''matière du tuyau alimentant l'exutoire - 1 = cuivre/ 2 = Acier galvanisé/ 3 = PER/ 4 = Multicouche/ 5 = PVC
    ''' </summary>
    Public Property Mat As Integer
        Get
            Mat = _mat
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _mat = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation de l'exutoire - Unité: m
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property

    ''' <summary>
    '''nombre d'appareils composant l'exutoire
    ''' </summary>
    Public Property App_nb As Integer
        Get
            App_nb = _App_nb
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _App_nb = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Coefficient de groupage fonction du nombre d'appareil - cf DTU60.11 §2.12
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Yind As Double
        Get
            Yind = _Yind
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Yind = value
            End If
        End Set
    End Property

    ''' <summary>
    '''nomenclature de l'alimentation de l'exutoire de ce type -ex: 26/34, 10/12, 
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Nom As String
        Get
            Nom = _Nom
        End Get
        Set(value As String)
            _Nom = value
        End Set
    End Property

#Region "Composants de l'exutoire: Eviers, baignoires, etc. ..."
    ''' <summary>
    '''caractéristiques générales de baignoire composant l'Exutoire
    ''' </summary>
    Public Property _Baignoire As New Baignoire
    ''' <summary>
    '''nombre de baignoire composant l'Exutoire
    ''' </summary>
    Public Property _Baignoire_Nb As Integer
    ''' <summary>
    '''caractéristiques générales de lavabo composant l'Exutoire
    ''' </summary>
    Public Property _lavabo As New Lavabo
    ''' <summary>
    '''nombre de lavabo composant l'Exutoire
    ''' </summary>
    Public Property _lavabo_nb As Integer
    ''' <summary>
    '''caractéristiques générales de douche composant l'Exutoire
    ''' </summary>
    Public Property _douche As New Douche
    ''' <summary>
    '''nombre de douche composant l'Exutoire
    ''' </summary>
    Public Property _douche_nb As Integer
    ''' <summary>
    '''caractéristiques générales de lavemain composant l'Exutoire
    ''' </summary>
    Public Property _lavemain As New Lavemain
    ''' <summary>
    '''nombre de lavemain composant l'Exutoire
    ''' </summary>
    Public Property _lavemain_nb As Integer
    ''' <summary>
    '''caractéristiques générales de WC avec Reservoir de chasse à usage individuel composant l'Exutoire
    ''' </summary>
    Public Property _WC_Reservoir As New WC_Reservoir
    ''' <summary>
    '''nombre de WC avec Reservoir de chasse à usage individuel composant l'Exutoire
    ''' </summary>
    Public Property _WC_Reservoir_nb As Integer
    ''' <summary>
    '''caractéristiques générales de WC avec Reservoir de chasse à usage collectif composant l'Exutoire
    ''' </summary>
    Public Property _WC_Reservoir_coll As New WC_Reservoir_Coll
    ''' <summary>
    '''nombre de WC avec Reservoir de chasse à usage collectif composant l'Exutoire
    ''' </summary>
    Public Property _WC_Reservoir_coll_nb As Integer
    ''' <summary>
    '''caractéristiques générales d'urinoir avec robinet  composant l'Exutoire
    ''' </summary>
    Public Property _Urinoir As New Urinoir
    ''' <summary>
    '''nombre d'urinoir avec robinet composant l'Exutoire
    ''' </summary>
    Public Property _Urinoir_nb As Integer
    ''' <summary>
    '''caractéristiques générales de Bidet composant l'Exutoire
    ''' </summary>
    Public Property _Bidet As New Bidet
    ''' <summary>
    '''nombre de Bidet composant l'Exutoire
    ''' </summary>
    Public Property _Bidet_nb As Integer
    ''' <summary>
    '''caractéristiques générales de Lave-linge composant l'Exutoire
    ''' </summary>
    Public Property _Lave_Linge As New Lave_Linge
    ''' <summary>
    '''nombre de Lave-linge composant l'Exutoire
    ''' </summary>
    Public Property _Lave_Linge_nb As Integer
    ''' <summary>
    '''caractéristiques générales de Lave-vaisselle composant l'Exutoire
    ''' </summary>
    Public Property _Lave_vaisselle As New Lave_Vaisselle
    ''' <summary>
    '''nombre de Lave-vaisselle composant l'Exutoire
    ''' </summary>
    Public Property _Lave_vaisselle_nb As Integer
    ''' <summary>
    '''caractéristiques générales d'évier composant l'Exutoire
    ''' </summary>
    Public Property _Evier As New Evier
    ''' <summary>
    '''nombre d'évier composant l'Exutoire
    ''' </summary>
    Public Property _Evier_nb As Integer
    ''' <summary>
    '''caractéristiques générales de Timbre d'Office composant l'Exutoire
    ''' </summary>
    Public Property _Timbre_Office As New Timbre_Office
    ''' <summary>
    '''nombre de Timbre d'Office composant l'Exutoire
    ''' </summary>
    Public Property _Timbre_Office_nb As Integer
    ''' <summary>
    '''caractéristiques générales de Bac à Laver composant l'Exutoire
    ''' </summary>
    Public Property _Bac_a_Laver As New Bac_a_Laver
    ''' <summary>
    '''nombre de Bac à Laver composant l'Exutoire
    ''' </summary>
    Public Property _Bac_a_Laver_nb As Integer
    ''' <summary>
    '''caractéristiques générales du poste d'eau 1/2 composant l'Exutoire
    ''' </summary>
    Public Property _Poste_eau As New Poste_eau
    ''' <summary>
    '''nombre de poste d'eau 1/2 composant l'Exutoire
    ''' </summary>
    Public Property _Poste_eau_nb As Integer
    ''' <summary>
    '''caractéristiques générales de lavabo collectif composant l'Exutoire
    ''' </summary>
    Public Property _lavabo_Coll As New Lavabo_Collectif
    ''' <summary>
    '''nombre de lavabo collectif composant l'Exutoire
    ''' </summary>
    Public Property _lavabo_Coll_nb As Integer
    ''' <summary>
    '''caractéristiques générales du poste d'eau 3/4 composant l'Exutoire
    ''' </summary>
    Public Property _Poste_eau_34 As New Poste_eau_34
    ''' <summary>
    '''nombre de poste d'eau 3/4 composant l'Exutoire
    ''' </summary>
    Public Property _Poste_eau_34_nb As Integer
#End Region

#End Region

#Region "Méthodes"
    Public Sub Initialisation()
        _Q_ES = Q_Exu_EF()
        _Q_EC = Q_Exu_EC()
        _Yind = Y_indiv()
        _App_nb = Nbre_Appareils()
    End Sub

    ''' <summary>
    '''Fonction - Calcul du débit brut de l'exutoire EF
    ''' </summary>
    Private Function Q_Exu_EF() As Double
        Q_Exu_EF = 0
        Q_Exu_EF = _Baignoire_Nb * _Baignoire.Q_EF + _lavabo_nb * _lavabo.Q_EF + _douche_nb * _douche.Q_EF + _lavemain_nb * _lavemain.Q_EF + _WC_Reservoir_nb * _WC_Reservoir.Q_EF + _Bidet_nb * _Bidet.Q_EF
        Q_Exu_EF += _Lave_Linge_nb * _Lave_Linge.Q_EF + _Lave_vaisselle_nb * _Lave_vaisselle.Q_EF + _Evier_nb * _Evier.Q_EF + _WC_Reservoir_coll_nb * _WC_Reservoir_coll.Q_EF + _Urinoir_nb * _Urinoir.Q_EF
        Q_Exu_EF += _Timbre_Office_nb * _Timbre_Office.Q_EF + _Bac_a_Laver_nb * _Bac_a_Laver.Q_EF + _Poste_eau_nb * _Poste_eau.Q_EF + _lavabo_Coll_nb * _lavabo_Coll.Q_EF + _Poste_eau_34_nb * _Poste_eau_34.Q_EF
    End Function

    ''' <summary>
    '''Fonction - Calcul du débit brut de l'exutoire ECS
    ''' </summary>
    Private Function Q_Exu_EC() As Double
        Q_Exu_EC = 0
        Q_Exu_EC = _Baignoire_Nb * _Baignoire.Q_EC + _lavabo_nb * _lavabo.Q_EC + _douche_nb * _douche.Q_EC + _lavemain_nb * _lavemain.Q_EC + _Bidet_nb * _Bidet.Q_EC
        Q_Exu_EC += _Lave_Linge_nb * _Lave_Linge.Q_EC + _Lave_vaisselle_nb * _Lave_vaisselle.Q_EC + _Evier_nb * _Evier.Q_EC
        Q_Exu_EC += _Timbre_Office_nb * _Timbre_Office.Q_EC + _Bac_a_Laver_nb * _Bac_a_Laver.Q_EC + _Poste_eau_nb * _Poste_eau.Q_EC + _lavabo_Coll_nb * _lavabo_Coll.Q_EC + _Poste_eau_34_nb * _Poste_eau_34.Q_EC
    End Function

    ''' <summary>
    '''Coefficient total pour installation individuelle
    ''' </summary>
    Private Function Y_indiv() As Double
        Y_indiv = 0
        Y_indiv = _Baignoire_Nb * _Baignoire.Y_app + _lavabo_nb * _lavabo.Y_app + _douche_nb * _douche.Y_app + _lavemain_nb * _lavemain.Y_app + _WC_Reservoir_nb * _WC_Reservoir.Y_app + _Bidet_nb * _Bidet.Y_app
        Y_indiv += _Lave_Linge_nb * _Lave_Linge.Y_app + _Lave_vaisselle_nb * _Lave_vaisselle.Y_app + _Evier_nb * _Evier.Y_app + _WC_Reservoir_coll_nb * _WC_Reservoir_coll.Y_app + _Urinoir_nb * _Urinoir.Y_app
        Y_indiv += _Timbre_Office_nb * _Timbre_Office.Y_app + _Bac_a_Laver_nb * _Bac_a_Laver.Y_app + _Poste_eau_nb * _Poste_eau.Y_app + _lavabo_Coll_nb * _lavabo_Coll.Y_app + _Poste_eau_34_nb * _Poste_eau_34.Y_app
    End Function

    ''' <summary>
    '''Fonction - nombre d'appareils composant l'exutoire 
    ''' </summary>
    Private Function Nbre_Appareils() As Integer
        Nbre_Appareils = _Baignoire_Nb + _lavabo_nb + _douche_nb + _lavemain_nb + _WC_Reservoir_nb + _Bidet_nb + _Lave_Linge_nb + _Lave_vaisselle_nb + _Evier_nb + _WC_Reservoir_coll_nb + _Urinoir_nb + _Timbre_Office_nb
        Nbre_Appareils += _Bac_a_Laver_nb + _Poste_eau_nb + _lavabo_Coll_nb + _Poste_eau_34_nb
    End Function
#End Region

End Class
#End Region

#Region "Appareils"

''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à une baignoire
''' </summary>
Public Class Baignoire

    Dim _Q_EF As Double = 0.33
    Dim _Q_EC As Double = 0.33
    Dim _Ø_int As Double = 13
    Dim _Y_app As Double = 3
    ''' <summary>
    '''débit de la baignoire - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''débit de la baignoire - Eau Chaude - Unité: l/s
    ''' </summary>
    Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coefficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_app
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_app = value
            End If
        End Set
    End Property
End Class

''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un lavabo
''' </summary>
<Serializable()> Public Class Lavabo

    Dim _Q_EF As Double = 0.2
    Dim _Q_EC As Double = 0.2
    Dim _Ø_int As Double = 10
    Dim _Y_App As Double = 1.5
    ''' <summary>
    '''débit du lavabo - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''débit du lavabo - Eau Chaude - Unité: l/s
    ''' </summary>
    Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_app
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_app = value
            End If
        End Set
    End Property
End Class

''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à une douche
''' </summary>
<Serializable()> Public Class Douche

    Dim _Q_EF As Double = 0.2
    Dim _Q_EC As Double = 0.2
    Dim _Ø_int As Double = 12
    Dim _Y_App As Double = 2
    ''' <summary>
    '''débit Douche - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''débit Douche - Eau Chaude - Unité: l/s
    ''' </summary>
    Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_App
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_App = value
            End If
        End Set
    End Property
End Class

''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un lavemain
''' </summary>
<Serializable()> Public Class Lavemain

    Dim _Q_EF As Double = 0.1
    Dim _Q_EC As Double = 0.1
    Dim _Ø_int As Double = 10
    Dim _Y_App As Double = 0.5
    ''' <summary>
    '''débit du lavabo - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''débit du lavabo - Eau chaude - Unité: l/s
    ''' </summary>
    Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_App
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_App = value
            End If
        End Set
    End Property
End Class
''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un WC avec réservoir de chasse à usage indiividuel
''' </summary>
<Serializable()> Public Class WC_Reservoir

    Dim _Q_EF As Double = 0.12
    Dim _Ø_int As Double = 10
    Dim _Y_App As Double = 0.5
    ''' <summary>
    '''débit du lavabo - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_App
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_App = value
            End If
        End Set
    End Property
End Class
''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un WC avec réservoir de chasse à usage collectif
''' </summary>
<Serializable()> Public Class WC_Reservoir_Coll

    Dim _Q_EF As Double = 0.12
    Dim _Ø_int As Double = 10
    Dim _Y_App As Double = 1
    ''' <summary>
    '''débit du lavabo - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_App
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_App = value
            End If
        End Set
    End Property
End Class
''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un urinoir avec robinet individuel
''' </summary>
<Serializable()> Public Class Urinoir

    Dim _Q_EF As Double = 0.15
    Dim _Ø_int As Double = 10
    Dim _Y_App As Double = 0.5
    ''' <summary>
    '''débit du lavabo - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_App
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_App = value
            End If
        End Set
    End Property
End Class
''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un bidet
''' </summary>
<Serializable()> Public Class Bidet

    Dim _Q_EF As Double = 0.2
    Dim _Q_EC As Double = 0.2
    Dim _Ø_int As Double = 10
    Dim _Y_app As Double = 1
    ''' <summary>
    '''débit du bidet - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''débit du bidet - Eau Chaude - Unité: l/s
    ''' </summary>
    Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_app
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_app = value
            End If
        End Set
    End Property
End Class
''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un lave-linge
''' </summary>
<Serializable()> Public Class Lave_Linge

    Dim _Q_EF As Double = 0.2
    Dim _Q_EC As Double = 0.2
    Dim _Ø_int As Double = 10
    Dim _Y_app As Double = 1
    ''' <summary>
    '''débit du lave-linge - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''débit du lave-linge - Eau Chaude - Unité: l/s
    ''' </summary>
    Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_app
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_app = value
            End If
        End Set
    End Property
End Class
''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un Lave_Vaisselle
''' </summary>
<Serializable()> Public Class Lave_Vaisselle

    Dim _Q_EF As Double = 0.1
    Dim _Q_EC As Double = 0.1
    Dim _Ø_int As Double = 10
    Dim _Y_app As Double = 1
    ''' <summary>
    '''débit du Lave_Vaisselle - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''débit du Lave_Vaisselle - Eau Chaude - Unité: l/s
    ''' </summary>
    Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_app
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_app = value
            End If
        End Set
    End Property
End Class

''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un Evier
''' </summary>
<Serializable()> Public Class Evier

    Dim _Q_EF As Double = 0.2
    Dim _Q_EC As Double = 0.2
    Dim _Ø_int As Double = 12
    Dim _Y_app As Double = 2.5
    ''' <summary>
    '''débit de l'évier - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''débit de l'évier - Eau Chaude - Unité: l/s
    ''' </summary>
    Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_app
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_app = value
            End If
        End Set
    End Property
End Class

''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un Timbre d'office
''' </summary>
<Serializable()> Public Class Timbre_Office

    Dim _Q_EF As Double = 0.2
    Dim _Q_EC As Double = 0.2
    Dim _Ø_int As Double = 12
    Dim _Y_app As Double = 2.5
    ''' <summary>
    '''débit de l'évier - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''débit de l'évier - Eau Chaude - Unité: l/s
    ''' </summary>
    Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_app
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_app = value
            End If
        End Set
    End Property
End Class
''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un Bac à Laver
''' </summary>
<Serializable()> Public Class Bac_a_Laver

    Dim _Q_EF As Double = 0.33
    Dim _Q_EC As Double = 0.33
    Dim _Ø_int As Double = 13
    Dim _Y_app As Double = 2.5
    ''' <summary>
    '''débit de Bac_a_Laver - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''débit de Bac_a_Laver - Eau Chaude - Unité: l/s
    ''' </summary>
    Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_app
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_app = value
            End If
        End Set
    End Property
End Class

''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un poste d'eau 1/2
''' </summary>
<Serializable()> Public Class Poste_eau

    Dim _Q_EF As Double = 0.33
    Dim _Q_EC As Double = 0.33
    Dim _Ø_int As Double = 12
    Dim _Y_app As Double = 2
    ''' <summary>
    '''débit de Poste_eau - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''débit de Poste_eau - Eau Chaude - Unité: l/s
    ''' </summary>
    Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_app
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_app = value
            End If
        End Set
    End Property
End Class

''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un lavabo collectif
''' </summary>
<Serializable()> Public Class Lavabo_Collectif ' <Xml.Serialization.XmlIgnore>

    Dim _Q_EF1 As Double = 0.05
    Dim _Q_EC As Double = 0.05
    Dim _Ø_int As Double = 10
    Dim _Y_App As Double = 1
    ''' <summary>
    '''débit du lavabo collectif par unité de jet - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF1
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF1 = value
            End If
        End Set
    End Property
    ''' <summary>
    '''débit du lavabo collectif par unité de jet - Eau Chaude - Unité: l/s
    ''' </summary>
    Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation par unité de jet- Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil collectif par unité de jet
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_App
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_App = value
            End If
        End Set
    End Property
End Class
''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à un poste d'eau 3/4
''' </summary>
<Serializable()> Public Class Poste_eau_34

    Dim _Q_EF As Double = 0.42
    Dim _Q_EC As Double = 0.42
    Dim _Ø_int As Double = 13
    Dim _Y_app As Double = 2
    ''' <summary>
    '''débit de Poste_eau 3/4 - Eau froide - Unité: l/s
    ''' </summary>
    Public Property Q_EF As Double
        Get
            Q_EF = _Q_EF
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EF = value
            End If
        End Set
    End Property
    ''' <summary>
    '''débit de Poste_eau 3/4 - Eau Chaude - Unité: l/s
    ''' </summary>
    Public Property Q_EC As Double
        Get
            Q_EC = _Q_EC
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Q_EC = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Diamètre intérieur du tuyau d'alimentation - Unité: mm 
    ''' </summary>
    Public Property Ø_int As Double
        Get
            Ø_int = _Ø_int
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Ø_int = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Coeeficient simultanéité rattaché à l'appareil
    ''' </summary>
    Public Property Y_app As Double
        Get
            Y_app = _Y_app
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Y_app = value
            End If
        End Set
    End Property
End Class
#End Region

#Region "Pompe"
''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à une pompe
''' </summary>
<Serializable()> Public Class Pompe
    Dim _PthCumul As Double = 0

    ''' <summary>
    '''indique si le diamètre intérieur du tuyau est imposé - Vrai si c'est le cas /  False dans le cas contraire
    ''' </summary>
    'Public Property Øimposée As Boolean
    '    Get
    '        Øimposée = _Øimposée
    '    End Get
    '    Set(value As Boolean)

    '        _Øimposée = value
    '    End Set
    'End Property

    ''' <summary>
    '''diamètre intérieur imposé du tuyau - Unité: m
    ''' </summary>
    'Public Property Øimp As Double
    '    Get
    '        Øimp = _Øimp
    '    End Get
    '    Set(value As Double)
    '        If Not IsNumeric(value) Then
    '            Throw New ArgumentException("La valeur n'est pas numérique.")
    '        Else
    '            _Øimp = value
    '        End If
    '    End Set
    'End Property
End Class
#End Region
