﻿Imports System.Math
''' <summary>
''' Classe encapsulant toutes les caractéristiques attachées à une installation de plomberie
''' </summary>
<Serializable()> Public Class Installation

    Dim _Modele_Calcul As Integer = 1
    Dim _Ycoef As Double = 1
    Dim _Pr_ES As Double = 10
    ' Dim _Pr_ECS As Double = 3
    Dim _VlimIndiv As Double = 2
    Dim _Têt_Colon_Nbre As Integer = 0
    Dim _Collecteur_NbreD As Integer = 0
    Dim _Collecteur_NbreR As Integer = 0
    Dim _PrEntree As Double = 0
    Dim _PdcVanne As Double = 0
    Dim _PdcClapet As Double = 0
    Dim _PdcCompteur As Double = 0
    Dim _PdcDisconnecteur As Double = 0
    Dim _PdcFiltre As Double = 0
    Dim _PdcReduc As Double = 0
    Dim _PdcPrepECS As Double = 0
    Dim _Qbcl_min As Double = 80 / 3600
    Dim _Vmin As Double = 0.2
    Dim _Type_dT As Integer = 2
    Dim _TprodECS As Double = 60
    Dim _dTBoucle As Double = 5
    Dim _Type_Org As Integer = 2
    Dim _Position_Org As Integer = 1
    Dim _ΔT_ECS As Double = 1

#Region "Propriétés"
    ''' <summary>
    '''Caractéristiques des exutoires composant l'installation
    ''' </summary>
    <Xml.Serialization.XmlArray(ElementName:="_Exutoire")>
    <Xml.Serialization.XmlArrayItem("_Exutoire", Type:=GetType(Exutoire))>
    Public Property _Exutoire As New List(Of Exutoire)

    ''' <summary>
    '''Caractéristiques des tuyauteries de distribution composant l'installation
    ''' </summary>
    <Xml.Serialization.XmlArray(ElementName:="_Tuyau")>
    <Xml.Serialization.XmlArrayItem("_Tuyau", Type:=GetType(Tuyau))>
    Public Property _Tuyau As New List(Of Tuyau)

    ''' <summary>
    '''Caractéristiques des tuyauteries de retour de boucle composant la boucle ECS
    ''' </summary>
    <Xml.Serialization.XmlArray(ElementName:="_TuyauR")>
    <Xml.Serialization.XmlArrayItem("_TuyauR", Type:=GetType(Tuyau))>
    Public Property _TuyauR As New List(Of Tuyau)

    ''' <summary>
    '''Réseau Eau Froide = 1/ Réseau Eau Chaude Sanitaire = 2
    ''' </summary>
    Public Property Modele_Calcul As Integer
        Get
            Modele_Calcul = _Modele_Calcul
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _Modele_Calcul = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Coefficient correcteur fonction du batiment alimentée par ce réseau (Hôpital, bureau, habitation, caserne, ...) et du DTU utilisé 
    ''' </summary>
    Public Property Ycoef As Double
        Get
            Ycoef = _Ycoef
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _Ycoef = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Pression Eau Sanitaire minimale exigée à l'exutoire - Unité: mCE
    ''' </summary>
    Public Property Pr_ES As Double
        Get
            Pr_ES = _Pr_ES
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _Pr_ES = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Vitesse limite dans le réseau individuel terminal - Unité:m/s
    ''' </summary>
    Public Property VlimIndiv As Double
        Get
            VlimIndiv = _VlimIndiv
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _VlimIndiv = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Nombre de tête de colonne que comporte le réseau étudié
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Têt_Colon_Nbre As Integer
        Get
            Têt_Colon_Nbre = _Têt_Colon_Nbre
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _Têt_Colon_Nbre = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Nombre collecteurs ALLER que comporte le réseau étudié - Uniquement pour DISTRIBUTION EFS ou ECS
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Collecteur_D_Nbre As Integer
        Get
            Collecteur_D_Nbre = _Collecteur_NbreD
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _Collecteur_NbreD = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Nombre collecteurs RETOUR que comporte le réseau étudié - Uniquement pour la boucle ECS
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Collecteur_R_Nbre As Integer
        Get
            Collecteur_R_Nbre = _Collecteur_NbreR
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _Collecteur_NbreR = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Circuit Distribution - indique le n° du tronçon final pour le collecteur i - i est la clé du dictionnary
    '''  - ne se sérialize pas car recalculer systématiquement
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Collecteur_Ex As New Dictionary(Of Integer, Integer)

    ''' <summary>
    '''Circuit Distribution - indique le n° du tronçon origine pour le collecteur i - i est la clé du dictionnary
    '''  - ne se sérialize pas car recalculer systématiquement
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Collecteur_Or As New Dictionary(Of Integer, Integer)

    ''' <summary>
    '''Retour Boucle Collecteur - indique le n° du tronçon final pour le collecteur i - i est la clé du dictionnary
    '''  - ne se sérialize pas car recalculer systématiquement
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Collecteur_Ex_R As New Dictionary(Of Integer, Integer)

    ''' <summary>
    '''Retour Boucle Collecteur - indique le n° du tronçon origine pour le collecteur i - i est la clé du dictionnary
    '''  - ne se sérialize pas car recalculer systématiquement
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Collecteur_Or_R As New Dictionary(Of Integer, Integer)

    ''' <summary>
    '''Pression entrée Eau Sanitaire - Unité: mCE
    ''' </summary>
    Public Property PrEntree As Double
        Get
            PrEntree = _PrEntree
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _PrEntree = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Pdc vannes - Unité: mCE
    ''' </summary>
    Public Property PdcVanne As Double
        Get
            PdcVanne = _PdcVanne
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _PdcVanne = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Pdc clapet anti-retour - Unité: mCE
    ''' </summary>
    Public Property PdcClapet As Double
        Get
            PdcClapet = _PdcClapet
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _PdcClapet = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Pdc compteur - Unité: mCE
    ''' </summary>
    Public Property PdcCompteur As Double
        Get
            PdcCompteur = _PdcCompteur
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _PdcCompteur = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Pdc disconnecteur - Unité: mCE
    ''' </summary>
    Public Property PdcDisconnecteur As Double
        Get
            PdcDisconnecteur = _PdcDisconnecteur
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _PdcDisconnecteur = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Pdc filtres - Unité: mCE
    ''' </summary>
    Public Property PdcFiltre As Double
        Get
            PdcFiltre = _PdcFiltre
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _PdcFiltre = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Pdc réduction - Unité: mCE
    ''' </summary>
    Public Property PdcReduc As Double
        Get
            PdcReduc = _PdcReduc
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _PdcReduc = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Pdc sur le préparateur d'eau chaude sanitaire (échangeur à plaque, ballon, ...) - Unité: mCE
    ''' </summary>
    Public Property PdcPrepECS As Double
        Get
            PdcPrepECS = _PdcPrepECS
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _PdcPrepECS = value
            End If
        End Set
    End Property


    ''' <summary>
    '''Débit minimal imposé en retour de boucle - unité: l/s
    ''' </summary>
    Public Property Qbcl_min As Double
        Get
            Qbcl_min = _Qbcl_min
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Qbcl_min = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Vitesse minimale imposé en retour de boucle - unité: m/s
    ''' </summary>
    Public Property Vmin As Double
        Get
            Vmin = _Vmin
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _Vmin = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Modèle d'organe de réglage: 1 = pas d'imposition particulière / 2 = Distance de passage de particule de 1 mm de diamètre dans organe de réglage
    ''' </summary>
    Public Property Type_Org As Integer
        Get
            Type_Org = _Type_Org
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _Type_Org = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Modèle d'organe de réglage: 1 = pas d'imposition particulière / 2 = Distance de passage de particule de 1 mm de diamètre dans organe de réglage
    ''' </summary>
    Public Property Position_Org As Integer
        Get
            Position_Org = _Position_Org
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _Position_Org = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Modèle d'écart de température: 1 = entre prod et Exut / 2 = entre prod et retour
    ''' </summary>
    Public Property Type_dT As Integer
        Get
            Type_dT = _Type_dT
        End Get
        Set(value As Integer)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0.1 Then
                '    Throw New ArgumentException("La valeur Portée doit être supérieure à 10 cm.")
            Else
                _Type_dT = value
            End If
        End Set
    End Property
    ''' <summary>
    '''Température de départ à la production d'eau chaude sanitaire - unité: °C
    ''' </summary>
    Public Property TprodECS As Double
        Get
            TprodECS = _TprodECS
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _TprodECS = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Ecart maximal de température autorisé suivant modèle écart - unité: °C
    ''' </summary>
    Public Property dTBoucle As Double
        Get
            dTBoucle = _dTBoucle
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
            ElseIf value < 0 Then
                Throw New ArgumentException("La valeur doit être positive.")
            Else
                _dTBoucle = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Chute de température pour obtenir la temérature moyenne d'eau chaude sanitaire - unité: °C
    ''' </summary>
    Public Property ΔT_ECS As Double
        Get
            ΔT_ECS = _ΔT_ECS
        End Get
        Set(value As Double)
            If Not IsNumeric(value) Then
                Throw New ArgumentException("La valeur n'est pas numérique.")
                'ElseIf value < 0 Then
                '    Throw New ArgumentException("La valeur doit être positive.")
            Else
                _ΔT_ECS = value
            End If
        End Set
    End Property

    ''' <summary>
    '''Hauteur manométrique vanne compensatrice - unité: mCE
    ''' </summary>
    Public Property HMVC As Double

    ''' <summary>
    '''Hauteur manométrique vanne réseau le plus défavorisée - unité: mCE
    ''' </summary>
    Public Property HMVrd As Double

    ''' <summary>
    '''Perte de charge totale du réseau alimentant et recyclant la colonne i -  i est la clé du dictionnary et correspond au n° de colonne - Unité: mCE
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Pdc_Tot As New Dictionary(Of Integer, Double)
    ''' <summary>
    '''Perte de charge totale de la partie colonne montante depuis le réseau distributeur et de la partie recyclage jusqu'au collecteur pour la colonne i - Sert à déterminer l'autorité de la vanne
    ''' -  i est la clé du dictionnary et correspond au n° de colonne - Unité: mCE
    ''' </summary>
    <Xml.Serialization.XmlIgnore> Public Property Pdc_Col As New Dictionary(Of Integer, Double)
#End Region

#Region "Méthodes"
    Public Sub Initialisation_Distribution()
        Call Definition_Tronçon_Aval()
        Call Tête_de_colonne()
        Call affectation_tronçon_colonne()
        Call affectation_tronçon_collecteur()

    End Sub

    '''' <summary>
    '''' Methode: calcul du débit brut pour chaque type d'exutoire
    '''' </summary>
    'Public Sub Debit()
    '    Select Case Modele_Calcul
    '        Case 1 'EFS
    '            For Each _Exu In _Exutoire
    '                _Exu.Q_ES = _Exu.Q_Exu_EF
    '            Next
    '        Case 2 ' ECS
    '            For Each _Exu In _Exutoire
    '                _Exu.Q_ES = _Exu.Q_Exu_EC
    '            Next

    '    End Select
    'End Sub

    ''' <summary>
    ''' Methode: Détermination du ou des tronçons avals sur l'ensemble du réseau de distribution
    ''' </summary>
    Private Sub Definition_Tronçon_Aval()
        'pour éviter un plantage sur le 1ier tronçon
        Reseau._Tuyau.Item(0).Tronçon_Amont.Clear()
        Reseau._Tuyau.Item(0).Tronçon_Amont.Add(0)
        '
        For Each tuy In _Tuyau
            For Each tuy1 In _Tuyau
                If tuy Is tuy1 Then Continue For
                If Reseau._Tuyau.IndexOf(tuy) + 1 = tuy1.Tronçon_Amont(0) Then
                    tuy.Tronçon_Aval.Add(Reseau._Tuyau.IndexOf(tuy1) + 1)
                    'exemple: le tronçon 2 (index 1) a:
                    ' - tronçon amont = 1 (index 0)
                    ' - tronçon aval = 3 (index 2)
                End If
            Next
        Next
    End Sub

    ''' <summary>
    ''' Methode: Détermination des tronçons tête de colonne et du nombre de tête de colonne sur le réseau
    ''' </summary>
    Private Sub Tête_de_colonne()
        Dim i As Integer = 0
        For Each tuy In _Tuyau
            If tuy.Tronçon_Aval.Count = 0 Then
                tuy.Tete_Colonne = True
                i = i + 1
            Else
                tuy.Tete_Colonne = False
            End If
        Next
        Reseau._Têt_Colon_Nbre = i
    End Sub

    ''' <summary>
    ''' Methode: Affectation des tronçons à une colonne
    ''' </summary>
    Private Sub affectation_tronçon_colonne()
        Dim colonne As Integer = 0
        Dim num_Amont As Integer
        Dim tuy1 As New Tuyau
        For Each tuy In _Tuyau
            If tuy.Tete_Colonne = True Then
                colonne += 1
                tuy.i_colonne = colonne
                num_Amont = tuy.Tronçon_Amont(0)
                Do
                    'recherche du tuyau amont
                    If Reseau._Tuyau.Item(num_Amont - 1).Tronçon_Aval.Count = 1 Then
                        Reseau._Tuyau.Item(num_Amont - 1).i_colonne = colonne
                        num_Amont = Reseau._Tuyau.Item(num_Amont - 1).Tronçon_Amont(0)
                        If num_Amont = 0 Then Exit Do
                    Else
                        Exit Do
                    End If
                Loop
            End If
        Next
    End Sub

    ''' <summary>
    ''' Methode: Affectation des tronçons à un collecteur Aller - distribution EFS et ECS
    ''' </summary>
    Private Sub affectation_tronçon_collecteur()
        Dim i1, i2, k, k1 As Integer ', k1
        Dim collecteur As Integer = 1
        Dim collecteur1 As Integer = 1
        Dim fourche_Collecteur(1) As Integer
        fourche_Collecteur(1) = 1
        Dim Fourche_Collecteur_Ex(1) As Boolean
        Fourche_Collecteur_Ex(1) = False
        Dim parcours As Boolean = False
        _Tuyau.Item(0).collecteur = collecteur
        Collecteur_Or(1) = 1 'tronçon n°1 d'index 0 est l'origine du circuit 1

        i1 = 1   'le 1ier tronçon est toujours le tronçon n°1 soit l'index 0
        Reseau.Collecteur_D_Nbre = collecteur
        Do
            Do
                k = 0 : i2 = 0 : collecteur1 = _Tuyau.Item(i1 - 1).collecteur ' 
                For j = 1 To _Tuyau.Item(i1 - 1).Tronçon_Aval.Count
                    k1 = _Tuyau.Item(i1 - 1).Tronçon_Aval.Item(j - 1) 'n° du tronçon aval = index du tronçon aval +1
                    If _Tuyau.Item(k1 - 1).i_colonne = 0 And _Tuyau.Item(k1 - 1).collecteur = 0 Then
                        'le tronçon n'est pas identifié comme une colonne et pas encore comme un collecteur
                        k = k + 1
                        If k > 1 Then
                            collecteur += 1
                            Reseau.Collecteur_D_Nbre += 1
                            '   _Tuyau.Item(k1 - 1).collecteur_Or = True 'identification du tronçon origine du collecteur
                            Collecteur_Or(Reseau.Collecteur_D_Nbre) = k1 'n° du tronçon
                            _Tuyau.Item(k1 - 1).collecteur = Reseau.Collecteur_D_Nbre
                            ReDim Preserve fourche_Collecteur(Reseau.Collecteur_D_Nbre), Fourche_Collecteur_Ex(Reseau.Collecteur_D_Nbre)
                            fourche_Collecteur(Reseau.Collecteur_D_Nbre) = k1 '_Tuyau.Item(i1).Tronçon_Aval.Item(j - 1)
                            Fourche_Collecteur_Ex(Reseau.Collecteur_D_Nbre) = False 'toute la branche reste à parcourir
                        Else
                            _Tuyau.Item(k1 - 1).collecteur = Reseau._Tuyau.Item(i1 - 1).collecteur
                            i2 = _Tuyau.Item(i1 - 1).Tronçon_Aval.Item(j - 1)
                        End If
                    End If
                Next
                ' i1 = i2
                If i2 = 0 Then
                    'fin du tronçon collecteur
                    Collecteur_Ex(collecteur1) = i1 'n° du tronçon extrémité du collecteur
                    Fourche_Collecteur_Ex(collecteur1) = True 'toute la branche a été parcourue
                    Exit Do
                Else
                    i1 = i2
                End If
            Loop
            '  If Reseau.Collecteur_D_Nbre < collecteur Then Reseau.Collecteur_D_Nbre = collecteur

            If collecteur1 = collecteur Then 'implique que le parcours s'est fait sur une seule branche
                i1 = 0
                For i = 1 To Collecteur_D_Nbre
                    If Fourche_Collecteur_Ex(i) = False Then i1 = fourche_Collecteur(i)
                Next
                If i1 = 0 Then parcours = True 'toutes les brnaches ont été parcourues
            Else
                'collecteur final <> du collecteur initial, je parcours la brnache à partir du dernier embranchement
                i1 = fourche_Collecteur(collecteur) ' = n° de tronçon de l'origine du collecteur = index + 1
                Dim passage As Integer = 0
                For j = 1 To _Tuyau.Item(i1 - 1).Tronçon_Aval.Count
                    k1 = _Tuyau.Item(i1 - 1).Tronçon_Aval.Item(j - 1) 'n° du tronçon aval = index du tronçon aval +1
                    If _Tuyau.Item(k1 - 1).i_colonne = 0 And _Tuyau.Item(k1 - 1).collecteur <> collecteur Then
                        passage += 1
                        If _Tuyau.Item(k1 - 1).collecteur = 0 And passage = 1 Then
                            _Tuyau.Item(k1 - 1).collecteur = _Tuyau.Item(i1 - 1).collecteur
                        ElseIf _Tuyau.Item(k1 - 1).collecteur = 0 And passage > 1 Then
                            Reseau.Collecteur_D_Nbre += 1
                            'identification du tronçon origine du collecteur
                            Collecteur_Or(Reseau.Collecteur_D_Nbre) = k1 'n° du tronçon
                            _Tuyau.Item(k1 - 1).collecteur = Reseau.Collecteur_D_Nbre
                        Else
                            ' a voir
                        End If
                        i1 = k1 '_Tuyau.Item(i1).Tronçon_Aval.Item(j - 1)
                        collecteur = _Tuyau.Item(k1 - 1).collecteur 'n° de collecteur qui va être suivi
                    End If
                Next
            End If

        Loop While parcours = False 'tant que toutes les branches n'ont pas été parcourues

    End Sub

    Public Sub Initialisation_Retour_Boucle()
        Call Definition_Tronçon_Amont()
        Call Colonne_Retour_BECS()
        Call affectation_tronçon_collecteur_Retour()

    End Sub
    ''' <summary>
    ''' Methode: Détermination du ou des tronçons amonts sur l'ensemble du réseau de retour boucle
    ''' </summary>
    Private Sub Definition_Tronçon_Amont()
        'pour éviter un plantage sur le 1ier tronçon
        Reseau._TuyauR.Item(0).Tronçon_Aval.Clear()
        Reseau._TuyauR.Item(0).Tronçon_Aval.Add(0)

        For Each tuy In _TuyauR
            For Each tuy1 In _TuyauR
                If tuy Is tuy1 Then Continue For
                If Reseau._TuyauR.IndexOf(tuy) + 1 = tuy1.Tronçon_Aval(0) Then
                    tuy.Tronçon_Amont.Add(Reseau._TuyauR.IndexOf(tuy1) + 1)
                    'exemple: le tronçon 2 (index 1) a:
                    ' - tronçon amont = 1 (index 0)
                    ' - tronçon aval = 3 (index 2)
                End If
            Next
        Next
    End Sub

    ''' <summary>
    ''' Methode: Détermination du n° de la colonne de retour de boucle - n° identique à la colonne montante
    ''' </summary>
    Private Sub Colonne_Retour_BECS()
        Dim colonne, i1 As Integer
        Dim tuy As Tuyau
        tuy = New Tuyau
        Dim TuyR As Tuyau
        TuyR = New Tuyau
        For colonne = 1 To Têt_Colon_Nbre
            'recherche index tuyau tête de colonne
            For Each tuy In Reseau._Tuyau
                If tuy.i_colonne = colonne And tuy.Tete_Colonne = True Then i1 = _Tuyau.IndexOf(tuy) : Exit For
            Next
            'affectation du n° de colonne sur le retour colonne
            For Each TuyR In Reseau._TuyauR
                If TuyR.Tronçon_Distrib = i1 + 1 Then TuyR.i_colonne = colonne : Exit For
            Next
        Next
        'recherche du tuyau aval et affectation si nécessaire
        For Each TuyR In _TuyauR
            If TuyR.i_colonne <> 0 Then
                i1 = TuyR.Tronçon_Aval(0)
                If i1 = 0 Then Exit For
                Do While _TuyauR.Item(i1 - 1).Tronçon_Amont.Count = 1
                    _TuyauR.Item(i1 - 1).i_colonne = TuyR.i_colonne
                    i1 = _TuyauR.Item(i1 - 1).Tronçon_Aval(0) 'tronçon suivant
                    If i1 = 0 Then Exit Do
                Loop
            End If
        Next
    End Sub

    ''' <summary>
    ''' Methode: Affectation des tronçons à un collecteur Retour - retour boucle ECS
    ''' </summary>
    Private Sub affectation_tronçon_collecteur_Retour()
        Dim i1, i2, k, k1 As Integer ', k1
        Dim collecteur As Integer = 1
        Dim collecteur1 As Integer = 1
        Dim fourche_Collecteur(1) As Integer
        fourche_Collecteur(1) = 1
        Dim Fourche_Collecteur_Ex(1) As Boolean
        Fourche_Collecteur_Ex(1) = False
        Dim parcours As Boolean = False

        _TuyauR.Item(0).collecteur = collecteur
        Collecteur_Or_R(1) = 1 'tronçon n°1 d'index 0 est l'origine du circuit 1
        i1 = 1   'le 1ier tronçon est toujours le tronçon n°1 soit l'index 0, il s'agit en l'occurence du tronçon collecteur final
        Reseau.Collecteur_R_Nbre = collecteur
        Do
            Do
                k = 0 : i2 = 0 : collecteur1 = _TuyauR.Item(i1 - 1).collecteur ' 
                For j = 1 To _TuyauR.Item(i1 - 1).Tronçon_Amont.Count
                    k1 = _TuyauR.Item(i1 - 1).Tronçon_Amont.Item(j - 1) 'n° du tronçon amont = index du tronçon amont +1
                    If _TuyauR.Item(k1 - 1).i_colonne = 0 And _TuyauR.Item(k1 - 1).collecteur = 0 Then
                        'le tronçon n'est pas identifié comme une colonne et pas encore comme un collecteur
                        k = k + 1
                        If k > 1 Then
                            collecteur += 1 '_TuyauR.Item(k1 - 1).collecteur_Or = True 'identification du tronçon origine du collecteur
                            Reseau.Collecteur_R_Nbre += 1
                            Collecteur_Or_R(Reseau.Collecteur_R_Nbre) = k1 'n° du tronçon
                            _TuyauR.Item(k1 - 1).collecteur = Reseau.Collecteur_R_Nbre
                            ReDim Preserve fourche_Collecteur(Reseau.Collecteur_R_Nbre), Fourche_Collecteur_Ex(Reseau.Collecteur_R_Nbre)
                            fourche_Collecteur(Reseau.Collecteur_R_Nbre) = k1 '_Tuyau.Item(i1).Tronçon_Aval.Item(j - 1)
                            Fourche_Collecteur_Ex(Reseau.Collecteur_R_Nbre) = False 'toute la branche reste à parcourir
                        Else
                            _TuyauR.Item(k1 - 1).collecteur = Reseau._TuyauR.Item(i1 - 1).collecteur
                            i2 = _TuyauR.Item(i1 - 1).Tronçon_Amont.Item(j - 1)
                        End If
                    End If
                Next
                ' i1 = i2
                If i2 = 0 Then
                    'fin du tronçon collecteur
                    '  _Tuyau.Item(i1 - 1).collecteur_Ex = True 'identification du tronçon extrémité du collecteur
                    Collecteur_Ex_R(collecteur1) = i1 'identification du n° du tronçon extrémité du collecteur
                    Fourche_Collecteur_Ex(collecteur1) = True 'toute la branche a été parcourue
                    Exit Do
                Else
                    i1 = i2
                End If
            Loop
            ' If Reseau.Collecteur_R_Nbre < collecteur Then Reseau.Collecteur_R_Nbre = collecteur

            If collecteur1 = collecteur Then 'implique que le parcours s'est fait sur une seule branche
                i1 = 0
                For i = 1 To Reseau.Collecteur_R_Nbre
                    If Fourche_Collecteur_Ex(i) = False Then i1 = fourche_Collecteur(i) ': collecteur = i
                Next
                If i1 = 0 Then parcours = True 'toutes les branches ont été parcourues
            Else
                'collecteur final <> du collecteur initial, je parcours la branche à partir du dernier embranchement
                i1 = fourche_Collecteur(collecteur) ' = n° de tronçon = index + 1
                Dim passage As Integer = 0
                For j = 1 To Reseau._TuyauR.Item(i1 - 1).Tronçon_Amont.Count
                    k1 = _TuyauR.Item(i1 - 1).Tronçon_Amont.Item(j - 1) 'n° du tronçon amont = index du tronçon amont +1
                    If _TuyauR.Item(k1 - 1).i_colonne = 0 And _TuyauR.Item(k1 - 1).collecteur <> collecteur Then
                        passage += 1
                        If _TuyauR.Item(k1 - 1).collecteur = 0 And passage = 1 Then
                            _TuyauR.Item(k1 - 1).collecteur = _TuyauR.Item(i1 - 1).collecteur
                        ElseIf _Tuyaur.Item(k1 - 1).collecteur = 0 And passage > 1 Then
                            Reseau.Collecteur_R_Nbre += 1
                            'identification du tronçon origine du collecteur
                            Collecteur_Or_R(Reseau.Collecteur_R_Nbre) = k1 'n° du tronçon
                            _TuyauR.Item(k1 - 1).collecteur = Reseau.Collecteur_R_Nbre
                        Else
                            ' a voir
                        End If
                        i1 = k1 '_Tuyau.Item(i1).Tronçon_Aval.Item(j - 1)
                        '  i1 = _TuyauR.Item(i1).Tronçon_Amont.Item(j - 1)
                        collecteur = _TuyauR.Item(k1 - 1).collecteur 'n° de collecteur qui va être suivi
                    End If
                Next
            End If

        Loop While parcours = False 'tant que toutes les branches n'ont pas été parcourues
    End Sub

    ''' <summary>
    ''' Methode: calcul de la perte thermique locale du tronçon
    ''' </summary>
    Public Sub Perte_Thermique()
        Dim de, hi, he, K As Double
        Dim V As Double = 0.2 'vitesse limite de retour de boucle
        For Each tuy In _Tuyau
            With tuy
                If .Pth_Val_Directe = False Then
                    de = D_Ext(.Øint, .Mat)
                    hi = 2538 * V ^ 0.8 / .Øint ^ 0.2   'formules guide AICVF
                    Select Case de
                        Case Is <= 0.017
                            he = 12.8
                        Case Is > 0.027
                            he = 11.6
                        Case Else
                            he = 11.9
                    End Select
                    K = (1 / hi) + (de / (2 * .Isol_λ)) * Log((de + 2 * .Isol_ep) / de) + (de / (he * (de + 2 * .Isol_ep)))
                    K = 1 / K
                    .Pth = K * PI * de * (Reseau.TprodECS - Reseau.ΔT_ECS - .Isol_T)
                End If
            End With
        Next
        For Each tuy In _TuyauR
            With tuy
                If .Pth_Val_Directe = False Then
                    de = D_Ext(.Øint, .Mat)
                    hi = 2538 * V ^ 0.8 / .Øint ^ 0.2   'formules guide AICVF
                    Select Case de
                        Case Is <= 0.017
                            he = 12.8
                        Case Is > 0.027
                            he = 11.6
                        Case Else
                            he = 11.9
                    End Select
                    K = (1 / hi) + (de / (2 * .Isol_λ)) * Log((de + 2 * .Isol_ep) / de) + (de / (he * (de + 2 * .Isol_ep)))
                    K = 1 / K
                    .Pth = K * PI * de * (Reseau.TprodECS - Reseau.ΔT_ECS - .Isol_T)
                End If
            End With
        Next
    End Sub

    Private Function D_Ext(ByVal Diam As Double, ByVal Matiere_Tube As Integer) As Double
        Dim j As Integer
        D_Ext = 0
        Select Case Matiere_Tube
            Case 1 'Cuivre 
                Dim tub As New Cuivre
                j = tub.Øext.Count
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until tub.Øint.Item(j) <= Diam
                D_Ext = tub.Øext.Item(j)
                tub = Nothing
            Case 2 'tube galva
                Dim tub As New AG
                j = tub.Øext.Count
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until tub.Øint.Item(j) <= Diam
                D_Ext = tub.Øext.Item(j)
                tub = Nothing
            Case 3 'PER
                Dim tub As New PER
                j = tub.Øext.Count
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until tub.Øint.Item(j) <= Diam
                D_Ext = tub.Øext.Item(j)
                tub = Nothing
            Case 4 'Multicouche
                Dim tub As New Multi_Couche
                j = tub.Øext.Count
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until tub.Øint.Item(j) <= Diam
                D_Ext = tub.Øext.Item(j)
                tub = Nothing
            Case 5 'PVC-C  "12,4/16 DN16", "15,4/20  DN20", "19,4/25  DN25", "24,8/32  DN32", "31,0/40  DN40", "38,8/50  DN50"
                Dim tub As New Multi_Couche
                j = tub.Øext.Count
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until tub.Øint.Item(j) <= Diam
                D_Ext = tub.Øext.Item(j)
                tub = Nothing
        End Select

    End Function
#End Region

End Class
