﻿Imports System.Math
Imports System.IO

Module code_calcul

#Region "Dimensionnement des réseaux EFS et ECS "
    ''' <summary>Programme général de calcul des distributions d'EFS et d'ECS</summary>
    '''  <param name="note_de_calcul">variable renvoyant le fichier de note de calcul sous format rtf</param>
    ''' <param name="verif"> variable prenant la valeur False si une erreur bloquante s'est produite pendant le calcul</param>
    Public Sub Plomberie_EF(ByRef Verif As Boolean, ByRef note_de_calcul As String)
        Dim msg As String
        Dim Y_Tot, Qprob, Δp_Entree, Ø As Double
        Verif = True
        'writer de sortie du RTF
        Dim sw As New System.IO.StringWriter
        'crée un writer de RTF avec une police par défaut
        Dim rtf As New To_Rtf.RtfAnsiTextWriter(sw, New Font(FontFamily.GenericSerif, 12, FontStyle.Regular))
        Dim rtff As String
        rtf.Bold = True : rtf.FontSize = 16 : rtf.Underline = True
        With Reseau
            .Initialisation_Distribution()
            Select Case .Modele_Calcul
                Case 1
                    rtf.WriteString("Note de calcul de dimensionnement de réseau eau froide sanitaire")
                Case 2
                    rtf.WriteString("Note de calcul de dimensionnement de réseau eau chaude sanitaire")
            End Select
            rtf.NewLine()
            rtf.Bold = False : rtf.FontSize = 10 : rtf.Underline = False : rtf.NewParagraph()
            rtf.WriteString("Note de calcul du : " & DateTime.Now.ToLongDateString() & " " & DateTime.Now.ToLongTimeString) : rtf.NewLine()
            rtf.WriteString("Rédacteur : " & Aff.Redacteur) : rtf.NewLine()
            rtf.WriteString("Chantier : " & Aff.Chantier) : rtf.NewLine()
            rtf.WriteString("Logiciel : Calculette Plomberie version " & My.Application.Info.Version.ToString & "   2013 - " & DateTime.Now.Year.ToString) : rtf.NewLine()
            rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
            rtf.WriteString("1 - Rappel des hypothèses") : rtf.Bold = False
            rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
            rtf.WriteString("Codes de calculs:") : rtf.NewLine()
            rtf.WriteString("-  Débits suivant DTU 60.11 d'octobre 1988") : rtf.NewLine()
            rtf.WriteString("-  Coefficients de simultanéité suivant DTU ")
            If .Ycoef = 1 Then
                rtf.WriteString("sans coefficient de correction (= 1).") : rtf.NewLine()
            Else
                rtf.WriteString("avec coefficient de correction pris égal à " & .Ycoef.ToString("0.00")) : rtf.NewLine()
            End If
            rtf.WriteString("-  Dimensions minimales des tuyauteries sur tronçons individuels suivant DTU") : rtf.NewLine()
            rtf.WriteString("Résultat à obtenir:") : rtf.NewLine()
            rtf.WriteString("-  Pression résiduelle en sortie de la robinetterie la plus défavorisée: ")
            rtf.WriteString(.Pr_ES.ToString("#0.0") & " mCE (" & (.Pr_ES / 10).ToString("#0.00") & " bar)") : rtf.NewLine()

            rtf.NewLine() : rtf.Bold = True : rtf.Underline = True : rtf.WriteString("Schéma type du réseau") : rtf.NewLine() : rtf.Bold = False : rtf.Underline = False
            'Try
            '    ' Create Image Element
            '    Dim myImage As Image
            '    myImage = Image.FromFile(Directory.GetCurrentDirectory.ToString() & "\Images\schema_EF_EC.png")
            '    rtf.InsertImage(myImage)
            'Catch ex As Exception
            '    msg = "Le logiciel n'a pas pu chargé l'image correspondante." & Environment.NewLine & "Erreur: " & ex.Message & ex.StackTrace & Environment.NewLine & "Note de calcul sans image"
            '    MsgBox(msg, MsgBoxStyle.Exclamation Or MsgBoxStyle.OkOnly, "Logiciel EF_ECS")
            'End Try
            rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
            rtf.WriteString("2 - Calcul des exutoires") : rtf.Bold = False : rtf.Underline = False
            rtf.FontSize = 10 : rtf.NewLine()

            For Each exu In Exutoires
                exu.Initialisation()  'calcul des débits,nbre d'appareils et coef Y pour chaque catégorie d'éxutoire
                rtf.NewLine()
                rtf.WriteString("Exutoire de type n°" & (Exutoires.IndexOf(exu) + 1).ToString & " comprenant:") : rtf.NewLine()
                If exu._Baignoire_Nb >= 1 Then rtf.WriteString("---- " & exu._Baignoire_Nb.ToString & " baignoire(s) - Ø alim individuelle intérieur mini: " & exu._Baignoire.Ø_int.ToString("#") & " mm.") : Ø = exu._Baignoire.Ø_int / 1000 : rtf.NewLine()
                If exu._Bidet_nb >= 1 Then rtf.WriteString("---- " & exu._Bidet_nb.ToString & " bidet(s) - Ø alim individuelle intérieur mini: " & exu._Bidet.Ø_int.ToString("#") & " mm.") : Ø = exu._Bidet.Ø_int / 1000 : rtf.NewLine()
                If exu._douche_nb >= 1 Then rtf.WriteString("---- " & exu._douche_nb.ToString & " douche(s) - Ø alim individuelle intérieur mini: " & exu._douche.Ø_int.ToString("#") & " mm.") : Ø = exu._douche.Ø_int / 1000 : rtf.NewLine()
                If exu._Evier_nb >= 1 Then rtf.WriteString("---- " & exu._Evier_nb.ToString & " évier(s) - Ø alim individuelle intérieur mini: " & exu._Evier.Ø_int.ToString("#") & " mm.") : Ø = exu._Evier.Ø_int / 1000 : rtf.NewLine()
                If exu._lavabo_nb >= 1 Then rtf.WriteString("---- " & exu._lavabo_nb.ToString & " lavabo(s) - Ø alim individuelle intérieur mini: " & exu._lavabo.Ø_int.ToString("#") & " mm.") : Ø = exu._lavabo.Ø_int / 1000 : rtf.NewLine()
                If exu._lavemain_nb >= 1 Then rtf.WriteString("---- " & exu._lavemain_nb.ToString & " lave-main(s) - Ø alim individuelle intérieur mini: " & exu._lavemain.Ø_int.ToString("#") & " mm.") : Ø = exu._lavemain.Ø_int / 1000 : rtf.NewLine()
                If exu._Lave_Linge_nb >= 1 Then rtf.WriteString("---- " & exu._Lave_Linge_nb.ToString & " Lave_Linge(s) - Ø alim individuelle intérieur mini: " & exu._Lave_Linge.Ø_int.ToString("#") & " mm.") : Ø = exu._Lave_Linge.Ø_int / 1000 : rtf.NewLine()
                If exu._Lave_vaisselle_nb >= 1 Then rtf.WriteString("---- " & exu._Lave_vaisselle_nb.ToString & " Lave-vaisselle(s) - Ø alim individuelle intérieur mini: " & exu._Lave_vaisselle.Ø_int.ToString("#") & " mm.") : Ø = exu._Lave_vaisselle.Ø_int / 1000 : rtf.NewLine()
                If exu._WC_Reservoir_nb >= 1 Then rtf.WriteString("---- " & exu._WC_Reservoir_nb.ToString & " WC avec réservoir de chasse à usage individuel - Ø alim individuelle intérieur mini: " & exu._WC_Reservoir.Ø_int.ToString("#") & " mm.") : Ø = exu._WC_Reservoir.Ø_int / 1000 : rtf.NewLine()
                If exu._WC_Reservoir_coll_nb >= 1 Then rtf.WriteString("---- " & exu._WC_Reservoir_coll_nb.ToString & " WC avec réservoir de chasse à usage collectif - Ø alim individuelle intérieur mini: " & exu._WC_Reservoir_coll.Ø_int.ToString("#") & " mm.") : Ø = exu._WC_Reservoir_coll.Ø_int / 1000 : rtf.NewLine()
                If exu._Timbre_Office_nb >= 1 Then rtf.WriteString("---- " & exu._Timbre_Office_nb.ToString & " timbre d'office - Ø alim individuelle intérieur mini: " & exu._Timbre_Office.Ø_int.ToString("#") & " mm.") : Ø = exu._Timbre_Office.Ø_int / 1000 : rtf.NewLine()
                If exu._Bac_a_Laver_nb >= 1 Then rtf.WriteString("---- " & exu._Bac_a_Laver_nb.ToString & " Bac à Laver - Ø alim individuelle intérieur mini: " & exu._Bac_a_Laver.Ø_int.ToString("#") & " mm.") : Ø = exu._Bac_a_Laver.Ø_int / 1000 : rtf.NewLine()
                If exu._Urinoir_nb >= 1 Then rtf.WriteString("---- " & exu._Urinoir_nb.ToString & " urinoir(s) à robinet individuel - Ø alim individuelle intérieur mini: " & exu._Urinoir.Ø_int.ToString("#") & " mm.") : Ø = exu._Urinoir.Ø_int / 1000 : rtf.NewLine()
                If exu._Poste_eau_nb >= 1 Then rtf.WriteString("---- " & exu._Poste_eau_nb.ToString & " poste d'eau 1/2 - Ø alim individuelle intérieur mini: " & exu._Poste_eau.Ø_int.ToString("#") & " mm.") : Ø = exu._Poste_eau.Ø_int / 1000 : rtf.NewLine()
                If exu._lavabo_Coll_nb >= 1 Then rtf.WriteString("---- " & exu._lavabo_Coll_nb.ToString & " lavabos collectifs - Ø alim individuelle intérieur mini: " & exu._lavabo_Coll.Ø_int.ToString("#") & " mm.") : Ø = exu._lavabo_Coll.Ø_int / 1000 : rtf.NewLine()
                If exu._Poste_eau_34_nb >= 1 Then rtf.WriteString("---- " & exu._Poste_eau_34_nb.ToString & " poste d'eau 3/4 - Ø alim individuelle intérieur mini: " & exu._Poste_eau_34.Ø_int.ToString("#") & " mm.") : Ø = exu._Poste_eau_34.Ø_int / 1000 : rtf.NewLine()

                Select Case exu.Yind
                    Case Is <= 15
                        rtf.WriteString(" - coefficient simultanéité = " & exu.Yind.ToString("#0.00") & " < 15 - Application des conditions de simultanéité des parties individuelles.") : rtf.NewLine()
                        Select Case Reseau.Modele_Calcul
                            Case 1 'EFS
                                rtf.WriteString(" - débit brut total: " & exu.Q_ES.ToString("#0.000") & " L/s.") : rtf.NewLine()
                            Case 2 'ECS
                                rtf.WriteString(" - débit brut total: " & exu.Q_EC.ToString("#0.000") & " L/s.") : rtf.NewLine()
                        End Select
                        If exu.App_nb > 1 Then exu.Ø_int = Diam_Exutoire(exu.Yind) Else exu.Ø_int = Ø
                        rtf.WriteString(" - réseau terminal de diamètre intérieur minimum " & (exu.Ø_int * 1000).ToString("#0.0") & " mm")
                    'exu.Nom = libel_diametre(Diam_Exutoire(exu.Y), exu.Mat)
                    'Select Case exu.Mat
                    '    Case 1 'cuivre
                    '        rtf.WriteString(" soit en tube cuivre " & exu.Nom) : rtf.NewLine()
                    '    Case 2
                    '        rtf.WriteString(" soit en tube en acier galvanisé " & exu.Nom) : rtf.NewLine()
                    '    Case 3    'PER
                    '        rtf.WriteString("Soit en tube PER " & exu.Nom) : rtf.NewLine()
                    '    Case 4  'tube multicouche
                    '        rtf.WriteString("Soit en tube multicouche " & exu.Nom) : rtf.NewLine()
                    'End Select
                    Case Else
                        rtf.WriteString(" - coefficient simultanéité = " & exu.Yind.ToString("#0.00") & "  > 15 - Application des conditions de simultanéité des parties collectives.") : rtf.NewLine()
                        rtf.WriteString(" - vitesse limite de dimensionnement retenue: " & .VlimIndiv.ToString("#0.00") & " m/s") : rtf.NewLine()
                        Y_Tot = .Ycoef * 0.8 / (exu.App_nb - 1) ^ 0.5
                        Select Case Reseau.Modele_Calcul
                            Case 1 'EFS
                                Qprob = Y_Tot * exu.Q_ES
                            Case 2 'ECS
                                Qprob = Y_Tot * exu.Q_EC
                        End Select
                        rtf.WriteString(" - coefficient simultanéité = " & Y_Tot.ToString("#0.000") & "  pour Qprob = " & (Qprob).ToString("#0.00") & "  L/s") : rtf.NewLine()
                        rtf.WriteString(" - diamètre minimal intérieur: " & ((Sqrt(4 * (Qprob * 0.001) / (.VlimIndiv * PI))) * 1000).ToString("#0.0") & " mm")
                        'exu.Nom = libel_diametre(Diam_Exutoire(exu.Y), exu.Mat)
                        'Select Case exu.Mat
                        '    Case 1
                        '        rtf.WriteString(" soit en tube cuivre " & exu.Nom) : rtf.NewLine()
                        '    Case 2
                        '        rtf.WriteString(" soit en tube en acier galvanisé " & exu.Nom) : rtf.NewLine()
                        '    Case 3    'PER
                        '        rtf.WriteString("Soit en tube PER " & exu.Nom) : rtf.NewLine()
                        '    Case 4  'tube multicouche
                        '        rtf.WriteString("Soit en tube multicouche " & exu.Nom) : rtf.NewLine()
                        'End Select
                        'J_Diam_Exut(i) = J_Flamant(Q_Exut(i), Diam_Exut(i), Modele_Calcul, Verif) 'formule de flamant
                        'If Verif = False Then rtf.WriteEndGroup() : Exit Sub
                End Select
                'If J_Diam_Exut(i) = 0 Then
                '    rtf.WriteString(" - J = 0 mCE. Perte de charge non significative sur la partie de tronçon individuel. Ne doit pas être pris en compte dans les calculs.") : rtf.NewLine()
                'Else
                '    rtf.WriteString(" - J : " & (J_Diam_Exut(i) * 1).ToString("#0.00") & " mCE/m. Perte de charge significative sur la partie de tronçon individuel. A tenir compte dans les calculs.") : rtf.NewLine()
                'End If

            Next
            rtf.NewLine() : rtf.Bold = True : rtf.FontSize = 12 : rtf.Underline = True
            rtf.WriteString("3 - Calcul des débits et dimensionnement des tuyauteries") : rtf.Underline = False : rtf.Bold = False : rtf.FontSize = 10
            rtf.NewLine() : rtf.NewLine()
            Call Calcul_debit_ES_Tuyauterie(Verif, rtf)
            If Verif = False Then Exit Sub
            rtf.WriteStartGroup() : rtf.NewLine() : rtf.Bold = True : rtf.FontSize = 12 : rtf.Underline = True
            rtf.WriteString("4 - Calcul des pertes de charges et pressions statiques disponibles") : rtf.Underline = False : rtf.Bold = False : rtf.FontSize = 10
            rtf.NewLine()
            rtf.WriteString("Pression disponible au raccordement réseau public :  " & .PrEntree.ToString("#0.0") & " mCE") : rtf.NewLine()
            rtf.WriteString("Pression résiduelle exigée :  " & .Pr_ES.ToString("#0.0") & " mCE") : rtf.NewLine()
            Δp_Entree = .PdcVanne + .PdcCompteur + .PdcDisconnecteur + .PdcFiltre + .PdcReduc
            If Reseau.Modele_Calcul = 2 Then Δp_Entree = Δp_Entree + .PdcPrepECS
            rtf.WriteString("Perte de charge totale pour l’ensemble des éléments communs à toutes les colonnes (compteur, …) :  " & Δp_Entree.ToString("#0.0") & " mCE.") : rtf.NewLine()
            rtf.NewLine() : rtf.WriteEndGroup()
            Call Pertes_de_charge_Reseau_EF_ECS(Δp_Entree, Verif, rtf)
            'génère le RTF complet
            Select Case .Modele_Calcul
                Case 1
                    note_de_calcul = "Ndc_EF_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
                Case 2 'ECS
                    note_de_calcul = "Ndc_ECS_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
            End Select

            rtf.Generate() : rtff = sw.ToString
            note_de_calcul = Aff.msgResult & "\" & note_de_calcul
            File.WriteAllText(note_de_calcul, rtff)
        End With

    End Sub

    ''' <summary>Détermination du débit pour chaque tronçon</summary>
    '''  <param name="rtf">variable renvoyant le fichier de note de calcul sous format rtf</param>
    Private Sub Calcul_debit_ES_Tuyauterie(ByRef Verif As Boolean, ByRef rtf As To_Rtf.RtfAnsiTextWriter)
        Dim msg As String = String.Empty
        Dim colonne, i1, i_aval As Integer
        Dim V_tr, Y As Double
        Dim Ø As Double
        msg = "Réseau constitué de "
        rtf.WriteStartGroup()
        rtf.NewParagraph()
        rtf.FontSize = 10
        Select Case Reseau._Tuyau.Item(0).Mat
            Case 1
                msg += "tuyauteries en cuivre"
            Case 2
                msg += "tuyauteries en acier galvanisé"
            Case 3
                msg += "tuyauteries en PER"
            Case 4
                msg += "tuyauteries en multicouche"
        End Select
        For i = 2 To Reseau._Tuyau.Count
            If Reseau._Tuyau.Item(i - 1).Mat <> Reseau._Tuyau.Item(0).Mat Then
                Select Case Reseau._Tuyau.Item(i - 1).Mat
                    Case 1
                        msg += " et en cuivre"
                    Case 2
                        msg += " et en galvanisé"
                    Case 3
                        msg += " et en PER"
                    Case 4
                        msg += " et en multicouche"
                End Select
                Exit For
            End If
        Next
        rtf.WriteString(msg) : rtf.NewLine()
        rtf.NewParagraph()
        rtf.FontSize = 8
        'Ligne 1
        rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Tr. Aval") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Tr. Amont") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Nb appareils") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Q brut (l/s)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("(Y) coef. Simult.") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Q prob (l/s)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("V (m/s)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Ø int (mm)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Ø retenue") : rtf.EndCell() : rtf.EndRow()
        '
        '--> Calcul Partie Colonnes
        For colonne = 1 To Reseau.Têt_Colon_Nbre
            'recherche index tuyau tête de colonne
            For Each tuy In Reseau._Tuyau
                If tuy.i_colonne = colonne And tuy.Tete_Colonne = True Then i1 = Reseau._Tuyau.IndexOf(tuy) : Exit For
            Next
            '    msg = String.Empty
            With Reseau._Tuyau.Item(i1)

                For j = 1 To .Exut_nbType.Count
                    '  Reseau._Tuyau.Item(i1).Appareils_Nbre +=Reseau._Tuyau.Item(i1).Exut_Type(j)
                    '  msg += Reseau._Tuyau.Item(i1).Exut_nbType(j - 1).ToString & ".Exu" & Reseau._Tuyau.Item(i1).Exut_Type(j - 1).ToString

                    For Each exu1 In Exutoires
                        If .Exut_Type(j - 1) = (Exutoires.IndexOf(exu1) + 1) Then 'vérification que ce type d'exutoire se trouve raccordé à ce tronçon
                            Ø = exu1.Ø_int
                            .Appareils_Nbre += exu1.App_nb * .Exut_nbType(j - 1)
                            Select Case Reseau.Modele_Calcul
                                Case 1 'EFS
                                    .Qbrut += exu1.Q_ES * .Exut_nbType(j - 1)
                                Case 2 'ECS
                                    .Qbrut += exu1.Q_EC * .Exut_nbType(j - 1)
                            End Select
                            .Yind += exu1.Yind
                            Exit For
                        End If
                    Next
                    'If j <> Reseau._Tuyau.Item(i1).Exut_nbType.Count Then msg += " + "
                Next
                Select Case .Appareils_Nbre
                    Case Is <= 5
                        .Qprob = .Qbrut
                        If .Appareils_Nbre > 1 Then .Øint = Diam_Exutoire(.Yind) Else .Øint = Ø
                        .Øint = Determination_diametre(.Øint, .Mat)
                    Case Is > 5
                        Select Case .Yind
                            Case < 15
                                Dim diam As Double
                                .Øint = Diam_Exutoire(.Yind)
                                Y = Reseau.Ycoef * 0.8 / (.Appareils_Nbre - 1) ^ 0.5
                                .Qprob = Y * .Qbrut
                                diam = Sqrt(.Qprob * 4 / 1000 / (PI * 2)) 'vitesse = 2m/s
                                If diam > .Øint Then
                                    .Øint = diam : Y = .Yind
                                End If
                                .Øint = Determination_diametre(.Øint, .Mat)
                            Case Else
                                Y = Reseau.Ycoef * 0.8 / (.Appareils_Nbre - 1) ^ 0.5
                                .Qprob = Y * .Qbrut
                                .Øint = Calcul_diametre(.Qprob, .Vlimit, .Mat)
                        End Select
                End Select
                If .Øimposée = True Then .Øint = .Øimp
                .Nom = libel_diametre(.Øint, .Mat)
                If .Qimposée = True Then .Qprob = .Qimp * 1000
                'Affichage de la ligne tête de colonne
                rtf.BeginRow() : rtf.DeclareCell(10000) : rtf.BeginCell(True) : rtf.WriteString("Colonne n°" & colonne.ToString) : rtf.EndCell() : rtf.EndRow()
                'Affichage de la 1ière ligne d'un élément tête de colonne
                rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((i1 + 1).ToString) : rtf.EndCell() 'n° de tronçon
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("S.O.") : rtf.EndCell() 'n° de tronçon Aval
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Tronçon_Amont.Item(0).ToString) : rtf.EndCell() ' n° de tronçon Amont
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Appareils_Nbre.ToString("#")) : rtf.EndCell()
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Qbrut.ToString("#0.00")) : rtf.EndCell()

                If .Appareils_Nbre <= 5 Then
                    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Y.ToString("#0.000")) : rtf.EndCell() 'coef Y
                    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("NA") : rtf.EndCell() ''Q prob
                    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("NA") : rtf.EndCell() ' V
                Else
                    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Y.ToString("#0.000")) : rtf.EndCell() 'coef Y
                    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Qprob.ToString("#0.00")) : rtf.EndCell() ''Q prob
                    V_tr = .Qprob / (PI * .Øint ^ 2 / 4) / 1000
                    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(V_tr.ToString("#0.00")) : rtf.EndCell() ' V
                End If
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((.Øint * 1000).ToString("#0.0")) : rtf.EndCell()
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((.Nom).ToString()) : rtf.EndCell() : rtf.EndRow()
            End With
            'pour les autres tronçons de la colonne
            Do
                i_aval = i1 'index du tronçon aval
                i1 = Reseau._Tuyau.Item(i_aval).Tronçon_Amont(0)
                i1 = i1 - 1 'base 0!!!! - i1 = index du tronçon amont
                With Reseau._Tuyau.Item(i1)
                    'vérification que le tronçon amont appartienne bien à la colonne
                    If .i_colonne = colonne Then
                        'prise en compte de l'aval
                        .Appareils_Nbre = Reseau._Tuyau.Item(i_aval).Appareils_Nbre
                        .Qbrut = Reseau._Tuyau.Item(i_aval).Qbrut
                        .Yind = Reseau._Tuyau.Item(i_aval).Yind
                        'prise en compte des exutoires directement raccordés au tronçon
                        For j = 1 To .Exut_nbType.Count
                            For Each exu1 In Exutoires
                                If .Exut_Type(j - 1) = (Exutoires.IndexOf(exu1) + 1) Then
                                    Ø = exu1.Ø_int
                                    .Appareils_Nbre += exu1.App_nb * .Exut_nbType(j - 1)
                                    Select Case Reseau.Modele_Calcul
                                        Case 1 'EFS
                                            .Qbrut += exu1.Q_ES * .Exut_nbType(j - 1)
                                        Case 2 'ECS
                                            .Qbrut += exu1.Q_EC * .Exut_nbType(j - 1)
                                    End Select
                                    .Yind += exu1.Yind
                                    Exit For
                                End If
                            Next
                        Next
                        Select Case .Appareils_Nbre
                            Case Is <= 5
                                .Qprob = .Qbrut
                                .Øint = Diam_Exutoire(.Yind)
                                If .Appareils_Nbre > 1 Then .Øint = Diam_Exutoire(.Yind) Else .Øint = Ø
                                .Øint = Determination_diametre(.Øint, .Mat)
                            Case Is > 5
                                Select Case .Yind
                                    Case < 15
                                        Dim diam As Double
                                        .Øint = Diam_Exutoire(.Yind)
                                        Y = Reseau.Ycoef * 0.8 / (.Appareils_Nbre - 1) ^ 0.5
                                        .Qprob = Y * .Qbrut
                                        diam = Sqrt(.Qprob * 4 / 1000 / (PI * 2)) 'vitesse = 2m/s
                                        If diam > .Øint Then
                                            .Øint = diam : Y = .Yind
                                        End If
                                        .Øint = Determination_diametre(.Øint, .Mat)
                                    Case Else
                                        Y = Reseau.Ycoef * 0.8 / (.Appareils_Nbre - 1) ^ 0.5
                                        .Qprob = Y * .Qbrut
                                        .Øint = Calcul_diametre(.Qprob, .Vlimit, .Mat)
                                End Select
                        End Select
                        If .Øimposée = True Then .Øint = .Øimp
                        If .Qimposée = True Then .Qprob = .Qimp * 1000
                        .Nom = libel_diametre(.Øint, .Mat)
                        'Affichage de la ligne d'un élément de tronçon de colonne
                        rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((i1 + 1).ToString) : rtf.EndCell() 'n° de tronçon
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((i_aval + 1).ToString) : rtf.EndCell() 'n° de tronçon Aval
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Tronçon_Amont.Item(0).ToString) : rtf.EndCell() ' n° de tronçon Amont
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Appareils_Nbre.ToString("#")) : rtf.EndCell()
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Qbrut.ToString("#0.00")) : rtf.EndCell()
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Y.ToString("#0.000")) : rtf.EndCell() 'coef Y
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Qprob.ToString("#0.00")) : rtf.EndCell() ''Q prob
                        V_tr = .Qprob / (PI * .Øint ^ 2 / 4) / 1000
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(V_tr.ToString("#0.00")) : rtf.EndCell() ' V
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((.Øint * 1000).ToString("#0.0")) : rtf.EndCell()
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Nom.ToString()) : rtf.EndCell() : rtf.EndRow()
                    Else
                        Exit Do
                    End If
                End With
            Loop
        Next
        '
        'Partie Collecteur
        For i = Reseau.Collecteur_D_Nbre To 1 Step -1
            'Affichage de la ligne tête de colonne
            rtf.BeginRow() : rtf.DeclareCell(10000) : rtf.BeginCell(True) : rtf.WriteString("Collecteur " & i.ToString) : rtf.EndCell() : rtf.EndRow()
            i1 = Reseau.Collecteur_Ex(i) 'n° du tronçon fin du collecteur
            Dim k As Integer
            k = i1 - 1 ' = index du tronçon n°i1
            'recherche de tous les exutoires raccordés directement sur le tronçon
            With Reseau._Tuyau.Item(k)
                For j = 1 To Reseau._Tuyau.Item(k).Exut_nbType.Count
                    For Each exu1 In Exutoires
                        If .Exut_Type(j - 1) = (Exutoires.IndexOf(exu1) + 1) Then
                            .Appareils_Nbre += exu1.App_nb * .Exut_nbType(j - 1)
                            Select Case Reseau.Modele_Calcul
                                Case 1 'EFS
                                    .Qbrut += exu1.Q_ES * .Exut_nbType(j - 1)
                                Case 2 'ECS
                                    .Qbrut += exu1.Q_EC * .Exut_nbType(j - 1)
                            End Select
                            .Yind += exu1.Yind
                            Exit For
                        End If
                    Next
                Next
                'ajout des débits et des appareils venant des tronçons aval
                For j = 1 To .Tronçon_Aval.Count
                    Dim i2 As Integer
                    i2 = Reseau._Tuyau.Item(k).Tronçon_Aval.Item(j - 1) - 1
                    .Appareils_Nbre += Reseau._Tuyau.Item(i2).Appareils_Nbre
                    .Qbrut += Reseau._Tuyau.Item(i2).Qbrut
                    .Yind += Reseau._Tuyau.Item(i2).Yind
                Next
                Select Case .Appareils_Nbre
                    Case Is <= 5
                        .Qprob = .Qbrut
                        .Øint = Diam_Exutoire(.Yind)
                        If .Appareils_Nbre > 1 Then .Øint = Diam_Exutoire(.Yind) Else .Øint = Ø
                        .Øint = Determination_diametre(.Øint, .Mat)
                    Case Is > 5
                        Select Case .Yind
                            Case < 15
                                Dim diam As Double
                                .Øint = Diam_Exutoire(.Yind)
                                Y = Reseau.Ycoef * 0.8 / (.Appareils_Nbre - 1) ^ 0.5
                                .Qprob = Y * .Qbrut
                                diam = Sqrt(.Qprob * 4 / 1000 / (PI * 2)) 'vitesse = 2m/s
                                If diam > .Øint Then
                                    .Øint = diam : Y = .Yind
                                End If
                                .Øint = Determination_diametre(.Øint, .Mat)
                            Case Else
                                'calcul Y, débit probable, diamètre, vitesse, diamètre et nomenclature
                                Y = Reseau.Ycoef * 0.8 / (.Appareils_Nbre - 1) ^ 0.5
                                .Qprob = Y * .Qbrut
                                .Øint = Calcul_diametre(.Qprob, .Vlimit, .Mat)
                        End Select
                End Select
                If .Øimposée = True Then .Øint = .Øimp
                If .Qimposée = True Then .Qprob = .Qimp * 1000
                .Nom = libel_diametre(.Øint, .Mat)
                'Affichage de la ligne d'un élément de tronçon de colonne
                rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((i1).ToString) : rtf.EndCell() 'n° de tronçon
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(" - ") : rtf.EndCell() 'n° de tronçon Aval
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Tronçon_Amont.Item(0).ToString) : rtf.EndCell() ' n° de tronçon Amont
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Appareils_Nbre.ToString("#")) : rtf.EndCell()
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Qbrut.ToString("#0.00")) : rtf.EndCell()
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Y.ToString("#0.000")) : rtf.EndCell() 'coef Y
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Qprob.ToString("#0.00")) : rtf.EndCell() ''Q prob
                V_tr = .Qprob / (PI * .Øint ^ 2 / 4) / 1000
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(V_tr.ToString("#0.00")) : rtf.EndCell() ' V
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((.Øint * 1000).ToString("#0.0")) : rtf.EndCell()
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((.Nom).ToString()) : rtf.EndCell() : rtf.EndRow()
            End With
            'tronçons suivants pour la partie collecteur
            If Reseau.Collecteur_Or(i) = k + 1 Then Continue For '=  tuyau origine = tuyau extrémité du collecteur
            i1 = Reseau._Tuyau.Item(k).Tronçon_Amont(0)
            Do

                i1 = i1 - 1 ' = index du tronçon n°i1
                If i1 < 0 Then Exit Do 'par mesure de sécurité!
                With Reseau._Tuyau.Item(i1)
                    If .collecteur = Reseau._Tuyau.Item(k).collecteur Then
                        'recherche de tous les exutoires raccordés directement sur le tronçon
                        For j = 1 To Reseau._Tuyau.Item(i1).Exut_nbType.Count
                            For Each exu1 In Exutoires
                                If .Exut_Type(j - 1) = (Exutoires.IndexOf(exu1) + 1) Then
                                    .Appareils_Nbre += exu1.App_nb * .Exut_nbType(j - 1)
                                    Select Case Reseau.Modele_Calcul
                                        Case 1 'EFS
                                            .Qbrut += exu1.Q_ES * .Exut_nbType(j - 1)
                                        Case 2 'ECS
                                            .Qbrut += exu1.Q_EC * .Exut_nbType(j - 1)
                                    End Select
                                    .Yind += exu1.Yind
                                    Exit For
                                End If
                            Next
                        Next
                        'ajout des débits et des appareils venant des tronçons aval
                        For j = 1 To .Tronçon_Aval.Count
                            Dim k1 As Integer
                            k1 = Reseau._Tuyau.Item(i1).Tronçon_Aval.Item(j - 1)
                            .Appareils_Nbre += Reseau._Tuyau.Item(k1 - 1).Appareils_Nbre
                            .Qbrut += Reseau._Tuyau.Item(k1 - 1).Qbrut
                            .Yind += Reseau._Tuyau.Item(k1 - 1).Yind
                        Next
                        Select Case .Appareils_Nbre
                            Case Is <= 5
                                .Qprob = .Qbrut
                                .Øint = Diam_Exutoire(.Yind)
                                If .Appareils_Nbre > 1 Then .Øint = Diam_Exutoire(.Yind) Else .Øint = Ø
                                .Øint = Determination_diametre(.Øint, .Mat)
                            Case Is > 5
                                Select Case .Yind
                                    Case < 15
                                        Dim diam As Double
                                        .Øint = Diam_Exutoire(.Yind)
                                        Y = Reseau.Ycoef * 0.8 / (.Appareils_Nbre - 1) ^ 0.5
                                        .Qprob = Y * .Qbrut
                                        diam = Sqrt(.Qprob * 4 / 1000 / (PI * 2)) 'vitesse = 2m/s
                                        If diam > .Øint Then
                                            .Øint = diam : Y = .Yind
                                        End If
                                        .Øint = Determination_diametre(.Øint, .Mat)
                                    Case Else
                                        'calcul Y, débit probable, diamètre, vitesse, diamètre et nomenclature
                                        Y = Reseau.Ycoef * 0.8 / (.Appareils_Nbre - 1) ^ 0.5
                                        .Qprob = Y * .Qbrut
                                        .Øint = Calcul_diametre(.Qprob, .Vlimit, .Mat)
                                End Select
                        End Select
                        If .Øimposée = True Then .Øint = .Øimp
                        If .Qimposée = True Then .Qprob = .Qimp * 1000
                        .Nom = libel_diametre(.Øint, .Mat)

                        'Affichage de la ligne d'un élément de tronçon de colonne
                        rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((i1 + 1).ToString) : rtf.EndCell() 'n° de tronçon
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(" - ") : rtf.EndCell() 'n° de tronçon Aval
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Tronçon_Amont.Item(0).ToString) : rtf.EndCell() ' n° de tronçon Amont
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Appareils_Nbre.ToString("#")) : rtf.EndCell()
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Qbrut.ToString("#0.00")) : rtf.EndCell()
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Y.ToString("#0.000")) : rtf.EndCell() 'coef Y
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Qprob.ToString("#0.00")) : rtf.EndCell() ''Q prob
                        V_tr = .Qprob / (PI * .Øint ^ 2 / 4) / 1000
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(V_tr.ToString("#0.00")) : rtf.EndCell() ' V
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((.Øint * 1000).ToString("#0.0")) : rtf.EndCell()
                        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((.Nom).ToString()) : rtf.EndCell() : rtf.EndRow()
                        '
                        If Reseau.Collecteur_Or(i) = i1 + 1 Then Exit Do '=  tuyau origine
                        i1 = .Tronçon_Amont(0)
                    End If
                End With
            Loop

        Next
        rtf.WriteEndGroup()
    End Sub

    ''' <summary>Calcul et affichage des pertes de charges et de la pression statique terminale</summary>
    '''  <param name="rtf">variable renvoyant le fichier de note de calcul sous format rtf</param>
    ''' <param name="verif"> variable prenant la valeur False si une erreur bloquante s'est produite pendant le calcul</param>
    Private Sub Pertes_de_charge_Reseau_EF_ECS(ByVal Δp_Entree As Double, ByRef Verif As Boolean, ByRef rtf As To_Rtf.RtfAnsiTextWriter) '
        Dim i, i1, j As Integer
        Dim J_tr, V, P_sort, Δp_loc As Double

        With Reseau
            rtf.WriteStartGroup() : rtf.NewParagraph() : rtf.FontSize = 8
            'Ligne 1
            rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Q prob (l/s)") : rtf.EndCell()
            rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString("Ø") : rtf.EndCell()
            rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString("V (m/s)") : rtf.EndCell()
            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("1,15j (mCE/m)") : rtf.EndCell()
            rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString("L (m)") : rtf.EndCell()
            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Δp local (mCE).") : rtf.EndCell() ' 
            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Δp totale (mCE)") : rtf.EndCell()
            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("P ent. (mCE)") : rtf.EndCell()
            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("h (m)") : rtf.EndCell()
            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("P sort. (mCE)") : rtf.EndCell() : rtf.EndRow()

            For colonne = 1 To Reseau.Têt_Colon_Nbre
                Dim Parcours() As Integer
                i = 0 : P_sort = .PrEntree
                rtf.BeginRow() : rtf.DeclareCell(10000) : rtf.BeginCell(True) : rtf.WriteString("Colonne n°" & CStr(colonne)) : rtf.EndCell() : rtf.EndRow()
                'recherche index tuyau tête de colonne
                For Each tuy In Reseau._Tuyau
                    If tuy.i_colonne = colonne And tuy.Tete_Colonne = True Then i1 = Reseau._Tuyau.IndexOf(tuy) : Exit For
                Next
                'détermination du parcours emprunté
                Do
                    i += 1
                    ReDim Preserve Parcours(i)
                    Parcours(i) = i1
                    i1 = ._Tuyau.Item(i1).Tronçon_Amont(0) - 1 'pour obtenir l'index
                Loop Until i1 = 0
                i = i + 1
                ReDim Preserve Parcours(i)
                Parcours(i) = 0 'pour la prise en compte du 1ier tronçon, index du 1ier tronçon = 0
                For j = i To 1 Step -1
                    rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((Parcours(j) + 1).ToString) : rtf.EndCell() 'tronçon
                    rtf.DeclareCell(1000) : rtf.BeginCell(True)
                    rtf.WriteString(._Tuyau.Item(Parcours(j)).Qprob.ToString("#0.000"))
                    rtf.EndCell() 'débit brut
                    rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString(._Tuyau.Item(Parcours(j)).Nom) : rtf.EndCell() 'nomenclature du tuyau
                    V = ._Tuyau.Item(Parcours(j)).Qprob * 0.001 / (PI * ._Tuyau.Item(Parcours(j)).Øint ^ 2 / 4)
                    rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString(V.ToString("#0.000")) : rtf.EndCell()
                    J_tr = J_Flamant(._Tuyau.Item(Parcours(j)).Qprob * 0.001, ._Tuyau.Item(Parcours(j)).Øint, Verif) 'formule de flamant
                    If Verif = False Then rtf.WriteEndGroup() : Exit Sub
                    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((J_tr * 1.15).ToString("##0.000")) : rtf.EndCell()
                    rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString(._Tuyau.Item(Parcours(j)).L.ToString("##0.0")) : rtf.EndCell()
                    If j = i Then Δp_loc = Δp_Entree Else Δp_loc = 0
                    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Δp_loc.ToString("##0.00")) : rtf.EndCell()
                    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(((J_tr * 1.15 * ._Tuyau.Item(Parcours(j)).L) + Δp_loc).ToString("##0.00")) : rtf.EndCell()
                    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(P_sort.ToString("#0.00")) : rtf.EndCell()
                    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(._Tuyau.Item(Parcours(j)).Hp.ToString("#0.00")) : rtf.EndCell()
                    P_sort = P_sort - (J_tr * 1.15 * ._Tuyau.Item(Parcours(j)).L) - Δp_loc - ._Tuyau.Item(Parcours(j)).Hp
                    If j < i Then P_sort = P_sort + ._Tuyau.Item(Parcours(j + 1)).Hp
                    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(P_sort.ToString("#0.00")) : rtf.EndCell()
                    rtf.DeclareCell(400) : rtf.BeginCell(True)
                    If P_sort >= .Pr_ES Then rtf.WriteString("S") Else rtf.WriteString("NS")
                    rtf.EndCell() : rtf.EndRow()
                Next
                Erase Parcours
            Next
        End With
        rtf.WriteEndGroup()

    End Sub

    '''<summary>Détermination du diamètre minimum pour alimenter l'exutoire en fonction de son coefficient DTU - Ø en m</summary>
    ''' <param name="tot">coefficient DTU d'exutoire</param>
    Private Function Diam_Exutoire(ByVal tot As Double) As Double
        Select Case tot
            Case Is <= 2.5
                Diam_Exutoire = 0.012
            Case Is <= 3.5
                Diam_Exutoire = 0.013
            Case Is <= 4.5
                Diam_Exutoire = 0.014
            Case Is <= 13
                Diam_Exutoire = ((tot * 2 / 3) + (34 / 3)) / 1000 'diamètre en mm
            Case Is <= 14
                Diam_Exutoire = 0.0195 + 0.0005 * (tot - 13)
            Case Else
                Diam_Exutoire = 0.021
        End Select
    End Function

#End Region


    '''<summary>Détermination du diamètre minimum fonction de la vitesse, débit et matériau (section disponible)</summary>
    ''' <param name="q">débit</param>
    ''' <param name="v">vitesse</param>
    ''' <param name="Matiere_Tube">matière du tube: cuivre, PVC, ...</param>
    Private Function Calcul_diametre(ByVal Q As Double, ByVal V As Double, ByVal Matiere_Tube As Integer) As Double
        Dim diam As Double
        Dim j As Integer
        Q = Q * 0.001 'l/s -> m3/s
        diam = Sqrt(4 * Q / (V * PI))
        Select Case Matiere_Tube
            Case 1 'Cuivre
                j = UBound(Di_Cu)
                Do
                    j = j - 1
                    If j < 0 Then j = -1 : Exit Do
                Loop Until Di_Cu(j) < diam
                Calcul_diametre = Di_Cu(j + 1)
            Case 2 'tube galva
                j = UBound(Di_Ag)
                Do
                    j = j - 1
                    If j < 0 Then j = -1 : Exit Do
                Loop Until Di_Ag(j) < diam
                Calcul_diametre = Di_Ag(j + 1)
            Case 3 'PER
                j = UBound(Di_PER)
                Do
                    j = j - 1
                    If j < 0 Then j = -1 : Exit Do
                Loop Until Di_PER(j) < diam
                Calcul_diametre = Di_PER(j + 1)
            Case 4 'Multicouche
                j = UBound(Di_MultiC)
                Do
                    j = j - 1
                    If j < 0 Then j = -1 : Exit Do
                Loop Until Di_MultiC(j) < diam
                Calcul_diametre = Di_MultiC(j + 1)
            Case 5 'PVC_C
                j = UBound(Di_PVC_C)
                Do
                    j = j - 1
                    If j < 0 Then j = -1 : Exit Do
                Loop Until Di_PVC_C(j) < diam
                Calcul_diametre = Di_PVC_C(j + 1)
        End Select
    End Function
    Private Function Determination_diametre(ByVal diam As Double, ByVal Matiere_Tube As Integer) As Double
        Dim j As Integer

        Select Case Matiere_Tube
            Case 1 'Cuivre
                j = UBound(Di_Cu)
                Do
                    j = j - 1
                    If j < 0 Then j = -1 : Exit Do
                Loop Until Di_Cu(j) < diam
                Determination_diametre = Di_Cu(j + 1)
            Case 2 'tube galva
                j = UBound(Di_Ag)
                Do
                    j = j - 1
                    If j < 0 Then j = -1 : Exit Do
                Loop Until Di_Ag(j) < diam
                Determination_diametre = Di_Ag(j + 1)
            Case 3 'PER
                j = UBound(Di_PER)
                Do
                    j = j - 1
                    If j < 0 Then j = -1 : Exit Do
                Loop Until Di_PER(j) < diam
                Determination_diametre = Di_PER(j + 1)
            Case 4 'Multicouche
                j = UBound(Di_MultiC)
                Do
                    j = j - 1
                    If j < 0 Then j = -1 : Exit Do
                Loop Until Di_MultiC(j) < diam
                Determination_diametre = Di_MultiC(j + 1)
            Case 5 'PVC_C
                j = UBound(Di_PVC_C)
                Do
                    j = j - 1
                    If j < 0 Then j = -1 : Exit Do
                Loop Until Di_PVC_C(j) < diam
                Determination_diametre = Di_PVC_C(j + 1)
        End Select
    End Function

    ''' <summary>Calcul de la Pdc linéique J suivant la formule de FLAMANT - Unité: mCE/m</summary>
    '''  <param name="Q">débit en m3/s</param>
    ''' <param name="diam">diamètre de la canalisation en m</param>
    ''' <param name="verif"> variable prenant la valeur False si une erreur bloquante s'est produite pendant le calcul</param>
    Private Function J_Flamant(ByVal Q As Double, ByVal Diam As Double, ByRef Verif As Boolean) As Double
        'Q en m3/s et D en m
        Dim V As Double
        Try
            V = Q / (PI * Diam ^ 2 / 4) 'mCE,  V en m/s
            Select Case Reseau.Modele_Calcul
                Case 1 'Eau froide
                    J_Flamant = (0.00092 * (V ^ 7 / Diam) ^ 0.25) / Diam  'formule de flamant
                Case 2 ' eau chaude
                    J_Flamant = (0.00046 * (V ^ 7 / Diam) ^ 0.25) / Diam  'formule de flamant
                Case Else
                    J_Flamant = 0 : Verif = False
                    MessageBox.Show("Erreur sur la formule de Flamant - Calcul arrêté", "Module Code_Calcul", MessageBoxButtons.OK, MessageBoxIcon.Error)
            End Select
        Catch ex As Exception
            J_Flamant = 0 : Verif = False
            MessageBox.Show("Erreur sur la formule de Flamant - Calcul arrêté", "Module Code_Calcul", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Function

#Region "Dimensionnement du bouclage d'un réseau ECS "

    ''' <summary>Programme général du bouclage d'ECS</summary>
    '''  <param name="note_de_calcul">variable renvoyant le fichier de note de calcul sous format rtf</param>
    ''' <param name="verif"> variable prenant la valeur False si une erreur bloquante s'est produite pendant le calcul</param>
    Public Sub Calcul_Boucle_ECS(ByRef Note_de_Calcul As String, ByRef Verif As Boolean)
        Dim msg As String = String.Empty
        Dim Qglob, PthG As Double
        'writer de sortie du RTF
        Dim sw As New System.IO.StringWriter
        'crée un writer de RTF avec une police par défaut
        Dim rtf As New To_Rtf.RtfAnsiTextWriter(sw, New Font(FontFamily.GenericSerif, 12, FontStyle.Regular))
        Dim rtff As String
        rtf.Bold = True : rtf.FontSize = 18 : rtf.Underline = True
        rtf.WriteString("Dimensionnement de la boucle d'eau chaude sanitaire")
        rtf.NewLine()
        rtf.Bold = False : rtf.FontSize = 10 : rtf.Underline = False : rtf.NewParagraph()
        rtf.WriteString("Note de calcul du : " & DateTime.Now.ToLongDateString() & " à " & DateTime.Now.ToLongTimeString) : rtf.NewLine()
        rtf.WriteString("Rédacteur : " & Aff.Redacteur) : rtf.NewLine()
        rtf.WriteString("Chantier : " & Aff.Chantier) : rtf.NewLine()
        rtf.WriteString("Logiciel : Calculette Plomberie version " & My.Application.Info.Version.ToString & "   2013 - " & DateTime.Now.Year.ToString) : rtf.NewLine()
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("1 - Rappel des hypothèses") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        rtf.WriteString("Codes de calcul:") : rtf.NewLine()
        rtf.WriteString("-  débits et coefficients de simultanéité suivant DTU 60.11 d'octobre 1988") : rtf.NewLine()
        rtf.WriteString("Critères de dimensionnement de la boucle d'eau chaude sanitaire :") : rtf.NewLine()
        With Reseau
            Select Case .Type_dT
                Case 1 'entre prod et Exut
                    rtf.WriteString(" - Ecart de température de " & .dTBoucle.ToString("##.0") & "°C entre le départ de la production d'eau chaude sanitaire et les exutoires terminaux, en" &
                                    " extrémité de colonnes.") : rtf.NewLine()
                Case 2 'entre prod et retour
                    rtf.WriteString(" - Ecart de température de " & .dTBoucle.ToString("##.0") & "°C entre le départ de la production d'eau chaude sanitaire et le retour de boucle") : rtf.NewLine()
            End Select

            rtf.WriteString(" - Débit minimal imposé: " & (.Qbcl_min * 3600).ToString("#0.0") & " L/h") : rtf.NewLine()
           
            Select Case .Vmin
                Case Is < 0.1
                    rtf.WriteString(" - Pas de vitesse minimale imposée") : rtf.NewLine()
                Case 0.2
                    rtf.WriteString(" - Vitesse minimale imposée sur retour de boucle :   0,20 m/s") : rtf.NewLine()
                Case Else
                    rtf.WriteString(" - Vitesse minimale imposée sur retour de boucle : " & .Vmin.ToString & " m/s") : rtf.NewLine()
            End Select
            Select Case .Type_Org
                Case 1
                    rtf.WriteString(" - Pas de caractéristique imposée pour les organes de réglage") : rtf.NewLine()
                Case 2
                    rtf.WriteString(" - Distance de passage de particule de 1 mm de diamètre dans organe de réglage") : rtf.NewLine()
            End Select
            rtf.WriteString("Température départ production ECS : " & .TprodECS.ToString("#.0") & "°C") : rtf.NewLine()
            rtf.WriteString("Température moyenne de calcul : " & (.TprodECS - .ΔT_ECS).ToString("#.0") & "°C") : rtf.NewLine()
            rtf.NewLine() : rtf.Bold = True : rtf.Underline = True : rtf.WriteString("Schéma type du réseau") : rtf.NewLine() : rtf.Bold = False : rtf.Underline = False
            Try
                ' Create Image Element
                Dim myImage As Image
                myImage = Image.FromFile(Directory.GetCurrentDirectory.ToString() & "\Images\schema_Bcl.png")
                rtf.InsertImage(myImage)
            Catch ex As Exception
                'msg = "Le logiciel n'a pas pu chargé l'image correspondante." &  Environment.NewLine & "Erreur: " & ex.Message & ex.StackTrace &  Environment.NewLine & "Note de calcul sans image"
                'MsgBox(msg, MsgBoxStyle.Exclamation Or MsgBoxStyle.OkOnly, "Logiciel EF_ECS")
            End Try
            .Initialisation_Distribution()
            .Initialisation_Retour_Boucle()
            .Perte_Thermique()   'Calcul de la perte thermique linéaire tronçon par tronçon sur l'ensemble du reseau (Aller et Retour)
            Call Tab_Caractéristiques_Réseau(rtf)
            '_____________________________________________________________________________________________________________________________________________________________________________________________________
            '  Calcul des débits de recyclage
            '
            rtf.WriteStartGroup()
            rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
            rtf.WriteString("2 - Calcul des débits de recyclage") : rtf.Bold = False
            rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
            'partie distribution
            PthG = 0
            For Each tuy In ._Tuyau
                PthG += tuy.Pth * tuy.L
            Next
            'partie retour boucle
            For Each tuy In ._TuyauR
                PthG += tuy.Pth * tuy.L
            Next
            Qglob = PthG / (1.16 * .dTBoucle)
            Reseau._Tuyau.Item(0).Qbcl = Qglob / 3600
            Reseau._TuyauR.Item(0).Qbcl = Qglob / 3600
            rtf.WriteString("Pertes thermiques totales du réseau: " & PthG.ToString("#,###.0") & " W.") : rtf.NewLine()
            rtf.WriteString("Débit global du bouclage pour compenser la perte thermique globale: " & Qglob.ToString("#,###.00") & " L/h.") : rtf.NewLine() : rtf.NewLine()
            rtf.WriteEndGroup()

            '--> Vérification que le réseau disributeur comporte plus d'une colonne
            Dim i As Integer = 0
            For Each tuy In ._Tuyau
                If tuy.Tete_Colonne = True Then i += 1
            Next
            '--> calcul et affichage de la répartition du débit global sur les différentes colonnes
            If i > 1 Then
                rtf.WriteStartGroup()
                rtf.WriteString("Tableau de calcul des débits par colonnes et tronçons") : rtf.NewLine()
                rtf.WriteEndGroup()
                Call Cumul_Perte_thermique_tronçon()
                Call Tab_Calcul_Debit_Recyclage(Verif, rtf)
                If Verif = False Then Exit Sub
                Call Correction_Debits_Recyclage()
            Else
                rtf.WriteStartGroup()
                rtf.WriteString("Réseau avec une seule boucle ECS") : rtf.NewLine()
                rtf.WriteEndGroup()
                'cas particulier du réseau avec une seule colonne et donc une seule boucle
                For Each tuy In Reseau._Tuyau
                    tuy.Qbcl = Qglob / 3600
                Next
                For Each tuy In Reseau._TuyauR
                    tuy.Qbcl = Qglob / 3600
                Next
            End If
            '--> affichage du tableau indiquant les débits dans tous les tronçons
            Call Tab_Debit_Recyclage(rtf)
            '_____________________________________________________________________________________________________________________________________________________________________________________________________
            '  Calcul des pertes de charge et de la pompe de bouclage
            '
            rtf.WriteStartGroup()
            rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
            rtf.WriteString("3 - Calcul des pertes de charges et de la pompe de bouclage") : rtf.Bold = False
            rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
            rtf.WriteString("Perte de charge commune à l’ensemble des réseaux (production ECS, clapets, …) : " & (.PdcVanne + .PdcPrepECS + .PdcClapet).ToString("#0.0") & " mCE.") : rtf.NewLine() : rtf.NewLine()
            rtf.WriteEndGroup()
            Dim Pdc_Max As Double = 0
            Dim i_min As Integer = 1
            Dim Autorite As Double
            For i = 1 To .Têt_Colon_Nbre
                Call Dim_Ppe_Boucle_ECS(i, Verif, rtf)
                If Verif = False Then Exit Sub
                If Pdc_Max < .Pdc_Tot(i) Then Pdc_Max = .Pdc_Tot(i) : i_min = i
            Next

            Dim Kv As Double
            rtf.WriteStartGroup()
            rtf.NewParagraph()
            rtf.WriteString("Caractéristiques requises pour la pompe de bouclage:") : rtf.NewLine()
            rtf.WriteString(" ► Vérification hypothèse Hauteur Manométrique vanne réglage sur réseau le plus défavorisé:") : rtf.NewLine()
            rtf.WriteString(" - N° de la colonne correspondant au réseau le plus défavorisé: " & i_min.ToString("#0")) : rtf.NewLine()
            rtf.WriteString(" - Perte de charge de la colonne: " & .Pdc_Col(i_min).ToString("#0.00") & " mCE") : rtf.NewLine()
            rtf.WriteString(" - Perte de charge de la vanne: " & .HMVrd.ToString("#0.00") & " mCE - Valeur prise par hypothèse") : rtf.NewLine()
            Autorite = .HMVrd / (.Pdc_Col(i_min) + .HMVrd)
            If Autorite >= 0.5 Then
                rtf.WriteString(" - Autorité = " & Autorite.ToString("#0.00") & " > 0,50 - Hypothèse correcte") : rtf.NewLine()
            Else
                rtf.WriteString(" - Autorité = " & Autorite.ToString("#0.00") & " < 0,50 - Hypothèse incorrecte, le reste du calcul ci-aprés ne représentera pas la réalité physique du réseau.") : rtf.NewLine()
                rtf.WriteString(" refaites le calcul avec une valeur minimale de " & .Pdc_Col(i_min).ToString("#0.000") & " mCE pour la hauteur manométrique de la vanne de réglage.") : rtf.NewLine()
            End If
            rtf.WriteEndGroup()
            Call Tab_Pompe(._Tuyau.Item(0).Qbcl * 3600, Pdc_Max, rtf)
            rtf.WriteStartGroup()
            rtf.WriteString(" Soit une pompe de hauteur manométrique minimale de " & (Pdc_Max + .HMVrd + .HMVC + .PdcVanne + .PdcPrepECS + .PdcClapet).ToString("#0.00") & " mCE pour un débit de " & (._Tuyau.Item(0).Qbcl * 3600 / 1000).ToString("#0.00") & " m3/h") : rtf.NewLine()
            rtf.NewParagraph()
            rtf.WriteString("Organes de réglage sur colonnes:") : rtf.NewLine()
            rtf.WriteEndGroup()
            Select Case .Position_Org
                Case 1 'suivant recommandation guide CSTB
                    For i = 1 To .Têt_Colon_Nbre
                        Dim Q_col As Double = 0
                        Dim ΔP As Double
                        Dim k As Integer
                        rtf.WriteStartGroup()
                        rtf.NewLine() : rtf.WriteString("- colonne n°" & i.ToString) : rtf.NewLine() : rtf.WriteEndGroup()
                        'recherche du débit de bouclage dans la colonne i
                        For Each tuy As Tuyau In ._Tuyau
                            If tuy.i_colonne = i And tuy.Tete_Colonne = True Then
                                Q_col = tuy.Qbcl
                                k = ._Tuyau.IndexOf(tuy)
                                Exit For
                            End If
                        Next
                        'recherche de l'index du tuyau de bouclage venant se raccorder sur le dernier tronçon (tête de colonne) de la colonne montante
                        For Each tuy As Tuyau In ._TuyauR
                            If tuy.Tronçon_Distrib = k + 1 Then
                                k = ._TuyauR.IndexOf(tuy)
                                Exit For
                            End If
                        Next
                        If .Pdc_Tot(i) = Pdc_Max Then
                            If .HMVrd > 0.001 Then
                                rtf.WriteStartGroup()
                                rtf.WriteString("  Colonne la plus défavorisée: Organe de réglage utilisé uniquement à titre de réglage et mesure de débit") : rtf.NewLine()
                                rtf.WriteString("  Soit une perte de charge de " & (.HMVrd * 1000).ToString("#,###0") & " mmCE pour un débit de " & (Q_col * 3600).ToString("#,##0.0") & " L/h.") : rtf.NewLine()
                                Kv = (Q_col * 36) / Sqrt(.HMVrd * 10) 'unité: L/s et kPa
                                rtf.WriteString("  Soit une vanne de réglage avec un Kv le plus proche possible de " & Kv.ToString("#,##0.00")) : rtf.NewLine()
                                Autorite = .HMVrd / (.Pdc_Col(i) + .HMVrd)
                                If Autorite > 0.33 Then msg = " (satisfaisant)" Else msg = " (Insuffisant)"
                                rtf.WriteString("  Autorité de la vanne de réglage sur la valeur de perte de charge demandée: " & Autorite.ToString("0.00") & msg) : rtf.NewLine() : rtf.WriteEndGroup()
                            Else
                                rtf.WriteStartGroup()
                                rtf.WriteString("  colonne la plus défavorisée - Pas d'organe de réglage suivant les hypothèses retenues") : rtf.NewLine() : rtf.WriteEndGroup()
                            End If
                        Else
                            rtf.WriteStartGroup()
                            rtf.WriteString("  A règler sur une valeur de " & (Pdc_Max + .HMVrd - .Pdc_Tot(i)).ToString("#,##0.00") & " mCE pour un débit de " & (Q_col * 3600).ToString("#,##0.0") & " L/h.") : rtf.NewLine()
                            ΔP = Pdc_Max + .HMVrd - .Pdc_Tot(i) 'différence de perte de charge entre le circuit le plus défavorisé et le circuit i, l'OR va compenser cette différence
                            Kv = (Q_col * 36) / Sqrt(ΔP * 10)
                            rtf.WriteString("  Soit une vanne de réglage avec un Kv le plus proche possible de " & Kv.ToString("#,##0.00")) : rtf.NewLine()
                            Autorite = ΔP / (ΔP + .Pdc_Col(i))
                            If Autorite > 0.33 Then msg = " (satisfaisant)" Else msg = " (Insuffisant)"
                            rtf.WriteString("  Autorité de la vanne de réglage sur la valeur de perte de charge demandée: " & Autorite.ToString("0.00") & msg) : rtf.NewLine() : rtf.WriteEndGroup()
                        End If
                        rtf.WriteStartGroup()
                        rtf.WriteString("Diamètre intérieur tuyauterie boucle: " & (._TuyauR.Item(k).Øint * 1000).ToString("#0.0") & " mm.") : rtf.NewLine() : rtf.WriteEndGroup()
                        Call Determination_Nbre_Tour_Vanne_Reglage(._TuyauR.Item(k).Øint, Kv, rtf)
                    Next
                    rtf.NewLine() : rtf.WriteString("Les organes de réglage sont à placer sur le retour de boucle de chaque colonne, en partie basse de cette dernière.") : rtf.NewLine() : rtf.NewLine()
                    rtf.WriteString("Vanne compensatrice:") : rtf.NewLine()
                    rtf.WriteString("  Elle est réglée pour une valeur minimale de " & (Reseau.HMVC * 1000).ToString("#,##0") & " mmCE.") : rtf.NewLine()
                    Kv = (._Tuyau.Item(0).Qbcl * 36) / Sqrt(.HMVrd * 10)
                    rtf.WriteString("  Soit une vanne de réglage avec un Kv le plus proche possible de " & Kv.ToString("#,##0.00")) : rtf.NewLine()
                    rtf.WriteEndGroup()
                Case 2 'uniquement sur colonnes défavorisées
                    rtf.NewParagraph()
                    rtf.WriteString("Organes de réglage sur colonnes défavorisées uniquement. Ce mode de calcul n'est pas implémenté dans cette version logicielle.") : rtf.NewLine()
                    rtf.WriteEndGroup()
                Case Else
                    rtf.NewParagraph()
                    rtf.WriteString("Aucune position des Organes de réglage n'a été renseignée. Calcul non effectué.") : rtf.NewLine()
                    rtf.WriteEndGroup()
            End Select

        End With
        'génère le RTF complet
        Note_de_Calcul = "Ndc_BECS_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
        rtf.Generate() : rtff = sw.ToString
        Note_de_Calcul = Aff.msgResult & "\" & Note_de_Calcul
        File.WriteAllText(Note_de_Calcul, rtff)
    End Sub

    ''' <summary>Tableau des caractéristiques du réseau d'ECS</summary>
    '''  <param name="rtf">variable renvoyant le fichier sous format rtf</param>
    Private Sub Tab_Caractéristiques_Réseau(ByRef rtf As To_Rtf.RtfAnsiTextWriter)
        Dim i As Integer

        Dim msg As String = String.Empty
        rtf.WriteStartGroup()
        rtf.NewParagraph()
        rtf.FontSize = 8
        'Ligne 1
        rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("Matière") : rtf.EndCell()
        rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString("Ø") : rtf.EndCell()
        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("Longueur (m)") : rtf.EndCell()
        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("Pdc Sing.(mCE)") : rtf.EndCell()
        rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString("ep (mm)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("λ (W/m°K)") : rtf.EndCell()
        rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString("T (°C)") : rtf.EndCell()
        rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString("P (W)") : rtf.EndCell() : rtf.EndRow()
        'Ligne 2
        rtf.BeginRow() : rtf.DeclareCell(8000) : rtf.BeginCell(True) : rtf.WriteString("Réseau Aller côté distribution ECS") : rtf.EndCell() : rtf.EndRow()
        'lignes 3 et suivantes
        For i = 0 To Reseau._Tuyau.Count - 1 'affichage des tronçons Distribution
            With Reseau._Tuyau.Item(i)
                rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((i + 1).ToString) : rtf.EndCell() 'n° de tronçon
                Select Case .Mat
                    Case 1 'cuivre
                        msg = "Cuivre"
                    Case 2
                        msg = "Acier Galva."
                    Case 3 '
                        msg = "PER"
                    Case 4
                        msg = "Multicouche"
                    Case 5 '
                        msg = "PVC-C"
                End Select
                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(msg) : rtf.EndCell() 'type de tube
                rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(.Nom) : rtf.EndCell() 'nomenclature du tube
                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(.L.ToString("#0.00")) : rtf.EndCell() 'Longueur
                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(.PdcLoc.ToString("#0.000")) : rtf.EndCell() 'Pdc locale
                rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString((.Isol_ep * 1000).ToString("#0.0")) : rtf.EndCell() 'épaisseur d'isolant autour de la tuyauterie
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Isol_λ.ToString("#0.000")) : rtf.EndCell() 'coef conductivité isolant
                rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(.Isol_T.ToString("#0.0")) : rtf.EndCell()
                rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString((.L * .Pth).ToString("#0.0")) : rtf.EndCell() : rtf.EndRow()
            End With
        Next
        'Ligne interligne
        rtf.BeginRow() : rtf.DeclareCell(8000) : rtf.BeginCell(True) : rtf.WriteString("Réseau Retour côté boucle ECS") : rtf.EndCell() : rtf.EndRow()
        For i = 0 To Reseau._TuyauR.Count - 1 'affichage des tronçons Distribution
            With Reseau._TuyauR.Item(i)
                rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((i + 1).ToString) : rtf.EndCell() 'n° de tronçon
                Select Case .Mat
                    Case 1 'cuivre
                        msg = "Cuivre"
                    Case 2
                        msg = "Acier Galva."
                    Case 3 '
                        msg = "PER"
                    Case 4
                        msg = "Multicouche"
                    Case 5 '
                        msg = "PVC-C"
                End Select
                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(msg) : rtf.EndCell() 'type de tube
                rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(.Nom) : rtf.EndCell() 'nomenclature du tube
                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(.L.ToString("#0.00")) : rtf.EndCell() 'Longueur
                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(.PdcLoc.ToString("#0.000")) : rtf.EndCell() 'Pdc locale
                rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString((.Isol_ep * 1000).ToString("#0.0")) : rtf.EndCell() 'épaisseur d'isolant autour de la tuyauterie
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(.Isol_λ.ToString("#0.000")) : rtf.EndCell() 'coef conductivité isolant
                rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(.Isol_T.ToString("#0.0")) : rtf.EndCell()
                rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString((.L * .Pth).ToString("#0.0")) : rtf.EndCell() : rtf.EndRow()
            End With
        Next


        rtf.WriteEndGroup()

    End Sub

    ''' <summary>Programme général du bouclage d'ECS</summary>
    '''  <param name="note_de_calcul">variable renvoyant le fichier de note de calcul sous format rtf</param>
    ''' <param name="verif"> variable prenant la valeur False si une erreur bloquante s'est produite pendant le calcul</param>
    Private Sub Cumul_Perte_thermique_tronçon()
        Dim i, i1, j, k, k1, k2 As Integer
        Dim PthCumulé, PthCumulé1 As Double
        Dim Aval(1) As Integer
        Dim Complet_D(Reseau.Collecteur_D_Nbre) As Boolean 'indique si le collecteur a été parcourue en antier
        Dim Complet_R(Reseau.Collecteur_R_Nbre) As Boolean
        Dim circuitD(Reseau.Collecteur_D_Nbre), circuitR(Reseau.Collecteur_R_Nbre) As Integer
        With Reseau
            'initialisation des données
            '--> pour la partie distribution
            For i = 1 To .Collecteur_D_Nbre
                Complet_D(i) = False : circuitD(i) = -1
            Next
            'Pour la partie Bouclage
            For i = 1 To .Collecteur_R_Nbre
                Complet_R(i) = False : circuitR(i) = -1
            Next
            '--> Mise à zero
            For Each tuy In ._Tuyau
                tuy.PthCumul = 0
            Next
            For Each tuy In ._TuyauR
                tuy.PthCumul = 0
            Next
        End With
        'Cumul_Perte_thermique des Pth sur la partie collecteur sans branche en remontant de l'extrémité vers le début
        '
        '--> pour la partie distribution
        With Reseau._Tuyau
            For i = Reseau.Collecteur_D_Nbre To 1 Step -1
                j = Reseau.Collecteur_Ex.Item(i)
                'Tous les tronçons Aval correspondant obligatoirement à des colonnnes
                'Détermination de toutes les colonnes alimenté par ce tronçon
                For k = 1 To .Item(j - 1).Tronçon_Aval.Count
                    k1 = .Item(j - 1).Tronçon_Aval.Item(k - 1) - 1 'pour avoir l'index
                    'recherche index tuyau tête de colonne.
                    If .Item(k1).Tete_Colonne = True Then
                        k2 = k1 - 1
                    Else
                        'détermination de la tête de colonne correspondante à cette colonne
                        For Each tuy In Reseau._Tuyau
                            If tuy.i_colonne = .Item(k1).i_colonne And tuy.Tete_Colonne = True Then k2 = .IndexOf(tuy) : Exit For
                        Next
                    End If
                    'détermination du parcours emprunté sur la colonne
                    PthCumulé1 = 0
                    Do Until k2 = j - 1
                        PthCumulé1 += .Item(k2).Pth * .Item(k2).L
                        .Item(k2).PthCumul += PthCumulé1 'permet d'avoir le Pth cumulé sur les pieds de colonnes
                        .Item(j - 1).PthCumul += .Item(k2).Pth * .Item(k2).L
                        k2 = .Item(k2).Tronçon_Amont(0) - 1 'pour obtenir l'index
                    Loop
                Next
                'cumul avec la pth linéaire du tronçon .Collecteur_Ex
                .Item(j - 1).PthCumul += .Item(j - 1).Pth * .Item(j - 1).L
                PthCumulé = .Item(j - 1).PthCumul
                If i = 1 Then
                    'puis tous les autres tronçons jusqu'à l'origine du circuit de distribution soit compteur ou prod ECS pour le circuit 1
                    Do
                        i1 = j
                        j = .Item(j - 1).Tronçon_Amont(0) 'circuit distribution = 1 seul circuit amont
                        If j = 0 Then Exit Do
                        If .Item(j - 1).Tronçon_Aval.Count = 1 Then
                            'le tronçon est bien un tronçon de distribution sans colonne et sans raccordement sur d'autres réseaux de distribution: changement de section par exemple
                        Else
                            For k = 1 To .Item(j - 1).Tronçon_Aval.Count
                                k1 = .Item(j - 1).Tronçon_Aval.Item(k - 1) - 1 'pour avoir l'index
                                If k1 <> i1 - 1 Then 'on ne cumule pas sur les tronçons pour lesquels on vient déjà de cumuler
                                    If .Item(k1).i_colonne = 0 Then
                                        PthCumulé += .Item(k1).PthCumul 'qui doit correspondre au départ d'une autre branche du collecteur
                                    Else
                                        'détermination du parcours emprunté sur la colonne
                                        'détermination de la tête de colonne correspondante à cette colonne
                                        For Each tuy In Reseau._Tuyau
                                            If tuy.i_colonne = .Item(k1).i_colonne And tuy.Tete_Colonne = True Then k2 = .IndexOf(tuy) : Exit For
                                        Next
                                        PthCumulé1 = 0
                                        Do Until k2 = j - 1
                                            PthCumulé1 += .Item(k2).Pth * .Item(k2).L
                                            .Item(k2).PthCumul += PthCumulé1 'permet d'avoir le Pth cumulé sur les pieds de colonnes
                                            k2 = .Item(k2).Tronçon_Amont(0) - 1 'pour obtenir l'index
                                        Loop
                                        PthCumulé += PthCumulé1
                                    End If
                                End If
                            Next
                        End If
                        .Item(j - 1).PthCumul = PthCumulé + .Item(j - 1).Pth * .Item(j - 1).L
                        PthCumulé = .Item(j - 1).PthCumul
                    Loop Until j = 1
                Else
                    'puis tous les autres tronçons jusqu'à l'origine du circuit de distribution soit compteur ou prod ECS pour le circuit 1
                    If j <> Reseau.Collecteur_Or(i) Then 'sinon plantage lorsque le collecteur ne comporte qu'un seul tronçon
                        Do
                            i1 = j
                            j = .Item(j - 1).Tronçon_Amont(0) 'circuit distribution = 1 seul circuit amont
                            If .Item(j - 1).Tronçon_Aval.Count = 1 Then
                                'le tronçon est bien un tronçon de distribution sans colonne et sans raccordement sur d'autres réseaux de distribution: changement de section par exemple
                            Else
                                For k = 1 To .Item(j - 1).Tronçon_Aval.Count
                                    k1 = .Item(j - 1).Tronçon_Aval.Item(k - 1) - 1 'pour avoir l'index
                                    If k1 <> i1 - 1 Then 'on ne cumule pas sur les tronçons pour lesquels on vient déjà de cumuler
                                        If .Item(k1).i_colonne = 0 Then
                                            PthCumulé += .Item(k1).PthCumul 'qui doit correspondre au départ d'une autre branche du collecteur
                                        Else
                                            'détermination du parcours emprunté sur la colonne
                                            'détermination de la tête de colonne correspondante à cette colonne
                                            For Each tuy In Reseau._Tuyau
                                                If tuy.i_colonne = .Item(k1).i_colonne And tuy.Tete_Colonne = True Then k2 = .IndexOf(tuy) : Exit For
                                            Next
                                            PthCumulé1 = 0
                                            Do Until k2 = j - 1
                                                PthCumulé1 += .Item(k2).Pth * .Item(k2).L
                                                .Item(k2).PthCumul += PthCumulé1 'permet d'avoir le Pth cumulé sur les pieds de colonnes
                                                k2 = .Item(k2).Tronçon_Amont(0) - 1 'pour obtenir l'index
                                            Loop
                                            PthCumulé += PthCumulé1
                                        End If
                                    End If
                                Next
                            End If
                            .Item(j - 1).PthCumul = PthCumulé + .Item(j - 1).Pth * .Item(j - 1).L
                            PthCumulé = .Item(j - 1).PthCumul
                        Loop Until j = Reseau.Collecteur_Or(i)
                    End If

                    'puis tous les autres tronçons jusqu'au tronçon 1
                    Do
                        j = .Item(j - 1).Tronçon_Amont(0) 'circuit distribution = 1 seul circuit amont
                        .Item(j - 1).PthCumul += PthCumulé
                    Loop Until j = 1
                End If
            Next
        End With

        'Pour la partie Bouclage
        With Reseau._TuyauR
            For i = Reseau.Collecteur_R_Nbre To 1 Step -1
                j = Reseau.Collecteur_Ex_R.Item(i)
                'Tous les tronçons Amont correspondant obligatoirement à des colonnnes
                'Détermination de toutes les colonnes alimenté par ce tronçon
                For k = 1 To .Item(j - 1).Tronçon_Amont.Count
                    k1 = .Item(j - 1).Tronçon_Amont.Item(k - 1) - 1 'pour avoir l'index
                    'recherche index tuyau tête de colonne.
                    If .Item(k1).Tronçon_Amont.Count = 0 Then ' = Tete_Colonne = True 
                        k2 = k1
                    Else
                        'détermination de la tête de colonne correspondante à cette colonne
                        For Each tuy In Reseau._TuyauR
                            If tuy.i_colonne = .Item(k1).i_colonne And tuy.Tronçon_Amont.Count = 0 Then k2 = .IndexOf(tuy) : Exit For
                        Next
                    End If
                    'détermination du parcours emprunté
                    PthCumulé1 = 0
                    Do Until k2 = j - 1
                        PthCumulé1 += .Item(k2).Pth * .Item(k2).L
                        .Item(k2).PthCumul += PthCumulé1 'permet d'avoir le Pth cumulé sur les pieds de colonnes côté Retour
                        .Item(j - 1).PthCumul += .Item(k2).Pth * .Item(k2).L
                        k2 = .Item(k2).Tronçon_Aval(0) - 1 'pour obtenir l'index
                    Loop
                Next
                'cumul avec la pth linéaire du tronçon .Collecteur_Ex
                .Item(j - 1).PthCumul += .Item(j - 1).Pth * .Item(j - 1).L
                PthCumulé = .Item(j - 1).PthCumul
                If i = 1 Then
                    'puis tous les autres tronçons jusqu'à l'origine du circuit de distribution soit compteur ou prod ECS pour le circuit 1
                    Do
                        i1 = j
                        j = .Item(j - 1).Tronçon_Aval(0) 'circuit retour boucle = 1 seul circuit aval
                        If j = 0 Then Exit Do
                        If .Item(j - 1).Tronçon_Amont.Count = 1 Then
                            'le tronçon est bien un tronçon de distribution sans retour colonne et sans raccordement sur d'autres réseaux collecteurn: changement de section par exemple
                        Else
                            For k = 1 To .Item(j - 1).Tronçon_Amont.Count
                                k1 = .Item(j - 1).Tronçon_Amont.Item(k - 1) - 1 'pour avoir l'index
                                If k1 <> i1 - 1 Then 'on ne cumule pas sur les tronçons pour lesquels on vient déjà de cumuler
                                    If .Item(k1).i_colonne = 0 Then
                                        PthCumulé += .Item(k1).PthCumul 'qui doit correspondre au départ d'une autre branche du collecteur
                                    Else
                                        'détermination du parcours emprunté sur la colonne
                                        'détermination de la tête de colonne correspondante à cette colonne
                                        For Each tuy In Reseau._TuyauR
                                            If tuy.i_colonne = .Item(k1).i_colonne And tuy.Tronçon_Amont.Count = 0 Then k2 = .IndexOf(tuy) : Exit For
                                        Next
                                        PthCumulé1 = 0
                                        Do Until k2 = j - 1
                                            PthCumulé1 += .Item(k2).Pth * .Item(k2).L
                                            .Item(k2).PthCumul += PthCumulé1 'permet d'avoir le Pth cumulé sur les pieds de colonnes
                                            k2 = .Item(k2).Tronçon_Aval(0) - 1 'pour obtenir l'index
                                        Loop
                                        PthCumulé += PthCumulé1
                                    End If
                                End If
                            Next
                        End If
                        .Item(j - 1).PthCumul = PthCumulé + .Item(j - 1).Pth * .Item(j - 1).L
                        PthCumulé = .Item(j - 1).PthCumul
                    Loop Until j = 1
                Else
                    'puis tous les autres tronçons jusqu'à l'origine du circuit de distribution soit compteur ou prod ECS pour le circuit 1
                    If j <> Reseau.Collecteur_Or_R(i) Then 'sinon plantage lorsque le collecteur ne comporte qu'un seul tronçon
                        Do
                            i1 = j
                            j = .Item(j - 1).Tronçon_Aval(0) 'circuit retour boucle = 1 seul circuit aval
                            If .Item(j - 1).Tronçon_Amont.Count = 1 Then
                                'le tronçon est bien un tronçon de distribution sans retour colonne et sans raccordement sur d'autres réseaux collecteurn: changement de section par exemple
                            Else
                                For k = 1 To .Item(j - 1).Tronçon_Amont.Count
                                    k1 = .Item(j - 1).Tronçon_Amont.Item(k - 1) - 1 'pour avoir l'index
                                    If k1 <> i1 - 1 Then 'on ne cumule pas sur les tronçons pour lesquels on vient déjà de cumuler
                                        If .Item(k1).i_colonne = 0 Then
                                            PthCumulé += .Item(k1).PthCumul 'qui doit correspondre au départ d'une autre branche du collecteur
                                        Else
                                            'détermination du parcours emprunté sur la colonne
                                            'détermination de la tête de colonne correspondante à cette colonne
                                            For Each tuy In Reseau._TuyauR
                                                If tuy.i_colonne = .Item(k1).i_colonne And tuy.Tronçon_Amont.Count = 0 Then k2 = .IndexOf(tuy) : Exit For
                                            Next
                                            PthCumulé1 = 0
                                            Do Until k2 = j - 1
                                                PthCumulé1 += .Item(k2).Pth * .Item(k2).L
                                                .Item(k2).PthCumul += PthCumulé1 'permet d'avoir le Pth cumulé sur les pieds de colonnes
                                                k2 = .Item(k2).Tronçon_Aval(0) - 1 'pour obtenir l'index
                                            Loop
                                            PthCumulé += PthCumulé1
                                        End If
                                    End If
                                Next
                            End If
                            .Item(j - 1).PthCumul = PthCumulé + .Item(j - 1).Pth * .Item(j - 1).L
                            PthCumulé = .Item(j - 1).PthCumul
                        Loop Until j = Reseau.Collecteur_Or_R(i)
                    End If

                    'puis tous les autres tronçons jusqu'au tronçon 1
                    Do
                        j = .Item(j - 1).Tronçon_Aval(0) 'circuit distribution = 1 seul circuit amont
                        .Item(j - 1).PthCumul += PthCumulé
                    Loop Until j = 1
                End If
            Next
            'si l'algorithme est bon, l'addition des Pth cumulé sur les 1ier tronçons circuit distribution et circuit collecteur Retour = Pth Global
        End With
    End Sub

    ''' <summary>
    ''' Calcul des débits de recyclage ECS
    ''' </summary>
    ''' <param name="rtf">renvoie fichier note de calcul</param>
    Private Sub Tab_Calcul_Debit_Recyclage(ByRef Verif As Boolean, ByRef rtf As To_Rtf.RtfAnsiTextWriter)

        Dim i, i1, j, j1 As Integer
        Dim V_Tr, PthG1, PthR1 As Double
        Dim Som_Q_Tr, Som_Q_Retenu As Double
        Dim Tot_Pth_Colonne, Q_Aval, QbclW As Double
        Dim N_Colo, N_bcl, N_Rbcl As Integer
        'pertes sur premiers tronçons jusqu'à la 1ière fourche et/ou colonne montante
        With Reseau._Tuyau
            i = 0 : PthG1 = .Item(i).L * .Item(i).Pth : j = .Item(0).Tronçon_Aval.Item(0) - 1 '= index
            If .Item(0).Tronçon_Aval.Count = 1 Then
                i = j
                Do
                    PthG1 = PthG1 + .Item(i).L * .Item(i).Pth
                    .Item(i).Qbcl = .Item(0).Qbcl
                    j = i
                    If .Item(j).Tronçon_Aval.Count = 0 Then Exit Do
                    i = .Item(j).Tronçon_Aval.Item(0) - 1 '= index

                Loop While .Item(j).Tronçon_Aval.Count = 1 'And .Item(j).Exutoire = False
            End If
        End With
        rtf.WriteStartGroup()
        rtf.NewParagraph()
        rtf.FontSize = 9
        rtf.WriteString("  - N° :") : rtf.NewLine()
        rtf.WriteString("       = n° Amont/aval pour le tronçon départ.") : rtf.NewLine()
        rtf.WriteString("       = n° Amont/aval pour le tronçon retour.") : rtf.NewLine()
        rtf.WriteString("       = n° Amont/aval pour le tronçon alimentant la colonne i.") : rtf.NewLine()
        rtf.WriteString("  - P (w) = déperditions cumulées sur le tronçon Aller/Retour de la colonne i.") : rtf.NewLine()
        rtf.WriteString("  - Qcal (L/h) = débit minimum pour compenser les déperditions cumulées sur le parcours Aller/Retour de la colonne i.") : rtf.NewLine()
        rtf.WriteString("  - V (m/s) = vitesse du débit Maxi(Qcal/Debit minimal) sur le parcours Retour de la colonne i.") : rtf.NewLine()
        rtf.WriteString("  - Qv (L/h) = débit minimum si vitesse minimale imposée sur le parcours Retour de la colonne i (Affiché si débit précédent insuffisant).") : rtf.NewLine()
        rtf.WriteEndGroup()
        rtf.WriteStartGroup()
        rtf.NewParagraph()
        rtf.FontSize = 8
        'Ligne 1
        rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("N° Tronçon") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("P (W)") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Qcal (L/h)") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Qmin (L/h)") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("V (m/s)") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Qv (L/h)") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Q retenu") : rtf.EndCell() : rtf.EndRow()
        'Ligne 2
        rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("Départ") : rtf.EndCell()
        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("1") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(PthG1.ToString("#,###.0")) : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((Reseau._Tuyau.Item(0).Qbcl * 3600).ToString("#,###.0")) : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        V_Tr = Reseau._TuyauR.Item(0).Qbcl / 1000 / (PI * Reseau._TuyauR.Item(0).Øint ^ 2 / 4)
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(V_Tr.ToString("#0.00")) : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((Reseau._TuyauR.Item(0).Qbcl * 3600).ToString("#,###.0")) : rtf.EndCell() : rtf.EndRow()
        'Ligne 2
        rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("Retour général") : rtf.EndCell()
        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("1") : rtf.EndCell()
        i = 0 : PthR1 = 0
        PthR1 = PthR1 + Reseau._TuyauR.Item(i).L * Reseau._TuyauR.Item(i).Pth
        i = Reseau._TuyauR.Item(i).Tronçon_Amont.Item(0) - 1
        Do
            If Reseau._TuyauR.Item(i).Tronçon_Amont.Count = 1 Then
                PthR1 = PthR1 + Reseau._TuyauR.Item(i).L * Reseau._TuyauR.Item(i).Pth
                i = Reseau._TuyauR.Item(i).Tronçon_Amont.Item(0) - 1
                If i < 0 Then Exit Do
            Else
                PthR1 = PthR1 + Reseau._TuyauR.Item(i).L * Reseau._TuyauR.Item(i).Pth
                Reseau._TuyauR.Item(i).Qbcl = Reseau._TuyauR.Item(0).Qbcl
                Exit Do
            End If
        Loop
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(PthR1.ToString("#,###.0")) : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((Reseau._TuyauR.Item(0).Qbcl * 3600).ToString("#,###.0")) : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        V_Tr = Reseau._TuyauR.Item(0).Qbcl / 1000 / (PI * Reseau._TuyauR.Item(0).Øint ^ 2 / 4)
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(V_Tr.ToString("#0.00")) : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((Reseau._TuyauR.Item(0).Qbcl * 3600).ToString("#,###.0")) : rtf.EndCell() : rtf.EndRow()
        rtf.WriteEndGroup()
        'initialisation du j (index du tronçon à partir duquel on alimente une colonne ou une fourche) pour le circuit n°1
        With Reseau._Tuyau
            i = 0 : j = 0
            'recherche de la 1ière fourche
            If .Item(j).Tronçon_Aval.Count = 1 Then
                Do
                    i = .Item(j).Tronçon_Aval.Item(0) - 1 '= index
                    If .Item(i).Tronçon_Aval.Count <> 1 Then j = i : Exit Do 'tronçon à partir duquel cela fourche
                    j = i
                Loop
            End If
        End With
        With Reseau._TuyauR
            i1 = 0 : j1 = 0
            'recherche de la 1ière fourche
            If .Item(j1).Tronçon_Amont.Count = 1 Then
                Do
                    i1 = .Item(j1).Tronçon_Amont.Item(0) - 1 '= index
                    If .Item(i1).Tronçon_Amont.Count <> 1 Then j1 = i1 : Exit Do 'tronçon à partir duquel cela fourche
                    j1 = i1
                Loop
            End If
        End With
        'calcul des données affichées
        Call Calcul_Affichage_Circuit_Fourche(j, j1, Verif)
        'Sur la 1ière fourche, recherche du tronçon j correspondant au collecteur 1
        With Reseau._Tuyau
            If .Item(j).collecteur = 1 And .Item(j).Tronçon_Aval.Count > 1 Then
                j = 0 'on ne change rien
            Else
                For j1 = 1 To .Item(j).Tronçon_Aval.Count
                    j = .Item(j).Tronçon_Aval.Item(j1 - 1) - 1 'index du tronçon aval
                    If .Item(j).collecteur = 1 Then Exit For
                Next
            End If
        End With
        'ligne 3 et suivantes
        For i = 1 To Reseau.Collecteur_D_Nbre
            If i <> 1 Then
                j = Reseau.Collecteur_Or(i) - 1 '=index du tronçon j
                N_Rbcl = Reseau.Collecteur_Or_R(i) - 1
            End If
            rtf.WriteStartGroup()
            rtf.FontSize = 8
            rtf.BeginRow() : rtf.DeclareCell(8000) : rtf.BeginCell(True) : rtf.WriteString("Circuit collecteur n°" & i.ToString) : rtf.EndCell() : rtf.EndRow()
            rtf.WriteEndGroup()
            Do

                Dim Colonne As Boolean = True
                Dim tronçon As Boolean = True
                With Reseau._Tuyau
                    'vérification que le tronçon ne se raccorde que sur des colonnes = cas dernier tronçon qui abouti sur une ou plusieurs colonnes
                    Dim k As Integer = 0
                    Do
                        k = k + 1
                        If .Item(j).Tronçon_Aval.Count = 0 OrElse .Item(j).Tronçon_Aval(k - 1) - 1 < 0 Then Exit Do
                        If .Item(.Item(j).Tronçon_Aval(k - 1) - 1).i_colonne = 0 Then Colonne = False : Exit Do '1 branchement se fait sur un circuit
                    Loop While k < .Item(j).Tronçon_Aval.Count
                    'vérification que le tronçon ne se raccorde que sur d'autres tronçons - Testé uniquement que si le test colonne s'est révélé faux
                    If Colonne = False Then
                        k = 0
                        Do
                            k = k + 1
                            If .Item(.Item(j).Tronçon_Aval(k - 1) - 1).i_colonne <> 0 Then tronçon = False : Exit Do '1 branchement se fait sur une colonne
                        Loop While k < .Item(j).Tronçon_Aval.Count
                    End If
                End With

                If Colonne = True Then
                    'dernier tronçon qui abouti sur une ou plusieurs colonnes
                    With Reseau._Tuyau
                        'circuit d'alimentation
                        Call Calcul_Affichage_Circuit(j, 0, N_Rbcl, Verif)
                        If Verif = False Then Exit Sub
                        Call Tab_Circuit(j, N_Rbcl, rtf)
                        Dim Pth_Reseau As Double = 0
                        'calcul de la valeur Pth_Reseau
                        For j1 = 1 To .Item(j).Tronçon_Aval.Count 'possibilité d'avoir plusieurs colonnes
                            Call Pth_Reseau_Terminal(j, j1 - 1, Pth_Reseau, Verif)
                            If Verif = False Then Exit Sub
                        Next
                        For j1 = 1 To .Item(j).Tronçon_Aval.Count 'possibilité d'avoir plusieurs colonnes
                            'circuit colonne
                            Call Calcul_Affichage_Colonne(j, j1 - 1, Pth_Reseau, .Item(j).Qbcl, True, N_Colo, N_bcl, Tot_Pth_Colonne, QbclW, V_Tr, Som_Q_Tr, Som_Q_Retenu, Verif)
                            If Verif = False Then Exit Sub
                            Call Tab_Colonne(j, N_Colo, N_bcl, Tot_Pth_Colonne, QbclW, V_Tr, rtf)
                        Next
                    End With
                    Exit Do ' branchement sur le collecteur suivant

                ElseIf tronçon = True Then
                    'uniquement branchement sur des circuits =  fourche de circuit
                    Call Recherche_index_tron_Recyclage(j, j1, Verif) : If Verif = False Then Exit Sub
                    Call Calcul_Affichage_Circuit_Fourche(j, j1, Verif) : If Verif = False Then Exit Sub
                    Call Tab_Circuit(j, j1, rtf)
                    With Reseau._Tuyau
                        Dim k As Integer
                        'circuit d'alimentation
                        For j1 = 1 To .Item(j).Tronçon_Aval.Count
                            k = .Item(j).Tronçon_Aval.Item(j1 - 1) - 1 'index du tronçon aval
                            If .Item(k).collecteur = i Then k = j1 - 1 : Exit For 'l'index correspond bien à un index de tronçon de colonne
                        Next
                        j = .Item(j).Tronçon_Aval.Item(k) - 1
                    End With
                Else
                    'branchement sur circuit et sur colonne = tronçon intermédiaire
                    With Reseau._Tuyau
                        Dim k, j2, j3 As Integer
                        Dim Tot_Pth_Reseau As Double
                        Q_Aval = 0
                        'circuit d'alimentation
                        For j1 = 1 To .Item(j).Tronçon_Aval.Count
                            k = .Item(j).Tronçon_Aval.Item(j1 - 1) - 1 'index du tronçon aval
                            If .Item(k).i_colonne <> 0 Then k = j1 - 1 : Exit For 'l'index correspond bien à un index de tronçon de colonne
                        Next
                        Call Calcul_Affichage_Circuit(j, k, N_Rbcl, Verif)
                        If Verif = False Then Exit Sub
                        Call Tab_Circuit(j, N_Rbcl, rtf)
                        'Détermination de j2 et j3
                        For j1 = 1 To .Item(j).Tronçon_Aval.Count
                            k = .Item(j).Tronçon_Aval.Item(j1 - 1) - 1 'index du tronçon aval
                            If .Item(k).i_colonne = 0 Then j2 = k : Exit For 'j2 est l'index du tronçon suivant
                        Next
                        If j2 = 0 Then
                            MessageBox.Show("Pb de modélisation du bouclage - Test dans module Tab_Calcul_Debit_Recyclage", "Bouclage ECS", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
                            Verif = False : Exit Sub
                        End If
                        For j1 = 1 To Reseau._TuyauR.Item(N_Rbcl).Tronçon_Amont.Count
                            k = Reseau._TuyauR.Item(N_Rbcl).Tronçon_Amont(j1 - 1) - 1 ' j3 = index du tronçon suivant pour la partie retour de boucle collecteur de même circuit 
                            If Reseau._TuyauR.Item(k).i_colonne = 0 Then j3 = k : Exit For 'j3 est l'index du tronçon collecteur
                        Next
                        If j3 = 0 Then
                            MessageBox.Show("Pb de modélisation du bouclage - Test dans module Tab_Calcul_Debit_Recyclage", "Bouclage ECS", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
                            Verif = False : Exit Sub
                        End If
                        'circuit colonne
                        For j1 = 1 To .Item(j).Tronçon_Aval.Count
                            k = .Item(j).Tronçon_Aval.Item(j1 - 1) - 1 'index du tronçon aval
                            If .Item(k).i_colonne <> 0 Then 'l'index correspond bien à un index de tronçon de colonne
                                ' j2 = index du tronçon suivant pour la partie distribution de même circuit 
                                ' j3 = index du tronçon suivant pour la partie retour de boucle collecteur de même circuit 
                                Tot_Pth_Reseau = Reseau._Tuyau.Item(j2).PthCumul + Reseau._TuyauR.Item(j3).PthCumul
                                Call Calcul_Affichage_Colonne(j, j1 - 1, Tot_Pth_Reseau, .Item(j).Qbcl, False, N_Colo, N_bcl, Tot_Pth_Colonne, QbclW, V_Tr, Som_Q_Tr, Som_Q_Retenu, Verif)
                                If Verif = False Then Exit Sub
                                Call Tab_Colonne(j, N_Colo, N_bcl, Tot_Pth_Colonne, QbclW, V_Tr, rtf)
                                If Q_Aval = 0 Then
                                    Q_Aval = .Item(j).Qbcl - QbclW '1ier branchement
                                Else
                                    Q_Aval = Q_Aval - QbclW 'branchement pour les autres colonnes
                                End If
                            End If
                        Next
                        .Item(j2).Qbcl = Q_Aval
                        j = j2
                    End With
                End If
            Loop
        Next
        'dernière ligne du tableau
        rtf.WriteStartGroup()
        rtf.FontSize = 9
        rtf.BeginRow() : rtf.DeclareCell(4000) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.Bold = True : rtf.Italic = True : rtf.WriteString((Som_Q_Tr * 3600).ToString("#,##0.0")) : rtf.Bold = False : rtf.Italic = False : rtf.EndCell() '"Qcal (L/h)"
        rtf.DeclareCell(2400) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell() 'Qv (L/h)
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((Som_Q_Retenu * 3600).ToString("#,##0.0")) : rtf.EndCell() : rtf.EndRow() 'Q retenu
        rtf.WriteEndGroup()
        ' If Som_Q_Retenu > 1.02 * Som_Q_Tr Then Correction = True 'modifier les débits des tronçons
    End Sub

    ''' <summary>
    ''' Calcul des données pour permettre l'affichage de la ligne colonne
    ''' </summary>
    ''' <param name="j">index du n° de tronçon venant alimenter le 1ier tronçon de la colonne</param>
    ''' <param name="k">rang pour l'index j conduisant à l'index du 1ier tronçon de colonne</param>
    ''' <param name="Tot_Pth_Reseau">total pertes thermiques sur le réseau Aval</param>
    ''' <param name="Q_amont">débit sur le tronçon d'index j</param>
    ''' <param name="Terminal">Vrai si le tronçon étudié est le tronçon terminal du distributeur, sinon false</param>
    ''' <param name="N_colo">index du 1ier tronçon de la colonne</param>
    ''' <param name="N_bcl">index du dernier n° de la boucle</param>
    ''' <param name="Tot_Pth_Colonne">déperdition totale de la colonne avec son retour</param>
    ''' <param name="QbclW">débit correspondant à la déperdition totale de la colonne avec son retour</param>
    ''' <param name="V_Tr">vitesse sur le tronçon correspondant soit à Qmin soit à Qw</param>
    ''' <param name="Som_Q_Tr">Totalisation des débits sur la colonne correspondant aux déperditions thermiques</param>
    ''' <param name="Som_Q_Retenu">Totalisation des débits sur la colonne prenant en compte déperditions, V limite et Q mini</param>
    Private Sub Calcul_Affichage_Colonne(ByVal j As Integer, ByVal k As Integer, ByVal Tot_Pth_Reseau As Double, ByVal Q_Amont As Double, ByVal Terminal As Boolean, ByRef N_colo As Integer, ByRef N_bcl As Integer,
                                         ByRef Tot_Pth_Colonne As Double, ByRef QbclW As Double, ByRef V_Tr As Double, ByRef Som_Q_Tr As Double, ByRef Som_Q_Retenu As Double, ByRef Verif As Boolean)
        Dim j1, j2, j3, N_TetedeColonne As Integer

        'Recherche de N_colo = index du 1ier tronçon de la colonne en partant du bas vers le haut
        With Reseau._Tuyau
            j1 = .Item(j).Tronçon_Aval.Item(k) - 1 'index du tronçon aval pour le tronçon amont d'indice j, classé au rang k - Il s'agit du 1ier tronçon de la colonne i
            N_colo = j1
            If .Item(j1).Tete_Colonne = False Then
                Do
                    j2 = .Item(j1).Tronçon_Aval.Item(0) - 1 '= index du dernier tronçon de la colonne côté alimentation
                    If .Item(j2).Tete_Colonne = True Then N_TetedeColonne = j2 : Exit Do
                    j1 = j2
                Loop
            Else
                N_TetedeColonne = j1 'la colonne montante côté distribution ne comporte qu'un seul tronçonj2 = j1 :
            End If
        End With
        'Recherche de N_Bcl =  index du dernier tronçon de la colonne côté retour
        With Reseau._TuyauR
            For j1 = 1 To .Count
                If .Item(j1 - 1).Tronçon_Distrib = N_TetedeColonne + 1 Then Exit For '= index du tronçon coté boucle ECS venant se raccorder à la tête de colonne côté distribution
            Next
            N_bcl = j1 - 1
            If N_bcl = .Count Then
                MessageBox.Show("Pb de modélisation du bouclage - Test dans module Calcul_Affichage_Colonne", "Bouclage ECS", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
                Verif = False : Exit Sub
            End If
            Do
                j3 = .Item(j1 - 1).Tronçon_Aval(0) 'n° du tronçon aval
                If .Item(j3 - 1).Tronçon_Amont.Count > 1 Then Exit Do
                N_bcl = j3 - 1
                j1 = j3
            Loop
        End With
        'calcul de la déperdition thermique totale de la colonne (Aller et Retour) et des tronçons aval distribution Aller et Retour - Voir sous-programme Cumul_Perte_thermique_tronçon()
        Tot_Pth_Colonne = Reseau._Tuyau.Item(N_colo).PthCumul + Reseau._TuyauR.Item(N_bcl).PthCumul

        'calcul du débit correspondant à la déperdition
        Select Case Terminal
            Case True
                QbclW = Q_Amont * Tot_Pth_Colonne / Tot_Pth_Reseau
            Case False
                QbclW = Q_Amont * Tot_Pth_Colonne / (Tot_Pth_Colonne + Tot_Pth_Reseau)
        End Select

        'sommation des débits correspondant à la déperdition
        Som_Q_Tr = Som_Q_Tr + QbclW
        '1ière affectation du débit
        Reseau._Tuyau.Item(N_colo).Qbcl = Max(QbclW, Reseau.Qbcl_min)
        V_Tr = Reseau._Tuyau.Item(N_colo).Qbcl / 1000 / (PI * Reseau._TuyauR.Item(N_bcl).Øint ^ 2 / 4)
        If V_Tr < Reseau.Vmin Then Reseau._Tuyau.Item(N_colo).Qbcl = 1000 * Reseau.Vmin * PI * Reseau._TuyauR.Item(N_bcl).Øint ^ 2 / 4 'pour débit en L/h
        'Sommation des débits retenus
        Som_Q_Retenu = Som_Q_Retenu + Reseau._Tuyau.Item(N_colo).Qbcl
        'Affectation des débits sur les colonnes Aller et Retour
        '  -> ^partie colonne Aller
        With Reseau._Tuyau
            If N_colo <> N_TetedeColonne Then
                j1 = .Item(N_colo).Tronçon_Aval.Item(0) - 1 'index du tronçon aval pour le tronçon amont d'indice j, classé au rang k - Il s'agit du 1ier tronçon de la colonne i
                Do
                    .Item(j1).Qbcl = .Item(N_colo).Qbcl
                    If j1 = N_TetedeColonne Then Exit Do
                    j1 = .Item(j1).Tronçon_Aval.Item(0) - 1
                Loop
            End If
        End With
        ' -> partie colonne Retour
        With Reseau._TuyauR
            .Item(N_bcl).Qbcl = Reseau._Tuyau.Item(N_colo).Qbcl
            j1 = N_bcl
            Do
                .Item(j1).Qbcl = Reseau._Tuyau.Item(N_colo).Qbcl
                If .Item(j1).Tronçon_Distrib = N_TetedeColonne + 1 Then Exit Do 'arrivé au dernier tronçon
                j1 = .Item(j1).Tronçon_Amont(0) - 1
            Loop
        End With
    End Sub
    ''' <summary>
    ''' Détermination des valeurs devant être affichées pour la ligne circuit dans le tableau débit recyclage pour la partie circuit avec fourche
    ''' </summary>
    ''' <param name="j">index du n° de tronçon amont avant la fouche côté distributeur</param>
    ''' <param name="j1">index du n° de tronçon aval après la fouche côté recyclage</param>
    Private Sub Calcul_Affichage_Circuit_Fourche(ByVal j As Integer, ByVal j1 As Integer, ByRef Verif As Boolean)
        Dim nb_Circuit, k, k1, i, i1 As Integer
        Dim Q_Amont, Tot_Pth As Double
        'pour la partie distribution
        With Reseau._Tuyau
            nb_Circuit = .Item(j).Tronçon_Aval.Count
            Q_Amont = .Item(j).Qbcl
            Tot_Pth = 0
            For i = 1 To nb_Circuit
                If .Item(j).Tronçon_Aval.Count = 0 Then Exit For
                k = .Item(j).Tronçon_Aval(i - 1) - 1 'index du tronçon aval
                Tot_Pth += .Item(k).PthCumul  'Sommation des déperditions sur l'ensemble des circuits distribution
            Next
        End With
        'pour la partie recyclage
        With Reseau._TuyauR
            .Item(j1).Qbcl = Q_Amont
            For i = 1 To nb_Circuit
                If .Item(j1).Tronçon_Amont.Count = 0 Then Exit For
                k = .Item(j1).Tronçon_Amont(i - 1) - 1 'index du tronçon aval
                Tot_Pth += .Item(k).PthCumul  'Sommation des déperditions sur l'ensemble des circuits recyclage
            Next
        End With
        'calcul répartition débit
        For i = 1 To nb_Circuit
            k = Reseau._Tuyau.Item(j).Tronçon_Aval(i - 1) - 1 'index du tronçon aval
            For i1 = 1 To nb_Circuit
                If Reseau._TuyauR.Item(j1).Tronçon_Amont.Count = 0 Then Exit For
                k1 = Reseau._TuyauR.Item(j1).Tronçon_Amont(i1 - 1) - 1 'index du tronçon aval
                If Reseau._Tuyau.Item(k).collecteur = Reseau._TuyauR.Item(k1).collecteur Then Exit For
            Next
            Reseau._Tuyau.Item(k).Qbcl = Q_Amont * (Reseau._Tuyau.Item(k).PthCumul + Reseau._TuyauR.Item(k1).PthCumul) / Tot_Pth  'répartition au prorata des déperditions
            Reseau._TuyauR.Item(k1).Qbcl = Reseau._Tuyau.Item(k).Qbcl
        Next
    End Sub

    ''' <summary>
    ''' Détermination de l'index du tronçon de recyclage // au tronçon distributeur
    ''' </summary>
    ''' <param name="j">index du n° de tronçon   côté distributeur</param>
    ''' <param name="jn">index du n° de tronçon   côté recyclage</param>
    Private Sub Recherche_index_tron_Recyclage(ByVal j As Integer, ByRef jn As Integer, ByRef Verif As Boolean)
        'le principe est de prendre le réseau distributeur et de remonter en amont jusqu'à trouver une colonne montante
        'de remonter cette colonne montante et de basculer alors sur le réseau de recyclage et retomber sur le collecteur recyclage
        'puis de remonter vers l'amont d'un tronçon pour trouver le tronçon parallèle au tronçon distributeur
        Dim i, j1, j3, j4, k, k1 As Integer
        j1 = j
        Do
            If Reseau._Tuyau.Item(j1).Tronçon_Amont.Count = 0 OrElse Reseau._Tuyau.Item(j1).Tronçon_Amont.Item(0) = 0 Then Exit Do
            i = Reseau._Tuyau.Item(j1).Tronçon_Amont.Item(0) - 1 '= index
            If Reseau._Tuyau.Item(i).Tronçon_Aval.Count = 0 Then Exit Do
            If Reseau._Tuyau.Item(i).Tronçon_Aval.Count <> 1 Then j1 = i : Exit Do 'tronçon à partir duquel cela fourche
            j1 = i
        Loop
        If j1 = 0 Then
            For i = 1 To Reseau._TuyauR.Item(j1).Tronçon_Amont.Count
                k = Reseau._TuyauR.Item(j1).Tronçon_Amont(i - 1) - 1 'index du tronçon aval
                If Reseau._TuyauR.Item(k).collecteur = Reseau._Tuyau.Item(j).collecteur Then jn = k : Exit For 'on a trouvé une colonne montante
            Next

        Else
            For i = 1 To Reseau._Tuyau.Item(j1).Tronçon_Aval.Count
                k = Reseau._Tuyau.Item(j1).Tronçon_Aval(i - 1) - 1 'index du tronçon aval
                If Reseau._Tuyau.Item(k).collecteur = 0 Then Exit For 'on a trouvé une colonne montante
            Next
            'détermination de la tête de colonne correspondante à cette colonne
            For Each tuy In Reseau._Tuyau
                If tuy.i_colonne = Reseau._Tuyau.Item(k).i_colonne AndAlso tuy.Tete_Colonne = True Then k1 = Reseau._Tuyau.IndexOf(tuy) : Exit For
            Next
            'Recherche de jn =  index du dernier tronçon de la colonne côté retour
            With Reseau._TuyauR
                For j1 = 1 To .Count
                    If .Item(j1 - 1).Tronçon_Distrib = k1 + 1 Then Exit For '= index du tronçon coté boucle ECS venant se raccorder à la tête de colonne côté distribution
                Next
                If j1 = .Count + 1 Then
                    MessageBox.Show("Erreur calculé", "Module Recherche_index_tron_Recyclage", MessageBoxButtons.OK, MessageBoxIcon.Error)
                    Verif = False : Exit Sub
                End If
                j4 = j1 - 1 '= index du tronçon coté boucle ECS venant se raccorder à la tête de colonne côté distribution
                Do
                    j3 = .Item(j1 - 1).Tronçon_Aval(0) 'n° du tronçon aval
                    If .Item(j3 - 1).Tronçon_Amont.Count > 1 Then Exit Do
                    j4 = j3 - 1 '= index du tronçon colonne retour boucle ECS venant se raccorder au collecteur côté boucle
                    j1 = j3
                Loop
                jn = .Item(j4).Tronçon_Aval(0) - 1 '= index du collecteur côté boucle sur lequel vient se raccorder le tronçon colonne
                'détermination de la tête de colonne correspondante à cette colonne
                For Each tuy In Reseau._TuyauR
                    If tuy.i_colonne = 0 AndAlso tuy.Tronçon_Aval(0) - 1 = jn Then jn = Reseau._TuyauR.IndexOf(tuy) : Exit For
                Next
            End With
        End If

    End Sub

    ''' <summary>
    ''' Détermination des valeurs devant être affichées pour la ligne circuit dans le tableau recyclage
    ''' </summary>
    ''' <param name="Mode_Calcul">= true si uniquement éclatement des tronçons en distribution</param>
    ''' <param name="j">index du n° de tronçon venant alimenter le 1ier tronçon de la colonne</param>
    ''' <param name="k1">rang pour l'index j conduisant à l'index du 1ier tronçon de colonne</param>
    ''' <param name="N_Rbcl">index du tronçon aval sur lequel vient se raccorder le dernier tronçon du retour de boucle colonne</param>
    Private Sub Calcul_Affichage_Circuit(ByVal j As Integer, ByVal k1 As Integer, ByRef N_Rbcl As Integer, ByRef Verif As Boolean)
        If k1 <> 100 Then '= tronçon intermédiaire
            Dim j1, j2, j3, j4 As Integer
            With Reseau._Tuyau
                If .Item(j).Tronçon_Aval.Count = 0 Then
                    MessageBox.Show("Pb modélisation: pas de tronçon aval correspondant au tronçon de distribution n°" & (j + 1).ToString(),
                                    "Module Calcul_Affichage_Circuit", MessageBoxButtons.OK, MessageBoxIcon.Error)
                    Verif = False : Exit Sub
                Else
                    j1 = .Item(j).Tronçon_Aval.Item(k1) - 1 'index du tronçon aval pour le tronçon amont d'indice j, classé au rang k - Il s'agit du 1ier tronçon de la colonne i
                    If .Item(j1).Tete_Colonne = False Then
                        Do
                            j2 = .Item(j1).Tronçon_Aval.Item(0) - 1 '= index du dernier tronçon de la colonne côté alimentation
                            If .Item(j2).Tete_Colonne = True Then Exit Do
                            j1 = j2
                        Loop
                    Else
                        j2 = j1 'la colonne montante côté distribution ne comporte qu'un seul tronçon
                    End If
                End If

            End With
            'Recherche de N_Rbcl =  index du dernier tronçon de la colonne côté retour
            With Reseau._TuyauR
                For j1 = 1 To .Count
                    If .Item(j1 - 1).Tronçon_Distrib = j2 + 1 Then Exit For '= index du tronçon coté boucle ECS venant se raccorder à la tête de colonne côté distribution
                Next
                If j1 = .Count + 1 Then
                    MessageBox.Show("Pb modélisation: impossible de trouver le n° de tronçon coté boucle correspondant au tronçon de distribution n°" & (j2 + 1).ToString(),
                                    "Module Calcul_Affichage_Circuit", MessageBoxButtons.OK, MessageBoxIcon.Error)
                    Verif = False : Exit Sub
                End If
                j4 = j1 - 1 '= index du tronçon coté boucle ECS venant se raccorder à la tête de colonne côté distribution
                j2 = j4
                Do
                    j3 = .Item(j1 - 1).Tronçon_Aval(0) 'n° du tronçon aval
                    If .Item(j3 - 1).Tronçon_Amont.Count > 1 Then Exit Do
                    j4 = j3 - 1 '= index du tronçon colonne retour boucle ECS venant se raccorder au collecteur côté boucle
                    j1 = j3
                    If j1 = 1 Then Exit Do 'cas particulier
                Loop
                If j1 = 1 Then
                    MessageBox.Show("Pb modélisation: pas de collecteur côté boucle reprenant le tronçon boucle n°" & (j2 + 1).ToString(),
                                    "Module Calcul_Affichage_Circuit", MessageBoxButtons.OK, MessageBoxIcon.Error)
                    Verif = False : Exit Sub
                Else
                    N_Rbcl = .Item(j4).Tronçon_Aval(0) - 1 '= index du collecteur côté boucle sur lequel vient se raccorder le tronçon colonne
                End If


            End With
        End If


    End Sub

    Private Sub Pth_Reseau_Terminal(ByVal j As Integer, ByVal k As Integer, ByRef Tot_Pth_Reseau As Double, ByRef Verif As Boolean)
        Dim j1, j2, j3, N_TetedeColonne, N_colo, N_bcl As Integer
        Dim Tot_Pth_Colonne As Double = 0
        'Recherche de N_colo = index du 1ier tronçon de la colonne en partant du bas vers le haut
        With Reseau._Tuyau
            j1 = .Item(j).Tronçon_Aval.Item(k) - 1 'index du tronçon aval pour le tronçon amont d'indice j, classé au rang k - Il s'agit du 1ier tronçon de la colonne i
            N_colo = j1
            If .Item(j1).Tete_Colonne = False Then
                Do
                    j2 = .Item(j1).Tronçon_Aval.Item(0) - 1 '= index du dernier tronçon de la colonne côté alimentation
                    If .Item(j2).Tete_Colonne = True Then N_TetedeColonne = j2 : Exit Do
                    j1 = j2
                Loop
            Else
                N_TetedeColonne = j1 'la colonne montante côté distribution ne comporte qu'un seul tronçonj2 = j1 :
            End If
        End With
        'Recherche de N_Bcl =  index du dernier tronçon de la colonne côté retour
        With Reseau._TuyauR
            For j1 = 1 To .Count
                If .Item(j1 - 1).Tronçon_Distrib = N_TetedeColonne + 1 Then Exit For '= index du tronçon coté boucle ECS venant se raccorder à la tête de colonne côté distribution
            Next
            N_bcl = j1 - 1
            If N_bcl = .Count Then
                MessageBox.Show("Pb de modélisation du bouclage - Test dans module Pth_Reseau_Terminal", "Bouclage ECS", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
                Verif = False : Exit Sub
            End If
            Do
                j3 = .Item(j1 - 1).Tronçon_Aval(0) 'n° du tronçon aval
                If .Item(j3 - 1).Tronçon_Amont.Count > 1 Then Exit Do
                N_bcl = j3 - 1
                j1 = j3
            Loop
        End With
        'calcul de la déperdition thermique totale de la colonne (Aller et Retour) et des tronçons aval distribution Aller et Retour - Voir sous-programme Cumul_Perte_thermique_tronçon()
        Tot_Pth_Colonne = Reseau._Tuyau.Item(N_colo).PthCumul + Reseau._TuyauR.Item(N_bcl).PthCumul
        Tot_Pth_Reseau += Tot_Pth_Colonne
    End Sub
    ''' <summary>
    ''' Affichage de la ligne du tableau correspondant aux données du circuit
    ''' </summary>
    '''     <param name="j">index du tronçon du distributeur Aller qui alimente la colonne côté Aller</param>
    ''' <param name="N_rbcl">index du tronçon retour de boucle côté collecteur sur lequel se raccorde la colonne</param>
    ''' <param name="rtf">renvoie du fichier texte</param> 
    Private Sub Tab_Circuit(ByVal j As Integer, ByVal N_Rbcl As Integer, ByRef rtf As To_Rtf.RtfAnsiTextWriter)

        'i_colo">n° de la colonne</param>
        Dim k As Integer
        Dim i_colo As String = String.Empty
        With Reseau._Tuyau
            For j1 = 1 To .Item(j).Tronçon_Aval.Count
                k = .Item(j).Tronçon_Aval.Item(j1 - 1) - 1 'index du tronçon aval
                If .Item(k).i_colonne <> 0 Then
                    'détermination des n° de colonnes
                    i_colo = i_colo & " " & .Item(k).i_colonne.ToString
                End If
            Next
        End With
        'Ligne Aller / Retour Colonne i
        rtf.WriteStartGroup()
        rtf.FontSize = 8
        rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("A/R alim colonne " & i_colo) : rtf.EndCell()
        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString((j + 1).ToString & " / " & (N_Rbcl + 1).ToString) : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((Reseau._Tuyau.Item(j).PthCumul + Reseau._TuyauR.Item(N_Rbcl).PthCumul).ToString("#,###.0")) : rtf.EndCell() 'P (w)
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((Reseau._Tuyau.Item(j).Qbcl * 3600).ToString("#,##0.0")) : rtf.EndCell() 'Qcal (L/h)
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell() 'Qmin (L/h)
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell() 'V (m/s)
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell() 'Qv (L/h)
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell() : rtf.EndRow() 'Q retenu
        rtf.WriteEndGroup()
    End Sub

    ''' <summary>
    ''' Affichage de la ligne du tableau correspondant aux données de la colonne
    ''' </summary>
    ''' <param name="j">index du n° de tronçon venant alimenter le 1ier tronçon de la colonne</param>
    ''' <param name="N_colo">index du 1ier tronçon de la colonne</param>
    ''' <param name="N_bcl">index du dernier n° de la boucle</param>
    ''' <param name="Tot_Pth_Colonne">déperdition totale de la colonne avec son retour</param>
    ''' <param name="QbclW">débit correspondant à la déperdition totale de la colonne avec son retour</param>
    ''' <param name="V_Tr">vitesse sur le tronçon correspondant soit à Qmin soit à Qw</param>
    ''' <param name="rtf">renvoie du fichier texte</param>
    Private Sub Tab_Colonne(ByVal j As Integer, ByVal N_colo As Integer, ByVal N_bcl As Integer, ByVal Tot_Pth_Colonne As Double, ByVal QbclW As Double, ByVal V_Tr As Double, ByRef rtf As To_Rtf.RtfAnsiTextWriter)
        rtf.WriteStartGroup()
        rtf.FontSize = 8
        rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("A/R colonne " & Reseau._Tuyau.Item(N_colo).i_colonne.ToString) : rtf.EndCell()
        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString((N_colo + 1).ToString & " - " & (N_bcl + 1).ToString) : rtf.EndCell() 'n° tronçon départ colonne - n° retour boucle
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Tot_Pth_Colonne.ToString("#,##0.0")) : rtf.EndCell() 'déperdition thermique totale de la colonne (Aller et Retour)P (w)
        rtf.DeclareCell(800) : rtf.BeginCell(True)
        rtf.Bold = True : rtf.Italic = True : rtf.WriteString((QbclW * 3600).ToString("#,##0.0")) : rtf.Bold = False : rtf.Italic = False : rtf.EndCell() 'Qcal = débit entrant correspondant à la déperdition de la colonne
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((Reseau.Qbcl_min * 3600).ToString("#,##0.0")) : rtf.EndCell() 'Qmin
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(V_Tr.ToString("#0.00")) : rtf.EndCell() 'V (m/s)
        If V_Tr < Reseau.Vmin Then
            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((Reseau._Tuyau.Item(N_colo).Qbcl * 3600).ToString("#,##0.0")) : rtf.EndCell() 'débit final suivant Vmin, Qmin ou déperdition débit en L/h
        Else
            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        End If
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((Reseau._Tuyau.Item(N_colo).Qbcl * 3600).ToString("#,##0.0")) : rtf.EndCell() : rtf.EndRow()
        rtf.WriteEndGroup()
    End Sub

    Private Sub Correction_Debits_Recyclage()
        'on va partir de la tête de colonne et en remontant vers la production ECS via le réseau de distribution. On additionne au fur et à mesure
        'remise à 0 de tous les débits des circuits distribution et Collecteur Retour
        For Each tuy In Reseau._Tuyau
            If tuy.i_colonne = 0 Then tuy.Qbcl = 0 'ce tuyau n'appartient pas à une colonne
        Next
        For Each tuy In Reseau._TuyauR
            If tuy.i_colonne = 0 Then tuy.Qbcl = 0 'ce tuyau n'appartient pas à une colonne
        Next
        '--> pour la partie distribution
        With Reseau._Tuyau
            For i = Reseau.Collecteur_D_Nbre To 1 Step -1
                Dim j As Integer
                '  Dim DebitCumulé As Double
                j = Reseau.Collecteur_Ex.Item(i)
                Dim k1, k2, k3 As Integer
                'Tous les tronçons Aval correspondant obligatoirement à des colonnnes
                'Détermination de toutes les colonnes alimenté par ce tronçon
                For k = 1 To .Item(j - 1).Tronçon_Aval.Count
                    k1 = .Item(j - 1).Tronçon_Aval.Item(k - 1) - 1 'pour avoir l'index
                    'recherche index tuyau tête de colonne.
                    If .Item(k1).Tete_Colonne = True Then
                        k2 = k1
                    Else
                        'détermination de la tête de colonne correspondante à cette colonne
                        For Each tuy In Reseau._Tuyau
                            If tuy.i_colonne = .Item(k1).i_colonne AndAlso tuy.Tete_Colonne = True Then k2 = .IndexOf(tuy) : Exit For
                        Next
                    End If
                    'Q tronçon .Collecteur_Ex = Q tête de colonne
                    .Item(j - 1).Qbcl += .Item(k2).Qbcl
                Next
                If j = Reseau.Collecteur_Or(i) Then Continue For ' le collecteur i ne comporte qu'un seul tronçon
                Do
                    k3 = j
                    j = .Item(j - 1).Tronçon_Amont(0) 'circuit distribution = 1 seul circuit amont
                    .Item(j - 1).Qbcl = .Item(k3 - 1).Qbcl 'débit du collecteur aval
                    'récupération des débits provenant des colonnes montantes
                    For k = 1 To .Item(j - 1).Tronçon_Aval.Count
                        k1 = .Item(j - 1).Tronçon_Aval.Item(k - 1) - 1 'pour avoir l'index
                        If .Item(k1).i_colonne >= 1 Then
                            '--> débit provenant des colonnes retours
                            'recherche index tuyau tête de colonne.
                            If .Item(k1).Tete_Colonne = True Then
                                k2 = k1
                            Else
                                'détermination de la tête de colonne correspondante à cette colonne
                                For Each tuy In Reseau._Tuyau
                                    If tuy.i_colonne = .Item(k1).i_colonne And tuy.Tete_Colonne = True Then k2 = .IndexOf(tuy) : Exit For
                                Next
                            End If
                            'Q tronçon .Collecteur  = Q tête de colonne (ajout des débits provenant des colonnes)
                            .Item(j - 1).Qbcl += .Item(k2).Qbcl
                        ElseIf k1 <> k3 - 1
                            'débit provenant d'un autre collecteur aller
                            .Item(j - 1).Qbcl += .Item(k1).Qbcl
                        End If
                    Next
                Loop Until j = Reseau.Collecteur_Or(i) '- 1
                'DebitCumulé+ =  .Item(j - 1).Qbcl
            Next
        End With

        'Pour la partie Bouclage
        With Reseau._TuyauR
            For i = Reseau.Collecteur_R_Nbre To 1 Step -1
                Dim j As Integer
                '  Dim DebitCumulé As Double
                Dim k1, k2, k3 As Integer
                j = Reseau.Collecteur_Ex_R.Item(i)
                'Tous les tronçons Amont correspondant obligatoirement à des colonnnes
                'Détermination de toutes les colonnes alimenté par ce tronçon
                For k = 1 To .Item(j - 1).Tronçon_Amont.Count
                    k1 = .Item(j - 1).Tronçon_Amont.Item(k - 1) - 1 'pour avoir l'index
                    'recherche index tuyau tête de colonne.
                    If .Item(k1).Tronçon_Amont.Count = 0 Then ' = Tete_Colonne = True 
                        k2 = .Item(k1).Tronçon_Distrib
                    Else
                        'détermination de la tête de colonne correspondante à cette colonne
                        k1 = k1 + 1
                        Do
                            k1 = .Item(k1 - 1).Tronçon_Amont(0)
                        Loop Until .Item(k1 - 1).Tronçon_Amont.Count = 0
                        k2 = .Item(k1 - 1).Tronçon_Distrib
                    End If
                    'détermination du parcours emprunté
                    'Q tronçon .Collecteur_Ex = Q tête de colonne
                    .Item(j - 1).Qbcl += Reseau._Tuyau.Item(k2 - 1).Qbcl
                Next
                If j = Reseau.Collecteur_Or_R(i) Then Continue For '- 1 le collecteur i ne comporte qu'un seul tronçon
                Do
                    k3 = j
                    j = .Item(j - 1).Tronçon_Aval(0) 'circuit retour boucle = 1 seul circuit aval
                    .Item(j - 1).Qbcl = .Item(k3 - 1).Qbcl ' = débit du collecteur amont
                    'récupération des débits provenant des colonnes montantes
                    For k = 1 To .Item(j - 1).Tronçon_Amont.Count
                        k1 = .Item(j - 1).Tronçon_Amont.Item(k - 1) - 1 'pour avoir l'index
                        If .Item(k1).i_colonne >= 1 Then
                            '--> débit provenant des colonnes retours
                            'recherche index tuyau tête de colonne.
                            If .Item(k1).Tronçon_Amont.Count = 0 Then ' = Tete_Colonne = True 
                                k2 = .Item(k1).Tronçon_Distrib
                            Else
                                'détermination de la tête de colonne correspondante à cette colonne
                                Do
                                    k1 = .Item(k1 - 1).Tronçon_Amont(0)
                                Loop Until .Item(k1 - 1).Tronçon_Amont.Count = 0
                                k2 = .Item(k1 - 1).Tronçon_Distrib
                            End If
                            'détermination du parcours emprunté
                            'Q tronçon .Collecteur = Q tête de colonne
                            .Item(j - 1).Qbcl += Reseau._Tuyau.Item(k2 - 1).Qbcl
                        ElseIf k1 <> k3 - 1
                            'débit provenant d'un autre collecteur retour
                            .Item(j - 1).Qbcl += .Item(k1).Qbcl
                        End If
                    Next
                Loop Until j = Reseau.Collecteur_Or_R(i) '- 1
                'DebitCumulé+ =  .Item(j - 1).Qbcl
            Next

        End With
    End Sub

    Private Sub Tab_Debit_Recyclage(ByRef rtf As To_Rtf.RtfAnsiTextWriter)
        Dim i As Integer
        rtf.WriteStartGroup()
        rtf.NewParagraph() : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("Récapitulatif des débits:") : rtf.NewLine()
        rtf.Bold = False : rtf.Underline = False : rtf.NewParagraph()
        rtf.WriteString("Circuit Distribution") : rtf.NewLine()
        rtf.NewParagraph()
        rtf.FontSize = 8
        'Ligne 1
        rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Q (L/h)") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Q (L/h)") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Q (L/h)") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Q (L/h)") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Q (L/h)") : rtf.EndCell() : rtf.EndRow()
        'Ligne 2
        i = -1
        Do
            i += 1
            With Reseau._Tuyau
                If i = .Count Then Exit Do
                rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((i + 1).ToString) : rtf.EndCell()
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((.Item(i).Qbcl * 3600).ToString("#0.00")) : rtf.EndCell()
                i += 1
                If i = .Count Then rtf.EndRow() : Exit Do
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((i + 1).ToString) : rtf.EndCell()
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((.Item(i).Qbcl * 3600).ToString("#0.00")) : rtf.EndCell()
                i += 1
                If i = .Count Then rtf.EndRow() : Exit Do
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((i + 1).ToString) : rtf.EndCell()
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((.Item(i).Qbcl * 3600).ToString("#0.00")) : rtf.EndCell()
                i += 1
                If i = .Count Then rtf.EndRow() : Exit Do
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((i + 1).ToString) : rtf.EndCell()
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((.Item(i).Qbcl * 3600).ToString("#0.00")) : rtf.EndCell()
                i += 1
                If i = .Count Then rtf.EndRow() : Exit Do
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((i + 1).ToString) : rtf.EndCell()
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((.Item(i).Qbcl * 3600).ToString("#0.00")) : rtf.EndCell() : rtf.EndRow()
            End With
        Loop
        rtf.WriteEndGroup()
        rtf.WriteStartGroup()
        rtf.NewParagraph()
        rtf.WriteString("Circuit Retour boucle") : rtf.NewLine()
        rtf.NewParagraph()
        rtf.FontSize = 12 : rtf.FontSize = 8
        'Ligne 1
        rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Q (L/h)") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Q (L/h)") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Q (L/h)") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Q (L/h)") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Q (L/h)") : rtf.EndCell() : rtf.EndRow()
        'Ligne 2
        i = -1
        Do
            i += 1
            With Reseau._TuyauR
                If i = .Count Then Exit Do
                rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((i + 1).ToString) : rtf.EndCell()
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((.Item(i).Qbcl * 3600).ToString("#0.00")) : rtf.EndCell()
                i += 1
                If i = .Count Then rtf.EndRow() : Exit Do
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((i + 1).ToString) : rtf.EndCell()
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((.Item(i).Qbcl * 3600).ToString("#0.00")) : rtf.EndCell()
                i += 1
                If i = .Count Then rtf.EndRow() : Exit Do
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((i + 1).ToString) : rtf.EndCell()
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((.Item(i).Qbcl * 3600).ToString("#0.00")) : rtf.EndCell()
                i += 1
                If i = .Count Then rtf.EndRow() : Exit Do
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((i + 1).ToString) : rtf.EndCell()
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((.Item(i).Qbcl * 3600).ToString("#0.00")) : rtf.EndCell()
                i += 1
                If i = .Count Then rtf.EndRow() : Exit Do
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((i + 1).ToString) : rtf.EndCell()
                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString((.Item(i).Qbcl * 3600).ToString("#0.00")) : rtf.EndCell() : rtf.EndRow()
            End With
        Loop
        rtf.WriteEndGroup()
    End Sub

    ''' <summary>
    ''' Dimensonnement de la pompe de boucle ECS
    ''' </summary>
    ''' <param name="i_colo">n° de la colonne</param>
    ''' <param name="Verif">False si erreur calcul</param>
    ''' <param name="rtf">renvoie du fichier texte</param>
    Private Sub Dim_Ppe_Boucle_ECS(ByVal i_colo As Integer, ByRef Verif As Boolean, ByRef rtf As To_Rtf.RtfAnsiTextWriter)
        Dim J_Tr, Pdc_Lin, Pdc_LinTot, Pdc_LocTot, V As Double '
        Dim j, J_tête As Integer

        'calcul partie réseau distribution
        With Reseau._Tuyau
            'Recherche du tronçon tête de colonne
            For Each tuy In Reseau._Tuyau
                If tuy.i_colonne = i_colo AndAlso tuy.Tete_Colonne = True Then j = Reseau._Tuyau.IndexOf(tuy) : Exit For
            Next
            J_tête = j
            rtf.WriteStartGroup()
            rtf.WriteString("Colonne n°" & i_colo.ToString & " - Tronçon d'extrémité de colonne: " & (j + 1)) : rtf.NewLine()
            rtf.WriteEndGroup()
            'Affichage de la tête de tableau
            Call Affichage_Tab_Pdc_TêteColonne(rtf)
            Do
                With .Item(j)
                    J_Tr = J_Flamant(.Qbcl * 0.001, .Øint, Verif) 'formule de flamant
                    If Verif = False Then MessageBox.Show("Défaut calcul Pdc suivant formule de Flamant - Sub Dim_Ppe_Boucle_ECS", "Note de calcul",
                                                             MessageBoxButtons.OK, MessageBoxIcon.Error) : Exit Sub
                    Pdc_Lin = .L * J_Tr * 1.15  'en mCE
                    Pdc_LinTot += Pdc_Lin
                    Pdc_LocTot += .PdcLoc
                    V = .Qbcl / 1000 / (PI * .Øint ^ 2 / 4)
                    Call Affichage_Tab_Pdc_Colonne(j + 1, .Qbcl * 3600, .Øint * 1000, J_Tr * 1000, .L, Pdc_Lin, V, .PdcLoc, rtf)
                    If .i_colonne = i_colo Then
                        If Reseau.Pdc_Col.ContainsKey(i_colo) = False Then
                            Reseau.Pdc_Col.Add(i_colo, Pdc_Lin + .PdcLoc)  'uniquement sur la partie colonne montante
                        Else
                            Reseau.Pdc_Col(i_colo) += Pdc_Lin + .PdcLoc
                        End If
                    End If
                End With
                j = .Item(j).Tronçon_Amont(0) - 1 'pour avoir directement l'index
            Loop Until j = -1
        End With
        'calcul partie réseau collecteur boucle ECS
        With Reseau._TuyauR
            'Recherche du tronçon tête de colonne
            For Each tuy In Reseau._TuyauR
                If tuy.Tronçon_Distrib = J_tête + 1 Then j = Reseau._TuyauR.IndexOf(tuy) : Exit For
            Next
            If j = -1 Then
                MessageBox.Show("Pb modélisation tuyau retour boucle - Sub Dim_Ppe_Boucle_ECS", "Note de calcul", MessageBoxButtons.OK, MessageBoxIcon.Error)
                Verif = False : Exit Sub
            End If
            Do
                With .Item(j)
                    J_Tr = J_Flamant(.Qbcl * 0.001, .Øint, Verif) 'formule de flamant
                    If Verif = False Then MessageBox.Show("Défaut Retour Bcl calcul Pdc suivant formule de Flamant - Sub Dim_Ppe_Boucle_ECS", "Note de calcul",
                                                             MessageBoxButtons.OK, MessageBoxIcon.Error) : Exit Sub
                    Pdc_Lin = .L * J_Tr * 1.15  'en mCE
                    Pdc_LinTot += Pdc_Lin
                    Pdc_LocTot += .PdcLoc
                    V = .Qbcl / 1000 / (PI * .Øint ^ 2 / 4)
                    Call Affichage_Tab_Pdc_Colonne(j + 1, .Qbcl * 3600, .Øint * 1000, J_Tr * 1000, .L, Pdc_Lin, V, .PdcLoc, rtf)
                    If .i_colonne = i_colo Then
                        'uniquement sur la partie recyclage // à la colonne montante
                        If Reseau.Pdc_Col.ContainsKey(i_colo) = False Then
                            Reseau.Pdc_Col.Add(i_colo, Pdc_Lin + .PdcLoc)
                        Else
                            Reseau.Pdc_Col(i_colo) += Pdc_Lin + .PdcLoc
                        End If
                    End If
                End With
                j = .Item(j).Tronçon_Aval(0) - 1 'pour avoir directement l'index
            Loop Until j = -1
        End With
        Reseau.Pdc_Tot.Add(i_colo, Pdc_LinTot + Pdc_LocTot)
        'Affichage de la dernière ligne du tableau
        Call AffichageFinal_Tab_Pdc_Colonne(Pdc_LinTot, Pdc_LocTot, Pdc_LinTot + Pdc_LocTot, rtf)
    End Sub

    ''' <summary>
    ''' Affichage de la tête de tableau pour la calcul des pertes de charges par colonnes
    ''' </summary>
    ''' <param name="rtf">renvoie du fichier texte</param>
    Private Sub Affichage_Tab_Pdc_TêteColonne(ByRef rtf As To_Rtf.RtfAnsiTextWriter)
        rtf.WriteStartGroup()
        rtf.NewParagraph()
        rtf.FontSize = 12 : rtf.FontSize = 8
        '     'Ligne 1
        rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Q (L/h)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Ø int (mm)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("J (mmCE/m)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("L (m)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("1.15JL (mCE)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("V (m/s)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Pdc sin (mCE) ") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Δp totale (mCE)") : rtf.EndCell() : rtf.EndRow()
        rtf.WriteEndGroup()
    End Sub

    ''' <summary>
    ''' Affichage intermédiaire de tableau pour la calcul des pertes de charges par colonnes
    ''' </summary>
    ''' <param name="Tronçon">index du n° de tronçon de la colonne</param>
    ''' <param name="Q">débit en L/h</param>
    ''' <param name="Dint">diamètre intérieur de la canalisation en mm</param>
    ''' <param name="J">en mmCE/m</param>
    ''' <param name="L">longueur du tronçon en m</param>
    ''' <param name="Pdc_lin">Pdc linéaire en mCE/m</param>
    ''' <param name="V">vitesse sur le tronçon en m/s</param>
    ''' <param name="Pdc_Sin">Pdc singulière en mCE</param>
    ''' <param name="rtf">renvoie du fichier texte</param>
    Private Sub Affichage_Tab_Pdc_Colonne(ByVal Tronçon As Integer, ByVal Q As Double, ByVal Dint As Double, ByVal J As Double, ByVal L As Double, ByVal Pdc_lin As Double, ByVal V As Double,
                                          ByVal Pdc_Sin As Double, ByRef rtf As To_Rtf.RtfAnsiTextWriter)
        rtf.WriteStartGroup() : rtf.FontSize = 12 : rtf.FontSize = 8
        rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Tronçon.ToString) : rtf.EndCell() '"Tronçon Aval/Amont  
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Q.ToString("##0.0")) : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Dint.ToString("##0.0")) : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(J.ToString("##0.00")) : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(L.ToString("##0.00")) : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Pdc_lin.ToString("##0.000")) : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(V.ToString("#0.00")) : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Pdc_Sin.ToString("##0.0")) : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(" ") : rtf.EndCell() : rtf.EndRow()
        rtf.WriteEndGroup()
    End Sub

    ''' <summary>
    ''' Affichage final tableau pour la calcul des pertes de charges par colonnes
    ''' </summary>
    ''' <param name="Pdc_lin">Pdc linéaire en mCE/m</param>
    ''' <param name="Pdc_Sin">Pdc singulière en mCE</param>
    ''' <param name="Pdc_tot">Pdc totale pour alimenter la colonne en mCE</param>
    ''' <param name="rtf">renvoie du fichier texte</param>
    Private Sub AffichageFinal_Tab_Pdc_Colonne(ByVal Pdc_linTot As Double, ByVal Pdc_SinTot As Double, ByVal Pdc_Tot As Double, ByRef rtf As To_Rtf.RtfAnsiTextWriter)
        rtf.WriteStartGroup() : rtf.FontSize = 12 : rtf.FontSize = 8
        rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("Total") : rtf.EndCell()
        rtf.DeclareCell(3000) : rtf.BeginCell(True) : rtf.WriteString(" ") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Pdc_linTot.ToString("#,##0.00")) : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(" ") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Pdc_SinTot.ToString("#,##0.00")) : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Pdc_Tot.ToString("#,##0.00")) : rtf.EndCell() : rtf.EndRow()
        rtf.WriteEndGroup()
    End Sub
    ''' <summary>
    ''' Affichage final tableau pour la calcul des pertes de charges par colonnes
    ''' </summary>
    ''' <param name="Q_deb">débit Max en L/h</param>
    ''' <param name="Pdc_Max">Pdc maximale sur le réseau non compris préparateur ECS, vannes générales, etc. ..Unité: mCE</param>
    ''' <param name="Pdc_tot">Pdc totale pour alimenter la colonne en mCE</param>
    ''' <param name="rtf">renvoie du fichier texte</param>
    Private Sub Tab_Pompe(ByVal Q_deb As Double, ByVal Pdc_Max As Double, ByRef rtf As To_Rtf.RtfAnsiTextWriter)
        rtf.WriteStartGroup()
        rtf.NewParagraph()
        '   rtf.FontSize = 8
        rtf.BeginRow() : rtf.DeclareCell(6000) : rtf.BeginCell(True) : rtf.WriteString("Débit  (L/h)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Q_deb.ToString("#,##0.0")) : rtf.EndCell() : rtf.EndRow()
        rtf.BeginRow() : rtf.DeclareCell(6000) : rtf.BeginCell(True) : rtf.WriteString("Hauteur Manométrique Totale réseau  (mCE)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((Pdc_Max + Reseau.PdcVanne + Reseau.PdcPrepECS + Reseau.PdcClapet).ToString("#,##0.00")) : rtf.EndCell() : rtf.EndRow()
        rtf.BeginRow() : rtf.DeclareCell(6000) : rtf.BeginCell(True) : rtf.WriteString("Hauteur Manométrique vanne compensatrice  (mCE)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Reseau.HMVC.ToString("#0.00")) : rtf.EndCell() : rtf.EndRow()
        rtf.BeginRow() : rtf.DeclareCell(6000) : rtf.BeginCell(True) : rtf.WriteString("Hauteur Manométrique vanne réglage réseau le plus défavorisé  (mCE)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Reseau.HMVrd.ToString("#0.00")) : rtf.EndCell() : rtf.EndRow()
        rtf.BeginRow() : rtf.DeclareCell(6000) : rtf.BeginCell(True) : rtf.WriteString("Hauteur Manométrique Totale HMT  (mCE)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((Pdc_Max + Reseau.PdcVanne + Reseau.PdcPrepECS + Reseau.PdcClapet + Reseau.HMVrd + Reseau.HMVC).ToString("#,##0.00")) : rtf.EndCell() : rtf.EndRow()
        rtf.WriteEndGroup()
    End Sub
    Private Sub Determination_Nbre_Tour_Vanne_Reglage(ByVal Diam_Colonne As Double, ByVal Kv As Double, ByRef rtf As To_Rtf.RtfAnsiTextWriter)
        Dim j As Integer
        Dim nbre_tour As Double
        rtf.WriteStartGroup()
        Select Case Diam_Colonne * 1000
            Case Is > 50
                j = UBound(TA_DN50)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN50(j) < Kv
                nbre_tour = ((Kv - TA_DN50(j)) / (TA_DN50(j + 1) - TA_DN50(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN50 réglée à " & nbre_tour.ToString("0.0") & " tours.") : rtf.NewLine()
            Case Is > 40
                j = UBound(TA_DN50)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN50(j) < Kv
                nbre_tour = ((Kv - TA_DN50(j)) / (TA_DN50(j + 1) - TA_DN50(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN50 réglée à " & nbre_tour.ToString("0.0") & " tours")
                If nbre_tour > 2 Then
                    rtf.WriteString(" (OK dans la plage recommandée par le constructeur)") : rtf.NewLine()
                Else
                    rtf.WriteString(" (A éviter car le nombre de tours n'est pas dans la plage recommandée par le constructeur)") : rtf.NewLine()
                End If
                j = UBound(TA_DN40)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN40(j) < Kv
                nbre_tour = ((Kv - TA_DN40(j)) / (TA_DN40(j + 1) - TA_DN40(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN40 réglée à " & nbre_tour.ToString("0.0") & " tours")
                If nbre_tour > 2 Then
                    rtf.WriteString(" (OK dans la plage recommandée par le constructeur)") : rtf.NewLine()
                Else
                    rtf.WriteString(" (A éviter car le nombre de tours n'est pas dans la plage recommandée par le constructeur)") : rtf.NewLine()
                End If
            Case Is > 32
                j = UBound(TA_DN32)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN32(j) < Kv
                nbre_tour = ((Kv - TA_DN32(j)) / (TA_DN32(j + 1) - TA_DN32(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN32 réglée à " & nbre_tour.ToString("0.0") & " tours")
                If nbre_tour > 2 Then
                    rtf.WriteString(" (OK dans la plage recommandée par le constructeur)") : rtf.NewLine()
                Else
                    rtf.WriteString(" (A éviter car le nombre de tours n'est pas dans la plage recommandée par le constructeur)") : rtf.NewLine()
                End If
                j = UBound(TA_DN40)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN40(j) < Kv
                nbre_tour = ((Kv - TA_DN40(j)) / (TA_DN40(j + 1) - TA_DN40(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN40 réglée à " & nbre_tour.ToString("0.0") & " tours")
                If nbre_tour > 2 Then
                    rtf.WriteString(" (OK dans la plage recommandée par le constructeur)") : rtf.NewLine()
                Else
                    rtf.WriteString(" (A éviter car le nombre de tours n'est pas dans la plage recommandée par le constructeur)") : rtf.NewLine()
                End If
            Case Is > 25
                j = UBound(TA_DN32)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN32(j) < Kv
                nbre_tour = ((Kv - TA_DN32(j)) / (TA_DN32(j + 1) - TA_DN32(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN32 réglée à " & nbre_tour.ToString("0.0") & " tours")
                If nbre_tour > 2 Then
                    rtf.WriteString(" (OK dans la plage recommandée par le constructeur)") : rtf.NewLine()
                Else
                    rtf.WriteString(" (A éviter car le nombre de tours n'est pas dans la plage recommandée par le constructeur)") : rtf.NewLine()
                End If
                j = UBound(TA_DN25)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN25(j) < Kv
                nbre_tour = ((Kv - TA_DN25(j)) / (TA_DN25(j + 1) - TA_DN25(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN25 réglée à " & nbre_tour.ToString("0.0") & " tours")
                If nbre_tour > 2 Then
                    rtf.WriteString(" (OK dans la plage recommandée par le constructeur)") : rtf.NewLine()
                Else
                    rtf.WriteString(" (A éviter car le nombre de tours n'est pas dans la plage recommandée par le constructeur)") : rtf.NewLine()
                End If
            Case Is > 20
                j = UBound(TA_DN20)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN20(j) < Kv
                nbre_tour = ((Kv - TA_DN20(j)) / (TA_DN20(j + 1) - TA_DN20(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN20 réglée à " & nbre_tour.ToString("0.0") & " tours")
                If nbre_tour > 2 Then
                    rtf.WriteString(" (OK dans la plage recommandée par le constructeur)") : rtf.NewLine()
                Else
                    rtf.WriteString(" (A éviter car le nombre de tours n'est pas dans la plage recommandée par le constructeur)") : rtf.NewLine()
                End If
                j = UBound(TA_DN25)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN25(j) < Kv
                nbre_tour = ((Kv - TA_DN25(j)) / (TA_DN25(j + 1) - TA_DN25(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN25 réglée à " & nbre_tour.ToString("0.0") & " tours")
                If nbre_tour > 2 Then
                    rtf.WriteString(" (OK dans la plage recommandée par le constructeur)") : rtf.NewLine()
                Else
                    rtf.WriteString(" (A éviter car le nombre de tours n'est pas dans la plage recommandée par le constructeur)") : rtf.NewLine()
                End If
            Case Is > 15
                j = UBound(TA_DN20)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN20(j) < Kv
                nbre_tour = ((Kv - TA_DN20(j)) / (TA_DN20(j + 1) - TA_DN20(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN20 réglée à " & nbre_tour.ToString("0.0") & " tours")
                If nbre_tour > 2 Then
                    rtf.WriteString(" (OK dans la plage recommandée par le constructeur)") : rtf.NewLine()
                Else
                    rtf.WriteString(" (A éviter car le nombre de tours n'est pas dans la plage recommandée par le constructeur)") : rtf.NewLine()
                End If
                j = UBound(TA_DN15)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN15(j) < Kv
                nbre_tour = ((Kv - TA_DN15(j)) / (TA_DN15(j + 1) - TA_DN15(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN15 réglée à " & nbre_tour.ToString("0.0") & " tours")
                If nbre_tour > 1.5 Then
                    rtf.WriteString(" (OK dans la plage recommandée par le constructeur)") : rtf.NewLine()
                Else
                    rtf.WriteString(" (A éviter car le nombre de tours n'est pas dans la plage recommandée par le constructeur)") : rtf.NewLine()
                End If
            Case Is > 10
                j = UBound(TA_DN15)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN15(j) < Kv
                nbre_tour = ((Kv - TA_DN15(j)) / (TA_DN15(j + 1) - TA_DN15(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN15 réglée à " & nbre_tour.ToString("0.0") & " tours")
                If nbre_tour > 1.5 Then
                    rtf.WriteString(" (OK dans la plage recommandée par le constructeur)") : rtf.NewLine()
                Else
                    rtf.WriteString(" (A éviter car le nombre de tours n'est pas dans la plage recommandée par le constructeur)") : rtf.NewLine()
                End If
                j = UBound(TA_DN10)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN10(j) < Kv
                nbre_tour = ((Kv - TA_DN10(j)) / (TA_DN10(j + 1) - TA_DN10(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN10 réglée à " & nbre_tour.ToString("0.0") & " tours.")
                If nbre_tour > 1.5 Then
                    rtf.WriteString(" (OK dans la plage recommandée par le constructeur)") : rtf.NewLine()
                Else
                    rtf.WriteString(" (A éviter car le nombre de tours n'est pas dans la plage recommandée par le constructeur)") : rtf.NewLine()
                End If
            Case Else
                j = UBound(TA_DN10)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until TA_DN10(j) < Kv
                nbre_tour = ((Kv - TA_DN10(j)) / (TA_DN10(j + 1) - TA_DN10(j)) * 0.5) + (j * 0.5) + 0.5 'j commençant à 0
                rtf.WriteString("Soit vanne T.A STAD DN10 réglée à " & nbre_tour.ToString("0.0") & " tours.")
                If nbre_tour > 1.5 Then
                    rtf.WriteString(" (OK dans la plage recommandée par le constructeur)") : rtf.NewLine()
                Else
                    rtf.WriteString(" (A éviter car le nombre de tours n'est pas dans la plage recommandée par le constructeur)") : rtf.NewLine()
                End If
        End Select
        rtf.WriteEndGroup()
    End Sub
#End Region

    Private Function Mise_en_Forme(ByVal Toto As String) As String
        Dim toti As String
        toti = Replace(Toto, "/", "_")
        Toto = Replace(toti, " ", "_")
        toti = Replace(Toto, ":", "_")
        Mise_en_Forme = toti
    End Function
    Private Function D_Ext(ByVal Diam As Double, ByVal Matiere_Tube As Integer) As Double
        Dim j As Integer
        Select Case Matiere_Tube
            Case 1 'Cuivre 
                Dim De_Cu() As Double = {0.01, 0.012, 0.014, 0.015, 0.016, 0.018, 0.02, 0.022, 0.025, 0.028, 0.032, 0.036, 0.042, 0.052, 0.054, 0.064, 0.0761, 0.0889, 0.108} 'diamètre extérieur tube cuivre
                j = UBound(De_Cu)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until Di_Cu(j) < Diam
                D_Ext = De_Cu(j + 1)
            Case 2 'tube galva
                Dim De_Ag() As Double = {0.017, 0.021, 0.027, 0.034, 0.042, 0.049, 0.06, 0.076, 0.09, 0.115} 'diamètre extérieur tube acier galvanisé
                j = UBound(De_Ag)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until Di_Ag(j) < Diam
                D_Ext = De_Ag(j + 1)
            Case 3 'PER
                Dim De_PER() As Double = {0.012, 0.016, 0.02, 0.025, 0.026} 'diamètre extérieur tube PER
                j = UBound(De_PER)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until De_PER(j) < Diam
                D_Ext = De_PER(j + 1)
            Case 4 'Multicouche
                Dim De_MultiC() As Double = {0.014, 0.016, 0.02, 0.026, 0.032} 'diamètre extérieur tube Multicouche
                j = UBound(De_MultiC)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until Di_MultiC(j) < Diam
                D_Ext = De_MultiC(j + 1)
            Case 5 'PVC-C  "12,4/16 DN16", "15,4/20  DN20", "19,4/25  DN25", "24,8/32  DN32", "31,0/40  DN40", "38,8/50  DN50"
                Dim De_PVC_C() As Double = {0.016, 0.02, 0.025, 0.032, 0.04, 0.05} 'diamètre extérieur tube Multicouche
                j = UBound(De_PVC_C)
                Do
                    j = j - 1
                    If j < 0 Then j = 0 : Exit Do
                Loop Until Di_PVC_C(j) < Diam
                D_Ext = De_PVC_C(j + 1)
        End Select
    End Function
    Private Function libel_diametre(ByVal Diam As Double, ByVal Matiere_Tube As Integer) As String
        Dim i As Integer
        Select Case Matiere_Tube
            Case 1 'Cuivre
                For i = 0 To T_Cu.Øint.Count - 1
                    If Diam <= T_Cu.Øint(i) Then Exit For
                Next
                libel_diametre = T_Cu.Nom(i).ToString
            Case 2 'tube galva
                For i = 0 To T_AG.Øint.Count - 1
                    If Diam <= T_AG.Øint(i) Then Exit For
                Next
                libel_diametre = T_AG.Nom(i).ToString
            Case 3 'PER
                For i = 0 To T_PER.Øint.Count - 1
                    If Diam <= T_PER.Øint(i) Then Exit For
                Next
                libel_diametre = T_PER.Nom(i).ToString
            Case 4 'Multicouche
                For i = 0 To T_MultiC.Øint.Count - 1
                    If Diam <= T_MultiC.Øint(i) Then Exit For
                Next
                libel_diametre = T_MultiC.Nom(i).ToString
            Case 5 'PVC-C
                For i = 0 To T_PVC_C.Øint.Count - 1
                    If Diam <= T_PVC_C.Øint(i) Then Exit For
                Next
                libel_diametre = T_PVC_C.Nom(i).ToString
        End Select
    End Function


    Public Sub Calcul_EP_Gouttiere(ByVal SurfPlan As Double, ByVal SurfBrute As Double, ByVal PenteCouv As Double, ByVal PenteConduit As Double, ByVal Pente_Impose As Boolean,
                                   ByRef Gout_Cir As Double, ByRef Gout_Rect As Double, ByRef Gout_Trian As Double, ByRef debit As Double, ByRef Note_de_Calcul As String,
                                   ByRef Verif As Boolean)
        'dimensionnement de la section de la gouttière suivant DTU 60.11 partie 2 §2
        Dim f_a, Diam_Col(8), V_col(8), γ As Double
        Dim msg As String
        'writer de sortie du RTF
        Dim sw As New System.IO.StringWriter
        'crée un writer de RTF avec une police par défaut
        Dim rtf As New To_Rtf.RtfAnsiTextWriter(sw, New Font(FontFamily.GenericSerif, 12, FontStyle.Regular))
        Dim rtff As String
        rtf.Bold = True : rtf.FontSize = 16 : rtf.Underline = True
        rtf.WriteString("Note de calcul de dimensionnement de gouttières et chéneaux")
        rtf.NewLine()
        rtf.Bold = False : rtf.FontSize = 10 : rtf.Underline = False : rtf.NewParagraph()
        rtf.WriteString("Note de calcul du : ") : msg = Mise_en_Forme(CStr(DateTime.Now)) : rtf.WriteString(msg) : rtf.NewLine()
        rtf.WriteString("Rédacteur : " & Aff.Redacteur) : rtf.NewLine()
        rtf.WriteString("Chantier : " & Aff.Chantier) : rtf.NewLine()
        rtf.WriteString("Logiciel : Calculette Plomberie version " & My.Application.Info.Version.ToString) : rtf.NewLine()
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("1 - Rappel des hypothèses") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        rtf.WriteString("Code de calculs: suivant chapitre 2 - Partie II - DTU 60.11 - Octobre 1988") : rtf.NewLine()
        If SurfPlan < 1 Then
            rtf.WriteString("Surface toiture: " & SurfBrute.ToString("#,##0.0") & " m²") : rtf.NewLine()
            rtf.WriteString("Pente de la toiture: " & (Tan(PenteCouv) * 100).ToString("#0.0") & " %") : rtf.NewLine()
            SurfPlan = SurfBrute * Cos(PenteCouv)
        End If
        rtf.WriteString("Surface plan: " & SurfPlan.ToString("#,##0.0") & " m²") : rtf.NewLine() : rtf.NewLine()
        If SurfPlan > 1000 Then
            rtf.WriteString("Le code de calcul DTU 60.11 d'octobre 1988 n'autorise pas une surface plane supérieure à 1000 m². La suite du calcul sera établie pour une surface " &
                            "plane de 1000 m².") : rtf.NewLine() : rtf.NewLine()
            SurfPlan = 1000
        End If
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("2 - Section de gouttière et chéneau") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        debit = SurfPlan * 3 / (60 * 1000) 'conversion L/mn en m3/s
        If Pente_Impose = True And PenteConduit < 1 Then
            MsgBox("Note de calcul incomplète." & Environment.NewLine & "Edition sur valeur par défaut.", MsgBoxStyle.Information, "Calcul EP gouttiere")
            PenteConduit = 10 'valeur par défaut
        ElseIf Pente_Impose = False Then
            PenteConduit = 10 'valeur par défaut
        End If
        PenteConduit = PenteConduit / 1000 'conversion mm/m en m/m
        Dim Pente_Col() As Double = {PenteConduit, 0.001, 0.002, 0.003, 0.005, 0.007, 0.01, 0.015, 0.02}
        γ = 0.38 ' 
        For i = 0 To 8
            Call Calcul_Collecteur_Separatif(γ, Pente_Col(i), debit, Diam_Col(i), f_a, V_col(i))
            If f_a < 0 Then
                MessageBox.Show("Défaut dans les données - Exécution arrêtée.", "Calcul EP gouttière", MessageBoxButtons.OK, MessageBoxIcon.Error)
                Note_de_Calcul = "Ndc_EP_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
                rtf.Generate() : rtff = sw.ToString : File.WriteAllText(Aff.msgResult & "\" & Note_de_Calcul, rtff)
                Verif = False : Exit Sub
            End If
            If Pente_Impose = True Then Exit For
        Next
        debit = debit * 1000 * 60 : debit = (Fix(debit * 10) + 1) / 10 'arrondi au décilitre supérieur
        If Pente_Impose = True Then
            Diam_Col(0) = Diam_Col(0) * 1000 + 1 : Diam_Col(0) = Fix(Diam_Col(0)) / 10 ''arrondi au mm supérieur et converti en cm
            Gout_Cir = PI * Diam_Col(0) ^ 2 / 4 'demi-circulaire et en cm²
            Gout_Cir = Gout_Cir / 2   'demi-circulaire  
            Gout_Rect = Gout_Cir * 1.1 : Gout_Trian = Gout_Cir * 1.2
            Gout_Cir = Fix(Gout_Cir) + 1 : Gout_Rect = Fix(Gout_Rect) + 1 : Gout_Trian = Fix(Gout_Trian) + 1 'arrondi au cm² supérieur
            rtf.WriteString("Pente appliquée à la gouttière: " & (PenteConduit * 1000).ToString("#,##0") & " mm/m") : rtf.NewLine() : rtf.NewLine()
            rtf.WriteString("Section minimale de la gouttière/cheneau de type: ") : rtf.NewLine()
            rtf.WriteString(" - demi-circulaire: " & Gout_Cir.ToString("#,##0.0") & " cm²") : rtf.NewLine()
            rtf.WriteString(" - rectangulaire/trapézoidale: " & Gout_Rect.ToString("#,##0.0") & " cm²") : rtf.NewLine()
            rtf.WriteString(" - triangulaire: " & Gout_Trian.ToString("#,##0.0") & " cm²") : rtf.NewLine()
            rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
            rtf.WriteString("3 - Débit") : rtf.Bold = False
            rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
            rtf.WriteString("débit: " & debit.ToString("#,##0.0") & " L/mn") : rtf.NewLine()
        Else
            rtf.NewParagraph()
            rtf.FontSize = 8
            rtf.BeginRow() : rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString("Pente (mm/m)") : rtf.EndCell()
            rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString("Débit (L/mn)") : rtf.EndCell()
            rtf.DeclareCell(2500) : rtf.BeginCell(True) : rtf.WriteString("Section gouttière (cm²)") : rtf.EndCell()
            rtf.DeclareCell(2500) : rtf.BeginCell(True) : rtf.WriteString("Vitesse ecoulement (m/s)") : rtf.EndCell() : rtf.EndRow()
            For i = 1 To 8
                rtf.BeginRow() : rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString((Pente_Col(i) * 1000).ToString("#0.0")) : rtf.EndCell()
                rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString((debit).ToString("##0.0")) : rtf.EndCell()
                Diam_Col(i) = Diam_Col(i) * 1000 + 1 : Diam_Col(i) = Fix(Diam_Col(i)) / 10 ''arrondi au mm supérieur et converti en cm
                Gout_Cir = PI * Diam_Col(i) ^ 2 / 4 'demi-circulaire et en cm²
                Gout_Cir = Gout_Cir / 2   'demi-circulaire 
                rtf.DeclareCell(2500) : rtf.BeginCell(True) : rtf.WriteString((Gout_Cir).ToString("#,##0.0")) : rtf.EndCell()
                rtf.DeclareCell(2500) : rtf.BeginCell(True) : rtf.WriteString((V_col(i)).ToString("##0.0")) : rtf.EndCell() : rtf.EndRow()
            Next
            Diam_Col(0) = Diam_Col(0) * 1000 + 1 : Diam_Col(0) = Fix(Diam_Col(0)) / 10 ''arrondi au mm supérieur et converti en cm
            Gout_Cir = PI * Diam_Col(0) ^ 2 / 4 'demi-circulaire et en cm²
            Gout_Cir = Gout_Cir / 2   'demi-circulaire  
            Gout_Rect = Gout_Cir * 1.1 : Gout_Trian = Gout_Cir * 1.2
        End If

        'génère le RTF complet
        Note_de_Calcul = "Ndc_EP_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
        rtf.Generate() : rtff = sw.ToString : File.WriteAllText(Aff.msgResult & "\" & Note_de_Calcul, rtff)
    End Sub
    Private Sub Tab_EP_Couv(ByVal i As Integer, ByVal PenteConduit As Double, ByVal Gout_Cir As Double, ByRef rtf As To_Rtf.RtfAnsiTextWriter)
        rtf.WriteStartGroup()
        rtf.FontSize = 8
        If i = 1 Then
            rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Pente du conduit (mm/m)") : rtf.EndCell()
            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Section gouttière demi-circulaire (cm²)") : rtf.EndCell() : rtf.EndRow()
        End If
        rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((PenteConduit * 1000).ToString("##0.0")) : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((Gout_Cir * 1000).ToString("##0.0")) : rtf.EndCell() : rtf.EndRow()
        rtf.WriteEndGroup()
    End Sub
    Public Sub Calcul_Descente_Tuile(ByVal SurfPlan As Double, ByRef SurfBrute As Double, ByVal PenteCouv As Double, ByRef Desc_Cyl As Integer, ByRef Desc_Cuv As Integer,
                                     ByRef note_de_calcul As String, ByRef Verif As Boolean, ByVal Editeur As Boolean)
        'dimensionnement de la section de la descente EP suivant DTU 60.11 partie 2 §3.1
        Dim msg As String
        'writer de sortie du RTF
        Dim sw As New System.IO.StringWriter
        'crée un writer de RTF avec une police par défaut
        Dim rtf As New To_Rtf.RtfAnsiTextWriter(sw, New Font(FontFamily.GenericSerif, 12, FontStyle.Regular))
        Dim rtff As String
        rtf.Bold = True : rtf.FontSize = 16 : rtf.Underline = True
        rtf.WriteString("Note de calcul de dimensionnement de descente EP")
        rtf.NewLine()
        rtf.Bold = False : rtf.FontSize = 10 : rtf.Underline = False : rtf.NewParagraph()
        rtf.WriteString("Note de calcul du : ") : msg = Mise_en_Forme(CStr(DateTime.Now)) : rtf.WriteString(msg) : rtf.NewLine()
        rtf.WriteString("Rédacteur : " & Aff.Redacteur) : rtf.NewLine()
        rtf.WriteString("Chantier : " & Aff.Chantier) : rtf.NewLine()
        rtf.WriteString("Logiciel : Calculette Plomberie version " & My.Application.Info.Version.ToString) : rtf.NewLine()
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("1 - Rappel des hypothèses") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        rtf.WriteString("Code de calculs: suivant chapitre 3,1 - Partie II - DTU 60.11 - Octobre 1988") : rtf.NewLine()
        rtf.WriteString("Couverture ne comportant pas un revètement d'étanchéité") : rtf.NewLine()
        If SurfPlan < 1 Then
            rtf.WriteString("Surface toiture: " & SurfBrute.ToString("#,##0.0") & " m²") : rtf.NewLine()
            rtf.WriteString("Pente de la toiture: " & (Tan(PenteCouv) * 100).ToString("#0.0") & " %") : rtf.NewLine()
            SurfPlan = SurfBrute * Cos(PenteCouv)
        End If
        rtf.WriteString("Surface plan: " & SurfPlan.ToString("#,##0.0") & " m²") : rtf.NewLine() : rtf.NewLine()
        If SurfPlan > 1000 Then
            rtf.WriteString("Le code de calcul DTU 60.11 d'octobre 1988 n'autorise pas une surface plane supérieure à 1000 m². La suite du calcul sera établie pour une surface " &
                            "plane de 1000 m².") : rtf.NewLine() : rtf.NewLine()
            SurfPlan = 1000
        End If
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("2 - Diamètre intérieur du tuyau de descente") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        Select Case SurfPlan
            Case Is <= 40
                Desc_Cyl = 60 : Desc_Cuv = 60
            Case Is <= 55
                Desc_Cyl = 70 : Desc_Cuv = 70
            Case Is <= 71
                Desc_Cyl = 80 : Desc_Cuv = 80
            Case Is <= 91
                Desc_Cyl = 90 : Desc_Cuv = 90
            Case Is <= 113
                Desc_Cyl = 100 : Desc_Cuv = 100
            Case Is <= 136
                Desc_Cyl = 110 : Desc_Cuv = 110
            Case Is <= 161
                Desc_Cyl = 120 : Desc_Cuv = 120
            Case Is <= 190
                Desc_Cyl = 130 : Desc_Cuv = 130
            Case Is <= 220
                Desc_Cyl = 140 : Desc_Cuv = 140
            Case Is <= 253
                Desc_Cyl = 150 : Desc_Cuv = 150
            Case Is <= 287
                Desc_Cyl = 160 : Desc_Cuv = 160
            Case Is <= 314
                Desc_Cyl = 200 : Desc_Cuv = 170
            Case Is <= 324
                Desc_Cyl = 210 : Desc_Cuv = 170
            Case Is <= 346
                Desc_Cyl = 210 : Desc_Cuv = 180
            Case Is <= 363
                Desc_Cyl = 220 : Desc_Cuv = 180
            Case Is <= 380
                Desc_Cyl = 220 : Desc_Cuv = 190
            Case Is <= 406
                Desc_Cyl = 230 : Desc_Cuv = 190
            Case Is <= 415
                Desc_Cyl = 230 : Desc_Cuv = 200
            Case Is <= 449
                Desc_Cyl = 240 : Desc_Cuv = 200
            Case Is <= 452
                Desc_Cyl = 240 : Desc_Cuv = 210
            Case Is <= 490
                Desc_Cyl = 250 : Desc_Cuv = 210
            Case Is <= 494
                Desc_Cyl = 260 : Desc_Cuv = 210
            Case Is <= 530
                Desc_Cyl = 260 : Desc_Cuv = 220
            Case Is <= 543
                Desc_Cyl = 270 : Desc_Cuv = 220
            Case Is <= 570
                Desc_Cyl = 270 : Desc_Cuv = 230
            Case Is <= 593
                Desc_Cyl = 280 : Desc_Cuv = 230
            Case Is <= 615
                Desc_Cyl = 280 : Desc_Cuv = 240
            Case Is <= 646
                Desc_Cyl = 290 : Desc_Cuv = 240
            Case Is <= 660
                Desc_Cyl = 290 : Desc_Cuv = 250
            Case Is <= 700
                Desc_Cyl = 300 : Desc_Cuv = 250
            Case Is <= 755
                Desc_Cyl = 310 : Desc_Cuv = 260
            Case Is <= 758
                Desc_Cyl = 320 : Desc_Cuv = 260
            Case Is <= 805
                Desc_Cyl = 320 : Desc_Cuv = 270
            Case Is <= 815
                Desc_Cyl = 330 : Desc_Cuv = 270
            Case Is <= 855
                Desc_Cyl = 330 : Desc_Cuv = 280
            Case Is <= 880
                Desc_Cyl = 340 : Desc_Cuv = 280
            Case Is <= 908
                Desc_Cyl = 340 : Desc_Cuv = 290
            Case Is <= 945
                Desc_Cyl = 350 : Desc_Cuv = 290
            Case Is <= 960
                Desc_Cyl = 350 : Desc_Cuv = 300
            Case Is <= 1000
                Desc_Cyl = 360 : Desc_Cuv = 300
        End Select
        rtf.WriteString("Tuyau raccordé au chéneau ou à la gouttière par un moignon cylindrique - diamètre minimal: " & Desc_Cyl.ToString("#") & " mm") : rtf.NewLine()
        rtf.WriteString("Tuyau raccordé par un large cône ou une cuvette - diamètre minimal: " & Desc_Cuv.ToString("#") & " mm") : rtf.NewLine()
        'génère le RTF complet
        note_de_calcul = "Ndc_EP_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
        rtf.Generate() : rtff = sw.ToString : File.WriteAllText(Aff.msgResult & "\" & note_de_calcul, rtff)
    End Sub
    Public Sub Calcul_Descente_Etancheite(ByVal SurfPlan As Double, ByRef SurfBrute As Double, ByVal PenteCouv As Double, ByVal Maçonnerie As Boolean,
                                            ByVal Acier As Boolean, ByVal Bois As Boolean, ByVal Autre As Boolean, ByRef Desc_Cyl As Integer, ByRef Desc_Cuv As Integer,
                                        ByRef note_de_calcul As String, ByRef Verif As Boolean, ByVal Editeur As Boolean)
        'dimensionnement de la section de la descente EP suivant DTU 60.11 partie 2 §3.1
        Dim msg As String
        'writer de sortie du RTF
        Dim sw As New System.IO.StringWriter
        'crée un writer de RTF avec une police par défaut
        Dim rtf As New To_Rtf.RtfAnsiTextWriter(sw, New Font(FontFamily.GenericSerif, 12, FontStyle.Regular))
        Dim rtff As String
        rtf.Bold = True : rtf.FontSize = 16 : rtf.Underline = True
        rtf.WriteString("Note de calcul de dimensionnement de descente EP")
        rtf.NewLine()
        rtf.Bold = False : rtf.FontSize = 10 : rtf.Underline = False : rtf.NewParagraph()
        rtf.WriteString("Note de calcul du : ") : msg = Mise_en_Forme(CStr(DateTime.Now)) : rtf.WriteString(msg) : rtf.NewLine()
        rtf.WriteString("Rédacteur : " & Aff.Redacteur) : rtf.NewLine()
        rtf.WriteString("Chantier : " & Aff.Chantier) : rtf.NewLine()
        rtf.WriteString("Logiciel : Calculette Plomberie version " & My.Application.Info.Version.ToString) : rtf.NewLine()
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("1 - Rappel des hypothèses") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        rtf.WriteString("Code de calculs: suivant chapitre 3,2 - Partie II - DTU 60.11 - Octobre 1988") : rtf.NewLine()
        rtf.WriteString("Couverture comportant un revètement d'étanchéité") : rtf.NewLine()
        If SurfPlan < 1 Then
            rtf.WriteString("Surface toiture: " & SurfBrute.ToString("#,##0.0") & " m²") : rtf.NewLine()
            rtf.WriteString("Pente de la toiture: " & (Tan(PenteCouv) * 100).ToString("#0.0") & " %") : rtf.NewLine()
            SurfPlan = SurfBrute * Cos(PenteCouv)
        End If
        rtf.WriteString("Surface plan: " & SurfPlan.ToString("#,##0.0") & " m²") : rtf.NewLine() : rtf.NewLine()
        If SurfPlan > 1000 Then
            rtf.WriteString("Le code de calcul DTU 60.11 d'octobre 1988 n'autorise pas une surface plane supérieure à 1000 m². La suite du calcul sera établie pour une surface " &
                            "plane de 1000 m².") : rtf.NewLine() : rtf.NewLine()
            SurfPlan = 1000
        End If
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("2 - Diamètre intérieur du tuyau de descente") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        If Maçonnerie = True Then
            rtf.WriteString("Revètement d'étanchéité sur toiture non accessible établie sur éléments porteurs en maçonnerie ( type A,B, C ou D suivant DTU 20.12)") : rtf.NewLine()
            rtf.WriteString("Selon les DTU de la série 43, les toitures non accessibles  sont celles squi ne reçoivent qu'une circulation réduite à l'entretien du revêtement de l'étanchéité ou d'accessoire de toiture.") : rtf.NewLine()
            Diam_Maçonnerie(SurfPlan, Desc_Cyl, Desc_Cuv)
        ElseIf Acier = True Then
            rtf.WriteString("Revètement d'étanchéité établi sur éléments porteurs en tôle d'acier nervurée (cf DTU 43.3)") : rtf.NewLine()
            Diam_Acier_Bois(SurfPlan, Desc_Cyl, Desc_Cuv)
        ElseIf Bois = True Then
            rtf.WriteString("Revètement d'étanchéité établi sur éléments porteurs en bois et panneaux dérivés du bois (cf DTU 43.4)") : rtf.NewLine()
            Diam_Acier_Bois(SurfPlan, Desc_Cyl, Desc_Cuv)
        ElseIf Autre = True Then
            rtf.WriteString("Revètement d'étanchéité établi sur éléments porteurs ne répondant pas aux critères des DTU 43.3 et 43.4 (éléments porteurs en tôle d'acier nervurée ou en bois et panneaux dérivés du bois)") : rtf.NewLine()
            rtf.WriteString("ou revètement d'étanchéité ne répondant pas aux critères du revètement d'étanchéité sur toiture non accessible établie sur éléments porteurs en maçonnerie ( type A,B, C ou D suivant DTU 20.12)") : rtf.NewLine()
            Diam_Autre(SurfPlan, Desc_Cyl, Desc_Cuv)
        End If
        rtf.NewLine()
        rtf.WriteString("Entrée d'eau avec moignon cylindrique - diamètre minimal du tuyau d'évacuation ou du moignon: " & Desc_Cyl.ToString("#") & " mm") : rtf.NewLine() : rtf.NewLine()
        rtf.WriteString("Entrée d'eau avec moignon tronconique - diamètre minimal: " & Desc_Cuv.ToString("#") & " mm") : rtf.NewLine() : rtf.NewLine()
        Try
            ' Create Image Element
            Dim myImage As Image
            myImage = Image.FromFile(Directory.GetCurrentDirectory.ToString() & "\Images\Entrée tronconique.png")
            rtf.InsertImage(myImage)
        Catch ex As Exception
            msg = "Le logiciel n'a pas pu chargé l'image correspondante." & Environment.NewLine & "Erreur: " & ex.Message & ex.StackTrace & Environment.NewLine & "Note de calcul sans image"
            MsgBox(msg, MsgBoxStyle.Exclamation Or MsgBoxStyle.OkOnly, "Logiciel EF_ECS")
        End Try
        rtf.NewLine()
        rtf.WriteString("D : " & (2 * Desc_Cuv).ToString) : rtf.NewLine()
        rtf.WriteString("d : " & Desc_Cuv.ToString) : rtf.NewLine()
        rtf.WriteString("h : " & Fix(1.5 * Desc_Cuv).ToString) : rtf.NewLine()
        If Desc_Cuv < 80 Or Desc_Cyl < 80 Then
            rtf.NewLine() : rtf.WriteString("Attention:") : rtf.NewLine()
            rtf.WriteString("Les diamètres de 60 et 70 mm ne sont autorisés que pour les balcons et logias (cf DTU 43.1).") : rtf.NewLine()
        End If
        'génère le RTF complet
        note_de_calcul = "Ndc_EP_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
        rtf.Generate() : rtff = sw.ToString : File.WriteAllText(Aff.msgResult & "\" & note_de_calcul, rtff)
    End Sub
    Private Sub Diam_Maçonnerie(ByVal SurfPlan As Double, ByRef Desc_Cyl As Integer, ByRef Desc_Cuv As Integer)
        Select Case SurfPlan
            Case Is <= 71
                Desc_Cyl = 80 : Desc_Cuv = 80
            Case Is <= 91
                Desc_Cyl = 90 : Desc_Cuv = 90
            Case Is <= 113
                Desc_Cyl = 100 : Desc_Cuv = 100
            Case Is <= 136
                Desc_Cyl = 110 : Desc_Cuv = 110
            Case Is <= 161
                Desc_Cyl = 120 : Desc_Cuv = 120
            Case Is <= 190
                Desc_Cyl = 130 : Desc_Cuv = 130
            Case Is <= 220
                Desc_Cyl = 140 : Desc_Cuv = 140
            Case Is <= 253
                Desc_Cyl = 150 : Desc_Cuv = 150
            Case Is <= 287
                Desc_Cyl = 160 : Desc_Cuv = 160
            Case Is <= 314
                Desc_Cyl = 200 : Desc_Cuv = 170
            Case Is <= 324
                Desc_Cyl = 210 : Desc_Cuv = 170
            Case Is <= 346
                Desc_Cyl = 210 : Desc_Cuv = 180
            Case Is <= 363
                Desc_Cyl = 220 : Desc_Cuv = 180
            Case Is <= 380
                Desc_Cyl = 220 : Desc_Cuv = 190
            Case Is <= 406
                Desc_Cyl = 230 : Desc_Cuv = 190
            Case Is <= 415
                Desc_Cyl = 230 : Desc_Cuv = 200
            Case Is <= 449
                Desc_Cyl = 240 : Desc_Cuv = 200
            Case Is <= 452
                Desc_Cyl = 240 : Desc_Cuv = 210
            Case Is <= 490
                Desc_Cyl = 250 : Desc_Cuv = 210
            Case Is <= 494
                Desc_Cyl = 260 : Desc_Cuv = 210
            Case Is <= 530
                Desc_Cyl = 260 : Desc_Cuv = 220
            Case Is <= 543
                Desc_Cyl = 270 : Desc_Cuv = 220
            Case Is <= 570
                Desc_Cyl = 270 : Desc_Cuv = 230
            Case Is <= 593
                Desc_Cyl = 280 : Desc_Cuv = 230
            Case Is <= 615
                Desc_Cyl = 280 : Desc_Cuv = 240
            Case Is <= 646
                Desc_Cyl = 290 : Desc_Cuv = 240
            Case Is <= 660
                Desc_Cyl = 290 : Desc_Cuv = 250
            Case Is <= 700
                Desc_Cyl = 300 : Desc_Cuv = 250
            Case Is <= 755
                Desc_Cyl = 310 : Desc_Cuv = 260
            Case Is <= 758
                Desc_Cyl = 320 : Desc_Cuv = 260
            Case Is <= 805
                Desc_Cyl = 320 : Desc_Cuv = 270
            Case Is <= 815
                Desc_Cyl = 330 : Desc_Cuv = 270
            Case Is <= 855
                Desc_Cyl = 330 : Desc_Cuv = 280
            Case Is <= 880
                Desc_Cyl = 340 : Desc_Cuv = 280
            Case Is <= 908
                Desc_Cyl = 340 : Desc_Cuv = 290
            Case Is <= 945
                Desc_Cyl = 350 : Desc_Cuv = 290
            Case Is <= 960
                Desc_Cyl = 350 : Desc_Cuv = 300
            Case Is <= 1000
                Desc_Cyl = 360 : Desc_Cuv = 300
        End Select
    End Sub
    Private Sub Diam_Autre(ByVal SurfPlan As Double, ByRef Desc_Cyl As Integer, ByRef Desc_Cuv As Integer)
        Select Case SurfPlan
            Case Is <= 28
                Desc_Cyl = 60 : Desc_Cuv = 60
            Case Is <= 38
                Desc_Cyl = 70 : Desc_Cuv = 60
            Case Is <= 40
                Desc_Cyl = 80 : Desc_Cuv = 60
            Case Is <= 50
                Desc_Cyl = 80 : Desc_Cuv = 70
            Case Is <= 55
                Desc_Cyl = 90 : Desc_Cuv = 70
            Case Is <= 64
                Desc_Cyl = 90 : Desc_Cuv = 80
            Case Is <= 71
                Desc_Cyl = 100 : Desc_Cuv = 80
            Case Is <= 79
                Desc_Cyl = 100 : Desc_Cuv = 90
            Case Is <= 91
                Desc_Cyl = 110 : Desc_Cuv = 90
            Case Is <= 95
                Desc_Cyl = 110 : Desc_Cuv = 100
            Case Is <= 113
                Desc_Cyl = 120 : Desc_Cuv = 100
            Case Is <= 133
                Desc_Cyl = 130 : Desc_Cuv = 110
            Case Is <= 136
                Desc_Cyl = 140 : Desc_Cuv = 110
            Case Is <= 154
                Desc_Cyl = 140 : Desc_Cuv = 120
            Case Is <= 161
                Desc_Cyl = 150 : Desc_Cuv = 120
            Case Is <= 177
                Desc_Cyl = 150 : Desc_Cuv = 130
            Case Is <= 190
                Desc_Cyl = 160 : Desc_Cuv = 130
            Case Is <= 201
                Desc_Cyl = 160 : Desc_Cuv = 140
            Case Is <= 220
                Desc_Cyl = 170 : Desc_Cuv = 140
            Case Is <= 227
                Desc_Cyl = 170 : Desc_Cuv = 150
            Case Is <= 253
                Desc_Cyl = 180 : Desc_Cuv = 150
            Case Is <= 254
                Desc_Cyl = 180 : Desc_Cuv = 160
            Case Is <= 284
                Desc_Cyl = 190 : Desc_Cuv = 160
            Case Is <= 287
                Desc_Cyl = 200 : Desc_Cuv = 160
            Case Is <= 314
                Desc_Cyl = 200 : Desc_Cuv = 170
            Case Is <= 324
                Desc_Cyl = 210 : Desc_Cuv = 170
            Case Is <= 346
                Desc_Cyl = 210 : Desc_Cuv = 180
            Case Is <= 363
                Desc_Cyl = 220 : Desc_Cuv = 180
            Case Is <= 380
                Desc_Cyl = 220 : Desc_Cuv = 190
            Case Is <= 406
                Desc_Cyl = 230 : Desc_Cuv = 190
            Case Is <= 415
                Desc_Cyl = 230 : Desc_Cuv = 200
            Case Is <= 449
                Desc_Cyl = 240 : Desc_Cuv = 200
            Case Is <= 452
                Desc_Cyl = 240 : Desc_Cuv = 210
            Case Is <= 490
                Desc_Cyl = 250 : Desc_Cuv = 210
            Case Is <= 494
                Desc_Cyl = 260 : Desc_Cuv = 210
            Case Is <= 530
                Desc_Cyl = 260 : Desc_Cuv = 220
            Case Is <= 543
                Desc_Cyl = 270 : Desc_Cuv = 220
            Case Is <= 570
                Desc_Cyl = 270 : Desc_Cuv = 230
            Case Is <= 593
                Desc_Cyl = 280 : Desc_Cuv = 230
            Case Is <= 615
                Desc_Cyl = 280 : Desc_Cuv = 240
            Case Is <= 646
                Desc_Cyl = 290 : Desc_Cuv = 240
            Case Is <= 660
                Desc_Cyl = 290 : Desc_Cuv = 250
            Case Is <= 700
                Desc_Cyl = 300 : Desc_Cuv = 250
            Case Is <= 755
                Desc_Cyl = 310 : Desc_Cuv = 260
            Case Is <= 758
                Desc_Cyl = 320 : Desc_Cuv = 260
            Case Is <= 805
                Desc_Cyl = 320 : Desc_Cuv = 270
            Case Is <= 815
                Desc_Cyl = 330 : Desc_Cuv = 270
            Case Is <= 855
                Desc_Cyl = 330 : Desc_Cuv = 280
            Case Is <= 880
                Desc_Cyl = 340 : Desc_Cuv = 280
            Case Is <= 908
                Desc_Cyl = 340 : Desc_Cuv = 290
            Case Is <= 945
                Desc_Cyl = 350 : Desc_Cuv = 290
            Case Is <= 960
                Desc_Cyl = 350 : Desc_Cuv = 300
            Case Is <= 1000
                Desc_Cyl = 360 : Desc_Cuv = 300
        End Select
    End Sub
    Private Sub Diam_Acier_Bois(ByVal SurfPlan As Double, ByRef Desc_Cyl As Integer, ByRef Desc_Cuv As Integer)
        Select Case SurfPlan
            Case Is <= 33
                Desc_Cyl = 80 : Desc_Cuv = 70
            Case Is <= 37
                Desc_Cyl = 90 : Desc_Cuv = 70
            Case Is <= 43
                Desc_Cyl = 90 : Desc_Cuv = 80
            Case Is <= 47
                Desc_Cyl = 100 : Desc_Cuv = 80
            Case Is <= 53
                Desc_Cyl = 100 : Desc_Cuv = 90
            Case Is <= 61
                Desc_Cyl = 110 : Desc_Cuv = 90
            Case Is <= 63
                Desc_Cyl = 110 : Desc_Cuv = 90
            Case Is <= 75
                Desc_Cyl = 120 : Desc_Cuv = 100
            Case Is <= 88
                Desc_Cyl = 130 : Desc_Cuv = 110
            Case Is <= 91
                Desc_Cyl = 140 : Desc_Cuv = 110
            Case Is <= 103
                Desc_Cyl = 140 : Desc_Cuv = 120
            Case Is <= 107
                Desc_Cyl = 150 : Desc_Cuv = 120
            Case Is <= 118
                Desc_Cyl = 150 : Desc_Cuv = 130
            Case Is <= 127
                Desc_Cyl = 160 : Desc_Cuv = 130
            Case Is <= 134
                Desc_Cyl = 160 : Desc_Cuv = 140
            Case Is <= 147
                Desc_Cyl = 170 : Desc_Cuv = 140
            Case Is <= 151
                Desc_Cyl = 170 : Desc_Cuv = 150
            Case Is <= 168
                Desc_Cyl = 180 : Desc_Cuv = 150
            Case Is <= 169
                Desc_Cyl = 180 : Desc_Cuv = 160
            Case Is <= 189
                Desc_Cyl = 190 : Desc_Cuv = 160
            Case Is <= 191
                Desc_Cyl = 200 : Desc_Cuv = 160
            Case Is <= 209
                Desc_Cyl = 200 : Desc_Cuv = 170
            Case Is <= 216
                Desc_Cyl = 210 : Desc_Cuv = 170
            Case Is <= 230
                Desc_Cyl = 210 : Desc_Cuv = 180
            Case Is <= 242
                Desc_Cyl = 220 : Desc_Cuv = 180
            Case Is <= 253
                Desc_Cyl = 220 : Desc_Cuv = 190
            Case Is <= 270
                Desc_Cyl = 230 : Desc_Cuv = 190
            Case Is <= 277
                Desc_Cyl = 230 : Desc_Cuv = 200
            Case Is <= 300
                Desc_Cyl = 240 : Desc_Cuv = 200
            Case Is <= 302
                Desc_Cyl = 240 : Desc_Cuv = 210
            Case Is <= 327
                Desc_Cyl = 250 : Desc_Cuv = 210
            Case Is <= 329
                Desc_Cyl = 260 : Desc_Cuv = 210
            Case Is <= 362
                Desc_Cyl = 260 : Desc_Cuv = 220
            Case Is <= 394
                Desc_Cyl = 260 : Desc_Cuv = 230
            Case Is <= 400
                Desc_Cyl = 260 : Desc_Cuv = 240
            Case Is <= 466
                Desc_Cyl = 270 : Desc_Cuv = 250
            Case Is <= 472
                Desc_Cyl = 270 : Desc_Cuv = 260
            Case Is <= 550
                Desc_Cyl = 280 : Desc_Cuv = 260
            Case Is <= 570
                Desc_Cyl = 290 : Desc_Cuv = 260
            Case Is <= 625
                Desc_Cyl = 290 : Desc_Cuv = 270
            Case Is <= 680
                Desc_Cyl = 300 : Desc_Cuv = 270
            Case Is <= 700
                Desc_Cyl = 300 : Desc_Cuv = 280
            Case Is <= 755
                Desc_Cyl = 310 : Desc_Cuv = 280
            Case Is <= 785
                Desc_Cyl = 320 : Desc_Cuv = 280
            Case Is <= 805
                Desc_Cyl = 320 : Desc_Cuv = 290
            Case Is <= 855
                Desc_Cyl = 330 : Desc_Cuv = 290
            Case Is <= 890
                Desc_Cyl = 340 : Desc_Cuv = 290
            Case Is <= 908
                Desc_Cyl = 340 : Desc_Cuv = 300
            Case Is <= 960
                Desc_Cyl = 350 : Desc_Cuv = 300
            Case Is <= 1000
                Desc_Cyl = 360 : Desc_Cuv = 300
        End Select
    End Sub
    Public Sub Calcul_Regroup_Descente(ByVal SurfPlan As Double, ByVal SurfBrute As Double, ByVal PenteCouv As Double, ByVal Etancheite As Boolean, ByRef Desc_Cyl As Integer,
                                       ByRef Debit As Double, ByVal Editeur As Boolean, ByRef note_de_calcul As String, ByRef Verif As Boolean)
        'dimensionnement de la section de regroupement des descentes EP suivant DTU 60.11 partie 2 §3.1
        Dim msg As String
        'writer de sortie du RTF
        Dim sw As New System.IO.StringWriter
        'crée un writer de RTF avec une police par défaut
        Dim rtf As New To_Rtf.RtfAnsiTextWriter(sw, New Font(FontFamily.GenericSerif, 12, FontStyle.Regular))
        Dim rtff As String
        rtf.Bold = True : rtf.FontSize = 16 : rtf.Underline = True
        rtf.WriteString("Note de calcul de dimensionnement de regroupement des descentes EP")
        rtf.NewLine()
        rtf.Bold = False : rtf.FontSize = 10 : rtf.Underline = False : rtf.NewParagraph()
        rtf.WriteString("Note de calcul du : ") : msg = Mise_en_Forme(CStr(DateTime.Now)) : rtf.WriteString(msg) : rtf.NewLine()
        rtf.WriteString("Rédacteur : " & Aff.Redacteur) : rtf.NewLine()
        rtf.WriteString("Chantier : " & Aff.Chantier) : rtf.NewLine()
        rtf.WriteString("Logiciel : Calculette Plomberie version " & My.Application.Info.Version.ToString) : rtf.NewLine()
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("1 - Rappel des hypothèses") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        rtf.WriteString("Code de calculs: suivant chapitre 5 - Partie II - DTU 60.11 - Octobre 1988") : rtf.NewLine()
        If Etancheite = False Then
            rtf.WriteString("Couverture ne comportant pas un revètement d'étanchéité") : rtf.NewLine()
        Else
            rtf.WriteString("Couverture comportant un revètement d'étanchéité") : rtf.NewLine()
        End If
        If SurfPlan < 1 Then
            rtf.WriteString("Surface toiture: " & SurfBrute.ToString("#,##0.0") & " m²") : rtf.NewLine()
            rtf.WriteString("Pente de la toiture: " & (Tan(PenteCouv) * 100).ToString("#0.0") & " %") : rtf.NewLine()
            SurfPlan = SurfBrute * Cos(PenteCouv)
        End If
        rtf.WriteString("Surface plan: " & SurfPlan.ToString("#,##0.0") & " m²") : rtf.NewLine() : rtf.NewLine()
        If SurfPlan > 1000 Then
            rtf.WriteString("Le code de calcul DTU 60.11 d'octobre 1988 n'autorise pas une surface plane supérieure à 1000 m². La suite du calcul sera établie pour une surface " &
                            "plane de 1000 m².") : rtf.NewLine() : rtf.NewLine()
            SurfPlan = 1000
        End If
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("2 - Diamètre intérieur du tuyau de descente") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        Debit = SurfPlan * 3  '  L/mn 
        Select Case Etancheite
            Case True
                Diam_Acier_Bois(SurfPlan, Desc_Cyl, 0)
            Case False
                Diam_SU_5(Debit, Desc_Cyl)
        End Select
        rtf.WriteString("Diamètre intérieur : " & Desc_Cyl.ToString("#,##0") & " mm") : rtf.NewLine()
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("3 - Débit") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        rtf.WriteString("débit: " & Debit.ToString("#,##0.0") & " L/mn") : rtf.NewLine()
        ' 
        If Editeur = True Then
            'génère le RTF complet et écriture dans le répertoire
            note_de_calcul = "Ndc_EP_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
            rtf.Generate() : rtff = sw.ToString : File.WriteAllText(Aff.msgResult & "\" & note_de_calcul, rtff)
        End If
    End Sub
    Private Sub Diam_SU_5(ByVal debit As Double, ByRef diam As Integer)
        debit = debit / 60
        Select Case debit
            Case Is < 3.67
                diam = 69
            Case Is < 4.97
                diam = 77
            Case Is < 6.31
                diam = 84
            Case Is < 8.6
                diam = 94
            Case Is < 11.35
                diam = 104
            Case Is < 16.4
                diam = 119
            Case Is < 20.44
                diam = 129
            Case Is < 22.67
                diam = 134
            Case Is < 32.5
                diam = 153
            Case Is < 33.08
                diam = 154
            Case Is < 59.27
                diam = 191
            Case Is < 69.86
                diam = 203
            Case Is < 107.21
                diam = 238
            Case Is < 144.52
                diam = 266
            Case Is < 199.45
                diam = 300
            Case Is < 231.12
                diam = 317
        End Select
    End Sub
    Public Sub Calcul_Collecteur_EP(ByVal SurfPlan As Double, ByVal SurfBrute As Double, ByVal PenteCouv As Double, ByVal Separatif As Boolean, ByVal Pente_Impose As Boolean, ByVal PenteCollecteur As Double,
                                    ByRef Diam_Col() As Double, ByRef Debit As Double, ByRef V_col() As Double, ByVal Editeur As Boolean, ByRef note_de_calcul As String, ByRef Verif As Boolean)
        'dimensionnement de la section du collecteur des descentes EP suivant DTU 60.11 partie 2 §6
        Dim msg As String
        Dim i As Integer
        Dim f_a As Double
        Const ϕ As Double = 1.159279481 'valeur de ϕ   pour un remplissage 7/10
        Const γ As Double = 0.16 'coefficient de frottement = 0.16 suivant DTU
        'writer de sortie du RTF
        Dim sw As New System.IO.StringWriter
        'crée un writer de RTF avec une police par défaut
        Dim rtf As New To_Rtf.RtfAnsiTextWriter(sw, New Font(FontFamily.GenericSerif, 12, FontStyle.Regular))
        Dim rtff As String
        rtf.Bold = True : rtf.FontSize = 16 : rtf.Underline = True
        rtf.WriteString("Note de calcul de dimensionnement du collecteur des descentes EP")
        rtf.NewLine()
        rtf.Bold = False : rtf.FontSize = 10 : rtf.Underline = False : rtf.NewParagraph()
        rtf.WriteString("Note de calcul du : ") : msg = Mise_en_Forme(CStr(DateTime.Now)) : rtf.WriteString(msg) : rtf.NewLine()
        rtf.WriteString("Rédacteur : " & Aff.Redacteur) : rtf.NewLine()
        rtf.WriteString("Chantier : " & Aff.Chantier) : rtf.NewLine()
        rtf.WriteString("Logiciel : Calculette Plomberie version " & My.Application.Info.Version.ToString) : rtf.NewLine()
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("1 - Rappel des hypothèses") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        rtf.WriteString("Code de calculs: suivant chapitre 6 - Partie II - DTU 60.11 - Octobre 1988") : rtf.NewLine()
        If Pente_Impose = False Then
            rtf.WriteString("Pas de pente de collecteur imposée. Le calcul sera établi pour les valeurs 1%, 2%, 3%, 4% et 5% pour permettre de comparer les résultats avec les " &
                            "valeurs du tableau 7 de la partie 1 du DTU 60.11.") : rtf.NewLine()
            PenteCollecteur = 1 'cm/m
        Else
            rtf.WriteString("Pente du collecteur imposée: " & PenteCollecteur.ToString("#0.00") & " cm/m (= %)") : rtf.NewLine()
        End If
        If SurfPlan < 1 And SurfBrute < 1 Then
            'on ne fait rien de particulier
        ElseIf SurfPlan < 1 And SurfBrute > 1 Then
            rtf.WriteString("Surface toiture: " & SurfBrute.ToString("#,##0.0") & " m²") : rtf.NewLine()
            rtf.WriteString("Pente de la toiture: " & (Tan(PenteCouv) * 100).ToString("#0.0") & " %") : rtf.NewLine()
            SurfPlan = SurfBrute * Cos(PenteCouv)
            rtf.WriteString("Surface plan: " & SurfPlan.ToString("#,##0.0") & " m²") : rtf.NewLine()
        Else
            rtf.WriteString("Surface plan: " & SurfPlan.ToString("#,##0.0") & " m²") : rtf.NewLine()
        End If
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("2 - Diamètre intérieur du tuyau du collecteur") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        rtf.WriteString("Calcul établi suivant la formule de Bazin avec tuyau coulant à 7/10 pleins et un coefficient de frottement égal à 0,16.") : rtf.NewLine() : rtf.NewLine()
        If SurfPlan < 1 And SurfBrute < 1 Then
            Debit = Debit / (60 * 1000)  '  L/mn-> m3/s 
        Else
            Debit = (SurfPlan * 3) / (60 * 1000)  '  L/mn-> m3/s 
        End If
        PenteCollecteur = PenteCollecteur / 100 'conversion cm/m en m/m
        If Pente_Impose = True Then
            i = 0
            Call Calcul_Collecteur_Unitaire(γ, PenteCollecteur, ϕ, Debit, Diam_Col(i), f_a, V_col(i)) 'car calcul à 7/10 plein (comme unitaire)
            If f_a < 0 Then
                MessageBox.Show("Défaut dans les données - Exécution arrêtée.", "Calcul collecteur EP", MessageBoxButtons.OK, MessageBoxIcon.Error)
                note_de_calcul = "Ndc_EP_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
                rtf.Generate() : rtff = sw.ToString : File.WriteAllText(Aff.msgResult & "\" & note_de_calcul, rtff)
                Verif = False : Exit Sub
            End If
        Else
            Dim Pente_Col() As Double = {PenteCollecteur, 0.01, 0.02, 0.03, 0.04, 0.05}
            For i = 1 To 5
                Call Calcul_Collecteur_Unitaire(γ, PenteCollecteur, ϕ, Debit, Diam_Col(i), f_a, V_col(i))
                If f_a < 0 Then
                    MessageBox.Show("Défaut dans les données - Exécution arrêtée.", "Calcul collecteur EP", MessageBoxButtons.OK, MessageBoxIcon.Error)
                    note_de_calcul = "Ndc_EP_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
                    rtf.Generate() : rtff = sw.ToString : File.WriteAllText(Aff.msgResult & "\" & note_de_calcul, rtff)
                    Verif = False : Exit Sub
                End If
            Next
        End If

        Debit = Debit * 1000 * 60 : Debit = (Fix(Debit * 10) + 1) / 10 'arrondi au décilitre supérieur, pour le bascler en L/mn
        rtf.NewParagraph()
        rtf.FontSize = 8
        rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Pente (cm/m)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Débit (L/mn)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Diamètre (mm)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Vitesse ecoulement (m/s)") : rtf.EndCell()
        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Tube PVC retenu") : rtf.EndCell() : rtf.EndRow()
        If Pente_Impose = True Then
            rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((PenteCollecteur * 100).ToString("#0.0")) : rtf.EndCell()
            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((Debit).ToString("##0.0")) : rtf.EndCell()
            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((Diam_Col(0)).ToString("##0.0")) : rtf.EndCell()
            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((V_col(0)).ToString("##0.0")) : rtf.EndCell()
            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(libel_diametre_PVC(Diam_Col(0) / 1000)) : rtf.EndCell() : rtf.EndRow()
        Else
            For i = 1 To 5
                rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(i.ToString("#0.0")) : rtf.EndCell()
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((Debit).ToString("##0.0")) : rtf.EndCell()
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((Diam_Col(i)).ToString("##0.0")) : rtf.EndCell()
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((V_col(i)).ToString("##0.0")) : rtf.EndCell()
                rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(libel_diametre_PVC(Diam_Col(i) / 1000)) : rtf.EndCell() : rtf.EndRow()
            Next
        End If
        rtf.WriteString("Le diamètre indiquée est le diamètre minimal pour satisfaire au débit demandé.") : rtf.NewLine()
        rtf.WriteString("La vitesse indiquée est celle correspondant à une tuyauterie au diamètre minimal.") : rtf.NewLine()
        If Editeur = True Then
            'génère le RTF complet et écriture dans le répertoire
            note_de_calcul = "Ndc_EP_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
            rtf.Generate() : rtff = sw.ToString : File.WriteAllText(Aff.msgResult & "\" & note_de_calcul, rtff)
        End If
    End Sub
    Public Sub Calcul_Collecteur_EU(ByVal Nb_lavabo As Integer, ByVal Nb_Baignoire As Integer, ByVal Nb_Douche As Integer, ByVal Nb_WCdirect As Integer, ByVal Nb_WCsiphon As Integer,
                                   ByVal Nb_bidet As Integer, ByVal Nb_Bonde As Integer, ByVal Nb_Bac As Integer, ByVal Nb_Urinoir As Integer, ByVal Nb_urinoirSiphon As Integer,
                                   ByVal Nb_MalLinge As Integer, ByVal Nb_MalVaisselle As Integer, ByVal Nb_Evier As Integer, ByVal Nb_lavaboColl As Integer, ByVal DebEP As Double, ByVal Unitaire As Boolean,
                                   ByVal Pente_Impose As Boolean, ByVal PenteCollecteur As Double,
                                   ByRef Diam_Col() As Double, ByRef Debit As Double, ByRef V_col() As Double, ByVal Editeur As Boolean, ByRef note_de_calcul As String, ByRef Verif As Boolean)
        'dimensionnement de la section du collecteur des descentes EP suivant DTU 60.11 partie 2 §6
        Dim msg As String = String.Empty
        Dim i As Integer
        Dim f_a, Q_deb, Q_debProb, x, y As Double
        Const ϕ As Double = 1.159279481 'valeur de ϕ   pour un remplissage 7/10
        Const γ As Double = 0.16 'coefficient de frottement = 0.16 suivant DTU
        'writer de sortie du RTF
        Dim sw As New System.IO.StringWriter
        'crée un writer de RTF avec une police par défaut
        Dim rtf As New To_Rtf.RtfAnsiTextWriter(sw, New Font(FontFamily.GenericSerif, 12, FontStyle.Regular))
        Dim rtff As String
        rtf.Bold = True : rtf.FontSize = 16 : rtf.Underline = True
        If Unitaire = False Then
            rtf.WriteString("Note de calcul de dimensionnement du collecteur des évacuations EU/EV")
        Else
            rtf.WriteString("Note de calcul de dimensionnement du collecteur des évacuations EU/EV/EP")
        End If

        rtf.NewLine()
        rtf.Bold = False : rtf.FontSize = 10 : rtf.Underline = False : rtf.NewParagraph()
        rtf.WriteString("Note de calcul du : ") : msg = Mise_en_Forme(CStr(DateTime.Now)) : rtf.WriteString(msg) : rtf.NewLine()
        rtf.WriteString("Rédacteur : " & Aff.Redacteur) : rtf.NewLine()
        rtf.WriteString("Chantier : " & Aff.Chantier) : rtf.NewLine()
        rtf.WriteString("Logiciel : Calculette Plomberie version " & My.Application.Info.Version.ToString) : rtf.NewLine()
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("1 - Rappel des hypothèses") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        rtf.WriteString("Code de calculs: suivant chapitre 3,3 - Partie I - DTU 60.11 - Octobre 1988") : rtf.NewLine() : rtf.NewLine()
        If Pente_Impose = False Then
            Dim Val_tab As Integer
            If Unitaire = False Then Val_tab = 6 Else Val_tab = 7
            rtf.WriteString("Pas de pente de collecteur imposée. Le calcul sera établi pour les valeurs 1%, 2%, 3%, 4% et 5% pour permettre de comparer les résultats avec les " &
                            "valeurs du tableau " & Val_tab.ToString & " de la partie 1 du DTU 60.11.") : rtf.NewLine()
            PenteCollecteur = 1 'cm/m
        Else
            rtf.WriteString("Pente du collecteur imposée: " & PenteCollecteur.ToString("#0.00") & " cm/m (= %)") : rtf.NewLine()
        End If
        rtf.NewLine()
        If Unitaire = False Then
            rtf.WriteString("Collecteur faisant partie d'un système séparatif:") : rtf.NewLine()
            rtf.WriteString(" - Calcul établi suivant la formule de Bazin") : rtf.NewLine()
            rtf.WriteString(" - coefficient de frottement = 0,16") : rtf.NewLine()
            rtf.WriteString(" - Hauteur d'eau maximale normale dans le collecteur = moitié du diamètre") : rtf.NewLine()
        Else
            rtf.WriteString("Collecteur faisant partie d'un système unitaire:") : rtf.NewLine()
            rtf.WriteString(" - Calcul établi suivant la formule de Bazin") : rtf.NewLine()
            rtf.WriteString(" - coefficient de frottement = 0,16") : rtf.NewLine()
            rtf.WriteString(" - Hauteur d'eau maximale normale dans le collecteur = 7/10 du diamètre") : rtf.NewLine()
            rtf.WriteString(" - Prise en compte de l'évacuation des euax pluviales: débit supplémantaire = " & (DebEP).ToString("##0.0")) : rtf.NewLine()
        End If
        rtf.NewLine()
        rtf.WriteString("Appareils évacués:") : rtf.NewLine()
        Q_deb = 0 : x = 0
        If Nb_lavabo > 0.5 Then rtf.WriteString(" - lavabo: " & Nb_lavabo.ToString("#")) : rtf.NewLine() : Q_deb = Nb_lavabo * 0.75 / 1000 : x = Nb_lavabo
        If Nb_Baignoire > 0.5 Then rtf.WriteString(" - baignoire: " & Nb_Baignoire.ToString("#")) : rtf.NewLine() : Q_deb = Q_deb + Nb_Baignoire * 1.2 / 1000 : x = x + Nb_Baignoire
        If Nb_Douche > 0.5 Then rtf.WriteString(" - douche: " & Nb_Douche.ToString("#")) : rtf.NewLine() : Q_deb = Q_deb + Nb_Douche * 0.5 / 1000 : x = x + Nb_Douche
        If Nb_WCdirect > 0.5 Then rtf.WriteString(" - WC à chasse directe: " & Nb_WCdirect.ToString("#")) : rtf.NewLine() : Q_deb = Q_deb + Nb_WCdirect * 1.5 / 1000 : x = x + Nb_WCdirect
        If Nb_WCsiphon > 0.5 Then rtf.WriteString(" - WC à action siphonique: " & Nb_WCsiphon.ToString("#")) : rtf.NewLine() : Q_deb = Q_deb + Nb_WCsiphon * 1.5 / 1000 : x = x + Nb_WCsiphon
        If Nb_bidet > 0.5 Then rtf.WriteString(" - bidet: " & Nb_bidet.ToString("#")) : rtf.NewLine() : Q_deb = Q_deb + Nb_bidet * 0.5 / 1000 : x = x + Nb_bidet
        If Nb_Bonde > 0.5 Then rtf.WriteString(" - appareil avec bonde à grille: " & Nb_Bonde.ToString("#")) : rtf.NewLine() : Q_deb = Q_deb + Nb_Bonde * 0.5 / 1000 : x = x + Nb_Bonde
        If Nb_Bac > 0.5 Then rtf.WriteString(" - bac à laver: " & Nb_Bac.ToString("#")) : rtf.NewLine() : Q_deb = Q_deb + Nb_Bac * 0.75 / 1000 : x = x + Nb_Bac
        If Nb_Urinoir > 0.5 Then rtf.WriteString(" - urinoir - timbre d'office : " & Nb_Urinoir.ToString("#")) : rtf.NewLine() : Q_deb = Q_deb + Nb_Urinoir * 0.5 / 1000 : x = x + Nb_Urinoir
        If Nb_urinoirSiphon > 0.5 Then rtf.WriteString(" - urinoir à action siphonique: " & Nb_urinoirSiphon.ToString("#")) : rtf.NewLine() : Q_deb = Q_deb + Nb_urinoirSiphon * 1 / 1000 : x = x + Nb_urinoirSiphon
        If Nb_MalLinge > 0.5 Then rtf.WriteString(" - machine à laver le linge (domestique): " & Nb_MalLinge.ToString("#")) : rtf.NewLine() : Q_deb = Q_deb + Nb_MalLinge * 0.65 / 1000 : x = x + Nb_MalLinge
        If Nb_MalVaisselle > 0.5 Then rtf.WriteString(" - machine à laver la vaisselle (domestique): " & Nb_MalVaisselle.ToString("#")) : rtf.NewLine() : Q_deb = Q_deb + Nb_MalVaisselle * 0.4 / 1000 : x = x + Nb_MalVaisselle
        If Nb_Evier > 0.5 Then rtf.WriteString(" - évier: " & Nb_Evier.ToString("#")) : rtf.NewLine() : Q_deb = Q_deb + Nb_Evier * 0.75 / 1000 : x = x + Nb_Evier
        If Nb_lavaboColl > 0.5 Then rtf.WriteString(" - lavabo collectif (par jet): " & Nb_lavaboColl.ToString("#")) : rtf.NewLine() : Q_deb = Q_deb + Nb_lavaboColl * 0.05 / 1000 : x = x + Nb_lavaboColl

        rtf.WriteString("Somme des débits individuels: " & (Q_deb * 1000).ToString("#,##0.00") & " L/s") : rtf.NewLine()
        rtf.WriteString("Nombre total d'appareils évacués: " & x.ToString("#")) : rtf.NewLine()
        If x <= 1 Then
            MessageBox.Show("Erreur: nombre total d'appareils <= 1", "Module Calcul_Collecteur_EU", MessageBoxButtons.OK, MessageBoxIcon.Error)
            Exit Sub
        End If
        rtf.WriteString("Coefficient correcteur de réseau: " & Reseau.Ycoef.ToString("#")) : rtf.NewLine()
        y = Reseau.Ycoef * 0.8 / (x - 1) ^ 0.5
        rtf.WriteString("Coefficient de simultanéité y: " & y.ToString("0.000")) : rtf.NewLine()
        Q_debProb = Q_deb * y
        rtf.WriteString("Débit probable: " & (Q_debProb * 1000).ToString("#,##0.00") & " L/s") : rtf.NewLine()
        rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        rtf.WriteString("2 - Diamètre intérieur du tuyau du collecteur") : rtf.Bold = False
        rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        If Unitaire = False Then
            Debit = Q_debProb
            rtf.WriteString("Système séparatif") : rtf.NewLine()
            rtf.WriteString("Débit à évacuer = " & (Debit * 1000).ToString("##0.00") & " L/s") : rtf.NewLine()
        Else
            Debit = Q_debProb + DebEP
            rtf.WriteString("Système unitaire") : rtf.NewLine()
            rtf.WriteString("Débit à évacuer = " & (Debit * 1000).ToString("##0.00") & " L/s") : rtf.NewLine()
        End If

        PenteCollecteur = PenteCollecteur / 100 'conversion cm/m en m/m
        If Unitaire = True Then
            If Pente_Impose = True Then
                i = 0
                Call Calcul_Collecteur_Unitaire(γ, PenteCollecteur, ϕ, Debit, Diam_Col(i), f_a, V_col(i))
                If f_a < 0 Then
                    MessageBox.Show("Défaut dans les données - Exécution arrêtée.", "Calcul collecteur EU/EV/EP unitaire", MessageBoxButtons.OK, MessageBoxIcon.Error)
                    note_de_calcul = "Ndc_EU_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
                    rtf.Generate() : rtff = sw.ToString : File.WriteAllText(Aff.msgResult & "\" & note_de_calcul, rtff)
                    Verif = False : Exit Sub
                End If
            Else
                Dim Pente_Col() As Double = {PenteCollecteur, 0.01, 0.02, 0.03, 0.04, 0.05}
                For i = 1 To 5
                    Call Calcul_Collecteur_Unitaire(γ, PenteCollecteur, ϕ, Debit, Diam_Col(i), f_a, V_col(i))
                    If f_a < 0 Then
                        MessageBox.Show("Défaut dans les données - Exécution arrêtée.", "Calcul collecteur EU/EV unitaire", MessageBoxButtons.OK, MessageBoxIcon.Error)
                        note_de_calcul = "Ndc_EU_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
                        rtf.Generate() : rtff = sw.ToString : File.WriteAllText(Aff.msgResult & "\" & note_de_calcul, rtff)
                        Verif = False : Exit Sub
                    End If
                Next
            End If

        Else
            If Pente_Impose = True Then
                i = 0
                Call Calcul_Collecteur_Separatif(γ, PenteCollecteur, Debit, Diam_Col(i), f_a, V_col(i))
                If f_a < 0 Then
                    MessageBox.Show("Défaut dans les données - Exécution arrêtée.", "Calcul collecteur EU/EV séparatif", MessageBoxButtons.OK, MessageBoxIcon.Error)
                    note_de_calcul = "Ndc_EU_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
                    rtf.Generate() : rtff = sw.ToString : File.WriteAllText(Aff.msgResult & "\" & note_de_calcul, rtff)
                    Verif = False : Exit Sub
                End If
            Else
                Dim Pente_Col() As Double = {PenteCollecteur, 0.01, 0.02, 0.03, 0.04, 0.05}
                For i = 1 To 5
                    Call Calcul_Collecteur_Separatif(γ, Pente_Col(i), Debit, Diam_Col(i), f_a, V_col(i))
                    If f_a < 0 Then
                        MessageBox.Show("Défaut dans les données - Exécution arrêtée.", "Calcul collecteur EU/EV séparatif", MessageBoxButtons.OK, MessageBoxIcon.Error)
                        note_de_calcul = "Ndc_EU_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
                        rtf.Generate() : rtff = sw.ToString : File.WriteAllText(Aff.msgResult & "\" & note_de_calcul, rtff)
                        Verif = False : Exit Sub
                    End If
                Next
            End If

        End If
        Debit = Debit * 1000 ': Debit = (Fix(Debit * 10) + 1) / 10 'arrondi au décilitre supérieur
        rtf.WriteStartGroup()
        rtf.NewParagraph()
        rtf.FontSize = 10 : rtf.FontSize = 9
        rtf.BeginRow() : rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString("Pente (cm/m)") : rtf.EndCell()
        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString("Débit (L/s)") : rtf.EndCell()
        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString("Diamètre (mm)") : rtf.EndCell()
        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString("Vitesse ecoulement (m/s)") : rtf.EndCell()
        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString("Tube PVC retenu") : rtf.EndCell() : rtf.EndRow()
        If Pente_Impose = True Then

            rtf.BeginRow() : rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString((PenteCollecteur * 100).ToString("#0.0")) : rtf.EndCell()
            rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString((Debit).ToString("##0.00")) : rtf.EndCell()
            rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString((Diam_Col(0) * 1000).ToString("#,###")) : rtf.EndCell()
            rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString((V_col(0)).ToString("##0.00")) : rtf.EndCell()
            rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(libel_diametre_PVC(Diam_Col(0)).ToString) : rtf.EndCell() : rtf.EndRow()

        Else

            For i = 1 To 5
                rtf.BeginRow() : rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(i.ToString("#0.0")) : rtf.EndCell()
                rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString((Debit).ToString("##0.00")) : rtf.EndCell()
                rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString((Diam_Col(i) * 1000).ToString("#,###")) : rtf.EndCell()
                rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString((V_col(i)).ToString("##0.00")) : rtf.EndCell()
                rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(libel_diametre_PVC(Diam_Col(i)).ToString) : rtf.EndCell() : rtf.EndRow()
            Next

        End If
        rtf.WriteEndGroup()
        rtf.WriteStartGroup()
        rtf.NewParagraph()
        rtf.FontSize = 12 : rtf.FontSize = 10
        rtf.WriteString("Le diamètre indiquée est le diamètre minimal pour satisfaire au débit demandé.") : rtf.NewLine()
        rtf.WriteString("La vitesse indiquée est celle correspondant à une tuyauterie au diamètre minimal.") : rtf.NewLine()
        rtf.WriteEndGroup()
        If Editeur = True Then
            'génère le RTF complet et écriture dans le répertoire
            note_de_calcul = Aff.msgResult & "\" & "Ndc_EU_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
            rtf.Generate() : rtff = sw.ToString : File.WriteAllText(note_de_calcul, rtff)
        End If

    End Sub
    '''<summary>Détermination du diamètre minimum du collecteur unitaire</summary>
    ''' <param name="γ">coefficient de frottement pour la formule de bazin</param>
    ''' <param name="PenteCollecteur">pente du collecteur (en m/m)</param>
    ''' <param name="ϕ">vitesse</param>
    ''' <param name="Debit">débit cumulé que doit évacuer le collecteur (en m/s)</param>
    ''' <param name="D2">diamètre théorique minimal du collecteur (en m)</param>
    ''' <param name="f_a">valeur de la dichotomie</param>
    ''' <param name="V_deb">débit calculé sur un coef remplissage 1/2 sur la section diamètre théorique minimale (en m/s)</param>
    Private Sub Calcul_Collecteur_Unitaire(ByVal γ As Double, ByVal PenteCollecteur As Double, ByVal ϕ As Double, ByVal Debit As Double, ByRef D2 As Double, ByRef f_a As Double, ByRef V_deb As Double)
        Dim f_diam, d1, diam, PM, SM, RH As Double

        'Recherche valeur diam par dichotomie
        d1 = 0 : D2 = 0.5
        PM = D2 * (PI - ϕ) 'valeur du PM pour un remplissage 7/10
        SM = D2 ^ 2 * (PI - (2 * ϕ - Sin(2 * ϕ)) / 2) / 4 'valeur duSM pour un remplissage 7/10
        RH = SM / PM 'valeur du RH  
        f_a = 87 * RH * SM * PenteCollecteur ^ 0.5 - Debit * (γ + RH ^ 0.5) 'formule de bazin
        If f_a < 0 Then Exit Sub
        f_a = -γ * Debit
        Do While (D2 - d1) > 0.002
            diam = (d1 + D2) / 2
            PM = diam * (PI - ϕ) 'valeur du PM pour un remplissage 7/10
            SM = diam ^ 2 * (PI - (2 * ϕ - Sin(2 * ϕ)) / 2) / 4 'surface plan occupée par le liquide
            RH = SM / PM 'valeur du RH  
            f_diam = 87 * RH * SM * PenteCollecteur ^ 0.5 - Debit * (γ + RH ^ 0.5)
            If f_a * f_diam < 0 Then D2 = diam Else d1 = diam
        Loop
        D2 = D2 * 1000 + 1 : D2 = Fix(D2) / 1000 ''arrondi au mm supérieur
        SM = diam ^ 2 * (PI - (2 * ϕ - Sin(2 * ϕ)) / 2) / 4 'valeur pour un remplissage 7/10
        V_deb = Debit / SM
        f_a = 1 'pour éviter tout plantage
    End Sub
    '''<summary>Détermination du diamètre minimum du collecteur unitaire</summary>
    ''' <param name="γ">coefficient de frottement pour la formule de bazin</param>
    ''' <param name="PenteCollecteur">pente du collecteur (en m/m)</param>
    ''' <param name="Debit">débit cumulé que doit évacuer le collecteur (en m/s)</param>
    ''' <param name="D2">diamètre théorique minimal du collecteur (en m)</param>
    ''' <param name="f_a">valeur de la dichotomie</param>
    ''' <param name="V_deb">débit calculé sur un coef remplissage 1/2 sur la section diamètre théorique minimale (en m/s)</param>
    Private Sub Calcul_Collecteur_Separatif(ByVal γ As Double, ByVal PenteCollecteur As Double, ByVal Debit As Double, ByRef D2 As Double, ByRef f_a As Double, ByRef V_deb As Double)
        Dim f_diam, d1, diam, SM As Double
        'Recherche valeur diam par dichotomie 
        d1 = 0 : D2 = 1
        f_a = (PI * 87 * PenteCollecteur ^ 0.5 / 32) - (0.5 * Debit) - γ * Debit 'formule de Bazin pour un remplissage 1/2 avec un diamètre de 1m! donne la valeur de départ
        If f_a < 0 Then Exit Sub
        f_a = -γ * Debit
        Do While (D2 - d1) > 0.002
            diam = (d1 + D2) / 2
            f_diam = (PI * 87 * PenteCollecteur ^ 0.5 * diam ^ 3 / 32) - (0.5 * Debit * diam ^ 0.5) - γ * Debit 'formule de Bazin pour un remplissage 1/2, f_diam tend vers 0 si le diamètre correspond au débit (1 équation avec 2 inconnues)
            If f_a * f_diam < 0 Then D2 = diam Else d1 = diam
        Loop
        D2 = D2 * 1000 + 1 : D2 = Fix(D2) / 1000 ''arrondi au mm supérieur
        SM = PI * D2 ^ 2 / 8
        V_deb = Debit / SM 'en m/s
        f_a = 1 'sinon souci logiciel
    End Sub
    Public Function libel_diametre_PVC(ByVal Diam As Double) As String
        Dim i As Integer
        'PVC EU
        For i = 0 To T_PVC.Øint.Count - 1
            If Diam <= T_PVC.Øint(i) Then Exit For
        Next
        libel_diametre_PVC = T_PVC.Nom(i).ToString
    End Function

    Private Sub Poubelle()
        'Public Sub Boucle_ECS(ByVal Total_Noeud As Integer, ByVal N_Collec() As Integer, ByVal Tr_c(,) As Integer, ByVal L_dev(,) As Double, ByVal Pdc(,) As Double,
        '                     ByVal Matiere_Tube(,) As Integer, ByVal Diam(,) As Double, ByVal Calcul_Pth(,) As Integer, ByVal Pth(,) As Double, ByVal ep(,) As Double, ByVal λ(,) As Double,
        '                     ByVal dT(,) As Double, ByVal Total_NoeudBcl As Integer, ByVal N_Col() As Integer, ByVal Tr_col(,) As Integer,
        '                      ByVal L_devCol(,) As Double, ByVal PdcCol(,) As Double, ByVal Matiere_Tubecol(,) As Integer, ByVal diamCol(,) As Double, ByVal Calcul_Pthcol(,) As Integer,
        '                       ByVal epcol(,) As Double, ByVal λcol(,) As Double, ByVal dTCol(,) As Double,
        '                      ByVal Tr_Bcl() As Integer, ByVal Tr_Bcl_amont(,) As Integer, ByVal j_amont() As Integer, ByVal L_devBcl() As Double, ByVal PdcBcl() As Double, ByVal Matiere_TubeBcl() As Integer, ByVal diamBcl() As Double,
        '                    ByVal Calcul_PthBcl() As Integer, ByVal epBcl() As Double, ByVal λBcl() As Double, ByVal dTBcl() As Double,
        '                   ByVal PdcVanne As Double, ByVal PdcPrepECS As Double, ByVal PdcClap As Double, ByVal PositionOrgReglage As Integer,
        '                     ByVal Type_dT As Integer, ByVal TprodECS As Double, ByVal dTBoucle As Double, ByVal DebMin As Double, ByVal Vmin As Double, ByVal Type_Org As Integer,
        '                     ByRef Note_de_Calcul As String, ByRef Verif As Boolean) 'ByVal PthBcl() As Double,ByVal PthCol(,) As Double,
        'Dim i, i1, j, total_Noeud_Ext, N_Ext(1) As Integer ', VdT
        'Dim PthG, PthG1, Qglob, Q_deb(Total_Noeud + Total_NoeudBcl, Total_Noeud + Total_NoeudBcl + 1), Q_col(1), autorite As Double
        'Dim Pdc_Max As Double ', Pth_col(1)dT_col(1),dT1,
        'Dim Branch(Total_Noeud + Total_NoeudBcl, 9) As Integer 'Topologie du réseau
        'Dim Tot_Pth(,) As Double
        'Dim niveau As Integer 'nombre de niveau du réseau ECS
        'Dim Q_Tr(,) As Double 'débit dans chaque tronçon du réseau
        'Dim msg As String
        'Dim Correction As Boolean
        ''réarrangement des variables

        ''writer de sortie du RTF
        'Dim sw As New System.IO.StringWriter
        ''crée un writer de RTF avec une police par défaut
        'Dim rtf As New To_Rtf.RtfAnsiTextWriter(sw, New Font(FontFamily.GenericSerif, 12, FontStyle.Regular))
        'Dim rtff As String
        'rtf.Bold = True : rtf.FontSize = 18 : rtf.Underline = True
        'rtf.WriteString("Dimensionnement de la boucle d'eau chaude sanitaire")
        'rtf.NewLine()
        'rtf.Bold = False : rtf.FontSize = 10 : rtf.Underline = False : rtf.NewParagraph()
        'rtf.WriteString("Note de calcul du : ") : msg = Mise_en_Forme(CStr(DateTime.Now)) : rtf.WriteString(msg) : rtf.NewLine()
        'rtf.WriteString("Rédacteur : " & Aff.Redacteur) : rtf.NewLine()
        'rtf.WriteString("Chantier : " & Aff.Chantier) : rtf.NewLine()
        'rtf.WriteString("Logiciel : Calculette Eau  -  version 1.0  2013 - 2016") : rtf.NewLine()
        'rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        'rtf.WriteString("1 - Rappel des hypothèses") : rtf.Bold = False
        'rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        'rtf.WriteString("Codes de calcul:") : rtf.NewLine()
        'rtf.WriteString("-  débits et coefficients de simultanéité suivant DTU 60.11 d'octobre 1988") : rtf.NewLine()
        'rtf.WriteString("Critères de dimensionnement de la boucle d'eau chaude sanitaire :") : rtf.NewLine()
        'Select Case Type_dT
        '    Case 1 'entre prod et Exut
        '        rtf.WriteString(" - Ecart de température de " & dTBoucle.ToString("##.0") & "°C entre le départ de la production d'eau chaude sanitaire et les exutoires terminaux, en" &
        '                        " extrémité de colonnes.") : rtf.NewLine()
        '    Case 2 'entre prod et retour
        '        rtf.WriteString(" - Ecart de température de " & dTBoucle.ToString("##.0") & "°C entre le départ de la production d'eau chaude sanitaire et le retour de boucle") : rtf.NewLine()
        'End Select
        'Select Case DebMin
        '    Case Is < 10
        '        rtf.WriteString(" - Pas de débit minimal imposé") : rtf.NewLine()
        '    Case 80
        '        rtf.WriteString(" - Débit minimal imposé: 80 L/h") : rtf.NewLine()
        '    Case 120
        '        rtf.WriteString(" - Débit minimal imposé: 120 L/h") : rtf.NewLine()
        '    Case Else
        '        rtf.WriteString(" - Débit minimal imposé: " & DebMin.ToString & " L/h") : rtf.NewLine()
        'End Select
        'Select Case Vmin
        '    Case Is < 0.1
        '        rtf.WriteString(" - Pas de vitesse minimale imposée") : rtf.NewLine()
        '    Case 0.2
        '        rtf.WriteString(" - Vitesse minimale imposée sur retour de boucle : 0,20 m/s") : rtf.NewLine()
        '    Case Else
        '        rtf.WriteString(" - Vitesse minimale imposée sur retour de boucle : " & Vmin.ToString & " m/s") : rtf.NewLine()
        'End Select
        'Select Case Type_Org
        '    Case 1
        '        rtf.WriteString(" - Pas de caractéristique imposée pour les organes de réglage") : rtf.NewLine()
        '    Case 2
        '        rtf.WriteString(" - Distance de passage de particule de 1 mm de diamètre dans organe de réglage") : rtf.NewLine()
        'End Select
        'rtf.WriteString("Température départ production ECS : " & TprodECS.ToString("#.0") & "°C") : rtf.NewLine()
        ''   rtf.WriteString("Température moyenne de calcul : " & (TprodECS - ΔT_ECS).ToString("#.0") & "°C") : rtf.NewLine()
        'rtf.NewLine() : rtf.Bold = True : rtf.Underline = True : rtf.WriteString("Schéma type du réseau") : rtf.NewLine() : rtf.Bold = False : rtf.Underline = False
        'Try
        '    ' Create Image Element
        '    Dim myImage As Image
        '    myImage = Image.FromFile(Directory.GetCurrentDirectory.ToString() & "\Images\schema_Bcl.png")
        '    rtf.InsertImage(myImage)
        'Catch ex As Exception
        '    'msg = "Le logiciel n'a pas pu chargé l'image correspondante." &  Environment.NewLine & "Erreur: " & ex.Message & ex.StackTrace &  Environment.NewLine & "Note de calcul sans image"
        '    'MsgBox(msg, MsgBoxStyle.Exclamation Or MsgBoxStyle.OkOnly, "Logiciel EF_ECS")
        'End Try
        ''Calcul de la perte thermique totale sur l'adduction d'ECS
        'For i = 1 To Total_Noeud
        '    For j = 1 To N_Collec(i)
        '        If Calcul_Pth(i, j) = 2 Then
        '            '     Call Perte_Thermique_Locale(0.2, Matiere_Tube(i, j), Diam(i, j), ep(i, j), λ(i, j), TprodECS, dT(i, j), Pth(i, j))
        '        End If
        '    Next
        'Next
        ''Calcul de la perte thermique totale de la boucle ECS
        'If Type_dT = 2 Then
        '    For i = Total_Noeud + 1 To Total_Noeud + Total_NoeudBcl - 1
        '        For j = 1 To N_Col(i)
        '            Select Case Calcul_Pthcol(i, j)
        '                Case 1
        '                    'calculé directement dans le tableau
        '                Case 2
        '                    '     Call Perte_Thermique_Locale(0.2, Matiere_Tubecol(i, j), diamCol(i, j), epcol(i, j), λcol(i, j), TprodECS, dTCol(i, j), Pth(i, j))
        '            End Select
        '        Next
        '        Select Case Calcul_PthBcl(i)
        '            Case 1
        '                'calculé directement dans le tableau
        '            Case 2
        '                '   Call Perte_Thermique_Locale(0.2, Matiere_TubeBcl(i), diamBcl(i), epBcl(i), λBcl(i), TprodECS, dTBcl(i), Pth(i, 0))
        '        End Select
        '    Next
        'End If
        ''Call Tab_Caractéristiques_Réseau(Total_Noeud, N_Collec, Tr_c, L_dev, Pdc, Matiere_Tube, Diam, Calcul_Pth, Pth, ep, λ, dT, Total_NoeudBcl, N_Col, Tr_col, L_devCol,
        ''                                 PdcCol, Matiere_Tubecol, diamCol, Calcul_Pthcol, epcol, λcol, dTCol, Tr_Bcl, L_devBcl, PdcBcl, Matiere_TubeBcl, diamBcl,
        ''                                 Calcul_PthBcl, epBcl, λBcl, dTBcl, rtf) 'PthBcl,
        'rtf.WriteStartGroup()
        'rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        'rtf.WriteString("2 - Calcul des débits de recyclage") : rtf.Bold = False
        'rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()

        'Call Perte_Thermique_Globale(Type_dT, Total_Noeud, Total_NoeudBcl, N_Collec, N_Col, L_dev, Pth, L_devCol, L_devBcl, PthG)
        'Call Recherche_Noeud_Extremite(Total_Noeud, N_Collec, N_Ext, total_Noeud_Ext, Tr_c, Verif, Total_NoeudBcl, Tr_col)
        'Call Topologie_Reseau(Total_Noeud, N_Collec, N_Ext, total_Noeud_Ext, Branch, Tr_c, Verif, Total_NoeudBcl, Tr_col, N_Col)
        'Call Topologie_Reseau_Bouclage(Total_Noeud, N_Col, N_Collec, N_Ext, total_Noeud_Ext, Tr_Bcl, Tr_Bcl_amont, Total_NoeudBcl, j_amont, Branch, Tr_c, Tr_col)
        'ReDim Q_col(total_Noeud_Ext) ' 'dT_col(total_Noeud_Ext),VdT(total_Noeud_Ext),
        ''  Call Perte_Thermique_Colonne(Total_Noeud, total_Noeud_Ext, N_Ext, L_dev, Pth, Tr_c, noe_br, Pth_col, rtf)
        'Qglob = PthG / (1.16 * dTBoucle)
        'rtf.WriteString("Pertes thermiques totales du réseau: " & PthG.ToString("#,###.0") & " W.") : rtf.NewLine()
        'rtf.WriteString("Débit global du bouclage pour compenser la perte thermique globale: " & Qglob.ToString("#,###.0") & " l/h.") : rtf.NewLine() : rtf.NewLine()
        'rtf.WriteString("Tableau de calcul des débits par colonnes et tronçons") : rtf.NewLine()

        'Select Case Type_dT
        '    Case 1 'entre prod et Exut
        '        'Call Tab_Debit_Recyclage_1(PthG1, Q_deb, noe_br, dTBoucle, Q_col, Pth_col, Total_Noeud, total_Noeud_Ext, N_Ext, N_Collec, Tr_c, L_dev, Pth,
        '        '                           Qglob, rtf) ' dT_col,dT1,
        '    Case 2 'entre prod et retour

        '        Call Cumul_Perte_thermique(Total_Noeud, Total_NoeudBcl, N_Collec, Branch, N_Ext, total_Noeud_Ext, Tr_c, L_dev, Pth, L_devCol, Tr_Bcl_amont, L_devBcl,
        '                                   Tr_col, N_Col, Tot_Pth, niveau)
        '        Call Debit_Pth_Colonne(Total_Noeud, Total_NoeudBcl, N_Collec, N_Ext, total_Noeud_Ext, Tr_c, Tr_col, N_Col, L_dev, Pth, L_devCol, niveau, Qglob, Branch,
        '                               Tot_Pth, Q_Tr)
        '        Correction = False
        '        Call Tab_Debit_Recyclage_2(Total_Noeud, Total_NoeudBcl, total_Noeud_Ext, N_Ext, Tr_c, N_Collec, Tr_col, N_Col, diamCol, L_dev, Pth, Diam, Tr_Bcl_amont,
        '                                   L_devBcl, diamBcl, Qglob, DebMin, Vmin, Q_Tr, Tot_Pth, Q_col, Correction, rtf)
        '        If Correction = True Then Call Correction_Debits(Total_Noeud, Total_NoeudBcl, total_Noeud_Ext, N_Ext, Tr_c, N_Collec, Tr_col, N_Col, niveau,
        '                                                         Branch, Q_col, Tr_Bcl_amont, Q_Tr) 'les débits sont modifiés par les conditions aux limites
        '        If Verif = False Then rtf.WriteEndGroup() : Exit Sub
        'End Select

        'rtf.WriteStartGroup()
        'rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        'rtf.WriteString("3 - Calcul des pertes de charges et de la pompe de bouclage") : rtf.Bold = False
        'rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        'rtf.WriteString("Perte de charge commune à l’ensemble des réseaux (production ECS, clapets, …) : " & (PdcVanne + PdcPrepECS + PdcClap).ToString("#0.0") & " mCE.") : rtf.NewLine() : rtf.NewLine()
        'rtf.WriteEndGroup()
        'Dim Qi(total_Noeud_Ext, 20), Øi(total_Noeud_Ext, 20), Ji(total_Noeud_Ext, 20), Li(total_Noeud_Ext, 20), Vi(total_Noeud_Ext, 20) As Double
        'Dim Pdc_lin(total_Noeud_Ext, 20), Pdc_Sin(total_Noeud_Ext, 20), Pdc_Tot(total_Noeud_Ext) As Double
        'Dim i1_tr(total_Noeud_Ext, 20), i2_tr(total_Noeud_Ext, 20), Ligne_colonne(total_Noeud_Ext), Ligne_colonne1(total_Noeud_Ext) As Integer
        'Pdc_Max = 0
        'For i = 1 To total_Noeud_Ext
        '    Call Pdc_Boucle_ECS(i, N_Ext, Tr_c, Tr_col, N_Collec, N_Col, Q_Tr, Tr_Bcl, Pdc, L_dev, Diam, L_devCol, diamCol, PdcCol, L_devBcl, PdcBcl,
        '                        diamBcl, Tr_Bcl_amont, Total_Noeud + Total_NoeudBcl, Ligne_colonne, Ligne_colonne1, i1_tr, i2_tr, Qi, Øi, Ji, Li, Vi, Pdc_lin, Pdc_Sin, Pdc_Tot)
        '    If Pdc_Tot(i) > Pdc_Max Then Pdc_Max = Pdc_Tot(i)
        '    rtf.WriteStartGroup()
        '    rtf.WriteString("Colonne n°" & i.ToString & " - Noeud d'extrémité de colonne: " & N_Ext(i)) : rtf.NewLine()
        '    rtf.WriteEndGroup()
        '    ' Call Affichage_Tab_Pdc_Colonne(i, Ligne_colonne, Ligne_colonne1, i1_tr, i2_tr, Qi, Øi, Ji, Li, Pdc_lin, Vi, Pdc_Sin, Pdc_Tot, rtf)
        'Next
        'Erase Qi, Øi, Ji, Li, Vi, Pdc_lin, Pdc_Sin 'utile uniquement pour le tableau


        'Dim Kv As Double
        'rtf.NewLine()
        'rtf.WriteString("Caractéristiques requises pour la pompe de bouclage:") : rtf.NewLine()
        ''    Tab_Pompe(Q_Tr(1, 1), Pdc_Max, PdcVanne, PdcPrepECS, PdcClap, rtf)
        'rtf.NewLine()
        'rtf.WriteString("Organes de réglage sur colonnes:") : rtf.NewLine()
        'For i = 1 To total_Noeud_Ext
        '    rtf.NewLine() : rtf.WriteString("- colonne n°" & i.ToString) : rtf.NewLine()
        '    If Pdc_Tot(i) = Pdc_Max Then
        '        'If HMVrd > 0.001 Then
        '        '    rtf.WriteString("  Utilisé uniquement à titre de mesure de débit sur la colonne la plus défavorisée") : rtf.NewLine()
        '        '    rtf.WriteString("  Soit une perte de charge de " & (HMVrd * 1000).ToString("#,###0") & " mmCE pour un débit de " & Q_col(i).ToString("#,##0.0") & " L/h.") : rtf.NewLine()
        '        '    Kv = (Q_col(i) / 1000) / Sqrt((HMVrd) / 10)
        '        '    rtf.WriteString("  Soit une vanne de réglage avec un Kv le plus proche possible de " & Kv.ToString("#,##0.00")) : rtf.NewLine()
        '        '    autorite = HMVrd / (Pdc_Max + HMVrd)
        '        '    If autorite > 0.33 Then msg = " (satisfaisant)" Else msg = " (Insuffisant)"
        '        '    rtf.WriteString("  Autorité de la vanne de réglage sur la valeur de perte de charge demandée: " & autorite.ToString("0.00") & msg) : rtf.NewLine()
        '        'Else
        '        '    rtf.WriteString("  colonne la plus défavorisée - Pas d'organe de réglage suivant les hypothèses retenues") : rtf.NewLine()
        '        'End If
        '    Else
        '        'rtf.WriteString("  A règler sur une valeur de " & (Pdc_Max + HMVrd - Pdc_Tot(i)).ToString("#,##0.00") & " mCE pour un débit de " & Q_col(i).ToString("#,##0.0") & " L/h.") : rtf.NewLine()
        '        'Kv = (Q_col(i) / 1000) / Sqrt((Pdc_Max + HMVrd - Pdc_Tot(i)) / 10)
        '        'rtf.WriteString("  Soit une vanne de réglage avec un Kv le plus proche possible de " & Kv.ToString("#,##0.00")) : rtf.NewLine()
        '        'autorite = (Pdc_Max + HMVrd - Pdc_Tot(i)) / (Pdc_Max + HMVrd)
        '        'If autorite > 0.33 Then msg = " (satisfaisant)" Else msg = " (Insuffisant)"
        '        'rtf.WriteString("  Autorité de la vanne de réglage sur la valeur de perte de charge demandée: " & autorite.ToString("0.00") & msg) : rtf.NewLine()
        '    End If
        '    Dim i2, k As Integer
        '    i2 = Tr_col(N_Ext(i), 0) 'i2 = noeud de la boucle sur lequel se raccorde N_Ext(i)
        '    For k = 1 To N_Col(i2)
        '        If Tr_col(i2, k) = N_Ext(i) Then Exit For
        '    Next
        '    rtf.WriteString("Diamètre intérieur tuyauterie boucle: " & (diamCol(i2, k) * 1000).ToString("#,##0.0") & " mm.") : rtf.NewLine()
        '    Call Determination_Nbre_Tour_Vanne_Reglage(diamCol(i2, k), Kv, rtf)
        'Next
        ''rtf.NewLine() : rtf.WriteString("Les organes de réglage sont à placer sur le retour de boucle de chaque colonne, en partie basse de cette dernière.") : rtf.NewLine() : rtf.NewLine()
        ''rtf.WriteString("Vanne compensatrice:") : rtf.NewLine()
        ''rtf.WriteString("  Elle est réglée pour une valeur minimale de " & (HMVC * 1000).ToString("#,##0") & " mmCE.") : rtf.NewLine()
        ''Kv = (Q_deb(Total_Noeud + Total_NoeudBcl - 1, Total_Noeud + Total_NoeudBcl) / 1000) / Sqrt((HMVrd) / 10)
        ''rtf.WriteString("  Soit une vanne de réglage avec un Kv le plus proche possible de " & Kv.ToString("#,##0.00")) : rtf.NewLine()
        'rtf.WriteEndGroup()
        ''génère le RTF complet
        'Note_de_Calcul = "Ndc_Bcl_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
        ''provisoire !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
        ''Aff.msgResult = Directory.GetParent(Directory.GetCurrentDirectory).ToString()
        'Verif = True
        'rtf.Generate() : rtff = sw.ToString : File.WriteAllText(Aff.msgResult & "\" & Note_de_Calcul, rtff)
        'End Sub
        'Private Function Q_max(ByVal Q1 As Double, ByVal Q2 As Double, ByVal Q3 As Double) As Double
        '    If Q1 > Q2 Then
        '        Q_max = Q1
        '    Else
        '        Q_max = Q2
        '    End If
        '    If Q3 > Q_max Then Q_max = Q3
        'End Function

        'Private Sub Recherche_Noeud_Extremite(ByVal Total_Noeud As Integer, ByVal N_Collec() As Integer, ByRef N_Ext() As Integer, ByRef total_Noeud_Ext As Integer,
        '                                      Optional ByRef Tr_c(,) As Integer = Nothing, Optional ByRef Verif As Boolean = True,
        '                                     Optional ByVal Total_NoeudBcl As Integer = 0, Optional ByVal Tr_col(,) As Integer = Nothing)
        '    Dim i, j As Integer
        '    ReDim N_Ext(1) 'pour la remise à 0
        '    total_Noeud_Ext = 0
        '    For i = 1 To Total_Noeud
        '        If N_Collec(i) = 0 Then
        '            j = j + 1
        '            total_Noeud_Ext = j
        '            ReDim Preserve N_Ext(total_Noeud_Ext)
        '            N_Ext(j) = i
        '        End If
        '    Next
        '    'détermination du noeud suivant à N_Ext = noeud aval à N_Ext
        '    If Total_NoeudBcl = 0 Then Exit Sub
        '    Dim i1, i2 As Integer
        '    For i = 1 To total_Noeud_Ext
        '        i1 = Total_Noeud + 1
        '        Do
        '            For i2 = 1 To 10
        '                If N_Ext(i) = Tr_col(i1, i2) Then 'Tr_col(i1, j) =  nœud amont pour le nœud aval i1 pour le numéro de colonne i2
        '                    Tr_c(N_Ext(i), 1) = i1 : Exit Do
        '                End If
        '            Next
        '            i1 = i1 + 1
        '            If i1 > Total_Noeud + Total_NoeudBcl Then
        '                MsgBox("Erreur modélisation", MsgBoxStyle.Critical Or vbOKOnly, "Module tableau débits")
        '                Verif = False : Exit Sub
        '            End If
        '        Loop
        '    Next
        'End Sub
        'Private Sub Topologie_Reseau(ByVal Total_Noeud As Integer, ByVal N_Collec() As Integer, ByVal N_Ext() As Integer, ByVal total_Noeud_Ext As Integer,
        '                                 ByRef Branch(,) As Integer, Optional ByRef Tr_c(,) As Integer = Nothing, Optional ByRef Verif As Boolean = True, Optional ByVal Total_NoeudBcl As Integer = 0,
        '                             Optional ByVal Tr_col(,) As Integer = Nothing, Optional ByVal N_Col() As Integer = Nothing)
        '    Dim branche, i, j, j1, j2, i1, i2, i3, j3, J4, unite, ind, Niv_branche As Integer 'dizaine, rang, centaine, 

        '    Dim terminal, terminus As Boolean
        '    i = 1 : ind = 1 : i1 = Tr_c(i, 1) : j2 = 1 : Branch(1, 1) = 0
        '    'Détermination du n° de noeud se trouvant sur le collecteur retour boucle ECS sur lequel vient se raccorder le noeud final de la colonne
        '    Call Deter_Noe_Amont_Terminaux(Total_Noeud, Total_NoeudBcl, Tr_col, N_Col, total_Noeud_Ext, N_Ext)

        '    branche = 0
        '    Do
        '        unite = 0 : terminal = False
        '        For j = 1 To N_Collec(i1)
        '            i2 = Tr_c(i1, j)
        '            For j1 = 1 To total_Noeud_Ext
        '                If i2 = N_Ext(j1) Then terminal = True : unite = unite + 1 : Exit For
        '            Next
        '        Next
        '        'aucun noeud suivant n'est un noeud terminal - Plusieurs noeuds = éclatement du réseau
        '        If terminal = False And N_Collec(i1) > 1 Then
        '            Branch(i1, 1) = Niv_branche * 10 + 1
        '            For j = 2 To N_Collec(i1)
        '                Branch(i1, j) = Branch(i1, 1) + 1
        '            Next
        '            'aucun noeud suivant n'est un noeud terminal et 1 seul noeud = même branche mais avec section réduite
        '        ElseIf terminal = False And N_Collec(i1) = 1 Then
        '            Branch(i1, 1) = Niv_branche : terminus = False : ind = 1
        '            'tous les noeuds suivants sont des noeuds terminaux
        '        ElseIf N_Collec(i1) = unite
        '            j3 = 0
        '            For j = 1 To N_Collec(i1)
        '                j3 = j3 + 1
        '                Branch(i1, j) = Niv_branche * 10 + j3
        '                i2 = Tr_c(i1, j)
        '                Branch(i2, 1) = Branch(i1, j)
        '                i3 = Tr_col(i2, 0)
        '                For j1 = 1 To N_Col(i3)
        '                    If Tr_col(i3, j1) = i2 Then
        '                        Branch(i3, j1) = Branch(i2, 1) 'retour de colonne sur le collecteur retour
        '                        Exit For
        '                    End If
        '                Next
        '                branche = branche + 1
        '            Next
        '            terminus = True 'toute la branche a été parcourue

        '        Else
        '            'un ou plusieurs noeuds suivant sont des noeuds terminaux mais continuation du réseau adducteur
        '            J4 = Niv_branche * 10
        '            For j = 1 To N_Collec(i1)
        '                terminus = False
        '                i2 = Tr_c(i1, j)
        '                J4 = J4 + 1
        '                Branch(i1, j) = J4
        '                For j1 = 1 To total_Noeud_Ext
        '                    If i2 = N_Ext(j1) Then
        '                        i2 = Tr_c(i1, j) : terminus = True : branche = branche + 1
        '                        Branch(i2, 1) = Branch(i1, j) 'retour de colonne sur le collecteur retour
        '                        i3 = Tr_col(i2, 0)
        '                        For j2 = 1 To N_Col(i3)
        '                            If Tr_col(i3, j2) = i2 Then Branch(i3, j2) = Branch(i2, 1) : Exit For
        '                        Next
        '                    End If
        '                Next
        '                If terminus = False Then ind = j
        '            Next
        '            terminus = False
        '        End If
        '        If terminus = False Then
        '            'noeud suivant
        '            Niv_branche = Branch(i1, ind)
        '            i1 = Tr_c(i1, ind)
        '        Else
        '            If branche = total_Noeud_Ext Then Exit Sub 'toutes les branches ont été parcourues
        '            'remonter jusqu'à trouver un embranchement 
        '            Do
        '                i1 = Tr_c(i1, 0)
        '            Loop While N_Collec(i1) = 1

        '            Do
        '                For j = 1 To N_Collec(i1)
        '                    i2 = Tr_c(i1, j) : Niv_branche = Branch(i1, j)
        '                    For j1 = 1 To N_Collec(i2)
        '                        If Branch(i2, j1) = 0 Then
        '                            i1 = i2 : ind = j1
        '                            Exit Do
        '                        End If
        '                    Next
        '                Next
        '                i1 = Tr_c(i1, 0)
        '                If i1 = 0 Then
        '                    MessageBox.Show("Pb de modélisation du bouclage", "Bouclage ECS", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
        '                    Verif = False : Exit Sub
        '                End If
        '            Loop While i1 <> 1
        '        End If
        '    Loop While branche < total_Noeud_Ext

        'End Sub
        'Private Sub Deter_Noe_Amont_Terminaux(ByVal Total_Noeud As Integer, ByVal Total_NoeudBcl As Integer, ByVal Tr_col(,) As Integer, ByVal N_Col() As Integer,
        '                                      ByVal total_Noeud_Ext As Integer, ByVal N_Ext() As Integer)
        '    'Détermination du n° de noeud se trouvant sur le collecteur retour boucle ECS sur lequel vient se raccorder le noeud final de la colonne
        '    '= tronçon retour entre noeud terminal colonne et collecteur boucle
        '    Dim i1, i2, j As Integer
        '    i1 = Total_Noeud + 1
        '    Do

        '        For j = 1 To N_Col(i1) 'nbre de retour de colonnes
        '            i2 = Tr_col(i1, j)
        '            For j1 = 1 To total_Noeud_Ext
        '                If i2 = N_Ext(j1) Then
        '                    Tr_col(i2, 0) = i1
        '                    Exit For
        '                End If
        '            Next
        '        Next

        '        i1 = i1 + 1
        '    Loop While i1 < Total_Noeud + Total_NoeudBcl
        'End Sub
        'Private Sub Topologie_Reseau_Bouclage(ByVal Total_Noeud As Integer, ByVal N_Col() As Integer, ByVal N_Collec() As Integer, ByVal N_Ext() As Integer,
        '                                      ByVal total_Noeud_Ext As Integer, ByVal Tr_Bcl() As Integer, ByVal Tr_Bcl_amont(,) As Integer, ByVal Total_NoeudBcl As Integer,
        '                                       ByVal j_amont() As Integer, ByRef Branch(,) As Integer,
        '                                     Optional ByVal Tr_c(,) As Integer = Nothing, Optional ByVal Tr_col(,) As Integer = Nothing,
        '                                      Optional ByRef Verif As Boolean = True)
        '    Dim i, i1, k, j, j1, j2, N_k As Integer


        '    For i = Total_Noeud + 1 To Total_Noeud + Total_NoeudBcl - 1
        '        For j = 1 To total_Noeud_Ext
        '            If i = Tr_col(N_Ext(j), 0) Then 'i est le noe de retour de boucle sur lequel se branche le noe final de la colonne N_Ext(j)
        '                j1 = Tr_c(N_Ext(j), 0) 'j1 = noe origine de la colonne
        '                j2 = Tr_c(j1, 0)   'recherche du noe amont au noe origine de la colonne
        '                For i1 = 1 To N_Collec(j2)
        '                    If j1 = Tr_c(j2, i1) Then
        '                        Branch(i, 0) = Branch(j2, i1)
        '                        Exit For 'indice de la branche identifié
        '                    End If
        '                Next
        '                Exit For
        '            End If
        '        Next
        '    Next
        '    Dim Boucle_complete As Boolean
        '    Do
        '        Boucle_complete = True
        '        Dim br(9) As Integer
        '        For i = Total_Noeud + 1 To Total_Noeud + Total_NoeudBcl - 1
        '            If Branch(i, 0) = 0 Then
        '                j = 0
        '                Do
        '                    j = j + 1
        '                    j1 = Tr_Bcl_amont(i, j)
        '                    If j1 = 0 Then Exit Do
        '                    br(j) = Branch(j1, 0)
        '                Loop While j <= 9
        '                j = j - 1
        '                If j = 1 Then
        '                    'simple réduction de diamètre = n° de branche identique
        '                    Branch(i, 0) = br(1)
        '                Else
        '                    'Plusieurs branches: on passe au niveau en dessous
        '                    Branch(i, 0) = CInt(Int(br(1) / 10))
        '                End If
        '            End If
        '            'vérification
        '            If i <> Tr_Bcl_amont(Total_Noeud + Total_NoeudBcl, 1) Then
        '                'le noe amont ne peut être identifié car le calcul se fait à rebours
        '                If Branch(i, 0) = 0 Then Boucle_complete = False
        '            End If
        '        Next
        '    Loop Until Boucle_complete = True
        'End Sub
        'Private Sub Cumul_Perte_thermique(ByVal Total_Noeud As Integer, ByVal Total_NoeudBcl As Integer, ByVal N_Collec() As Integer, ByVal Branch(,) As Integer,
        '                                ByVal N_Ext() As Integer, ByVal total_Noeud_Ext As Integer, ByVal Tr_c(,) As Integer, ByVal L_dev(,) As Double, ByVal Pth(,) As Double,
        '                                ByVal L_devCol(,) As Double, ByVal Tr_Bcl_amont(,) As Integer, ByVal L_devBcl() As Double, ByVal Tr_col(,) As Integer,
        '                                  ByVal N_Col() As Integer, ByRef Tot_Pth(,) As Double, ByRef Niveau As Integer)
        '    Dim i, i1, i11, i2, j, j1, k As Integer
        '    Dim A_rentrer As Boolean = True
        '    Dim Max As Double
        '    ReDim Tot_Pth(Total_Noeud + Total_NoeudBcl, 9)
        '    Dim Cumule(Total_Noeud, 9, Total_Noeud + Total_NoeudBcl, 9) As Boolean 'initialisé à False
        '    Max = 10 ' 
        '    For i = 1 To total_Noeud_Ext
        '        k = N_Ext(i) 'noeud final de la colonne
        '        i1 = Tr_c(k, 0) 'noeud amont de la colonne
        '        'recherche du n° de branchement j1
        '        For j1 = 1 To N_Collec(i1)
        '            If Tr_c(i1, j1) = k Then Exit For
        '        Next
        '        If Branch(i1, j1) > Max Then Max = Branch(i1, j1)
        '    Next
        '    i = 1
        '    Do
        '        i = i + 1
        '    Loop While Max > 10 ^ i
        '    Niveau = i 'nbre de dérivations

        '    For i1 = 2 To Total_Noeud - 1
        '        For i11 = 1 To N_Collec(i1)
        '            Tot_Pth(i1, i11) = L_dev(i1, i11) * Pth(i1, i11) 'initialisation
        '            'pour la partie Addcution
        '            For j1 = i1 + 1 To Total_Noeud
        '                For j11 = 1 To N_Collec(j1)
        '                    If Branch(i1, i11) = Branch(j1, j11) Then
        '                        If Cumule(i1, i11, j1, j11) = False Then
        '                            Tot_Pth(i1, i11) = Tot_Pth(i1, i11) + L_dev(j1, j11) * Pth(j1, j11)
        '                            Cumule(i1, i11, j1, j11) = True 'pour éviter de cumuler plusieurs fois la même valeur
        '                            Exit For
        '                        End If
        '                    Else
        '                        For j = 1 To Niveau
        '                            If Branch(i1, i11) = CInt(Int(Branch(j1, j11) / 10 ^ j)) Then
        '                                If Cumule(i1, i11, j1, j11) = False Then
        '                                    Tot_Pth(i1, i11) = Tot_Pth(i1, i11) + L_dev(j1, j11) * Pth(j1, j11)
        '                                    Cumule(i1, i11, j1, j11) = True 'pour éviter de cumuler plusieurs fois la même valeur
        '                                    Exit For
        '                                End If
        '                            End If
        '                        Next
        '                    End If
        '                Next
        '            Next
        '            'pour la partie Bouclage
        '            'pas de réinitialisation de la variable cumule car on ne la pointe qu'une fois
        '            For i = Total_Noeud + 1 To Total_Noeud + Total_NoeudBcl - 1
        '                'bouclage ECS // à l'adduction d'eau
        '                If Branch(i1, i11) = Branch(i, 0) Then
        '                    If Cumule(i1, i11, i, 0) = False Then
        '                        Tot_Pth(i1, i11) = Tot_Pth(i1, i11) + L_devBcl(i) * Pth(i, 0)
        '                        Cumule(i1, i11, i, 0) = True 'pour éviter de cumuler plusieurs fois la même valeur
        '                    End If
        '                Else
        '                    For k = 1 To Niveau
        '                        If Branch(i1, i11) = CInt(Int(Branch(i, 0) / 10 ^ k)) Then
        '                            If Cumule(i1, i11, i, 0) = False Then
        '                                Tot_Pth(i1, i11) = Tot_Pth(i1, i11) + L_devBcl(i) * Pth(i, 0)
        '                                Cumule(i1, i11, i, 0) = True 'pour éviter de cumuler plusieurs fois la même valeur
        '                                Exit For
        '                            End If
        '                        End If
        '                    Next
        '                End If
        '                'ajout du retour colonne si existe
        '                For j = 1 To N_Col(i)
        '                    If Branch(i1, i11) = Branch(i, j) Then
        '                        If Cumule(i1, i11, i, j) = False Then
        '                            Tot_Pth(i1, i11) = Tot_Pth(i1, i11) + L_devCol(i, j) * Pth(i, j)
        '                            Cumule(i1, i11, i, j) = True 'pour éviter de cumuler plusieurs fois la même valeur
        '                        End If
        '                    Else
        '                        For k = 1 To Niveau
        '                            If Branch(i1, i11) = CInt(Int(Branch(i, j) / 10 ^ k)) Then
        '                                If Cumule(i1, i11, i, j) = False Then
        '                                    Tot_Pth(i1, i11) = Tot_Pth(i1, i11) + +L_devCol(i, j) * Pth(i, j)
        '                                    Cumule(i1, i11, i, j) = True 'pour éviter de cumuler plusieurs fois la même valeur
        '                                    Exit For
        '                                End If
        '                            End If
        '                        Next
        '                    End If
        '                Next
        '            Next
        '        Next
        '    Next
        'End Sub
        'Private Sub Debit_Pth_Colonne(ByVal Total_Noeud As Integer, ByVal Total_NoeudBcl As Integer, ByVal N_Collec() As Integer, ByVal N_Ext() As Integer, ByVal total_Noeud_Ext As Integer,
        '                         ByVal Tr_c(,) As Integer, ByVal Tr_col(,) As Integer, ByVal N_col() As Integer, ByVal L_dev(,) As Double, ByVal Pth(,) As Double,
        '                                ByVal L_devCol(,) As Double, ByVal Niveau As Integer, ByVal Qglobal As Double, ByVal Branch(,) As Integer, ByVal Tot_Pth(,) As Double,
        '                              ByRef Q_Tr(,) As Double)
        '    Dim i1, i2, i3, i4, jj(Total_Noeud - 1, 9) As Integer
        '    Dim ind, ind_Branch(1) As Integer
        '    Dim Tot_Deper(1), Tot_Q(1) As Double
        '    Dim test_OK As Boolean
        '    ReDim Q_Tr(Total_Noeud + Total_NoeudBcl, 9)
        '    Q_Tr(1, 1) = Qglobal : Tot_Pth(1, 1) = 0
        '    i1 = Tr_c(1, 1)
        '    For j = 1 To N_Collec(i1)
        '        Tot_Deper(0) = Tot_Deper(0) + Tot_Pth(i1, j)
        '    Next
        '    Tot_Q(0) = Qglobal
        '    'débit sur la colonne pour compenser les pertes thermiques.
        '    For i = 0 To Niveau - 1
        '        'calcul du débit par niveau et par branche
        '        'Détermination du débit et de la déperdition thermique totale sur la branche Amont
        '        ind = 0
        '        If i > 0 Then
        '            For i1 = 2 To Total_Noeud - 1
        '                For i2 = 1 To N_Collec(i1)
        '                    If Branch(i1, i2) < 10 ^ i And Branch(i1, i2) >= 10 ^ (i - 1) Then
        '                        test_OK = False
        '                        'la Branch(i1, i2) appartient au niveau i-1  
        '                        For j = 1 To UBound(ind_Branch)
        '                            'vérification dans le cas d'une branche de même numéro = réduction de diamètre
        '                            If Branch(i1, i2) = ind_Branch(j) And Q_Tr(i1, i2) = 0 Then
        '                                Q_Tr(i1, i2) = Tot_Q(j)  'total des déperditions pour la branche j du niveau i
        '                                jj(i1, i2) = j 'tableau de correspondance
        '                                test_OK = True : Exit For
        '                            End If
        '                        Next
        '                        If test_OK = False Then
        '                            ind = ind + 1
        '                            ReDim Preserve Tot_Deper(ind), Tot_Q(ind), ind_Branch(ind)
        '                            ind_Branch(ind) = Branch(i1, i2)
        '                            jj(i1, i2) = ind 'tableau de correspondance
        '                            Tot_Q(ind) = Q_Tr(i1, i2) 'débit total pour la branche j du niveau
        '                        End If
        '                    End If
        '                Next
        '            Next
        '            ReDim Tot_Deper(ind)
        '            'Calcul de la déperdition totale
        '            For i1 = 2 To Total_Noeud - 1
        '                If N_Collec(i1) >= 1 Then
        '                    For i2 = 1 To N_Collec(i1)
        '                        If Branch(i1, i2) < 10 ^ (i + 1) And Branch(i1, i2) >= 10 ^ i Then
        '                            'la Branch(i1, i2) appartient au niveau i
        '                            For j = 1 To UBound(ind_Branch)
        '                                If CInt(Int(Branch(i1, i2) / 10)) = ind_Branch(j) Then
        '                                    Tot_Deper(j) = Tot_Deper(j) + Tot_Pth(i1, i2) 'total des déperditions pour la branche j du niveau i
        '                                    Exit For
        '                                End If
        '                            Next
        '                        End If
        '                    Next
        '                End If
        '            Next
        '        End If

        '        ' Calcul de la répartition du débit sur les branches aval fonction de la déperdition thermique de la branche Aval
        '        For i1 = 2 To Total_Noeud - 1
        '            If N_Collec(i1) >= 1 Then
        '                For i2 = 1 To N_Collec(i1)
        '                    If Branch(i1, i2) < 10 ^ (i + 1) And Branch(i1, i2) >= 10 ^ i Then
        '                        'détermination du noeud amont et de sa branche
        '                        i3 = Tr_c(i1, 0)
        '                        For i4 = 1 To N_Collec(i3)
        '                            If Tr_c(i3, i4) = i1 Then Exit For
        '                        Next
        '                        For j = 1 To UBound(ind_Branch)
        '                            'la Branch(i1, i2) appartient au niveau i
        '                            Q_Tr(i1, i2) = Tot_Q(jj(i3, i4)) * Tot_Pth(i1, i2) / Tot_Deper(jj(i3, i4))
        '                            Exit For
        '                        Next

        '                    End If
        '                Next
        '            End If
        '        Next

        '        Erase Tot_Deper, Tot_Q, ind_Branch
        '        ReDim jj(Total_Noeud - 1, 9) 'remise à 0
        '        ReDim Tot_Deper(1), Tot_Q(1), ind_Branch(1)
        '    Next

        'End Sub
        'Private Sub Pdc_Boucle_ECS(ByVal N_colonne As Integer, ByVal N_Ext() As Integer, ByVal Tr_C(,) As Integer, ByVal Tr_Col(,) As Integer, ByVal N_Collec() As Integer,
        '                           ByVal N_Col() As Integer, ByVal Q_Tr(,) As Double, ByVal Tr_Bcl() As Integer,
        '                          ByVal Pdc(,) As Double, ByVal L_dev(,) As Double, ByVal Diam(,) As Double, ByVal L_devCol(,) As Double, ByVal DiamCol(,) As Double,
        '                           ByVal PdcCol(,) As Double, ByVal L_devBcl() As Double, ByVal PdcBcl() As Double, ByVal DiamBcl() As Double, ByVal Tr_Bcl_amont(,) As Integer,
        '                           ByVal Total As Integer,
        '                        ByRef Ligne_colonne() As Integer, ByRef Ligne_colonne1() As Integer, ByRef i1_tr(,) As Integer, ByRef i2_tr(,) As Integer,
        '                           ByRef Qi(,) As Double, ByRef Øi(,) As Double,
        '                           ByRef Ji(,) As Double, ByRef Li(,) As Double,
        '                            ByRef Vi(,) As Double, ByRef Pdc_lin(,) As Double, ByRef Pdc_Sin(,) As Double, ByRef Pdc_Tot() As Double)
        '    Dim temp11(20), temp12(20) As Integer
        '    Dim temp13(20), temp14(20), temp15(20), temp16(20), temp17(20), temp18(20), temp19(20) As Double
        '    Dim Verif As Boolean = True
        '    Dim i, i1, i2, j, k, noe, ic, temp1 As Integer
        '    'Calcul du réseau du noeud final de la colonne au noeud de production ECS
        '    i1_tr(N_colonne, 1) = N_Ext(N_colonne)
        '    i1 = N_Ext(N_colonne)
        '    ic = 0
        '    Do
        '        ic = ic + 1 'compteur
        '        noe = Tr_C(i1, 0) 'noeud amont
        '        'détermination du n° d'indice de la branche
        '        For k = 1 To N_Collec(noe)
        '            If Tr_C(noe, k) = i1 Then Exit For
        '        Next
        '        'Ji(N_colonne, ic) = J_Flamant(Q_Tr(noe, k) / 3600000.0, Diam(noe, k), 2, Verif)
        '        If Verif = False Then MessageBox.Show("Défaut calcul Pdc suivant formule de Flamant - Sub Pdc_Boucle_ECS", "Note de calcul",
        '                                              MessageBoxButtons.OK, MessageBoxIcon.Warning) : Exit Sub
        '        Pdc_lin(N_colonne, ic) = Pdc_lin(N_colonne, ic) + L_dev(noe, k) * Ji(N_colonne, ic) * 1.15  'en mCE
        '        Vi(N_colonne, ic) = Q_Tr(noe, k) / (PI * Diam(noe, k) ^ 2 / 4) / 3600000.0 'Q en L/h et D en m ->m/s
        '        Pdc_Sin(N_colonne, ic) = Pdc_Sin(N_colonne, ic) + Pdc(noe, k) '* L_dev(noe, k) * V ^ 2 / 2
        '        'Affectation
        '        Qi(N_colonne, ic) = Q_Tr(noe, k) : Øi(N_colonne, ic) = Diam(noe, k) : Li(N_colonne, ic) = L_dev(noe, k)
        '        ' Tab_Pdc_Bcl(noe, i1, Q_col(N_colonne), Diam(noe, k), L_dev(noe, k), V, Pdc(noe, k), rtf)
        '        i1_tr(N_colonne, ic) = noe   'noeud amont
        '        i2_tr(N_colonne, ic) = i1 'noeud amont précédent
        '        i1 = noe
        '    Loop Until noe = 1 'le noeud 1 est toujours le départ
        '    Ligne_colonne1(N_colonne) = ic

        '    ic = ic + 1
        '    'colonne retour boucle
        '    i1_tr(N_colonne, ic) = N_Ext(N_colonne) : i2_tr(N_colonne, ic) = Tr_Col(N_Ext(N_colonne), 0)
        '    i1 = i2_tr(N_colonne, ic) 'par simplification d'écriture
        '    For k = 1 To N_Col(i1)
        '        If Tr_Col(i1, k) = N_Ext(N_colonne) Then Exit For
        '    Next
        '    ' Ji(N_colonne, ic) = J_Flamant(Q_Tr(i1, k) / 3600000.0, DiamCol(i1, k), 2, Verif)
        '    If Verif = False Then MessageBox.Show("Défaut calcul Pdc suivant formule de Flamant - Sub Pdc_Boucle_ECS", "Note de calcul",
        '                                              MessageBoxButtons.OK, MessageBoxIcon.Warning) : Exit Sub
        '    Pdc_lin(N_colonne, ic) = Pdc_lin(N_colonne, ic) + L_devCol(i1, k) * Ji(N_colonne, ic) * 1.15   'en mCE
        '    Vi(N_colonne, ic) = Q_Tr(i1, k) / (PI * DiamCol(i1, k) ^ 2 / 4) / 3600000.0 'Q en L/h et D en mm ->m/s
        '    Pdc_Sin(N_colonne, ic) = Pdc_Sin(N_colonne, ic) + PdcCol(i1, k)
        '    'Affectation
        '    Qi(N_colonne, ic) = Q_Tr(i1, k) : Øi(N_colonne, ic) = DiamCol(i1, k) : Li(N_colonne, ic) = L_devCol(i1, k)
        '    'bouclage pour terminer sur le noeud final de la boucle'collecteur boucle
        '    Do
        '        ic = ic + 1
        '        i2 = Tr_Bcl(i1)
        '        ' Ji(N_colonne, ic) = J_Flamant(Q_Tr(i1, 0) / 3600000.0, DiamBcl(i1), 2, Verif)
        '        If Verif = False Then MessageBox.Show("Défaut calcul Pdc suivant formule de Flamant - Sub Pdc_Boucle_ECS", "Note de calcul",
        '                                              MessageBoxButtons.OK, MessageBoxIcon.Warning) : Exit Sub
        '        Pdc_lin(N_colonne, ic) = Pdc_lin(N_colonne, ic) + L_devBcl(i1) * Ji(N_colonne, ic) * 1.15  'en mCE
        '        Vi(N_colonne, ic) = Q_Tr(i1, 0) / (PI * DiamBcl(i1) ^ 2 / 4) / 3600000.0 'Q en L/h et D en m ->m/s
        '        Pdc_Sin(N_colonne, ic) = Pdc_Sin(N_colonne, ic) + PdcBcl(i1) '* L_devBcl(i1) * V ^ 2 / 2
        '        'Affectation
        '        i1_tr(N_colonne, ic) = i1 : i2_tr(N_colonne, ic) = i2
        '        Qi(N_colonne, ic) = Q_Tr(i1, 0) : Øi(N_colonne, ic) = DiamBcl(i1) : Li(N_colonne, ic) = L_devBcl(i1)
        '        i1 = i2
        '    Loop While i1 <> Tr_Bcl_amont(Total, 1)
        '    'collecteur final boucle
        '    ic = ic + 1
        '    i1 = Tr_Bcl_amont(Total, 1) : i2 = Total
        '    'Ji(N_colonne, ic) = J_Flamant(Q_Tr(i1, 0) / 3600000.0, DiamBcl(i1), 2, Verif)
        '    If Verif = False Then MessageBox.Show("Défaut calcul Pdc suivant formule de Flamant - Sub Pdc_Boucle_ECS", "Note de calcul",
        '                                              MessageBoxButtons.OK, MessageBoxIcon.Warning) : Exit Sub
        '    Pdc_lin(N_colonne, ic) = Pdc_lin(N_colonne, ic) + L_devBcl(i1) * Ji(N_colonne, ic) * 1.15  'en mCE
        '    Vi(N_colonne, ic) = Q_Tr(i1, 0) / (PI * DiamBcl(i1) ^ 2 / 4) / 3600000.0 'Q en L/h et D en mm ->m/s
        '    Pdc_Sin(N_colonne, ic) = Pdc_Sin(N_colonne, ic) + PdcBcl(i1) '* L_devBcl(i1) * V ^ 2 / 2
        '    'Affectation
        '    i1_tr(N_colonne, ic) = i1 : i2_tr(N_colonne, ic) = Total
        '    Qi(N_colonne, ic) = Q_Tr(i1, 0) : Øi(N_colonne, ic) = DiamBcl(i1) : Li(N_colonne, ic) = L_devBcl(i1)
        '    'Cumul pour les Pdc_Lin et Pdc_Sin
        '    ic = ic + 1 : i2 = ic
        '    For i = 1 To ic - 1
        '        Pdc_lin(N_colonne, i2) = Pdc_lin(N_colonne, i2) + Pdc_lin(N_colonne, i)
        '        Pdc_Sin(N_colonne, i2) = Pdc_Sin(N_colonne, i2) + Pdc_Sin(N_colonne, i)
        '    Next
        '    Pdc_Tot(N_colonne) = Pdc_lin(N_colonne, i2) + Pdc_Sin(N_colonne, i2)
        '    Ligne_colonne(N_colonne) = ic
        'End Sub


        'Private Sub Perte_Thermique_Locale(ByVal V As Double, ByVal Mat_Tube As Integer, ByVal d As Double, ByVal ep As Double, ByVal λ As Double, ByVal TprodECS As Double,
        '                                   ByVal dT As Double, ByRef Pth As Double)
        '    Dim de, hi, he, K As Double
        '    'formules guide AICVF
        '    de = D_Ext(d, Mat_Tube)
        '    hi = 2538 * V ^ 0.8 / d ^ 0.2
        '    Select Case de
        '        Case Is <= 0.017
        '            he = 12.8
        '        Case Is > 0.027
        '            he = 11.6
        '        Case Else
        '            he = 11.9
        '    End Select
        '    K = (1 / hi) + (de / (2 * λ)) * Log((de + 2 * ep) / de) + (de / (he * (de + 2 * ep)))
        '    K = 1 / K
        '    Pth = K * PI * de * (TprodECS - ΔT_ECS - dT)
        'End Sub

        'Private Sub Perte_Thermique_Globale(ByVal Type_dT As Integer, ByVal Total_Noeud As Integer, ByVal Total_NoeudBcl As Integer, ByVal N_Collec() As Integer, ByVal N_Col() As Integer,
        '                                    ByVal L_dev(,) As Double, ByVal Pth(,) As Double, ByVal L_devCol(,) As Double, ByVal L_devBcl() As Double, ByRef PthG As Double)
        '    Dim i, j As Integer
        '    For i = 1 To Total_Noeud
        '        For j = 1 To N_Collec(i)
        '            PthG = PthG + L_dev(i, j) * Pth(i, j)
        '        Next
        '    Next
        '    ' Type_dT = 1 'entre prod et Exut
        '    If Type_dT = 2 Then
        '        'entre prod et retour
        '        For i = Total_Noeud + 1 To Total_Noeud + Total_NoeudBcl - 1
        '            For j = 1 To N_Col(i)
        '                PthG = PthG + L_devCol(i, j) * Pth(i, j)
        '            Next
        '            PthG = PthG + L_devBcl(i) * Pth(i, 0)
        '        Next
        '    End If
        'End Sub
        'Private Sub Perte_Thermique_Colonne(ByVal Total_Noeud As Integer, ByVal total_Noeud_Ext As Integer, ByVal N_ext() As Integer, ByVal L_dev(,) As Double, ByVal Pth(,) As Double, _
        '                          ByVal Tr_c(,) As Integer, ByRef noe_br() As Integer, ByRef Pth_col() As Double, ByRef rtf As RtfAnsiTextWriter)
        '    Dim i, i1, ind, k, noe As Integer 'j,
        '    ReDim noe_br(total_Noeud_Ext), Pth_col(total_Noeud_Ext)
        '    For i = 1 To total_Noeud_Ext
        '        k = 1 : i1 = N_ext(i)
        '        noe = Tr_c(N_ext(i), 0)
        '        Do
        '            'permet de déterminer si plusieurs branchement sur le noeud noe
        '            If Tr_c(noe, 2) <> 0 Then
        '                ind = 2
        '                'détermination du n° de départ
        '                For k = 1 To 5
        '                    If Tr_c(noe, k) = i1 Then Exit For
        '                Next
        '            Else
        '                ind = 1
        '                k = 1 'k est le n° de départ
        '            End If
        '            Pth_col(i) = Pth_col(i) + L_dev(noe, k) * Pth(noe, k)
        '            i1 = noe 'Tr_c(noe, 0) 'noeud amont
        '            If ind = 2 Then noe_br(i) = noe 'noeud amont précédent
        '            noe = Tr_c(i1, 0) 'noeud amont
        '        Loop While ind = 1
        '    Next
        'End Sub
        'Private Sub Perte_Thermique_Tronçon(ByVal Total_Noeud As Integer, ByVal N_Collec() As Integer, ByVal Tr_c(,) As Integer, ByVal Noeud_precedent As Integer, _
        '                                    ByVal Noeud_suivant As Integer, ByVal L_dev(,) As Double, ByVal Pth(,) As Double, ByRef Pth_Tron As Double)
        '    'noeud suivant = noeud aval - noeud précédent = noeud amont
        '    Dim i, j, k As Integer
        '    Pth_Tron = 0
        '    j = Noeud_suivant
        '    Do
        '        i = Tr_c(j, 0)
        '        For k = 1 To N_Collec(i)
        '            If j = Tr_c(i, k) Then Pth_Tron = Pth_Tron + L_dev(i, k) * Pth(i, k) : Exit For
        '        Next
        '        j = i
        '        If j = 0 Then Exit Do
        '    Loop Until Noeud_precedent = j
        'End Sub
        'Private Sub Tab_Debit_Recyclage_1(ByVal PthG1 As Double, ByVal Q_deb(,) As Double, ByVal noe_br() As Integer, ByVal dTBoucle As Double,
        '                                 ByVal Q_col() As Double, ByVal Pth_col() As Double, ByVal Total_Noeud As Integer, ByVal Total_Noeud_Ext As Integer,
        '                                ByVal N_Ext() As Integer, ByVal N_Collec() As Integer, ByVal Tr_c(,) As Integer, ByVal L_dev(,) As Double, ByVal Pth(,) As Double,
        '                                ByVal Qglob As Double, ByRef rtf As RtfAnsiTextWriter)
        '    ' ByVal dT_col() As Double,
        '    Dim i, Vdt As Integer
        '    Dim Q_Som_Col, dT1 As Double
        '    Dim Pth_Tr(Total_Noeud_Ext), dT_col(Total_Noeud_Ext) As Double
        '    Q_deb(1, noe_br(1)) = Qglob
        '    If noe_br(1) > 2 Then
        '        i = 1
        '        Do While i < noe_br(1)
        '            Q_deb(i, i + 1) = Q_deb(1, noe_br(1))
        '            i = i + 1
        '        Loop
        '    End If
        '    ' Type_dT=1 'entre prod et Exut
        '    'pertes sur premiers tronçons
        '    i = 1 : PthG1 = 0
        '    Do
        '        PthG1 = PthG1 + L_dev(i, 1) * Pth(i, 1)
        '        i = i + 1
        '    Loop While N_Collec(i) = 1
        '    dT1 = PthG1 / (1.16 * Qglob)
        '    Vdt = Tr_c(i - 1, 1)

        '    rtf.WriteStartGroup()
        '    rtf.NewParagraph()
        '    rtf.FontSize = 8
        '    'Ligne 1
        '    rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("N° Amont") : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("N° Aval") : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("P (W)") : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Q (L/h)") : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("ΔT °C") : rtf.EndCell() : rtf.EndRow()
        '    'Ligne 2
        '    rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Départ") : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("1") : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(noe_br(1).ToString) : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(PthG1.ToString("#,###.0")) : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Q_deb(1, noe_br(1)).ToString("#,###.0")) : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(dT1.ToString("#0.00")) : rtf.EndCell() : rtf.EndRow()
        '    'ligne 3 et suivantes
        '    '_dT= 1 'entre prod et Exut
        '    i = 1
        '    Do
        '        'colonne i
        '        Q_Som_Col = 0
        '        Do While noe_br(i) = Vdt
        '            dT_col(i) = dTBoucle - dT1
        '            Q_col(i) = Pth_col(i) / (1.16 * dT_col(i))
        '            rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Colonne " & i.ToString) : rtf.EndCell()
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(noe_br(i).ToString) : rtf.EndCell()
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(N_Ext(i).ToString) : rtf.EndCell()
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Pth_col(i).ToString("#,###.0")) : rtf.EndCell()
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Q_col(i).ToString("#,###.0")) : rtf.EndCell()
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(dT_col(i).ToString("#0.00")) : rtf.EndCell() : rtf.EndRow()
        '            Q_Som_Col = Q_Som_Col + Q_col(i)
        '            i = i + 1
        '            If i > Total_Noeud_Ext Then Exit Do
        '        Loop
        '        If i > Total_Noeud_Ext Then Exit Do
        '        'tronçon collecteur i
        '        Perte_Thermique_Tronçon(Total_Noeud, N_Collec, Tr_c, noe_br(i - 1), noe_br(i), L_dev, Pth, Pth_Tr(i))
        '        Q_deb(noe_br(i - 1), noe_br(i)) = Qglob - Q_Som_Col
        '        dT1 = dT1 + (Pth_Tr(i) / (1.16 * Q_deb(noe_br(i - 1), noe_br(i))))
        '        Vdt = noe_br(i)
        '        rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("tronçon " & i.ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(noe_br(i - 1).ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(noe_br(i).ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Pth_Tr(i).ToString("#,###.0")) : rtf.EndCell()
        '        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Q_deb(noe_br(i - 1), noe_br(i)).ToString("#,###.0")) : rtf.EndCell()
        '        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((Pth_Tr(i) / (1.16 * Q_deb(noe_br(i - 1), noe_br(i)))).ToString("#0.00")) : rtf.EndCell() : rtf.EndRow()
        '    Loop
        '    rtf.WriteEndGroup()
        '    rtf.WriteStartGroup()
        '    rtf.WriteString("Vérifications: ") : rtf.NewLine()
        '    Q_Som_Col = 0
        '    For i = 1 To Total_Noeud_Ext
        '        Q_Som_Col = Q_Som_Col + Q_col(i)
        '    Next
        '    rtf.WriteString("Cumul débits sur les colonnes: " & Q_Som_Col.ToString("#,###.0") & " L/h.") : rtf.NewLine() : rtf.NewLine()
        '    ' rtf.WriteString("Cumul ΔT °C sur les colonnes: " & PthG.ToString("#,###.0") & " W.") : rtf.NewLine()
        '    rtf.WriteEndGroup()
        'End Sub
        'Private Sub Tab_Debit_Recyclage_2(ByVal Total_Noeud As Integer, ByVal Total_NoeudBcl As Integer, ByVal Total_Noeud_Ext As Integer, ByVal N_Ext() As Integer,
        '                                  ByVal Tr_C(,) As Integer, ByVal N_Collec() As Integer, ByVal Tr_col(,) As Integer, ByVal N_Col() As Integer, ByVal DiamCol(,) As Double,
        '                                  ByVal L_dev(,) As Double, ByVal Pth(,) As Double, ByVal Diam(,) As Double, ByVal Tr_Bcl_amont(,) As Integer,
        '                                  ByVal L_devBcl() As Double, ByVal diamBcl() As Double, ByVal Qglob As Double, ByVal Debmin As Double, ByVal Vmin As Double,
        '                               ByVal Q_Tr(,) As Double, ByVal Tot_Pth(,) As Double, ByRef Q_col() As Double, ByRef Correction As Boolean, ByRef rtf As To_Rtf.RtfAnsiTextWriter)

        '    Dim i, j, j1 As Integer ', Vdt(1) 
        '    Dim V_Tr, PthG1, PthR1 As Double 'Q_Tr,  Pthi, dt_ColA, dt_ColR,Q_Som_Col1,Q_Som_Coli,
        '    Dim Som_Q_Tr, Som_Q_Retenu As Double 'Pth_Tr(Total_Noeud_Ext), dT_col(Total_Noeud_Ext), dT1, dTR1, dT2, dTR2, Tg 

        '    'pertes sur premiers tronçons
        '    i = 1 : PthG1 = 0
        '    Do While N_Collec(i) = 1
        '        PthG1 = PthG1 + L_dev(i, 1) * Pth(i, 1)
        '        i = Tr_C(i, 1)
        '    Loop
        '    ' dT1 = PthG1 / (1.16 * Qglob) 'perte température sur les tronçons après le noeud 1 jusqu'au 1ier raccordement collectif
        '    rtf.WriteStartGroup()
        '    rtf.WriteString("  - N° :") : rtf.NewLine()
        '    rtf.WriteString("       = n° Amont/aval pour le tronçon départ.") : rtf.NewLine()
        '    rtf.WriteString("       = n° Amont/aval pour le tronçon retour.") : rtf.NewLine()
        '    rtf.WriteString("       = n° Amont/aval pour le tronçon alimentant la colonne i.") : rtf.NewLine()
        '    rtf.WriteString("  - P (w) = déperditions cumulées sur le tronçon Aller/Retour de la colonne i.") : rtf.NewLine()
        '    rtf.WriteString("  - Qcal (L/h) = débit minimum pour compenser les déperditions cumulées sur le parcours Aller/Retour de la colonne i.") : rtf.NewLine()
        '    rtf.WriteString("  - V (m/s) = vitesse du débit Maxi(Qcal/Debit minimal) sur le parcours Retour de la colonne i.") : rtf.NewLine()
        '    rtf.WriteString("  - Qv (L/h) = débit minimum si vitesse minimale imposée sur le parcours Retour de la colonne i (Affiché si débit précédent insuffisant).") : rtf.NewLine()
        '    rtf.WriteEndGroup()
        '    rtf.WriteStartGroup()
        '    rtf.NewParagraph()
        '    rtf.FontSize = 8
        '    'Ligne 1
        '    rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("N° Terminal") : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("P (W)") : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Qcal (L/h)") : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Qmin (L/h)") : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("V (m/s)") : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Qv (L/h)") : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Q retenu") : rtf.EndCell() : rtf.EndRow()
        '    'Ligne 2
        '    rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("Départ") : rtf.EndCell()
        '    rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("1 - " & Tr_C(1, 1).ToString) : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(PthG1.ToString("#,###.0")) : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Qglob.ToString("#,###.0")) : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    V_Tr = Qglob / 1000 / (3600 * PI * Diam(1, 1) ^ 2 / 4)
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(V_Tr.ToString("#0.00")) : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Qglob.ToString("#,###.0")) : rtf.EndCell() : rtf.EndRow()
        '    'Ligne 2
        '    rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("Retour général") : rtf.EndCell()
        '    i = Total_Noeud + Total_NoeudBcl
        '    rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(Tr_Bcl_amont(i, 1).ToString & " - " & i.ToString) : rtf.EndCell()
        '    PthR1 = L_devBcl(Tr_Bcl_amont(i, 1)) * Pth(Tr_Bcl_amont(i, 1), 0)
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(PthR1.ToString("#,###.0")) : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Qglob.ToString("#,###.0")) : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    V_Tr = Qglob / 1000 / (3600 * PI * diamBcl(Tr_Bcl_amont(i, 1)) ^ 2 / 4)
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(V_Tr.ToString("#0.00")) : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Qglob.ToString("#,###.0")) : rtf.EndCell() : rtf.EndRow()
        '    'ligne 3 et suivantes
        '    Som_Q_Tr = 0 : Som_Q_Retenu = 0
        '    For i = 1 To Total_Noeud_Ext
        '        Dim N_or, N_fin, N_bcl, N_final As Integer 'noe origine colonne, noe fin colonne, noe départ branche, noe retour branche (sur circuit bouclage)
        '        N_or = Tr_C(N_Ext(i), 0) : N_fin = N_Ext(i) : N_bcl = Tr_col(N_Ext(i), 0) : N_final = Tr_Bcl_amont(Total_Noeud + Total_NoeudBcl, 1)
        '        'n° d'indice de la colonne
        '        For j = 1 To N_Collec(N_or)
        '            If Tr_C(N_or, j) = N_fin Then Exit For
        '        Next
        '        'n° d'indice de la branche amont
        '        For j1 = 1 To N_Collec(Tr_C(N_or, 0))
        '            If Tr_C(Tr_C(N_or, 0), j1) = N_or Then Exit For
        '        Next
        '        Q_col(i) = 0
        '        'Ligne Aller / Retour Colonne i
        '        rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("A/R alim colonne " & i.ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(Tr_C(1, 1).ToString & " - " & N_or.ToString & "/" & N_bcl.ToString & " - " & N_final.ToString) : rtf.EndCell()
        '        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Tot_Pth(Tr_C(N_or, 0), j1).ToString("#,###.0")) : rtf.EndCell() 'P (w)
        '        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell() 'Qcal (L/h)
        '        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell() 'Qmin (L/h)
        '        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell() 'V (m/s)
        '        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell() 'Qv (L/h)
        '        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell() : rtf.EndRow() 'Q retenu
        '        'Ligne Retour Colonne i
        '        rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("A/R colonne " & i.ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(N_fin.ToString & " - " & N_bcl.ToString) : rtf.EndCell()
        '        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Tot_Pth(N_or, j).ToString("#,##0.0")) : rtf.EndCell() 'P (w)
        '        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_Tr(N_or, j).ToString("#,##0.0")) : rtf.EndCell() 'Qcal = débit entrant
        '        Som_Q_Tr = Som_Q_Tr + Q_Tr(N_or, j)
        '        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Debmin.ToString("#,##0.0")) : rtf.EndCell() 'Qmin
        '        Q_col(i) = Max(Q_Tr(N_or, j), Debmin)
        '        For j = 1 To N_Col(N_bcl)
        '            If Tr_col(N_bcl, j) = N_fin Then Exit For 'n° d'indice de la branche pour la colonne retour
        '        Next
        '        V_Tr = Q_col(i) / 1000 / (3600 * PI * DiamCol(N_bcl, j) ^ 2 / 4)
        '        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(V_Tr.ToString("#0.00")) : rtf.EndCell() 'V (m/s)
        '        If V_Tr < Vmin Then
        '            Q_col(i) = 1000 * Vmin * 3600 * PI * DiamCol(N_bcl, j) ^ 2 / 4 'pour débit en L/h
        '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_col(i).ToString("#,##0.0")) : rtf.EndCell()
        '        Else
        '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '        End If
        '        rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_col(i).ToString("#,##0.0")) : rtf.EndCell() : rtf.EndRow()
        '        Som_Q_Retenu = Som_Q_Retenu + Q_col(i)
        '    Next
        '    rtf.BeginRow() : rtf.DeclareCell(4000) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Som_Q_Tr.ToString("#,##0.0")) : rtf.EndCell() '"Qcal (L/h)"
        '    rtf.DeclareCell(2400) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell() 'Qv (L/h)
        '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Som_Q_Retenu.ToString("#,##0.0")) : rtf.EndCell() : rtf.EndRow() 'Q retenu
        '    rtf.WriteEndGroup()
        '    If Som_Q_Retenu > 1.02 * Som_Q_Tr Then Correction = True 'modifier les débits des tronçons
        'End Sub
        'Private Sub Correction_Debits(ByVal Total_Noeud As Integer, ByVal Total_NoeudBcl As Integer, ByVal Total_Noeud_Ext As Integer, ByVal N_Ext() As Integer,
        '                                  ByVal Tr_C(,) As Integer, ByVal N_Collec() As Integer, ByVal Tr_col(,) As Integer, ByVal N_Col() As Integer, ByVal niveau As Integer,
        '                               ByVal Branch(,) As Integer, ByVal Q_col() As Double, ByVal Tr_Bcl_amont(,) As Integer, ByRef Q_Tr(,) As Double)
        '    Dim i, i1, i2, i3, i4, j As Integer
        '    Dim Cumule(Total_Noeud + Total_NoeudBcl) As Boolean 'initialisé à False
        '    Dim Cumule1(Total_Noeud, 1) As Boolean 'initialisé à False
        '    Dim Qglobal As Double
        '    For i = 1 To Total_Noeud_Ext
        '        Qglobal = Qglobal + Q_col(i)
        '    Next
        '    'Remise à 0 des Q_tr
        '    i = 0
        '    Erase Q_Tr
        '    ReDim Q_Tr(Total_Noeud + Total_NoeudBcl, 9)
        '    'Affectation des Q_tr sur la colonne: aller et retour
        '    For i = 1 To Total_Noeud_Ext
        '        For j = 1 To Total_Noeud
        '            If j = N_Ext(i) Then
        '                'détermination du noeud amont et de sa branche - Affectation du débit
        '                i1 = Tr_C(j, 0)
        '                For i2 = 1 To N_Collec(i1)
        '                    If Tr_C(i1, i2) = j Then
        '                        Q_Tr(i1, i2) = Q_col(i)
        '                        Exit For
        '                    End If
        '                Next
        '                'détermination du noeud boucle
        '                i1 = Tr_col(j, 0)
        '                For i2 = 1 To N_Col(i1)
        '                    If Tr_col(i1, i2) = j Then
        '                        Q_Tr(i1, i2) = Q_col(i)
        '                        Exit For
        '                    End If
        '                Next
        '            End If
        '        Next
        '    Next
        '    'Affectation des Q_tr en partant des colonnes et en remontant vers la production 
        '    For i = niveau - 1 To 0 Step -1
        '        'calcul du débit par niveau et par branche
        '        'Détermination du débit et de la déperdition thermique totale sur la branche Amont

        '        For i1 = 2 To Total_Noeud
        '            For i2 = 1 To N_Collec(i1)
        '                If Branch(i1, i2) < 10 ^ i And Branch(i1, i2) >= 10 ^ (i - 1) Then
        '                    'la Branch(i1, i2) appartient au niveau i-1  
        '                    i3 = Tr_C(i1, i2)
        '                    Do While Branch(i3, 1) = Branch(i1, i2)
        '                        'i3 au même niveau que i1 = réduction de diamètre ou accident localisé
        '                        i3 = Tr_C(i3, 1)
        '                    Loop
        '                    For i4 = 1 To N_Collec(i3)
        '                        Q_Tr(i1, i2) = Q_Tr(i1, i2) + Q_Tr(i3, i4)
        '                    Next
        '                End If
        '            Next
        '        Next
        '    Next
        '    'pour la partie collectif du collecteur retour, le tronçon est identifié par son numéro amont
        '    For i1 = 2 To Total_Noeud - 1
        '        For i2 = 1 To N_Collec(i1)
        '            'pour la partie Bouclage
        '            For i = Total_Noeud + 1 To Total_Noeud + Total_NoeudBcl - 1
        '                'bouclage ECS // à l'adduction d'eau
        '                If Branch(i1, i2) = Branch(i, 0) And Cumule(i) = False Then
        '                    Q_Tr(i, 0) = Q_Tr(i1, i2) : Cumule(i) = True 'pour éviter de cumuler plusieurs fois la même valeur
        '                End If
        '            Next
        '        Next
        '    Next
        '    'Pour le noeud initial
        '    i = 1
        '    Do While N_Collec(i) = 1
        '        i = Tr_C(i, 1)
        '    Loop
        '    i2 = Tr_C(i, 0)
        '    For i1 = 1 To N_Collec(i)
        '        Q_Tr(i2, 1) = Q_Tr(i2, 1) + Q_Tr(i, i1)
        '    Next
        '    Do Until i2 = 1
        '        i1 = i2
        '        i2 = Tr_C(i2, 0)
        '        Q_Tr(i2, 1) = Q_Tr(i1, 1)
        '    Loop
        '    'Pour le noeud Final
        '    i = Total_Noeud + Total_NoeudBcl
        '    j = Tr_Bcl_amont(i, 1)
        '    Do
        '        Q_Tr(j, 0) = Q_Tr(1, 1)
        '        j = Tr_Bcl_amont(i, 1)
        '    Loop While Tr_Bcl_amont(j, 2) = 0 'une seule connexion
        'End Sub


        'If noe_br(1) <> Vdt Then

        '    'tronçon aller collecteur i
        '    'Perte_Thermique_Tronçon(Total_Noeud, N_Collec, Tr_c, noe_br(i - 1), noe_br(i), L_dev, Pth, Pth_Tr(i))
        '    'Q_Som_Coli = Q_Som_Coli + Q_Som_Col
        '    'Q_deb(noe_br(i - 1), noe_br(i)) = Qglob - Q_Som_Coli
        '    'dT2 = (Pth_Tr(i) / (1.16 * Q_deb(noe_br(i - 1), noe_br(i))))
        '    'dT1 = dT1 + dT2
        '    'Vdt = noe_br(i)
        '    'V_Tr = Q_deb(noe_br(i - 1), noe_br(i)) / 1000 / (3600 * PI * Diam(noe_br(i - 1), 2) ^ 2 / 4)
        '    'Call Ligne_Tab_Debit_Recyclage_2(3, i, noe_br, N_Ext, Pth_col, Q_col, dT2, Debmin, V_Tr, Q_Tr, j, PthG1, Q_colRet, Pth_Tr, Q_deb, i1, rtf) 'affichage de la ligne tronçon

        'End If
        'i = 1 : i4 = 1 : Q_Som_ColR = 0
        'Do
        '    'colonne i
        '    'Calcul des débits et déperditions sur les colonnes raccordées sur le même noeud de branchement
        '    Q_Som_Col = 0
        '    Do While noe_br(i) = Vdt(i4) 'pour toutes les colonnes revenant sur le même noeud
        '        dT_col(i) = dTBoucle - dT1 - dTR1
        '        'i1 = n° du noeud aval se trouvant sur le collecteur retour; soit dans le sens amont - Aval pour la colonne i:
        '        'noe_br(i)  --->   N_Ext(i)  --->  i1
        '        'i2 = n° de la colonne retour venant se raccorder sur le noeud i1
        '        i1 = Tr_c(N_Ext(i), 1)
        '        For i2 = 1 To 10
        '            If Tr_col(i1, i2) = N_Ext(i) Then Exit For
        '        Next
        '        If i2 = 11 Then MsgBox("Erreur modélisation - Ligne 1643", MsgBoxStyle.Critical Or vbOKOnly, "Module tableau débits") : Verif = False : Exit Sub
        '        'i3 = n° de la colonne montante ayant pour origine noe_br(i) et pour extrémité N_Ext(i)
        '        For i3 = 1 To 10
        '            If Tr_c(noe_br(i), i3) = N_Ext(i) Then Exit For
        '        Next
        '        If i3 = 11 Then MsgBox("Erreur modélisation - Ligne 1648", MsgBoxStyle.Critical Or vbOKOnly, "Module tableau débits") : Verif = False : Exit Sub
        '        'affichage de la ligne colonne i  Aller
        '        PthG1 = L_devCol(i1, i2) * Pth(i1, i2) 'déperdition sur la partie Retour
        '        Q_col(i) = (Pth_col(i) + PthG1) / (1.16 * dT_col(i)) 'débit dans la colonne
        '        dt_ColA = Pth_col(i) / (1.16 * Q_col(i)) 'ΔT sur la partie Aller
        '        dt_ColR = dT_col(i) - dt_ColA 'ΔT sur la partie Retour
        '        V_Tr = Q_col(i) / 1000 / (3600 * PI * Diam(noe_br(i), i3) ^ 2 / 4)
        '        Call Ligne_Tab_Debit_Recyclage_2(1, i, noe_br(i), N_Ext(i), Pth_col, Q_col, dt_ColA, Debmin, V_Tr, 0, PthG1, Q_colRet, Pth_Tr, Q_deb, rtf) 'affichage de la ligne colonne dans le tableau
        '        'affichage de la ligne colonne i Retour
        '        Q_Som_Col = Q_Som_Col + Q_col(i)
        '        V_Tr = Q_col(i) / 1000 / (3600 * PI * DiamCol(i1, i2) ^ 2 / 4)
        '        Q_Tr = 0
        '        If V_Tr < Vmin Then Q_Tr = 1000 * Vmin * 3600 * PI * DiamCol(i1, i2) ^ 2 / 4 'pour débit en L/h
        '        Q_colRet(i) = Q_max(Q_col(i), Debmin, Q_Tr)

        '        Call Ligne_Tab_Debit_Recyclage_2(2, i, N_Ext(i), Tr_c(N_Ext(i), 1), Pth_col, Q_col, dt_ColR, Debmin, V_Tr, Q_Tr, PthG1, Q_colRet, Pth_Tr, Q_deb, rtf) 'affichage de la ligne retour colonne dans le tableau         
        '        Q_Som_ColR = Q_Som_ColR + Q_colRet(i)
        '        i = i + 1 'branchement sur la colonne suivante
        '        If i > Total_Noeud_Ext Then Exit Do
        '    Loop

        '    ReDim tr_noe(0)
        '    Parcours = False
        '    Do While Parcours = False
        '        If noe_br(i) <> Vdt(i4) Then
        '            If Tr_c(noe_br(i), 0) = Vdt(i4) Then
        '                'Pas de noeud intermédiaire entre noe_br(i) et Vdt(i4) - le noeud noe_br(i+1) est sur la même conduite que noe_br(i)
        '                Parcours = True : Exit Do
        '            Else
        '                '1 noeud intermédiaire entre noe_br(i) et Vdt(i4)
        '                For j = 1 To N_Collec(Vdt(i4))
        '                    If Tr_c(noe_br(i), 0) = Tr_c(Vdt(i4), j) Then
        '                        '1 noeud intermédiaire entre noe_br(i) et Vdt(i4)
        '                        Parcours = True
        '                        ReDim tr_noe(1)
        '                        tr_noe(1) = Tr_c(Vdt(i4), j)
        '                        Exit Do
        '                    End If
        '                Next
        '                'sinon vérification avec 2 noeuds intermédiaire
        '                If Parcours = False Then
        '                    '2 noeud intermédiaire entre noe_br(i) et Vdt(i4)
        '                    i2 = Tr_c(noe_br(i), 0)
        '                    For j = 1 To N_Collec(Vdt(i4))
        '                        For i1 = 1 To N_Collec(i2)
        '                            If Tr_c(i2, i1) = Tr_c(Vdt(i4), j) Then
        '                                '2 noeud intermédiaire entre noe_br(i) et Vdt(i4)
        '                                Parcours = True
        '                                ReDim tr_noe(2)
        '                                tr_noe(1) = Tr_c(Vdt(i4), j)
        '                                tr_noe(2) = i2
        '                                Exit Do
        '                            End If
        '                        Next
        '                    Next
        '                End If
        '                'sinon si plus de 2 noeuds intermédiaires

        '            End If
        '        End If
        '        i4 = i4 - 1
        '        If i4 = 0 Then
        '            MsgBox("Erreur modélisation - Ligne 1707", MsgBoxStyle.Critical Or vbOKOnly, "Module tableau débits")
        '            Verif = False
        '            Exit Sub
        '        End If
        '    Loop

        'Select Case N_Collec(Vdt(i4))
        '        Case 1
        '            If Tr_c(i4, 1) = noe_br(i) Then

        '            Else

        '            End If
        '        Case 2


        '            'Aller tronçon i
        '            'Perte_Thermique_Tronçon(Total_Noeud, N_Collec, Tr_c, Vdt(i4), Tr_c(Vdt(i4), 1), L_dev, Pth, Pthi)
        '            'Q_Som_Coli = Q_Som_Coli + Q_Som_Col
        '            'Q_deb(Vdt(i4), Tr_c(Vdt(i4), 1)) = Qglob - Q_Som_Coli
        '            'dT2 = (Pth_Tr(i) / (1.16 * Q_deb(Vdt(i4), Tr_c(Vdt(i4), 1))))
        '            'dT1 = dT1 + dT2
        '            'Vdt = noe_br(i)
        '            'V_Tr = Q_deb(Vdt(i4), Tr_c(Vdt(i4), 1)) / 1000 / (3600 * PI * Diam(noe_br(i - 1), 2) ^ 2 / 4)
        '            'Call Ligne_Tab_Debit_Recyclage_2(3, i, noe_br(i), N_Ext(i), Pth_col, Q_col, dT2, Debmin, V_Tr, Q_Tr, PthG1, Q_colRet, Pth_Tr, Q_deb, rtf) 'affichage de la ligne tronçon
        '            'retour tronçon i soit // au tronçon i
        '            If i <> 1 Then 'i2 = 1 And
        '                i1 = Total_Noeud + Total_NoeudBcl - i 'Total_Noeud + 1
        '                ''Do
        '                ''    If Tr_Bcl(j) = i1 Then Exit Do
        '                ''    i1 = i1 - 1 '+ 1
        '                ''Loop Until i1 = Total_Noeud + 1
        '                'PthG1 = L_devBcl(i1) * Pth(i1, 0)
        '                'V_Tr = Q_deb(noe_br(i - 1), noe_br(i)) / 1000 / (3600 * PI * DiamBcl(i1) ^ 2 / 4)
        '                'Q_Tr = 0
        '                'If V_Tr < Vmin Then Q_Tr = 1000 * Vmin * 3600 * PI * DiamBcl(i1) ^ 2 / 4 'pour débit en L/h
        '                'dTR2 = (PthG1 / (1.16 * Q_deb(noe_br(i - 1), noe_br(i))))
        '                'dTR1 = dTR1 + dTR2
        '                'If noe_br(i - 1) < noe_br(i) Then Inversion_colonne = True
        '                'Call Ligne_Tab_Debit_Recyclage_2(4, i, noe_br(i), i1 + 1, Pth_col, Q_col, dTR2, Debmin, V_Tr, Q_Tr, PthG1, Q_colRet, Pth_Tr, Q_deb, rtf) 'affichage de la ligne tronçon
        '            End If
        '            End If
        'Case 2
        '            'tronçon Aller
        '            For j = 1 To 10
        '                If Tr_c(noe_br(i), 0) = Tr_c(Vdt(i4), j) Then
        '                  
        '                End If
        '            Next

        '            If j = 11 Then
        '                MsgBox("Erreur modélisation", MsgBoxStyle.Critical Or vbOKOnly, "Module tableau débits") : Verif = False : Exit Sub
        '            End If

        '            Case 3
        '            Stop 'a faire
        '    End Select

        '' Else
        'Stop

        'tronçon aller collecteur i
        'Select Case UBound(tr_noe)
        '        Case 0 'pas de point intermédiaire
        '            Perte_Thermique_Tronçon(Total_Noeud, N_Collec, Tr_c, Vdt(i4), noe_br(i), L_dev, Pth, Pth_Tr(i))
        '            Q_Som_Coli = Q_Som_Coli + Q_Som_Col
        '            Q_deb(Vdt(i4), noe_br(i)) = Qglob - Q_Som_Coli
        '            dT2 = (Pth_Tr(i) / (1.16 * Q_deb(Vdt(i4), noe_br(i))))
        '            dT1 = dT1 + dT2
        '            V_Tr = Q_deb(Vdt(i4), noe_br(i)) / 1000 / (3600 * PI * Diam(noe_br(i - 1), 2) ^ 2 / 4)
        '            Call Ligne_Tab_Debit_Recyclage_2(3, i, Vdt(i4), noe_br(i), Pth_col, Q_col, dT2, Debmin, V_Tr, Q_Tr, PthG1, Q_colRet, Pth_Tr, Q_deb, rtf) 'affichage de la ligne tronçon
        '            i4 = UBound(Vdt)
        '            i4 = i4 + 1
        '            ReDim Preserve Vdt(i4)
        '            Vdt(i4) = noe_br(i)

        '        Case 1 '1 point intermédiaire
        '            Perte_Thermique_Tronçon(Total_Noeud, N_Collec, Tr_c, Vdt(i4), tr_noe(1), L_dev, Pth, Pthi)
        '            Perte_Thermique_Tronçon(Total_Noeud, N_Collec, Tr_c, tr_noe(1), noe_br(i), L_dev, Pth, Pth_Tr(i))
        '            Pth_Tr(i) = Pthi + Pth_Tr(i)
        '            'call nb_branchement
        '            nb_branchement = 2
        '            Q_deb(Vdt(i4), noe_br(i)) = nb_branchement * 80 'provisoire
        '            Q_Tr = Q_deb(Vdt(i4), noe_br(i))
        '            dT2 = (Pth_Tr(i) / (1.16 * Q_deb(Vdt(i4), noe_br(i))))
        '            dT1 = dT1 + dT2
        '            Call Ligne_Tab_Debit_Recyclage_2(3, i, Vdt(i4), noe_br(i), Pth_col, Q_col, dT2, Debmin, V_Tr, Q_Tr, PthG1, Q_colRet, Pth_Tr, Q_deb, rtf) 'affichage de la ligne tronçon
        '            i4 = UBound(Vdt)
        '            i4 = i4 + 1
        '            ReDim Preserve Vdt(i4)
        '            Vdt(i4) = noe_br(i)

        '        Case 2 '2 points intermédiaires
        '            i4 = UBound(Vdt)
        '            i4 = i4 + 1
        '            ReDim Preserve Vdt(i4)
        '            Vdt(i4) = noe_br(i)
        '    End Select
        '    'Tronçon retour // au tronçon Aller
        '    j = Tr_c(noe_br(i), 1)
        '    i1 = Tr_c(j, 1) 'déterminer dans le prog "Recherche_Noeud_Extremite" - i1 = n° du noeud se trouvant sur le collecteur retour sur lequel est raccordé la colonne retour
        '    For j = 1 To 10
        '        If i1 = Tr_Bcl_amont(Tr_Bcl_amont(Total_Noeud + Total_NoeudBcl, 1), j) Then
        '            PthG1 = L_devBcl(i1) * Pth(i1, 0)
        '            Q_deb(i1, Tr_Bcl_amont(Total_Noeud + Total_NoeudBcl, 1)) = Q_Tr 'débit identique au tronçon au dessus
        '            V_Tr = Q_Tr / 1000 / (3600 * PI * DiamBcl(i1) ^ 2 / 4)
        '            If V_Tr < Vmin Then Q_Tr = 1000 * Vmin * 3600 * PI * DiamBcl(i1) ^ 2 / 4 'pour débit en L/h
        '            dTR2 = (PthG1 / (1.16 * Q_Tr))
        '            dTR1 = dTR1 + dTR2
        '            ' If noe_br(i - 1) < noe_br(i) Then Inversion_colonne = True
        '            Call Ligne_Tab_Debit_Recyclage_2(4, i, i1, Tr_Bcl_amont(Total_Noeud + Total_NoeudBcl, 1), Pth_col, Q_col, dTR2, Debmin, V_Tr, Q_Tr, PthG1, Q_colRet, Pth_Tr, Q_deb, rtf) 'affichage de la ligne tronçon
        '            Exit For
        '        End If
        '    Next
        '    If j = 11 Then
        '        MsgBox("Erreur modélisation - Ligne 1819", MsgBoxStyle.Critical Or vbOKOnly, "Module tableau débits") : Verif = False : Exit Sub
        '    End If
        ''retour tronçon X soit // au tronçon X
        'If i <> 1 Then 'i2 = 1 And
        '    i1 = Total_Noeud + Total_NoeudBcl - i 'Total_Noeud + 1
        '    'Do
        '    '    If Tr_Bcl(j) = i1 Then Exit Do
        '    '    i1 = i1 - 1 '+ 1
        '    'Loop Until i1 = Total_Noeud + 1
        '    PthG1 = L_devBcl(i1) * Pth(i1, 0)
        '    V_Tr = Q_deb(noe_br(i - 1), noe_br(i)) / 1000 / (3600 * PI * DiamBcl(i1) ^ 2 / 4)
        '    Q_Tr = 0
        '    If V_Tr < Vmin Then Q_Tr = 1000 * Vmin * 3600 * PI * DiamBcl(i1) ^ 2 / 4 'pour débit en L/h
        '    dTR2 = (PthG1 / (1.16 * Q_deb(noe_br(i - 1), noe_br(i))))
        '    dTR1 = dTR1 + dTR2
        '    If noe_br(i - 1) < noe_br(i) Then Inversion_colonne = True
        '    Call Ligne_Tab_Debit_Recyclage_2(4, i, noe_br(i), i1 + 1, Pth_col, Q_col, dTR2, Debmin, V_Tr, Q_Tr, PthG1, Q_colRet, Pth_Tr, Q_deb, rtf) 'affichage de la ligne tronçon
        'End If


        ' Loop While i <= Total_Noeud_Ext   'Fin du calcul du réseau

        'rtf.WriteStartGroup()
        'rtf.NewLine()
        ''If Inversion_colonne = True Then
        ''    rtf.WriteString("Attention: retour colonne inversé - Vérifier la validité des retours température dans le tableau ci-dessous sinon utiliser la méthode de répartition.") : rtf.NewLine()
        ''End If
        'rtf.NewLine()
        'rtf.WriteString("Vérifications: ") : rtf.NewLine()
        ''Q_Som_Col = 0
        ''For i = 1 To Total_Noeud_Ext
        ''    Q_Som_Col = Q_Som_Col + Q_col(i)
        ''Next
        ''rtf.WriteString("Cumul débits sur les retours colonnes: " & Q_Som_ColR.ToString("#,###.0") & " L/h.") : rtf.NewLine()
        'rtf.WriteEndGroup()
        '  If Q_Som_ColR > Q_deb(1, noe_br(1)) Then
        'rtf.WriteStartGroup()
        'rtf.NewLine() : rtf.WriteString("Tableau correctif débits : ") : rtf.NewLine()
        'rtf.NewParagraph()
        'rtf.FontSize = 8
        ''Ligne 1
        'rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString("N° Amont") : rtf.EndCell()
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString("N° Aval") : rtf.EndCell()
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString("Q corrigé (L/h)") : rtf.EndCell()
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString("ΔT (°C)") : rtf.EndCell()
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString("T retour (°C)") : rtf.EndCell() : rtf.EndRow()
        ''Ligne 2
        'rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("Départ") : rtf.EndCell()
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString("1") : rtf.EndCell()
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(noe_br(1).ToString) : rtf.EndCell()
        'i = 1 : PthG1 = 0
        'Do
        '    PthG1 = PthG1 + L_dev(i, 1) * Pth(i, 1)
        '    i = i + 1
        'Loop While N_Collec(i) = 1
        'Q_deb(1, noe_br(1)) = Q_Som_ColR
        'dT1 = PthG1 / (1.16 * Q_deb(1, noe_br(1))) 'perte température sur les tronçons après le noeud 1 jusqu'au 1ier raccordement collectif
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(Q_deb(1, noe_br(1)).ToString("#,###.0")) : rtf.EndCell()
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(dT1.ToString("#0.000")) : rtf.EndCell()
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(" ") : rtf.EndCell() : rtf.EndRow()
        ''Ligne 3
        'rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("Retour général") : rtf.EndCell()
        'i = Total_Noeud + Total_NoeudBcl - 1
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(i.ToString) : rtf.EndCell()
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString((i + 1).ToString.ToString) : rtf.EndCell()
        'Q_deb(i, i + 1) = Q_Som_ColR
        'PthR1 = L_devBcl(i) * Pth(i, 0)
        'dTR1 = PthR1 / (1.16 * Q_deb(i, i + 1))
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(Q_deb(i, i + 1).ToString("#,###.0")) : rtf.EndCell()
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(dTR1.ToString("#0.000")) : rtf.EndCell()
        'rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(" ") : rtf.EndCell() : rtf.EndRow()
        ''ligne 4 et suivantes
        'j = i : i = 1 : Q_Som_Col1 = 0
        'Do
        '    'colonne i

        '    Do While noe_br(i) = Vdt
        '        rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("Colonne " & i.ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(noe_br(i).ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(N_Ext(i).ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(Q_colRet(i).ToString("#,###.0")) : rtf.EndCell()
        '        dt_ColA = Pth_col(i) / (1.16 * Q_colRet(i))
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(dt_ColA.ToString("#0.000")) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(" ") : rtf.EndCell() : rtf.EndRow()
        '        Q_Som_Col1 = Q_Som_Col1 + Q_colRet(i)
        '        Q_col(i) = Q_colRet(i)
        '        rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("Retour Colonne " & i.ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(N_Ext(i).ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(Tr_c(N_Ext(i), 1).ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(Q_colRet(i).ToString("#,###.0")) : rtf.EndCell()
        '        PthG1 = L_devCol(i1, i2) * Pth(i1, i2)
        '        dt_ColR = PthG1 / (1.16 * Q_colRet(i))
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(dt_ColR.ToString("#0.000")) : rtf.EndCell()
        '        If i = 1 Then
        '            Tg = TprodECS - dT1 - dTR1 - dt_ColA - dt_ColR
        '        Else
        '            Tg = TprodECS - dT1 - dt_ColA - dt_ColR
        '        End If
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(Tg.ToString("#0.000")) : rtf.EndCell() : rtf.EndRow()
        '        i = i + 1
        '        If i > Total_Noeud_Ext Then Exit Do
        '    Loop
        '    If i > Total_Noeud_Ext Then Exit Do
        '    'tronçon aller collecteur i
        '    If i = 1 Then
        '        Q_deb(1, noe_br(i)) = Q_Som_ColR - Q_Som_Col1
        '    Else
        '        Q_deb(noe_br(i - 1), noe_br(i)) = Q_Som_ColR - Q_Som_Col1
        '        ind = 2
        '        For k = 1 To 5
        '            If noe_br(i) = Tr_c(noe_br(i - 1), k) Then ind = 1 : Exit For
        '        Next
        '        If ind = 2 Then
        '            i1 = noe_br(i)
        '            Do
        '                i2 = Tr_c(i1, 0)
        '                Q_deb(i2, i1) = Q_deb(noe_br(i - 1), noe_br(i))
        '                i1 = i2
        '                If i2 = 0 Then Exit Do

        '            Loop Until i2 = noe_br(i - 1)
        '        End If
        '    End If
        '    Vdt = noe_br(i)
        '    If i <> 1 Then
        '        dT2 = (Pth_Tr(i) / (1.16 * Q_deb(noe_br(i - 1), noe_br(i))))
        '        dT1 = dT1 + dT2
        '        rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("tronçon " & i.ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(noe_br(i - 1).ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(noe_br(i).ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(Q_deb(noe_br(i - 1), noe_br(i)).ToString("#,###.0")) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(dT2.ToString("#0.000")) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(" ") : rtf.EndCell() : rtf.EndRow()
        '        rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("Retour tronçon " & i.ToString) : rtf.EndCell()
        '        i1 = Total_Noeud + Total_NoeudBcl - i  'noe amont
        '        j = Total_Noeud + Total_NoeudBcl - i + 1 'noe aval
        '        'Do
        '        '    If j = Tr_Bcl(i1) Then
        '        '        Exit Do
        '        '    End If
        '        '    i1 = i1 + 1
        '        '    If i1 > Total_Noeud + Total_NoeudBcl - 1 Then Exit Do
        '        'Loop
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(i1.ToString) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(j.ToString) : rtf.EndCell()
        '        PthG1 = L_devBcl(i1) * Pth(i1, 0)
        '        If Inversion_colonne = False Then
        '            Q_deb(i1, j) = Q_deb(noe_br(i - 1), noe_br(i))
        '        Else
        '            'provisoire
        '            Select Case i
        '                Case 2
        '                    Q_deb(i1, j) = Q_deb(1, noe_br(1)) - Q_col(i)
        '                Case 3
        '                    Q_deb(i1, j) = Q_deb(noe_br(i - 1), noe_br(i))
        '            End Select
        '        End If
        '        dt_ColR = PthG1 / (1.16 * Q_deb(i1, j))
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(Q_deb(i1, j).ToString("#,###.0")) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(dt_ColR.ToString("#0.000")) : rtf.EndCell()
        '        rtf.DeclareCell(1500) : rtf.BeginCell(True) : rtf.WriteString(" ") : rtf.EndCell() : rtf.EndRow()
        '    End If
        'Loop
        'rtf.WriteEndGroup()
        ' End If


        'Private Sub Debit_Colonne(ByVal i As Integer, ByVal i_Retour As Integer, ByVal noe_br() As Integer, ByVal Tr_c(,) As Integer, ByVal L_dev(,) As Double,
        '                              ByVal Pth(,) As Double, ByVal PthG1 As Double, ByVal Pth_col() As Double, ByVal dTBoucle As Double, ByVal Tr_Bcl() As Integer,
        '                              ByVal L_devBcl() As Double, ByRef Q_col() As Double, ByRef dT_col() As Double, ByRef dt_ColA As Double, ByRef dt_ColR As Double)
        '    '    'Tr_col(i1, j) =  nœud amont pour le nœud aval i1 pour le numéro de colonne i2
        '    '    'Pth_col(i) + PthG1: perte thermique colonne et son retour de colonne
        '    '    'noe_br(i): noeud de la base de la colonne
        '    '    'Tr_Bcl(i) = nœud aval à partir du nœud amont i
        '    '    'L_devBcl(i) =
        '    '    'PthBcl(i)

        '    '    Dim i1, i2, k, noe As Integer
        '    '    Dim Pth_Aller(1), Pth_Retour(1), Deb_Aller(1), Deb_Retour(1) As Double
        '    '    'calcul déperdition thermique sur circuit aller
        '    '    noe = Tr_c(noe_br(i), 0) : i1 = noe_br(i) '=n° du noeud se trouvant à la base de la colonne i
        '    '    i2 = 1
        '    '    Do
        '    '        For k = 1 To 5
        '    '            If Tr_c(noe, k) = i1 Then Exit For
        '    '        Next
        '    '        Pth_Aller(i2) = L_dev(noe, k) * Pth(noe, k)
        '    '        ' Deb_Aller(i2) =
        '    '        i1 = noe 'Tr_c(noe, 0) 'noeud amont
        '    '        noe = Tr_c(i1, 0) 'noeud amont
        '    '        i2 = i2 + 1
        '    '        ReDim Preserve Pth_Aller(i2), Deb_Aller(i2)
        '    '    Loop Until noe = 0
        '    '    'calcul déperdition thermique sur circuit Retour collecteur général boucle
        '    '    noe = Tr_Bcl(i_Retour) 'détermination du n° de départ
        '    '    '  Pth_Retour = 0
        '    '    Do
        '    '        Pth_Retour(i2) = Pth_Retour(i2) + L_devBcl(noe) * Pth(noe, 0)
        '    '        noe = Tr_Bcl(noe) 'noeud aval
        '    '    Loop Until noe = 0
        '    '    Q_col(i) = (Pth_Aller(i2) + Pth_Retour(i2) + Pth_col(i) + PthG1) / (1.16 * dTBoucle)
        '    '    dT_col(i) = (Pth_col(i) + PthG1) / (1.16 * Q_col(i))
        '    '    dt_ColA = Pth_col(i) / (1.16 * Q_col(i))
        '    '    dt_ColR = dT_col(i) - dt_ColA
        '    'End Sub
        '    'Private Sub Ligne_Tab_Debit_Recyclage_2(ByVal type_ligne As Integer, ByVal i As Integer, ByVal Noe_Amont As Integer, ByVal Noe_Aval As Integer, ByVal Pth_col() As Double,
        '    '                                        ByVal Q_col() As Double, ByVal dT As Double, ByVal Debmin As Double, ByVal V_Tr As Double, ByVal Q_tr As Double,
        '    '                                       ByVal PthG1 As Double, ByVal Q_colRet() As Double,
        '    '                                    ByVal Pth_Tr() As Double, ByVal Q_deb(,) As Double, ByRef rtf As RtfAnsiTextWriter)
        '    '    rtf.WriteStartGroup()
        '    '    rtf.FontSize = 12
        '    '    rtf.FontSize = 8
        '    '    Select Case type_ligne
        '    '        Case 1
        '    '            rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("Colonne " & i.ToString) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Noe_Amont.ToString) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Noe_Aval.ToString) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Pth_col(i).ToString("#,###.0")) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_col(i).ToString("#,###.0")) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(dT.ToString("#0.00")) : rtf.EndCell()
        '    '            If Q_col(i) < Debmin Then
        '    '                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Debmin.ToString("#,###.0")) : rtf.EndCell()
        '    '            Else
        '    '                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    '            End If
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(V_Tr.ToString("#0.00")) : rtf.EndCell()
        '    '            'If V_Tr < Vmin Then
        '    '            '    Q_Tr = 1000 * Vmin * 3600 * PI * Diam(noe_br(i), 1) ^ 2 / 4 'pour débit en L/h
        '    '            '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_Tr.ToString("#,###.0")) : rtf.EndCell()
        '    '            'Else
        '    '            'Q_tr = 0
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    '            ' End If
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_max(Q_col(i), Debmin, Q_tr).ToString("#,###.0")) : rtf.EndCell() : rtf.EndRow()
        '    '        Case 2 'Retour Colonne
        '    '            rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("Retour Colonne " & i.ToString) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Noe_Amont.ToString) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Noe_Aval.ToString) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(PthG1.ToString("#,###.0")) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_col(i).ToString("#,###.0")) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(dT.ToString("#0.00")) : rtf.EndCell()
        '    '            If Q_col(i) < Debmin Then
        '    '                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Debmin.ToString("#,###.0")) : rtf.EndCell()
        '    '            Else
        '    '                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    '            End If
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(V_Tr.ToString("#0.00")) : rtf.EndCell()
        '    '            If Q_tr = 0 Then
        '    '                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    '            Else
        '    '                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_tr.ToString("#,###.0")) : rtf.EndCell()
        '    '            End If
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_colRet(i).ToString("#,###.0")) : rtf.EndCell() : rtf.EndRow()
        '    '        Case 3 'tronçon n°i
        '    '            rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("tronçon " & i.ToString) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Noe_Amont.ToString) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Noe_Aval.ToString) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Pth_Tr(i).ToString("#,###.0")) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_deb(Noe_Amont, Noe_Aval).ToString("#,###.0")) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(dT.ToString("#0.00")) : rtf.EndCell()
        '    '            If Q_deb(Noe_Amont, Noe_Aval) < Debmin Then
        '    '                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Debmin.ToString("#,###.0")) : rtf.EndCell()
        '    '            Else
        '    '                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    '            End If

        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(V_Tr.ToString("#0.00")) : rtf.EndCell()
        '    '            'If V_Tr < Vmin Then
        '    '            '    Q_Tr = 1000 * Vmin * 3600 * PI * Diam(noe_br(i - 1), 2) ^ 2 / 4 'pour débit en L/h
        '    '            '    rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_Tr.ToString("#,###.0")) : rtf.EndCell()
        '    '            'Else
        '    '            Q_tr = 0
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    '            'End If
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_max(Q_deb(Noe_Amont, Noe_Aval), Debmin, Q_tr).ToString("#,###.0")) : rtf.EndCell() : rtf.EndRow()
        '    '        Case 4 'tronçon collecteur retour
        '    '            rtf.BeginRow() : rtf.DeclareCell(2000) : rtf.BeginCell(True) : rtf.WriteString("Retour tronçon " & i.ToString) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Noe_Amont.ToString) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Noe_Aval.ToString) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(PthG1.ToString("#,###.0")) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_deb(Noe_Amont, Noe_Aval).ToString("#,###.0")) : rtf.EndCell()
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(dT.ToString("#0.00")) : rtf.EndCell()
        '    '            If Q_deb(Noe_Amont, Noe_Aval) < Debmin Then
        '    '                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Debmin.ToString("#,###.0")) : rtf.EndCell()
        '    '            Else
        '    '                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    '            End If
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(V_Tr.ToString("#0.00")) : rtf.EndCell()
        '    '            If Q_tr = 0 Then
        '    '                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("") : rtf.EndCell()
        '    '            Else
        '    '                rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_tr.ToString("#,###.0")) : rtf.EndCell()
        '    '            End If
        '    '            rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(Q_max(Q_deb(Noe_Amont, Noe_Aval), Debmin, Q_tr).ToString("#,###.0")) : rtf.EndCell() : rtf.EndRow()
        '    '    End Select
        '    '    rtf.WriteEndGroup()

        '      Private Sub calcul_branche(ByVal total As Integer, ByVal branche() As Integer, ByRef n_app_Br() As Integer, ByRef tot_debit_br() As Double, ByRef noe_br1() As Integer,
        '                         ByVal Tr_c(,) As Integer, ByVal Tr_i(,) As Integer, ByVal N_appareil() As Integer, ByVal Q_Exut() As Double, ByVal V_limit(,) As Double,
        '                          ByVal Matiere_Tube(,) As Integer, ByVal DiamImpos(,) As Double, ByVal Ycoef As Double,
        '                          ByRef j As Integer, ByRef total_deb() As Double, ByRef diam_tr() As Double, ByRef J_tr() As Double, ByRef n_app_Tr() As Integer,
        '                          ByRef tot_debit_Tr() As Double, ByRef k2 As Integer, ByRef Nom_tr() As String, ByRef Aval_tr() As Integer, ByRef Amont_tr() As Integer, ByRef Verif As Boolean, ByRef rtf As RtfAnsiTextWriter)
        '    Dim i, i1, k, k1, noe As Integer ' , noe1 

        '    Dim y, Ø_int As Double
        '    i1 = noe_br1(branche(1))
        '    noe = Tr_c(noe_br1(branche(1)), 0) 'noeud amont
        '    j = j + 1
        '    rtf.WriteStartGroup()
        '    rtf.FontSize = 10 : rtf.FontSize = 8
        '    rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(j.ToString) : rtf.EndCell() '"Tronçon n° 
        '    Aval_tr(j) = i1 : Amont_tr(j) = noe
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(i1.ToString) : rtf.EndCell() '"Noeud aval 
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(noe.ToString) : rtf.EndCell() '"Noeud amont 
        '    'cumul sur le noeud amont
        '    n_app_Tr(j) = n_app_Br(branche(1))
        '    tot_debit_Tr(j) = tot_debit_br(branche(1))
        '    For i = 2 To total
        '        n_app_Tr(j) = n_app_Tr(j) + n_app_Br(branche(i))
        '        tot_debit_Tr(j) = tot_debit_Tr(j) + tot_debit_br(branche(i))
        '    Next
        '    'cumul sur les appareils branchés individuellement sur le noeud
        '    k1 = 1
        '    Do
        '        n_app_Tr(j) = n_app_Tr(j) + N_appareil(Tr_i(i1, k1))
        '        tot_debit_Tr(j) = tot_debit_Tr(j) + Q_Exut(Tr_i(i1, k1))
        '        k1 = k1 + 1
        '        If k1 = 6 Then Exit Do 'limité à 6 branchement individuel
        '    Loop Until Tr_i(i1, k1) = 0
        '    'dimensionnement diamètre et pdc
        '    y = Ycoef * 0.8 / (n_app_Tr(j) - 1) ^ 0.5
        '    total_deb(j) = y * tot_debit_Tr(j)
        '    'détermination du n° de départ
        '    For k = 1 To 5
        '        If Tr_c(noe, k) = i1 Then Exit For
        '    Next
        '    If DiamImpos(noe, k) < 0.001 Then
        '        diam_tr(j) = Calcul_diametre(total_deb(j), V_limit(noe, k), Matiere_Tube(noe, k))
        '    Else
        '        diam_tr(j) = DiamImpos(noe, k)
        '    End If
        '    J_tr(j) = J_Flamant(total_deb(j), diam_tr(j), Modele_Calcul, Verif) 'formule de flamant
        '    If Verif = False Then rtf.WriteEndGroup() : Exit Sub
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(n_app_Tr(j).ToString("#")) : rtf.EndCell() '"   - nombre d'appareil: " &
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(tot_debit_Tr(j).ToString("#0.000")) : rtf.EndCell() '"   - débit total: " && "L/s"
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(y.ToString("#0.000")) : rtf.EndCell() '"   - y coef. pondéré: " & 
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(total_deb(j).ToString("#0.000")) : rtf.EndCell() '"   - débit pondéré total: " & & "L/s"
        '    If DiamImpos(noe, k) < 0.001 Then
        '        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(V_limit(noe, k).ToString("#0.00")) : rtf.EndCell() '"   - vitesse limite: " && "m/s"
        '        Ø_int = Sqrt(total_deb(j) * 0.001 * 4 / (V_limit(noe, k) * PI)) * 1000 'en mm
        '    Else
        '        Dim V As Double
        '        V = total_deb(j) * 0.001 / (diam_tr(j) ^ 2 * PI / 4)
        '        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(V.ToString("#0.00")) : rtf.EndCell() '"   - vitesse limite: " && "m/s"
        '        Ø_int = diam_tr(j) * 1000 'en mm
        '    End If
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Ø_int.ToString("#0.0")) : rtf.EndCell() '- diamètre minimal intérieur en mm.
        '    Nom_tr(j) = libel_diametre(diam_tr(j), Matiere_Tube(noe, k))
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Nom_tr(j)) : rtf.EndCell() : rtf.EndRow() '- diamètre normalisé retenu
        '    '  rtf.WriteString("   - J : " & (J_tr(j) * 1).ToString("#0.00") & " mCE.") : rtf.NewLine()
        '    'réarrangement du graphe
        '    noe_br1(branche(1)) = noe
        '    n_app_Br(branche(1)) = n_app_Tr(j)
        '    tot_debit_br(branche(1)) = tot_debit_Tr(j)
        '    For i = 2 To total
        '        noe_br1(branche(i)) = 0
        '    Next
        '    '        'vérification que le tronçon amont soit unique
        '    '        k = 1
        '    '        Do Until Tr_c(noe, k) = noe_br(i)
        '    '            k = k + 1
        '    '        Loop
        '    '        i1 = Tr_c(noe, 0) 'noeud amont
        '    '        If k <> 1 Then
        '    '            k2 = k2 + 1
        '    '            n_app_Br(k2) = n_app(i)
        '    '            tot_debit_br(k2) = tot_debit(i)
        '    '            noe_br(k2) = i1
        '    '        End If
        '    '    Loop While k = 1
        '    'Next
        '    rtf.WriteEndGroup()
        'End Sub

        'Private Sub Calcul_debit(ByVal Total_Noeud As Integer, ByVal total_Noeud_Ext As Integer, ByVal Diam_Exut() As Double, ByVal Q_Exut() As Double, ByVal N_appareil() As Integer,
        '                            ByVal N_ext() As Integer, ByVal Tr_c(,) As Integer, ByVal V_limit(,) As Double, ByVal Tr_i(,) As Integer, ByVal Matiere_Tube(,) As Integer,
        '                         ByVal DiamImpos(,) As Double, ByVal Ycoef As Double, ByVal Q_Exut_Pond() As Double,
        '                         ByRef Total_Tronçon As Integer, ByRef total_deb() As Double, ByRef diam_tr() As Double, ByRef Aval_tr() As Integer, ByRef Amont_tr() As Integer,
        '                           ByRef Nom_Tr() As String, ByRef noe_br() As Integer, ByRef Verif As Boolean, ByRef rtf As RtfAnsiTextWriter)
        '       Dim i, i1, ind, j, k, k1, noe, n_app(total_Noeud_Ext), n_app_Tr(Total_Noeud), noe_br1(total_Noeud_Ext) As Integer ' k2,n_app_Br(Total_Noeud),
        '       Dim J_tr(Total_Noeud), y, tot_debit_Tr(Total_Noeud), tot_debit(total_Noeud_Ext), Ø_int As Double ', tot_debit_br(Total_Noeud)
        '       ReDim total_deb(Total_Noeud), diam_tr(Total_Noeud), Aval_tr(Total_Noeud), Amont_tr(Total_Noeud), Nom_Tr(Total_Noeud), noe_br(total_Noeud_Ext)
        '       j = 0 ': k2 = 0
        '       rtf.WriteStartGroup()
        '       Select Case Matiere_Tube(1, 1)
        '           Case 1
        '               rtf.WriteString("Tuyauteries en cuivre") : k = 1
        '           Case 2
        '               rtf.WriteString("Tuyauteries en acier galvanisé") : k = 2 : rtf.NewLine()
        '           Case 3
        '               rtf.WriteString("Tuyauteries en PER") : k = 3 : rtf.NewLine()
        '           Case 4
        '               rtf.WriteString("Tuyauteries en multicouche") : k = 4 : rtf.NewLine()
        '       End Select
        '       For i = 2 To Total_Noeud
        '           For j = 1 To 2
        '               If Matiere_Tube(i, j) > 0 And Matiere_Tube(i, j) <> k Then
        '                   Select Case k
        '                       Case 1
        '                           rtf.WriteString(" et en cuivre") : rtf.NewLine()
        '                       Case 2
        '                           rtf.WriteString(" et en galvanisé") : rtf.NewLine()
        '                       Case 3
        '                           rtf.WriteString(" et en PER") : rtf.NewLine()
        '                       Case 4
        '                           rtf.WriteString(" et en multicouche") : rtf.NewLine()
        '                   End Select
        '                   j = 3 : Exit For
        '               End If
        '           Next
        '           If j = 3 Then Exit For
        '       Next
        '       j = 0
        '       rtf.NewParagraph()
        '       rtf.FontSize = 8
        '       'Ligne 1
        '       rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        '       rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Aval") : rtf.EndCell()
        '       rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Amont") : rtf.EndCell()
        '       rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Nb appareils") : rtf.EndCell()
        '       rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Q brut (l/s)") : rtf.EndCell()
        '       rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("(Y) coef. Simult.") : rtf.EndCell()
        '       rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Q prob (l/s)") : rtf.EndCell()
        '       rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("V lim (m/s)") : rtf.EndCell()
        '       rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Ø int (mm)") : rtf.EndCell()
        '       rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Ø retenue") : rtf.EndCell() : rtf.EndRow()
        '       For i = 1 To total_Noeud_Ext
        '           j = j + 1
        '           k = 1 : n_app(i) = 0 : tot_debit(i) = 0
        '           rtf.BeginRow() : rtf.DeclareCell(10000) : rtf.BeginCell(True) : rtf.WriteString("Colonne n°" & CStr(i)) : rtf.EndCell() : rtf.EndRow()
        '           rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(j.ToString) : rtf.EndCell() '"Tronçon n°"
        '           Do
        '               n_app(i) = n_app(i) + N_appareil(Tr_i(N_ext(i), k))
        '               tot_debit(i) = tot_debit(i) + Q_Exut(Tr_i(N_ext(i), k))
        '               k = k + 1
        '               If k = 6 Then Exit Do 'limité à 5 branchement individuel
        '           Loop Until Tr_i(N_ext(i), k) = 0
        '           Aval_tr(j) = N_ext(i)
        '           rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Aval_tr(j).ToString) : rtf.EndCell()
        '           noe = Tr_c(N_ext(i), 0) : Amont_tr(j) = noe
        '           rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Amont_tr(j).ToString) : rtf.EndCell()
        '           If k > 2 Then 'au minimum 2 branchements individuels
        '               y = Ycoef * 0.8 / (n_app(i) - 1) ^ 0.5
        '               total_deb(j) = y * tot_debit(i)
        '               If DiamImpos(noe, 1) < 0.001 Then
        '                   diam_tr(j) = Calcul_diametre(total_deb(j), V_limit(noe, 1), Matiere_Tube(noe, 1))
        '               Else
        '                   diam_tr(j) = DiamImpos(noe, 1)
        '               End If
        '               J_tr(j) = J_Flamant(total_deb(j), diam_tr(j), Modele_Calcul, Verif) 'formule de flamant
        '               If Verif = False Then rtf.WriteEndGroup() : Exit Sub
        '               'rtf.WriteString(" - J : " & (J_tr(j) * 1).ToString("#0.00") & " mCE.") : rtf.NewLine()
        '           Else
        '               total_deb(j) = Q_Exut_Pond(Tr_i(N_ext(i), 1)) 'dimensionnement uniquement sur le débit probable individuel
        '               If DiamImpos(noe, 1) < 0.001 Then
        '                   diam_tr(j) = Diam_Exut(Tr_i(N_ext(i), 1))
        '               Else
        '                   diam_tr(j) = DiamImpos(noe, 1)
        '               End If
        '               '  J_tr(j) = J_Diam_Exut(i)
        '           End If
        '           tot_debit_Tr(j) = tot_debit(i) 'cumul sans pondération
        '           n_app_Tr(j) = n_app(i) 'nbre d'appareil par tronçon
        '           rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(n_app_Tr(j).ToString("#")) : rtf.EndCell()
        '           rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(tot_debit_Tr(j).ToString("#0.000")) : rtf.EndCell()
        '           If k > 2 Then
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(y.ToString("#")) : rtf.EndCell()
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(total_deb(j).ToString("#0.000")) : rtf.EndCell()
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(V_limit(noe, 1).ToString("#0.00")) : rtf.EndCell() '"   - vitesse limite: " && "m/s"
        '               Ø_int = Sqrt(total_deb(j) * 0.001 * 4 / (V_limit(noe, 1) * PI)) * 1000 'en mm
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Ø_int.ToString("#0.0")) : rtf.EndCell()
        '           Else
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("NA") : rtf.EndCell()
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("NA") : rtf.EndCell()
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("NA") : rtf.EndCell()
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((diam_tr(j) * 1000).ToString("#0.0")) : rtf.EndCell()
        '           End If
        '           Nom_Tr(j) = libel_diametre(diam_tr(j), Matiere_Tube(noe, 1))
        '           rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Nom_Tr(j)) : rtf.EndCell() : rtf.EndRow()
        '           i1 = Tr_c(N_ext(i), 0) 'noe amont du noe terminal de la colonne
        '           Do
        '               j = j + 1
        '               noe = Tr_c(i1, 0) 'noeud amont
        '               rtf.BeginRow() : rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(j.ToString) : rtf.EndCell() '"Tronçon n° 
        '               Aval_tr(j) = i1 : Amont_tr(j) = noe
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(i1.ToString) : rtf.EndCell() '"Noeud aval 
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(noe.ToString) : rtf.EndCell() '"Noeud amont 
        '               'permet de déterminer si plusieurs branchement sur le noeud noe
        '               If Tr_c(noe, 2) <> 0 Then
        '                   ind = 2
        '                   'détermination du n° de départ
        '                   For k = 1 To 5
        '                       If Tr_c(noe, k) = i1 Then Exit For
        '                   Next
        '               Else
        '                   ind = 1
        '                   k = 1 'k est le n° de départ
        '               End If
        '               k1 = 1
        '               Do
        '                   n_app(i) = n_app(i) + N_appareil(Tr_i(i1, k1))
        '                   tot_debit(i) = tot_debit(i) + Q_Exut(Tr_i(i1, k1))
        '                   k1 = k1 + 1
        '                   If k1 = 6 Then Exit Do 'limité à 6 branchement individuel
        '               Loop Until Tr_i(i1, k1) = 0
        '               n_app_Tr(j) = n_app(i) 'nbre d'appareil par tronçon
        '               tot_debit_Tr(j) = tot_debit(i) 'cumul sans pondération
        '               y = Ycoef * 0.8 / (n_app(i) - 1) ^ 0.5
        '               total_deb(j) = y * tot_debit(i)
        '               If DiamImpos(noe, 1) < 0.001 Then
        '                   diam_tr(j) = Calcul_diametre(total_deb(j), V_limit(noe, k), Matiere_Tube(noe, k)) 'car sur colonne montante
        '               Else
        '                   diam_tr(j) = DiamImpos(noe, k)
        '               End If

        '               J_tr(j) = J_Flamant(total_deb(j), diam_tr(j), Modele_Calcul, Verif) 'formule de flamant
        '               If Verif = False Then rtf.WriteEndGroup() : Exit Sub
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(n_app_Tr(j).ToString("#")) : rtf.EndCell() '"   - nombre d'appareil: " &
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(tot_debit_Tr(j).ToString("#0.000")) : rtf.EndCell() '"   - débit total: " && "L/s"
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(y.ToString("#0.000")) : rtf.EndCell() '"   - y coef. pondéré: " & 
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(total_deb(j).ToString("#0.000")) : rtf.EndCell() '"   - débit pondéré total: " & & "L/s"
        '               If DiamImpos(noe, k) < 0.001 Then
        '                   rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(V_limit(noe, k).ToString("#0.00")) : rtf.EndCell() '"   - vitesse limite: " && "m/s"
        '                   Ø_int = Sqrt(total_deb(j) * 0.001 * 4 / (V_limit(noe, k) * PI)) * 1000 'en mm
        '               Else
        '                   Dim V As Double
        '                   V = total_deb(j) * 0.001 / (diam_tr(j) ^ 2 * PI / 4)
        '                   rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(V.ToString("#0.00")) : rtf.EndCell() '"   - vitesse limite: " && "m/s"
        '                   Ø_int = diam_tr(j) * 1000 'en mm
        '               End If
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Ø_int.ToString("#0.0")) : rtf.EndCell()

        '               Nom_Tr(j) = libel_diametre(diam_tr(j), Matiere_Tube(noe, k))
        '               rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Nom_Tr(j)) : rtf.EndCell() : rtf.EndRow()
        '               i1 = noe 'Tr_c(noe, 0) 'noeud amont
        '               If ind = 2 Then
        '                   'k2 = k2 + 1
        '                   ' n_app_Br(k2) = n_app(i)
        '                   ' tot_debit_br(k2) = tot_debit(i)
        '                   noe_br(i) = noe 'noeud amont précédent' noe_br(k2)'noe de raccordement sur le collecteur
        '                   noe_br1(i) = noe
        '               End If
        '           Loop While ind = 1

        '       Next
        '       Dim k3, branche(1) As Integer
        '       Dim Passage As Boolean = True
        '       rtf.BeginRow() : rtf.DeclareCell(10000) : rtf.BeginCell(True) : rtf.WriteString("Collecteur") : rtf.EndCell() : rtf.EndRow()
        '       rtf.WriteEndGroup()
        '       Total_Tronçon = j
        '       Do
        '           Passage = False
        '           For i = 1 To total_Noeud_Ext - 1
        '               k3 = 1
        '               For k = i + 1 To total_Noeud_Ext 'k2
        '                   If noe_br1(i) = noe_br1(k) And noe_br1(i) <> 0 Then
        '                       k3 = k3 + 1
        '                       ReDim Preserve branche(k3)
        '                       branche(1) = i : branche(k3) = k
        '                   End If
        '               Next
        '               If k3 > 1 Then
        '                   calcul_branche(k3, branche, n_app, tot_debit, noe_br1, Tr_c, Tr_i, N_appareil, Q_Exut, V_limit, Matiere_Tube, DiamImpos, Ycoef, Total_Tronçon, total_deb, diam_tr, J_tr,
        '                                 n_app_Tr, tot_debit_Tr, total_Noeud_Ext, Nom_Tr, Aval_tr, Amont_tr, Verif, rtf)
        '                   Passage = True
        '               End If
        '           Next
        '       Loop While Passage = True
        '       Erase n_app, n_app_Tr, noe_br1, J_tr, tot_debit_Tr, tot_debit 'libération mémoire
        '   End Sub

        '       Private Sub Debit_Exutoire(ByVal Total_Noeud As Integer, ByVal Total_Exutoire As Integer, ByVal N_App(,) As Integer, ByVal Matiere_TubeInd(,) As Integer, ByVal Ycoef As Double,
        '                           ByVal Tr_i(,) As Integer, ByRef Q_Exut() As Double, ByRef Q_Exut_Pond() As Double, ByRef Diam_Exut() As Double, ByRef J_Diam_Exut() As Double,
        '                            ByRef N_appareil() As Integer, ByRef Verif As Boolean, ByRef rtf As To_Rtf.RtfAnsiTextWriter)
        '    Dim i, j, i1, j1, k As Integer
        '    Dim Y_tot(Total_Exutoire) As Double
        '    rtf.WriteStartGroup() : rtf.NewLine()
        '    For i = 1 To Total_Exutoire
        '        Q_Exut(i) = 0 : Q_Exut_Pond(i) = 0 : N_appareil(i) = 0
        '        rtf.WriteString("Exutoire de type n°" & CStr(i) & " comprenant:") : rtf.NewLine()
        '        Select Case Modele_Calcul
        '            Case 1 'EF
        '                For j = 0 To 24
        '                    Q_Exut(i) = Q_Exut(i) + N_App(i, j) * Q_EF(j)
        '                    Y_tot(i) = Y_tot(i) + N_App(i, j) * Y_App(j)
        '                    Q_Exut_Pond(i) = Q_Exut_Pond(i) + N_App(i, j) * Q_EF(j) * Y_App(j)
        '                    N_appareil(i) = N_appareil(i) + N_App(i, j)
        '                    If N_App(i, j) > 0.1 Then
        '                        rtf.WriteString("---- " & N_App(i, j).ToString & " " & Q_Name(j) & " - Ø alim inviduelle intérieur mini: " & Di_EF(j).ToString("#") & " mm.") : rtf.NewLine()
        '                    End If
        '                Next
        '            Case 2 'ECS
        '                For j = 0 To 24
        '                    Q_Exut(i) = Q_Exut(i) + N_App(i, j) * Q_EC(j)
        '                    Y_tot(i) = Y_tot(i) + N_App(i, j) * Y_App(j)
        '                    Q_Exut_Pond(i) = Q_Exut_Pond(i) + N_App(i, j) * Q_EC(j) * Y_App(j)
        '                    N_appareil(i) = N_appareil(i) + N_App(i, j)
        '                    If N_App(i, j) > 0.1 Then
        '                        rtf.WriteString("---- " & N_App(i, j).ToString & " " & Q_Name(j) & " - Ø alim inviduelle intérieur mini: " & Di_EC(j).ToString("#") & " mm.") : rtf.NewLine()
        '                    End If
        '                Next
        '        End Select

        '        rtf.WriteString(" - débit total brut: " & Q_Exut(i).ToString("#0.000") & " L/s.") : rtf.NewLine()
        '        rtf.WriteString(" - nombre total d'appareil: " & N_appareil(i).ToString) : rtf.NewLine()
        '        If N_appareil(i) > 1 Then
        '            rtf.WriteString(" - coefficient simultanéité sur installation individuelle: " & Y_tot(i).ToString("#0.000")) : rtf.NewLine()
        '            Select Case Y_tot(i)
        '                Case Is <= 15
        '                    J_Diam_Exut(i) = 0
        '                    Diam_Exut(i) = Diam_Exutoire(Y_tot(i))
        '                    rtf.WriteString("coefficient simultanéité < 15 - Application des conditions de simultanéité des parties individuelles.") : rtf.NewLine()
        '                    rtf.WriteString(" - débit total pondéré: " & Q_Exut_Pond(i).ToString("#0.000") & " L/s.") : rtf.NewLine()
        '                    k = 1
        '                    For i1 = 1 To Total_Noeud
        '                        For j1 = 1 To 5
        '                            If Tr_i(i1, j1) = i Then
        '                                Select Case Matiere_TubeInd(i1, j1)
        '                                    Case 1
        '                                        rtf.WriteString(" soit en tube cuivre " & libel_diametre(Diam_Exut(i), 1)) : rtf.NewLine()
        '                                        k = 2 : Exit For
        '                                    Case 2
        '                                        rtf.WriteString(" soit en tube galvanisé " & libel_diametre(Diam_Exut(i), 2)) : rtf.NewLine()
        '                                        k = 2 : Exit For
        '                                    Case 3
        '                                        rtf.WriteString(" soit en tube PER " & libel_diametre(Diam_Exut(i), 3)) : rtf.NewLine()
        '                                        k = 2 : Exit For
        '                                    Case 4
        '                                        rtf.WriteString(" soit en tube multicouche " & libel_diametre(Diam_Exut(i), 4)) : rtf.NewLine()
        '                                        k = 2 : Exit For
        '                                End Select
        '                            End If
        '                        Next
        '                        If k = 2 Then Exit For
        '                    Next
        '                Case Is > 15
        '                    rtf.WriteString("coefficient simultanéité > 15 - Application des conditions de simultanéité des parties collectives.") : rtf.NewLine()
        '                    rtf.WriteString(" - vitesse limite de dimensionnement retenue: " & VlimIndiv.ToString("#0.00") & " m/s") : rtf.NewLine()
        '                    Y_tot(i) = Ycoef * 0.8 / (N_appareil(i) - 1) ^ 0.5
        '                    Q_Exut_Pond(i) = Y_tot(i) * Q_Exut(i)
        '                    k = 1
        '                    For i1 = 1 To Total_Noeud
        '                        For j1 = 1 To 5
        '                            If Tr_i(i1, j1) = i Then
        '                                Select Case Matiere_TubeInd(i1, j1)
        '                                    Case 1
        '                                        Diam_Exut(i) = Calcul_diametre(Q_Exut_Pond(i), VlimIndiv, 1) ' Matiere_Tube)Matiere_TubeInd
        '                                        rtf.WriteString(" - diamètre minimal intérieur: " & (Diam_Exut(i) * 1000).ToString("#0.0") & " mm.")
        '                                        rtf.WriteString(" soit en tube cuivre " & libel_diametre(Diam_Exut(i), 1)) : rtf.NewLine()
        '                                        k = 2 : Exit For
        '                                    Case 2
        '                                        Diam_Exut(i) = Calcul_diametre(Q_Exut_Pond(i), VlimIndiv, 2) ' Matiere_Tube)Matiere_TubeInd
        '                                        rtf.WriteString(" - diamètre minimal intérieur: " & (Diam_Exut(i) * 1000).ToString("#0.0") & " mm.")
        '                                        rtf.WriteString(" soit en tube galvanisé " & libel_diametre(Diam_Exut(i), 2)) : rtf.NewLine()
        '                                    Case 3
        '                                        Diam_Exut(i) = Calcul_diametre(Q_Exut_Pond(i), VlimIndiv, 3) ' Matiere_Tube)Matiere_TubeInd
        '                                        rtf.WriteString(" - diamètre minimal intérieur: " & (Diam_Exut(i) * 1000).ToString("#0.0") & " mm.")
        '                                        rtf.WriteString(" soit en tube PER " & libel_diametre(Diam_Exut(i), 3)) : rtf.NewLine()
        '                                    Case 4
        '                                        Diam_Exut(i) = Calcul_diametre(Q_Exut_Pond(i), VlimIndiv, 4) ' Matiere_Tube)Matiere_TubeInd
        '                                        rtf.WriteString(" - diamètre minimal intérieur: " & (Diam_Exut(i) * 1000).ToString("#0.0") & " mm.")
        '                                        rtf.WriteString(" soit en tube multicouche " & libel_diametre(Diam_Exut(i), 4)) : rtf.NewLine()
        '                                End Select
        '                            End If
        '                        Next
        '                        If k = 2 Then Exit For
        '                    Next
        '                    J_Diam_Exut(i) = J_Flamant(Q_Exut(i), Diam_Exut(i), Modele_Calcul, Verif) 'formule de flamant
        '                    If Verif = False Then rtf.WriteEndGroup() : Exit Sub
        '            End Select
        '            If J_Diam_Exut(i) = 0 Then
        '                rtf.WriteString(" - J = 0 mCE. Perte de charge non significative sur la partie de tronçon individuel. Ne doit pas être pris en compte dans les calculs.") : rtf.NewLine()
        '            Else
        '                rtf.WriteString(" - J : " & (J_Diam_Exut(i) * 1).ToString("#0.00") & " mCE/m. Perte de charge significative sur la partie de tronçon individuel. A tenir compte dans les calculs.") : rtf.NewLine()
        '            End If

        '        End If
        '    Next
        '    rtf.WriteEndGroup()
        'End Sub
        '      Public Sub Calcul_EF(ByVal Total_Noeud As Integer, ByVal N_Collec() As Integer, ByVal N_Indiv() As Integer, ByVal Total_Exutoire As Integer, ByVal N_App(,) As Integer,
        '                     ByVal Tr_c(,) As Integer, ByVal Tr_i(,) As Integer, ByVal V_limit(,) As Double, ByVal L_dev(,) As Double, ByVal Hp(,) As Double,
        '                     ByVal Matiere_Tube(,) As Integer, ByVal DiamImpos(,) As Double, ByVal Matiere_TubeInd(,) As Integer, ByVal Ycoef As Double, ByVal PdcVanne As Double, ByVal PdcCompteur As Double,
        '                     ByVal PdcDisconnecteur As Double, ByVal PdcFiltre As Double, ByVal PdcPrepECS As Double, ByVal PdcReduc As Double, ByVal PrEntree As Double,
        '                     ByVal PrResiduel As Double, ByRef Verif As Boolean, ByVal Ecriture As Boolean, Optional ByRef note_de_calcul As String = "")
        '    Dim total_Noeud_Ext, N_appareil(Total_Exutoire), N_Ext(), Total_Tronçon, Aval_tr(), Amont_tr(), noe_br() As Integer
        '    Dim Q_Exut(Total_Exutoire), Q_Exut_Pond(Total_Exutoire), Diam_Exut(Total_Exutoire), J_Diam_Exut(Total_Exutoire), Δp_Entree, total_deb(), diam_tr() As Double

        '    Dim msg, Nom_Tr() As String
        '    Verif = True
        '    'writer de sortie du RTF
        '    Dim sw As New System.IO.StringWriter
        '    'crée un writer de RTF avec une police par défaut
        '    Dim rtf As New To_Rtf.RtfAnsiTextWriter(sw, New Font(FontFamily.GenericSerif, 12, FontStyle.Regular))
        '    Dim rtff As String
        '    rtf.Bold = True : rtf.FontSize = 16 : rtf.Underline = True
        '    'Select Case Modele_Calcul
        '    '    Case 1
        '    '        rtf.WriteString("Note de calcul de dimensionnement de réseau eau froide sanitaire")
        '    '    Case 2
        '    '        rtf.WriteString("Note de calcul de dimensionnement de réseau eau chaude sanitaire")
        '    'End Select
        '    rtf.NewLine()
        '    rtf.Bold = False : rtf.FontSize = 10 : rtf.Underline = False : rtf.NewParagraph()
        '    rtf.WriteString("Note de calcul du : ") : msg = Mise_en_Forme(CStr(DateTime.Now)) : rtf.WriteString(msg) : rtf.NewLine()
        '    rtf.WriteString("Rédacteur : " & Redacteur) : rtf.NewLine()
        '    rtf.WriteString("Chantier : " & Chantier) : rtf.NewLine()
        '    rtf.WriteString("Logiciel : Calculette Plomberie version 1.0  2014") : rtf.NewLine()
        '    rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        '    rtf.WriteString("1 - Rappel des hypothèses") : rtf.Bold = False
        '    rtf.FontSize = 10 : rtf.Underline = False : rtf.NewLine() : rtf.NewLine()
        '    rtf.WriteString("Codes de calculs:") : rtf.NewLine()
        '    rtf.WriteString("-  Débits suivant DTU 60.11 d'octobre 1988") : rtf.NewLine()
        '    rtf.WriteString("-  Coefficients de simultanéité suivant DTU ")
        '    If Ycoef = 1 Then
        '        rtf.WriteString("sans coefficient de correction.") : rtf.NewLine()
        '    Else
        '        rtf.WriteString("avec coefficient de correction pris égal à " & Ycoef.ToString("0.00")) : rtf.NewLine()
        '    End If
        '    rtf.WriteString("-  Dimensions minimales des tuyauteries sur tronçons individuels suivant DTU") : rtf.NewLine()
        '    'rtf.WriteString("Pression résiduelle au branchement prise égale à ")
        '    'Select Case Modele_Calcul
        '    '    Case 1
        '    '        rtf.WriteString(Pr_EFS.ToString("#0.00") & " bar (" & (Pr_EFS * 10).ToString("#0.0") & " mCE)") : rtf.NewLine()
        '    '    Case 2
        '    '        rtf.WriteString(Pr_ECS.ToString("#0.00") & " bar (" & (Pr_ECS * 10).ToString("#0.0") & " mCE)") : rtf.NewLine()
        '    'End Select
        '    rtf.NewLine() : rtf.Bold = True : rtf.Underline = True : rtf.WriteString("Schéma type du réseau") : rtf.NewLine() : rtf.Bold = False : rtf.Underline = False
        '    Try
        '        ' Create Image Element
        '        Dim myImage As Image
        '        myImage = Image.FromFile(Directory.GetCurrentDirectory.ToString() & "\Images\schema_EF_EC.png")
        '        rtf.InsertImage(myImage)
        '    Catch ex As Exception
        '        msg = "Le logiciel n'a pas pu chargé l'image correspondante." &  Environment.NewLine & "Erreur: " & ex.Message & ex.StackTrace &  Environment.NewLine & "Note de calcul sans image"
        '        MsgBox(msg, MsgBoxStyle.Exclamation Or MsgBoxStyle.OkOnly, "Logiciel EF_ECS")
        '    End Try
        '    rtf.NewLine() : rtf.FontSize = 12 : rtf.Bold = True : rtf.Underline = True
        '    rtf.WriteString("2 - Calcul des exutoires") : rtf.Bold = False : rtf.Underline = False
        '    rtf.FontSize = 10 : rtf.NewLine() : rtf.NewLine()
        '    Call Debit_Exutoire(Total_Noeud, Total_Exutoire, N_App, Matiere_TubeInd, Ycoef, Tr_i, Q_Exut, Q_Exut_Pond, Diam_Exut, J_Diam_Exut, N_appareil, Verif, rtf)
        '    Call Recherche_Noeud_Extremite(Total_Noeud, N_Collec, N_Ext, total_Noeud_Ext)
        '    rtf.WriteStartGroup() : rtf.NewLine() : rtf.Bold = True : rtf.FontSize = 12 : rtf.Underline = True
        '    rtf.WriteString("3 - Calcul des débits et dimensionnement tuyauteries") : rtf.Underline = False : rtf.Bold = False : rtf.FontSize = 10
        '    rtf.NewLine() : rtf.NewLine() : rtf.WriteEndGroup()
        '    Call Calcul_debit(Total_Noeud, total_Noeud_Ext, Diam_Exut, Q_Exut, N_appareil, N_Ext, Tr_c, V_limit, Tr_i, Matiere_Tube, DiamImpos, Ycoef, Q_Exut_Pond, Total_Tronçon, total_deb, diam_tr, Aval_tr, Amont_tr, Nom_Tr, noe_br, Verif, rtf)
        '    rtf.WriteStartGroup() : rtf.NewLine() : rtf.Bold = True : rtf.FontSize = 12 : rtf.Underline = True
        '    rtf.WriteString("4 - Calcul des pertes de charges et pressions statiques disponibles") : rtf.Underline = False : rtf.Bold = False : rtf.FontSize = 10
        '    rtf.NewLine()
        '    rtf.WriteString("Pression disponible au raccordement réseau public :  " & PrEntree.ToString("#0.0") & " mCE") : rtf.NewLine()
        '    Δp_Entree = PdcVanne + PdcCompteur + PdcDisconnecteur + PdcFiltre + PdcReduc
        '    rtf.WriteString("Perte de charge totale pour l’ensemble des éléments communs à toutes les colonnes (compteur, …) :  " & Δp_Entree.ToString("#.000") & " mCE.") : rtf.NewLine()

        '    rtf.NewLine() : rtf.WriteEndGroup()
        '    Call Pertes_de_charge(total_Noeud_Ext, Total_Tronçon, Tr_c, L_dev, Hp, total_deb, diam_tr, Aval_tr, Amont_tr, Nom_Tr, noe_br, N_Ext, PdcVanne, PdcCompteur, PdcDisconnecteur, PdcFiltre, PdcReduc, PrEntree, PrResiduel, Verif, rtf)
        '    'génère le RTF complet
        '    'Select Case Modele_Calcul
        '    '    Case 1
        '    '        note_de_calcul = "Ndc_EF_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
        '    '    Case 2 'ECS
        '    '        note_de_calcul = "Ndc_ECS_" & Mise_en_Forme(CStr(DateTime.Now)) & ".rtf"
        '    'End Select

        '    rtf.Generate() : rtff = sw.ToString
        '    If Ecriture = True Then File.WriteAllText(Aff.msgResult & "\" & note_de_calcul, rtff)
        'End Sub

        '     Private Sub Pertes_de_charge(ByVal total_Noeud_Ext As Integer, ByVal total_tronçon As Integer, ByVal Tr_c(,) As Integer, ByVal L_dev(,) As Double, ByVal Hp(,) As Double,
        '                             ByVal total_deb() As Double,
        '                             ByVal diam_tr() As Double, ByVal Aval_tr() As Integer, ByVal Amont_tr() As Integer, ByVal Nom_Tr() As String, ByVal noe_br() As Integer,
        '                            ByVal N_Ext() As Integer, ByVal PdcVanne As Double, ByVal PdcCompteur As Double,
        '                     ByVal PdcDisconnecteur As Double, ByVal PdcFiltre As Double, ByVal PdcReduc As Double, ByVal PrEntree As Double,
        '                     ByVal PrResiduel As Double, ByRef Verif As Boolean, ByRef rtf As RtfAnsiTextWriter)
        '    Dim i, j, j1, j2, j3, k1, k2, k3 As Integer
        '    Dim J_tr, L, Δp_Entree, Hm(total_tronçon + 1), P_sort(total_tronçon + 1), Δp_loc As Double 'Pe, P_ent(total_tronçon),
        '    Dim V As Double
        '    Δp_Entree = PdcVanne + PdcCompteur + PdcDisconnecteur + PdcFiltre + PdcReduc
        '    rtf.WriteStartGroup()
        '    rtf.NewParagraph()
        '    rtf.FontSize = 8
        '    'Ligne 1
        '    rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString("Tronçon") : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Q prob (l/s)") : rtf.EndCell()
        '    rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString("Ø") : rtf.EndCell()
        '    rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString("V (m/s)") : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("1,15j (mCE/m)") : rtf.EndCell()
        '    rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString("L (m)") : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("J loc.") : rtf.EndCell() ' 
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("Δp totale (mCE)") : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("P ent. (mCE)") : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("h (m)") : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString("P sort. (mCE)") : rtf.EndCell() : rtf.EndRow()
        '    j = 0
        '    For i = 1 To total_Noeud_Ext
        '        rtf.BeginRow() : rtf.DeclareCell(10000) : rtf.BeginCell(True) : rtf.WriteString("Colonne n°" & CStr(i)) : rtf.EndCell() : rtf.EndRow()
        '        j1 = total_tronçon : P_sort(total_tronçon + 1) = PrEntree
        '        Do
        '            rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(j1.ToString) : rtf.EndCell()
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(total_deb(j1).ToString("#0.000")) : rtf.EndCell()
        '            rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString(Nom_Tr(j1)) : rtf.EndCell()
        '            V = total_deb(j1) * 0.001 / (PI * diam_tr(j1) ^ 2 / 4)
        '            rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString(V.ToString("#0.000")) : rtf.EndCell()
        '            J_tr = J_Flamant(total_deb(j1) * 0.001, diam_tr(j1), Modele_Calcul, Verif) 'formule de flamant
        '            If Verif = False Then rtf.WriteEndGroup() : Exit Sub
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((J_tr * 1.15).ToString("##0.000")) : rtf.EndCell()
        '            If j1 <> total_tronçon Then
        '                k1 = Amont_tr(j1)
        '                For k2 = 1 To 5
        '                    If Tr_c(k1, k2) = Aval_tr(j1) Then Exit For
        '                    If k2 = 5 Then MsgBox("Erreur dans l'affichage du tableau de sortie des pressions.", MsgBoxStyle.Critical Or MsgBoxStyle.OkOnly, "Calcul") : Verif = False : rtf.EndRow() : rtf.WriteEndGroup() : Exit Sub
        '                Next
        '                L = L_dev(k1, k2) : Hm(j1) = Hp(k1, k2) : Δp_loc = 0
        '            Else
        '                L = L_dev(1, 1) : Hm(j1) = Hp(1, 1) : Δp_loc = Δp_Entree
        '            End If
        '            rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString((L).ToString("##0.0")) : rtf.EndCell()
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Δp_loc.ToString("##0.00")) : rtf.EndCell()
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(((J_tr * 1.15 * L) + Δp_loc).ToString("##0.00")) : rtf.EndCell()
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(P_sort(j1 + 1).ToString("#0.00")) : rtf.EndCell()
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Hm(j1).ToString("#0.00")) : rtf.EndCell()
        '            P_sort(j1) = P_sort(j1 + 1) - (J_tr * 1.15 * L) - Δp_loc + Hm(j1 + 1) - Hm(j1)
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(P_sort(j1).ToString("#0.00")) : rtf.EndCell() : rtf.EndRow()
        '            If Aval_tr(j1) = noe_br(i) Then Exit Do
        '            j1 = j1 - 1
        '        Loop
        '        j2 = j
        '        Do 'pour l'avoir de l'amont vers l'aval
        '            j = j + 1 : j3 = j
        '            If j = total_tronçon Then Exit Do
        '        Loop Until Amont_tr(j) = noe_br(i)
        '        P_sort(j3 + 1) = P_sort(total_tronçon) : Hm(j3 + 1) = Hm(total_tronçon) : k3 = 1
        '        Do

        '            rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(j3.ToString) : rtf.EndCell()
        '            If total_deb(j3) > total_deb(j3 + 1) And k3 = 2 Then total_deb(j3) = total_deb(j3 + 1) 'pour les pb de raccordement colonne sur Exutoire individuel
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(total_deb(j3).ToString("#0.000")) : rtf.EndCell()
        '            rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString(Nom_Tr(j3)) : rtf.EndCell()
        '            V = total_deb(j3) * 0.001 / (PI * diam_tr(j3) ^ 2 / 4) 'en m/s
        '            rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString(V.ToString("#0.000")) : rtf.EndCell()
        '            J_tr = J_Flamant(total_deb(j3) * 0.001, diam_tr(j3), Modele_Calcul, Verif) 'formule de flamant
        '            If Verif = False Then rtf.EndRow() : rtf.WriteEndGroup() : Exit Sub
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString((J_tr * 1.15).ToString("##0.000")) : rtf.EndCell()
        '            k1 = Amont_tr(j3)
        '            For k2 = 1 To 5
        '                If Tr_c(k1, k2) = Aval_tr(j3) Then Exit For
        '                If k2 = 5 Then MsgBox("Erreur dans l'affichage du tableau de sortie des pressions.", MsgBoxStyle.Critical Or MsgBoxStyle.OkOnly, "Calcul") : Verif = False : rtf.EndRow() : rtf.WriteEndGroup() : Exit Sub
        '            Next
        '            L = L_dev(k1, k2)
        '            rtf.DeclareCell(600) : rtf.BeginCell(True) : rtf.WriteString((L).ToString("##0.0")) : rtf.EndCell()
        '            Δp_loc = 0 'provisoire
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Δp_loc.ToString("##0.00")) : rtf.EndCell()
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(((J_tr * 1.15 * L) + Δp_loc).ToString("##0.00")) : rtf.EndCell()
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(P_sort(j3 + 1).ToString("#0.00")) : rtf.EndCell()
        '            Hm(j3) = Hp(k1, k2)
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(Hm(j3).ToString("#0.000")) : rtf.EndCell()
        '            P_sort(j3) = P_sort(j3 + 1) - (J_tr * 1.15 * L) - Δp_loc + Hm(j3 + 1) - Hm(j3)
        '            rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(P_sort(j3).ToString("#0.00")) : rtf.EndCell() : rtf.EndRow()
        '            j3 = j3 - 1 : k3 = 2
        '        Loop While j3 > j2
        '    Next
        '    rtf.WriteEndGroup()
        '    Erase P_sort
        'End Sub


        'Tableau caractéristiques réseau boucle ECS
        'i = 1 : W1 = 0
        'Do
        '    For j = 1 To N_Collec(i) 'affichage des tronçons colonnes
        '        k = 1
        '        rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(i.ToString & " - " & Tr_c(i, j).ToString) : rtf.EndCell()
        '        Select Case Matiere_Tube(i, j)
        '            Case 1
        '                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("Cuivre") : rtf.EndCell()
        '                Do
        '                    If Diam(i, j) = Di_Cu(k) Then Exit Do
        '                    k = k + 1
        '                Loop While k <= UBound(Di_Cu)
        '                If k > UBound(Di_Cu) Then
        '                    MessageBox.Show("Problème indice diamètre tube", "Note de calcul", MessageBoxButtons.OK, MessageBoxIcon.Warning)
        '                Else
        '                    rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_Cu(k)) : rtf.EndCell()
        '                End If

        '            Case 2
        '                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("Acier galvanisé") : rtf.EndCell()
        '                Do
        '                    If Diam(i, j) = Di_Ag(k) Then Exit Do
        '                    k = k + 1
        '                Loop While k <= UBound(Di_Ag)
        '                If k > UBound(Di_Ag) Then
        '                    MessageBox.Show("Problème indice diamètre tube", "Note de calcul", MessageBoxButtons.OK, MessageBoxIcon.Warning)
        '                Else
        '                    rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_Ag(k)) : rtf.EndCell()
        '                End If
        '            Case 3
        '                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("PER") : rtf.EndCell()
        '                Do
        '                    If Diam(i, j) = Di_PER(k) Then Exit Do
        '                    k = k + 1
        '                Loop While k <= UBound(Di_PER)
        '                If k > UBound(Di_PER) Then
        '                    MessageBox.Show("Problème indice diamètre tube", "Note de calcul", MessageBoxButtons.OK, MessageBoxIcon.Warning)
        '                Else
        '                    rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_PER(k)) : rtf.EndCell()
        '                End If
        '            Case 4
        '                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("Multicouche") : rtf.EndCell()
        '                Do
        '                    If Diam(i, j) = Di_MultiC(k) Then Exit Do
        '                    k = k + 1
        '                Loop While k <= UBound(Di_MultiC)
        '                If k > UBound(Di_MultiC) Then
        '                    MessageBox.Show("Problème indice diamètre tube", "Note de calcul", MessageBoxButtons.OK, MessageBoxIcon.Warning)
        '                Else
        '                    rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_MultiC(k)) : rtf.EndCell()
        '                End If
        '            Case 5
        '                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("PVC-C") : rtf.EndCell()
        '                Do
        '                    If Diam(i, j) = Di_PVC_C(k) Then Exit Do
        '                    k = k + 1
        '                Loop While k <= UBound(Di_PVC_C)
        '                If k > UBound(Di_PVC_C) Then
        '                    MessageBox.Show("Problème indice diamètre tube", "Note de calcul", MessageBoxButtons.OK, MessageBoxIcon.Warning)
        '                Else
        '                    rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_PVC_C(k)) : rtf.EndCell()
        '                End If
        '        End Select
        '        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(L_dev(i, j).ToString("#0.00")) : rtf.EndCell()
        '        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(Pdc(i, j).ToString("#0.000")) : rtf.EndCell()
        '        rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString((ep(i, j) * 1000).ToString("#0.0")) : rtf.EndCell()
        '        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(λ(i, j).ToString("#0.000")) : rtf.EndCell()
        '        rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(dT(i, j).ToString("#0.0")) : rtf.EndCell()
        '        W = L_dev(i, j) * Pth(i, j) : W1 = W1 + W
        '        rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(W.ToString("#0.0")) : rtf.EndCell() : rtf.EndRow()
        '    Next
        '    i = i + 1
        'Loop While i < Total_Noeud
        'i = i + 1 'i = total_noeud + 1
        'Do
        '    For j = 1 To N_Col(i) 'Affichage des tronçons collectifs: circuit aller ou retour (= collecteur)
        '        k = 1
        '        rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(i.ToString & " - " & Tr_col(i, j).ToString) : rtf.EndCell()
        '        Select Case Matiere_Tubecol(i, j)
        '            Case 1
        '                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("Cuivre") : rtf.EndCell()
        '                Do
        '                    If diamCol(i, j) = Di_Cu(k) Then Exit Do
        '                    k = k + 1
        '                Loop While k <= UBound(Di_Cu)
        '                If k > UBound(Di_Cu) Then
        '                    MessageBox.Show("Problème indice diamètre tube", "Note de calcul", MessageBoxButtons.OK, MessageBoxIcon.Warning)
        '                Else
        '                    rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_Cu(k)) : rtf.EndCell()
        '                End If
        '            Case 2
        '                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("Acier galvanisé") : rtf.EndCell()
        '                Do
        '                    If diamCol(i, j) = Di_Ag(k) Then Exit Do
        '                    k = k + 1
        '                Loop While k <= UBound(Di_Ag)
        '                If k > UBound(Di_Ag) Then
        '                    MessageBox.Show("Problème indice diamètre tube", "Note de calcul", MessageBoxButtons.OK, MessageBoxIcon.Warning)
        '                Else
        '                    rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_Ag(k)) : rtf.EndCell()
        '                End If

        '            Case 3
        '                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("PER") : rtf.EndCell()
        '                Do
        '                    If diamCol(i, j) = Di_PER(k) Then Exit Do
        '                    k = k + 1
        '                Loop While k <= UBound(Di_PER)
        '                If k > UBound(Di_PER) Then
        '                    MessageBox.Show("Problème indice diamètre tube", "Note de calcul", MessageBoxButtons.OK, MessageBoxIcon.Warning)
        '                Else
        '                    rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_PER(k)) : rtf.EndCell()
        '                End If

        '            Case 4
        '                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("Multicouche") : rtf.EndCell()
        '                Do
        '                    If diamCol(i, j) = Di_MultiC(k) Then Exit Do
        '                    k = k + 1
        '                Loop While k <= UBound(Di_MultiC)
        '                If k > UBound(Di_MultiC) Then
        '                    MessageBox.Show("Problème indice diamètre tube", "Note de calcul", MessageBoxButtons.OK, MessageBoxIcon.Warning)
        '                Else
        '                    rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_MultiC(k)) : rtf.EndCell()
        '                End If

        '            Case 5
        '                rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("PVC-C") : rtf.EndCell()
        '                Do
        '                    If diamCol(i, j) = Di_PVC_C(k) Then Exit Do
        '                    k = k + 1
        '                Loop While k <= UBound(Di_PVC_C)
        '                If k > UBound(Di_PVC_C) Then
        '                    MessageBox.Show("Problème indice diamètre tube", "Note de calcul", MessageBoxButtons.OK, MessageBoxIcon.Warning)
        '                Else
        '                    rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_PVC_C(k)) : rtf.EndCell()
        '                End If

        '        End Select
        '        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(L_devCol(i, j).ToString("#0.00")) : rtf.EndCell()
        '        rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(PdcCol(i, j).ToString("#0.000")) : rtf.EndCell()
        '        rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString((epcol(i, j) * 1000).ToString("#0.0")) : rtf.EndCell()
        '        rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(λcol(i, j).ToString("#0.000")) : rtf.EndCell()
        '        rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(dTCol(i, j).ToString("#0.0")) : rtf.EndCell()
        '        W = L_devCol(i, j) * Pth(i, j) : W1 = W1 + W
        '        rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(W.ToString("#0.0")) : rtf.EndCell() : rtf.EndRow()
        '    Next

        '    rtf.BeginRow() : rtf.DeclareCell(800) : rtf.BeginCell(True) : rtf.WriteString(i.ToString & " - " & Tr_Bcl(i).ToString) : rtf.EndCell()
        '    k = 1
        '    Select Case Matiere_TubeBcl(i)
        '        Case 1
        '            rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("Cuivre") : rtf.EndCell()
        '            Do
        '                If diamBcl(i) = Di_Cu(k) Then Exit Do
        '                k = k + 1
        '            Loop While k <= UBound(Di_Cu)
        '            rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_Cu(k)) : rtf.EndCell()
        '        Case 2
        '            rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("Acier galvanisé") : rtf.EndCell()
        '            Do
        '                If diamBcl(i) = Di_Ag(k) Then Exit Do
        '                k = k + 1
        '            Loop While k <= UBound(Di_Ag)
        '            rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_Ag(k)) : rtf.EndCell()
        '        Case 3
        '            rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("PER") : rtf.EndCell()
        '            Do
        '                If diamBcl(i) = Di_PER(k) Then Exit Do
        '                k = k + 1
        '            Loop While k <= UBound(Di_PER)
        '            rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_PER(k)) : rtf.EndCell()
        '        Case 4
        '            rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("Multicouche") : rtf.EndCell()
        '            Do
        '                If diamBcl(i) = Di_MultiC(k) Then Exit Do
        '                k = k + 1
        '            Loop While k <= UBound(Di_MultiC)
        '            rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_MultiC(k)) : rtf.EndCell()
        '        Case 5
        '            rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString("PVC-C") : rtf.EndCell()
        '            Do
        '                If diamBcl(i) = Di_PVC_C(k) Then Exit Do
        '                k = k + 1
        '            Loop While k <= UBound(Di_PVC_C)
        '            rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(Nom_PVC_C(k)) : rtf.EndCell()
        '    End Select
        '    rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(L_devBcl(i).ToString("#0.00")) : rtf.EndCell()
        '    rtf.DeclareCell(1200) : rtf.BeginCell(True) : rtf.WriteString(PdcBcl(i).ToString("#0.000")) : rtf.EndCell()
        '    rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString((epBcl(i) * 1000).ToString("#0.0")) : rtf.EndCell()
        '    rtf.DeclareCell(1000) : rtf.BeginCell(True) : rtf.WriteString(λBcl(i).ToString("#0.000")) : rtf.EndCell()
        '    rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(dTBcl(i).ToString("#0.0")) : rtf.EndCell()
        '    W = L_devBcl(i) * Pth(i, 0) : W1 = W1 + W
        '    rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(W.ToString("#0.0")) : rtf.EndCell() : rtf.EndRow()
        '    i = i + 1
        'Loop While i < Total_Noeud + Total_NoeudBcl
        'rtf.BeginRow() : rtf.DeclareCell(7350) : rtf.BeginCell(True) : rtf.WriteString(" ") : rtf.EndCell()
        'rtf.DeclareCell(650) : rtf.BeginCell(True) : rtf.WriteString(W1.ToString("#0.0")) : rtf.EndCell() : rtf.EndRow()

    End Sub
End Module